# Skill Profile Tool Mooc Backend

## Prerequisites

### Java
Please install Java 8.

### Maven
Please install maven 3.x from [the official website](https://maven.apache.org/install.html).

### Elasticsearch
Please download elasticsearch 6.2.x from [the official website](https://www.elastic.co/downloads/elasticsearch).

## Use idea project settings
The `/tools/src/main/resources/SKPTFileTemplates.zip` contains all the files templates for the project.

To use it in IntelliJ, please open the .idea project file, unzip the `SKPTFileTemplates.zip` and replace the `/.idea/filTemplates` folder by the unzipped folder.  
Then, restart IntelliJ, go to File > Settings > Editor > File and Code Templates, select the scheme `Project` and click on `Apply`. 

## Mail configuration
The `application-*.yml` files contains the configuration of the e-mail for the mail service. 

At the moment, the email is left blank. To make the mail service work, add a working e-mail address configuration (to be used as a "sender").

The configuration need to be like the following empty example :
```
spring:
  mail:
    host:
    port:
    username:
    password:
    protocol:
    properties:
      mail.smtp.starttls.enable: true
      mail.smtp.from:
```

If the code above is empty, the app will run correctly but it will not be possible to send some e-mails.

## Elasticsearch configuration

### Installation
Add the following elastic configuration in `{elasticfolder}/config/elasticsearch.yml` : 
```
cluster.name: mooc
```

After that, run the elasticsearch executable found in `{elasticfolder}/bin/`.

The `application-*.yml` files of the skpt-mooc-backend project contains configuration to run elasticsearch as explained above (localhost ports 9200 and 9300). These settings will have to be adjusted if elasticsearch runs elsewhere.
Note that the cluster name mentioned in `application-*.yml`, must always be aligned with the cluster name configured in the `elasticsearch.yml`.

### Indexing
The folder `courses` (folder name configured in `application-*.yml` on `jsonDir`) contains the latest export of courses to be indexed in elastic.

To (re)index all courses, do a `POST` call to `/elastic/indexAllCourses`

## Build
To build the project, simply execute the normal maven commands. E.g., at the root of the project:
```
mvn clean install
```

## Deploy locally
At the root of the project : 
```
mvn clean package spring-boot:run
```

Before run this command, you need to launch an elasticsearch instance (like describing above).

## Deploy on a standalone Tomcat 

### Installation procedure

1. Unarchive the file `mooc.war` in `<tomcat_installation_dir>\webapps\mooc` (the name of the folder `mooc` can be changed).
2. Copy the folder `courses` in `<tomcat_installation_dir>`.
3. Update the file `<tomcat_installation_dir>\webapps\mooc\WEB-INF\classes\application.yaml` with the following properties:
   ```
   userDir: ${user.dir}
   
   jsonDir: <courses_folder>
   
   elasticsearch:
       cluster-name: mooc
       url: <elasticsearch_url>
       javaApiPort: 9300
       jsonApiPort: 9200
       courses:
           default-index: courses
           type: course
           
   # TODO: add mail configuration
   spring:
       mail:       
           host: <mail_host>
           port: <mail_port>
           username: <mail_username>
           password: <mail_password>
           protocol: <mail_protocol>
           properties:
               mail.smtp.starttls.enable: <mail_tls>
               mail.smtp.from: <mail_from>
	```

    Value with <> must be replaced by installation environment value depending on the installation.
    - `${user.dir}` is the user working directory.
    - `<courses_folder>` is the folder containing the courses to index (see point 2).
    - `<elasticsearch_url>` is the address of the ElasticSearch endpoint.
    - `<mail_host>` is the mail hostname.
    - `<mail_port>` is the mail port.
    - `<mail_username>` is the username to access mail account (can be empty if no authentication required).
    - `<mail_password>` is the password to access mail account (can be empty if no authentication required).
    - `<mail_protocol>` is the mail protocol used i.e. smtp.
    - `<mail_tls>` if SMTP mail requires TLS.
    - `<mail_from>` is the mail from address.

    Note that you can also create a new configuration file and set it at Tomcat startup with `-Dspring.config.location=$CATALINA_HOME/bin/application.yaml`

4. Run `<tomcat_installation_dir>\bin\startup.sh` (Linux) or `<tomcat_installation_dir>\bin\startup.bat` (Windows).
5. The application is available at `http://localhost:8080/` with default Tomcat configuration.
6. To index the courses in the ElasticSearch index, execute the following curl command by replacing <hostname> and <port> parameter using the server information: 
    ```bash
    curl -XPOST http://<hostname>:<port>/elastic/indexAllCourses .
    ```
