/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool MOOC Backend
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 01/04/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.google.common.base.Preconditions;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.function.Predicate;

/**
 * Course
 *
 * @author ARHS Spikeseed
 */
@JsonIgnoreProperties(ignoreUnknown = true)
public class Course {

  /**
   * Test if a course contain the uri
   * @param uri   uri to find
   * @return the course found
   */
  public static Predicate<Course> byUri(String uri) {
    Preconditions.checkNotNull(uri, "uri is null");
    return course -> Objects.equals(course.getUri(), uri);
  }

  /**
   * Test if a course contain the id
   *
   * @param id    id to find
   * @return the course found
   */
  public static Predicate<Course> byId(String id) {
    Preconditions.checkNotNull(id, "id is null");
    return course -> Objects.equals(course.getId(), id);
  }

  private String uri;
  private String id;
  private String name;
  private String educationLevel;
  private String provider;
  private String developer;
  private String website;
  private String description;
  private String contactName;
  private String contactPosition;
  private String contactPhone;
  private String contactEmail;
  private String participationRequirements;
  private String participationFees;
  private String trainingMode;
  private List<String> languages;
  private List<String> subtitles;
  private String topic;
  private List<String> isceds;
  private String nace;

  private List<String> digitalSkills = new ArrayList<>();
  private List<String> learningOutcomeUris = new ArrayList<>();


  public String getUri() {
    return uri;
  }

  public void setUri(String uri) {
    this.uri = uri;
  }

  public String getId() {
    return id;
  }

  /**
   * Set the id of the course
   *
   * @param id new id of the course
   */
  public void setId(String id) {
    Preconditions.checkNotNull(id, "id cannot be null");
    this.id = id;
    setUri("http://data.europa.eu/lo/course/" + id);
  }

  public String getName() {
    return name;
  }

  /**
   * Set the name of the course
   *
   * @param name new name of the course
   */
  public void setName(String name) {
    Preconditions.checkNotNull(name, "name cannot be null");
    this.name = name;
  }

  public String getEducationLevel() {
    return educationLevel;
  }

  public void setEducationLevel(String educationLevel) {
    this.educationLevel = educationLevel;
  }

  public String getProvider() {
    return provider;
  }

  public void setProvider(String provider) {
    this.provider = provider;
  }

  public String getDeveloper() {
    return developer;
  }

  public void setDeveloper(String developer) {
    this.developer = developer;
  }

  public String getDescription() {
    return description;
  }

  public void setDescription(String description) {
    this.description = description;
  }

  public String getWebsite() {
    return website;
  }

  public void setWebsite(String website) {
    this.website = website;
  }

  /**
   * return true if the course has contact info
   *
   * @return boolean
   */
  public boolean hasContactInfo() {
    return contactName != null
           || contactPosition != null
           || contactPhone != null
           || contactEmail != null;
  }

  public String getContactName() {
    return contactName;
  }

  public void setContactName(String contactName) {
    this.contactName = contactName;
  }

  public String getContactPosition() {
    return contactPosition;
  }

  public void setContactPosition(String contactPosition) {
    this.contactPosition = contactPosition;
  }

  public String getContactPhone() {
    return contactPhone;
  }

  public void setContactPhone(String contactPhone) {
    this.contactPhone = contactPhone;
  }

  public String getContactEmail() {
    return contactEmail;
  }

  public void setContactEmail(String contactEmail) {
    this.contactEmail = contactEmail;
  }

  public String getParticipationRequirements() {
    return participationRequirements;
  }

  public void setParticipationRequirements(String participationRequirements) {
    this.participationRequirements = participationRequirements;
  }

  public String getParticipationFees() {
    return participationFees;
  }

  public void setParticipationFees(String participationFees) {
    this.participationFees = participationFees;
  }

  public String getTrainingMode() {
    return trainingMode;
  }

  public void setTrainingMode(String trainingMode) {
    this.trainingMode = trainingMode;
  }

  public List<String> getLanguages() {
    return languages;
  }

  public void setLanguages(List<String> languages) {
    this.languages = languages;
  }

  public List<String> getSubtitles() {
    return subtitles;
  }

  public void setSubtitles(List<String> subtitles) {
    this.subtitles = subtitles;
  }

  public String getTopic() {
    return topic;
  }

  public void setTopic(String topic) {
    this.topic = topic;
  }

  public List<String> getIsceds() {
    return isceds;
  }

  public void setIsceds(List<String> isceds) {
    this.isceds = isceds;
  }

  public String getNace() {
    return nace;
  }

  public void setNace(String nace) {
    this.nace = nace;
  }

  public List<String> getDigitalSkills() {
    return digitalSkills;
  }

  public void setDigitalSkills(List<String> digitalSkills) {
    this.digitalSkills = digitalSkills;
  }

  public List<String> getLearningOutcomeUris() {
    return learningOutcomeUris == null ? new ArrayList<>() : learningOutcomeUris;
  }

  public void setLearningOutcomeUris(List<String> learningOutcomeUris) {
    this.learningOutcomeUris = learningOutcomeUris == null ? new ArrayList<>() : learningOutcomeUris;
  }
}
