/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool MOOC Backend
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 01/04/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.elastic.controller;

import eu.europa.empl.skpt.elastic.service.ElasticProxyService;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpEntity;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.RequestMapping;

import javax.annotation.PostConstruct;

import static org.springframework.web.bind.annotation.RequestMethod.POST;

/**
 * Elastic Proxy Controller
 *
 * @author ARHS Spikeseed
 */
@Controller
@CrossOrigin
public class ElasticProxyController {

    @Value("${elasticsearch.url}")
    private String name;

    @Value("${elasticsearch.jsonApiPort}")
    private int port;

    private String url;

    private final ElasticProxyService elasticProxyService;

    /**
     * Constructor
     *
     * @param elasticProxyService elastic proxy service
     */
    public ElasticProxyController(ElasticProxyService elasticProxyService) {
        this.elasticProxyService = elasticProxyService;
    }

    @PostConstruct
    private void init() {
        url = "http://" + name + ":" + port;
    }

    /**
     * Returns a list of courses for the "Courses" section
     *
     * @param httpEntity    serialized form information
     * @return a list of courses
     */
    @RequestMapping(
            value = {"/api/elastic/courses/_search"},
            method = POST,
            produces = "application/json"
    )
    public ResponseEntity search(HttpEntity<?> httpEntity) {
        return elasticProxyService.sendToElastic(httpEntity, this.url);
    }
}