/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool MOOC Backend
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 01/04/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.elastic.service;

import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import eu.europa.empl.skpt.elastic.repository.ElasticRepository;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.thymeleaf.util.StringUtils;

import java.io.File;
import java.io.IOException;

/**
 * Elastic Index Service
 *
 * @author ARHS Spikeseed
 */
@Service
public class ElasticIndexService {

    private static final Logger LOGGER = LoggerFactory.getLogger(ElasticIndexService.class);

    @Value("${jsonDir}")
    private String folderLocation;

    @Value("${elasticsearch.courses.default-index}")
    private String index;

    @Value("${elasticsearch.courses.type}")
    private String type;

    private final ElasticRepository elasticRepository;

    /**
     * Constructor
     *
     * @param elasticRepository   elastic repository
     */
    public ElasticIndexService(ElasticRepository elasticRepository) {
        this.elasticRepository = elasticRepository;
    }

    /**
     * Takes the exported courses folder
     */
    public void indexAllCourses() {
        File folder = new File(folderLocation);
        File[] files = folder.listFiles();
        for (File file : files) {
            try {
                JsonNode jsonNode = new ObjectMapper().readTree(file);
                String afterDash = StringUtils.substringAfter(file.getName(), "-");
                String trimmedId = StringUtils.substringBefore(afterDash, ".");
                elasticRepository.insertJson(index, type, trimmedId, jsonNode);
            } catch (IOException e) {
                LOGGER.error("Error when indexing all courses", e);
            }
            LOGGER.info("Indexing file: {}", file.getName());
        }

    }

}
