/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool MOOC Backend
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 01/04/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.elastic.service;

import org.springframework.http.HttpEntity;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.web.client.RestTemplate;
import org.springframework.web.util.UriComponentsBuilder;
import org.springframework.http.HttpMethod;
import org.springframework.http.client.ClientHttpRequestFactory;
import org.springframework.http.client.HttpComponentsClientHttpRequestFactory;


/**
 * Elastic Proxy Service
 *
 * @author ARHS Spikeseed
 */
@Service
public class ElasticProxyService {

    private final RestTemplate restTemplate;

    /**
     * Constructor
     */
    public ElasticProxyService() {
        restTemplate = new RestTemplate(clientHttpRequestFactory(5000, 1000));
    }

    /**
     * Send a request to the elastic server
     *
     * @param httpEntity    serialized form information
     * @param url           destination url
     * @return a list of courses
     */
    public ResponseEntity sendToElastic(HttpEntity<?> httpEntity, String url) {
        UriComponentsBuilder builder = UriComponentsBuilder.fromHttpUrl(url + "/courses/_search");
        return restTemplate.exchange(builder.toUriString(), HttpMethod.POST, httpEntity, String.class);
    }

    private ClientHttpRequestFactory clientHttpRequestFactory(int readTimeout, int connectTimeout) {
        HttpComponentsClientHttpRequestFactory factory = new HttpComponentsClientHttpRequestFactory();

        factory.setReadTimeout(readTimeout);
        factory.setConnectTimeout(connectTimeout);

        return factory;
    }

}
