/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool MOOC Backend
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 01/04/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.languages;

import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.core.io.ClassPathResource;
import org.springframework.stereotype.Service;

import javax.annotation.PostConstruct;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;
import java.util.Optional;

/**
 * Iso 6391 Code To Concept Service
 *
 * @author ARHS Spikeseed
 */
@Service
class Iso6391CodeToConceptService {

    private static final Logger LOGGER = LoggerFactory.getLogger(Iso6391CodeToConceptService.class);

    private final Map<String, String> iso6391Map = new HashMap<>();

    @PostConstruct
    private void readIso6391() {
        try {
            JsonNode iso6931 = new ObjectMapper().readValue(new ClassPathResource("json/iso_639_1.json").getInputStream(), JsonNode.class);
            iso6931.get("results").get("bindings")
                    .forEach(result -> iso6391Map.put(result.get("o").get("value").asText(),
                            result.get("s").get("value").asText()));
        } catch (IOException e) {
            LOGGER.error("Reading from json file 'json/iso_639_1.json' failed.", e);
        }
    }

    /**
     * Method to get the uri corresponding to the iso6391Code
     *
     * @param iso6391Code   iso 6391 code
     * @return an Optional String
     */
    public Optional<String> getConceptUri(String iso6391Code) {
        return Optional.ofNullable(iso6391Map.get(iso6391Code));
    }

}
