/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool MOOC Backend
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 01/04/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.mail;

import eu.europa.empl.skpt.Course;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.mail.MailException;
import org.springframework.mail.javamail.JavaMailSender;
import org.springframework.mail.javamail.MimeMessageHelper;
import org.springframework.mail.javamail.MimeMessagePreparator;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * Mail Sender Service
 *
 * @author ARHS Spikeseed
 */
@Service
public class MailSenderService {

    private static final Logger LOGGER = LoggerFactory.getLogger(MailSenderService.class);

    private final JavaMailSender mailSender;
    private final MailTemplateBuilder mailTemplateBuilder;

    /**
     * Constructor
     *
     * @param mailSender          mailSender
     * @param mailTemplateBuilder mailTemplateBuilder
     */
    MailSenderService(JavaMailSender mailSender, MailTemplateBuilder mailTemplateBuilder) {
        this.mailSender = mailSender;
        this.mailTemplateBuilder = mailTemplateBuilder;
    }

    /**
     * This method will generate and send an email containing information regarding the selected courses.
     * The content of the email is generated using the ThymeLeaf template "course-list-mail.html".
     * Once generated, it is then sent using JavaMailSender.
     *
     * @param to      encoded email(s) address(es)
     * @param courses selected course(s)
     */
    public void sendCourses(List<String> to, List<Course> courses) {

        MimeMessagePreparator messagePreparator = mimeMessage -> {
            MimeMessageHelper messageHelper = new MimeMessageHelper(mimeMessage);
            messageHelper.setTo(to.toArray(new String[to.size()]));
            messageHelper.setSubject("MOOC Course List");

            String text = mailTemplateBuilder.build(courses);

            messageHelper.setText(text, true);
        };
        try {
            mailSender.send(messagePreparator);
        } catch (MailException e) {
            LOGGER.error("Error when sending courses", e);
            throw new IllegalStateException(e);
        }

    }

}
