/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool MOOC Backend
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 01/04/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.elastic.controller;

import org.json.JSONException;
import org.json.JSONObject;
import org.junit.Before;
import org.junit.Test;

import java.util.ArrayList;
import java.util.List;

import static eu.europa.empl.skpt.matcher.CustomMatchers.matchesRegex;
import static io.restassured.RestAssured.given;
import static org.hamcrest.Matchers.*;

/**
 * Elastic Proxy Controller Test
 *
 * @author ARHS Spikeseed
 */
public class ElasticProxyControllerTest {

    private String url;

    @Before
    public void setup() {
        this.url = "http://skpt-dev.divpqaubuk.eu-west-1.elasticbeanstalk.com/api/elastic/courses/_search";
    }

    @Test
    public void checkJsonCourseFormat() throws JSONException {
        String size = "10000";
        JSONObject query = this.generateElasticQuery(new ArrayList<>(), size);

        given()
                .header("Content-Type", "application/json")
                .body(query.toString()).
        when()
                .post(this.url).
        then()
                .statusCode(200)
                .contentType("application/json")
                .body("hits.hits.size()", not(equalTo(0)))
                .body("hits.hits", everyItem(allOf(
                        hasEntry(is("_index"), matchesRegex("courses")),
                        hasEntry(is("_type"), matchesRegex("course")),
                        hasEntry(is("_id"), matchesRegex("[0-9]+")),
                        hasEntry(is("_score"), matchesRegex("1"))
                )))
                .body("hits.hits", everyItem(
                        hasEntry(is("_source"), allOf(
                                hasEntry(is("uri"), matchesRegex("http://data.europa.eu/lo/course/[0-9]+")),
                                hasEntry(is("id"), matchesRegex("[0-9]+")),
                                hasEntry(is("name"), matchesRegex("[a-zA-Z0-9]+")),
                                hasEntry(is("educationLevel"), matchesRegex("http://data.europa.eu/esco/ConceptScheme/at-ed-level/isced-[0-9]+")),
                                hasEntry(is("provider"), matchesRegex("https?://[a-zA-Z0-9]+")),
                                hasEntry(is("developer"), matchesRegex(".*")),
                                hasEntry(is("website"), matchesRegex("https?://[a-zA-Z0-9]+")),
                                hasEntry(is("description"), matchesRegex(".+")),
                                hasEntry(is("contactName"), matchesRegex(".*")),
                                hasEntry(is("contactPosition"), matchesRegex(".*")),
                                hasEntry(is("contactPhone"), matchesRegex("(Not found||[Phone:]? \\+[0-9 ]+)")),
                                hasEntry(is("contactEmail"), matchesRegex("(.+@.+||https?://[a-zA-Z0-9]+)")),
                                hasEntry(is("participationRequirements"), matchesRegex("(None|NOT FOUND|.+)")),
                                hasEntry(is("participationFees"), matchesRegex("(http://data.europa.eu/esco/ConceptScheme/at-fees/(free|free-paid-certif)|.+)")),
                                hasEntry(is("trainingMode"), matchesRegex("(MOOC|Online digital resources)"))
                        ))
                ))
                .body("hits.hits", everyItem(
                        hasEntry(is("_source"), allOf(
                                hasEntry(is("languages"), everyItem(is(matchesRegex("http://publications.europa.eu/resource/authority/language/[A-Z]{3}"))))
                        ))
                ))
                .body("hits.hits", everyItem(
                        hasEntry(is("_source"), allOf(
                                hasEntry(is("subtitles"), anyOf(
                                        matchesRegex("null"),
                                        everyItem(is(matchesRegex("http://publications.europa.eu/resource/authority/language/[A-Z]{3}")))
                                ))
                        ))
                ))
                .body("hits.hits", everyItem(
                        hasEntry(is("_source"), allOf(
                                hasEntry(is("topic"), matchesRegex("http://data.europa.eu/esco/ConceptScheme/at-topics/.+"))
                        ))
                ))
                .body("hits.hits", everyItem(
                        hasEntry(is("_source"), allOf(
                                hasEntry(is("isceds"), anyOf(
                                        matchesRegex("null"),
                                        everyItem(is(matchesRegex("http://data.europa.eu/esco/isced-f/[0-9]+")))
                                ))
                        ))
                ))
                .body("hits.hits", everyItem(
                        hasEntry(is("_source"), allOf(
                                hasEntry(is("nace"), matchesRegex("http://data.europa.eu/esco/ConceptScheme/NACErev2/.+"))
                        ))
                ))
                .body("hits.hits", everyItem(
                        hasEntry(is("_source"), allOf(
                                hasEntry(is("languageSkills"), everyItem(allOf(
                                        hasEntry(is("language"), matchesRegex("http://publications.europa.eu/resource/authority/language/[A-Z]{3}")),
                                        hasEntry(is("writing"), matchesRegex("(null|[0-9]+)")),
                                        hasEntry(is("reading"), matchesRegex("(null|[0-9]+)")),
                                        hasEntry(is("speaking"), matchesRegex("(null|[0-9]+)")),
                                        hasEntry(is("listening"), matchesRegex("(null|[0-9]+)"))
                                )))
                        ))
                ))
                .body("hits.hits", everyItem(
                        hasEntry(is("_source"), allOf(
                                hasEntry(is("digitalSkills"), everyItem(is(matchesRegex("http://data.europa.eu/esco/ConceptScheme/digital-skills/.+"))))
                        ))
                ))
                .body("hits.hits", everyItem(
                        hasEntry(is("_source"), allOf(
                                hasEntry(is("learningOutcomes"), everyItem(allOf(
                                   hasEntry(is("uri"), matchesRegex("http://data.europa.eu/lo/learningOutcome/[0-9]+")),
                                   hasEntry(is("id"), matchesRegex("[0-9]+")),
                                   hasEntry(is("label"), matchesRegex(".+"))
                                )))
                        ))
                ))
                .body("hits.hits", everyItem(
                        hasEntry(is("_source"), allOf(
                                hasEntry(is("learningOutcomes"), everyItem(allOf(
                                        hasEntry(is("skillRelations"), everyItem(allOf(
                                                hasEntry(is("relation"), matchesRegex("http://www.w3.org/2004/02/skos/core#(closeMatch|narrowMatch|broadMatch)")),
                                                hasEntry(is("skillUri"), matchesRegex("http://data.europa.eu/esco/skill/.+"))
                                        )))
                                )))
                        ))
                ));
    }

    @Test
    public void searchFirst10() {
        given()
                .header("Content-Type", "application/json").
        when()
                .post(this.url).
        then()
                .statusCode(200)
                .contentType("application/json")
                .body("hits.hits.size()", equalTo(10));
    }

    @Test
    public void searchByLanguage() throws JSONException {
        String language = "http://publications.europa.eu/resource/authority/language/ENG";
        String size = "10000";

        List<String> terms = new ArrayList<>();
        terms.add("{'term':{'languages.keyword':'" + language + "'}}");

        JSONObject jsonQuery = this.generateElasticQuery(terms, size);

        this.testAPI("hits.hits._source.languages", jsonQuery, new String[] {language});
    }

    @Test
    public void searchBySubtitles() throws JSONException {
        String subtitle = "http://publications.europa.eu/resource/authority/language/ENG";
        String size = "10000";

        List<String> terms = new ArrayList<>();
        terms.add("{'term':{'subtitles.keyword':'" + subtitle + "'}}");

        JSONObject jsonQuery = this.generateElasticQuery(terms, size);

        this.testAPI("hits.hits._source.subtitles", jsonQuery, new String[] {subtitle});
    }

    @Test
    public void searchByFieldsOfStudy() throws JSONException {
        String[] fieldsOfStudy = {
                "http://data.europa.eu/esco/isced-f/01",
                "http://data.europa.eu/esco/isced-f/011",
                "http://data.europa.eu/esco/isced-f/0110",
                "http://data.europa.eu/esco/isced-f/0111",
                "http://data.europa.eu/esco/isced-f/0112",
                "http://data.europa.eu/esco/isced-f/0113",
                "http://data.europa.eu/esco/isced-f/0114",
                "http://data.europa.eu/esco/isced-f/0119",
                "http://data.europa.eu/esco/isced-f/018",
                "http://data.europa.eu/esco/isced-f/0188"
        };
        String size = "10000";

        List<String> terms = new ArrayList<>();
        terms.add("{'terms':{'isceds.keyword':['" + String.join("','", fieldsOfStudy) + "']}}");

        JSONObject jsonQuery = this.generateElasticQuery(terms, size);

        this.testAPI("hits.hits._source.isceds", jsonQuery, fieldsOfStudy);
    }

    @Test
    public void searchByEducationLevel() throws JSONException {
        String educationLevel = "http://data.europa.eu/esco/ConceptScheme/at-ed-level/isced-1";
        String size = "10000";

        List<String> terms = new ArrayList<>();
        terms.add("{'term':{'educationLevel.keyword':'" + educationLevel + "'}}");

        JSONObject jsonQuery = this.generateElasticQuery(terms, size);

        this.testAPI("hits.hits._source.educationLevel", jsonQuery, educationLevel);
    }

    @Test
    public void searchByCourseTopics() throws JSONException {
        String courseTopic = "http://data.europa.eu/esco/ConceptScheme/at-topics/lang-training";
        String size = "10000";

        List<String> terms = new ArrayList<>();
        terms.add("{'term':{'topic.keyword':'" + courseTopic + "'}}");

        JSONObject jsonQuery = this.generateElasticQuery(terms, size);

        this.testAPI("hits.hits._source.topic", jsonQuery, courseTopic);
    }

    @Test
    public void searchByProvider() throws JSONException {
        String provider = "https://www.rwaq.org";
        String size = "10000";

        List<String> terms = new ArrayList<>();
        terms.add("{'term':{'provider.keyword':'" + provider + "'}}");

        JSONObject jsonQuery = this.generateElasticQuery(terms, size);

        this.testAPI("hits.hits._source.provider", jsonQuery, provider);
    }

    @Test
    public void searchWithAllFilters() throws JSONException {
        String[] languages = {
                "http://publications.europa.eu/resource/authority/language/ENG",
                "http://publications.europa.eu/resource/authority/language/FRA"
        };
        String[] subtitles = {
                "http://publications.europa.eu/resource/authority/language/ENG"
        };
        String[] fieldsOfStudy = {
                "http://data.europa.eu/esco/isced-f/10",
                "http://data.europa.eu/esco/isced-f/100",
                "http://data.europa.eu/esco/isced-f/1000",
                "http://data.europa.eu/esco/isced-f/101",
                "http://data.europa.eu/esco/isced-f/1010",
                "http://data.europa.eu/esco/isced-f/1011",
                "http://data.europa.eu/esco/isced-f/1012",
                "http://data.europa.eu/esco/isced-f/1013",
                "http://data.europa.eu/esco/isced-f/1014",
                "http://data.europa.eu/esco/isced-f/1015",
                "http://data.europa.eu/esco/isced-f/1019",
                "http://data.europa.eu/esco/isced-f/108",
                "http://data.europa.eu/esco/isced-f/1088",
                "http://data.europa.eu/esco/isced-f/109",
                "http://data.europa.eu/esco/isced-f/1099"
        };
        String educationLevel = "http://data.europa.eu/esco/ConceptScheme/at-ed-level/isced-6";
        String courseTopic = "http://data.europa.eu/esco/ConceptScheme/at-topics/vet";
        String provider = "https://www.fun-mooc.fr";
        String size = "10000";

        List<String> terms = new ArrayList<>();
        for (String language : languages) {
            terms.add("{'term':{'languages.keyword':'" + language + "'}},");
        }
        for (String subtitle : subtitles) {
            terms.add("{'term':{'subtitles.keyword':'" + subtitle + "'}},");
        }
        terms.add("{'terms':{'isceds.keyword':['" + String.join("','", fieldsOfStudy) + "']}},");
        terms.add("{'term':{'educationLevel.keyword':'" + educationLevel + "'}},");
        terms.add("{'term':{'topic.keyword':'" + courseTopic + "'}},");
        terms.add("{'term':{'provider.keyword':'" + provider + "'}}");

        JSONObject query = this.generateElasticQuery(terms, size);

        given()
                .header("Content-Type", "application/json")
                .body(query.toString()).
        when()
                .post(this.url).
        then()
                .statusCode(200)
                .contentType("application/json")
                .body("hits.hits._source.languages", everyItem(hasItem(isIn(languages))))
                .body("hits.hits._source.subtitles", everyItem(hasItem(isIn(subtitles))))
                .body("hits.hits._source.isceds", everyItem(hasItem(isIn(fieldsOfStudy))))
                .body("hits.hits._source.educationLevel", everyItem(is(educationLevel)))
                .body("hits.hits._source.topic", everyItem(is(courseTopic)))
                .body("hits.hits._source.provider", everyItem(is(provider)));
    }

    /**
     * Test used to compare an array (elements received) with another array (elements expected)
     * One or more element in the expected array need to be in each element received
     *
     * @param pathJson          path of the elements in the body of the response
     * @param query             request's query
     * @param elementsToFind    string array expected
     */
    private void testAPI(String pathJson, JSONObject query, String[] elementsToFind) {
        given()
                .header("Content-Type", "application/json")
                .body(query.toString()).
        when()
                .post(this.url).
        then()
                .statusCode(200)
                .contentType("application/json")
                .body(pathJson, everyItem(hasItem(isIn(elementsToFind))));
    }

    /**
     * Test used to compare an array (elements received) with a string (element expected)
     *
     * @param pathJson          path of the elements in the body of the response
     * @param query             request's query
     * @param elementToFind     string expected
     */
    private void testAPI(String pathJson, JSONObject query, String elementToFind) {
        given()
                .header("Content-Type", "application/json")
                .body(query.toString()).
        when()
                .post(this.url).
        then()
                .statusCode(200)
                .contentType("application/json")
                .body(pathJson, everyItem(is(elementToFind)));
    }

    /**
     * Create an elastic query from a list of terms
     *
     * @param terms filters
     * @param size size of the result
     * @return a jsonObject
     */
    private JSONObject generateElasticQuery(List<String> terms, String size) throws JSONException {
        String query =
                "{" +
                "   'query':{" +
                "       'bool':{" +
                "           'filter':[" +
                String.join(",", terms) +
                "           ]," +
                "           'must':[]," +
                "           'should':[]" +
                "       }" +
                "   }," +
                "   'aggs':{" +
                "       'globalAggs':{" +
                "           'global':{}," +
                "           'aggs':{}" +
                "       }," +
                "       'topic':{" +
                "           'terms':{" +
                "               'field':'topic.keyword'," +
                "               'size':" + size +
                "           }" +
                "       }," +
                "       'languages':{" +
                "           'terms':{" +
                "               'field':'languages.keyword'," +
                "               'size':" + size +
                "           }" +
                "       }," +
                "       'subtitles':{" +
                "           'terms':{" +
                "               'field':'subtitles.keyword'," +
                "               'size':" + size +
                "           }" +
                "       }," +
                "       'educationLevel':{" +
                "           'terms':{" +
                "               'field':'educationLevel.keyword'," +
                "               'size':" + size +
                "           }" +
                "       }," +
                "       'provider':{" +
                "           'terms':{" +
                "               'field':'provider.keyword'," +
                "               'size':" + size +
                "           }" +
                "       }" +
                "   }," +
                "   'from':0," +
                "   'size':" + size +
                "}";

        return new JSONObject(query);
    }

}