package eu.europa.empl.skpt.elastic.service;

import org.elasticsearch.index.query.BoolQueryBuilder;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.Mock;
import org.mockito.runners.MockitoJUnitRunner;

import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.function.Supplier;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

@RunWith(MockitoJUnitRunner.class)
public class ElasticQueryServiceTest {
    @Mock
    private ElasticQueryService elasticQueryService;
    @Mock
    private ElasticLanguageCoursesQueryService languageCoursesQueryService;
    @Mock
    private ElasticIntegrationCoursesQueryService integrationCoursesQueryService;
    @Mock
    private ElasticStudyCoursesQueryService studyCoursesQueryService;
    @Mock
    private ElasticQueryResultService queryResultService;

    @Before
    public void init() {
        this.elasticQueryService = new ElasticQueryService(languageCoursesQueryService, integrationCoursesQueryService, studyCoursesQueryService, queryResultService);
    }

    @Test
    public void getLanguageCourses() {
        Set<String> language = Collections.emptySet();
        Set<String> motherTongue = Collections.emptySet();

        Supplier<BoolQueryBuilder> boolQueryBuilderSupplier = mock(Supplier.class);
        List<Supplier<BoolQueryBuilder>> suppliers = Collections.singletonList(boolQueryBuilderSupplier);
        when(languageCoursesQueryService.getLanguageCoursesQuery(language, motherTongue)).thenReturn(suppliers);

        Map<String, Object> result = Collections.singletonMap("key", "result");
        List<Map<String, Object>> results = Collections.singletonList(result);
        when(queryResultService.getResults(suppliers)).thenReturn(results);

        List<Map<String, Object>> languageCourses = elasticQueryService.getLanguageCourses(language, motherTongue);
        assertNotNull(languageCourses);
        assertEquals(1, languageCourses.size());
        assertEquals(result, languageCourses.get(0));
    }

    @Test
    public void getIntegrationCourses() {
        Set<String> countryLanguage = Collections.emptySet();
        Set<String> understoodLanguages = Collections.emptySet();

        Supplier<BoolQueryBuilder> boolQueryBuilderSupplier = mock(Supplier.class);
        List<Supplier<BoolQueryBuilder>> suppliers = Collections.singletonList(boolQueryBuilderSupplier);
        when(integrationCoursesQueryService.getIntegrationCoursesQuery(countryLanguage, understoodLanguages)).thenReturn(suppliers);

        Map<String, Object> result = Collections.singletonMap("key", "result");
        List<Map<String, Object>> results = Collections.singletonList(result);
        when(queryResultService.getResults(suppliers)).thenReturn(results);

        List<Map<String, Object>> languageCourses = elasticQueryService.getIntegrationCourses(countryLanguage, understoodLanguages);
        assertNotNull(languageCourses);
        assertEquals(1, languageCourses.size());
        assertEquals(result, languageCourses.get(0));
    }

    @Test
    public void getStudyCourses() {
        Set<String> educationLevel = Collections.emptySet();
        Set<String> studyField = Collections.emptySet();
        Set<String> understoodLanguages = Collections.emptySet();

        Supplier<BoolQueryBuilder> boolQueryBuilderSupplier = mock(Supplier.class);
        List<Supplier<BoolQueryBuilder>> suppliers = Collections.singletonList(boolQueryBuilderSupplier);
        when(studyCoursesQueryService.getStudyCoursesQuery(educationLevel, studyField, understoodLanguages)).thenReturn(suppliers);

        Map<String, Object> result = Collections.singletonMap("key", "result");
        List<Map<String, Object>> results = Collections.singletonList(result);
        when(queryResultService.getResults(suppliers)).thenReturn(results);

        List<Map<String, Object>> languageCourses = elasticQueryService.getStudyCourses(educationLevel, studyField, understoodLanguages);
        assertNotNull(languageCourses);
        assertEquals(1, languageCourses.size());
        assertEquals(result, languageCourses.get(0));
    }
}