/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool MOOC Backend
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 01/04/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.mail;

import org.junit.Before;
import org.junit.Test;

import java.util.Arrays;
import java.util.List;

import static io.restassured.RestAssured.given;
import static org.hamcrest.Matchers.equalTo;

/**
 * Mail Sender Controller Test
 *
 * @author ARHS Spikeseed
 */
public class MailSenderControllerTest {

    private String url;

    @Before
    public void setup() {
        this.url = "http://skpt-dev.divpqaubuk.eu-west-1.elasticbeanstalk.com/courses/mail/send";
    }

    @Test
    public void sendValidMail() {
        List<String> addresses = Arrays.asList("test1@test.com", "test2@test.com");
        List<String> coursesId = Arrays.asList("105", "110");

        given()
                .param("address", addresses)
                .param("courseId", coursesId).
        when()
                .post(this.url).
        then()
                .statusCode(200);
    }

    @Test
    public void sendInvalidMailEmptyEmails() {
        List<String> addresses = Arrays.asList();
        List<String> coursesId = Arrays.asList("105", "110");

        given()
                .param("address", addresses)
                .param("courseId", coursesId).
        when()
                .post(this.url).
        then()
                .statusCode(400)
                .contentType("application/json")
                .body("message", equalTo("No addresses provided for email"));
    }

    @Test
    public void sendInvalidMailEmptyCourses() {
        List<String> addresses = Arrays.asList("test1@test.com", "test2@test.com");
        List<String> coursesId = Arrays.asList();

        given()
                .param("address", addresses)
                .param("courseId", coursesId).
        when()
                .post(this.url).
        then()
                .statusCode(400)
                .contentType("application/json")
                .body("message", equalTo("No courses provided for email"));
    }

}
