# Skills Profile Tool

## Prerequisites

### Java

Please install Java 8.x

### Maven

Please install maven 3.x from [the official website](https://maven.apache.org/install.html).

### Node.js / npm

Please install Node.js 6.x from [the official website](https://nodejs.org/en/download/).

### yarn

Please install yarn from [the official website](https://yarnpkg.com/en/docs/install#windows-tab).

### angular-cli

Please install angular/cli like this: 
```sh
yarn install -g @angular/cli
```

### Python

The following installation is for a Windows system.

If you haven't got python installed along with all the node-gyp dependecies, simply execute:

```sh
npm install --global --production windows-build-tools
```

and then to install the package:

```sh
npm install --global node-gyp
```

Once installed, you will have all the node-gyp dependencies downloaded.
You still need the environment variable. 
Python is found in the folder:

```
C:\Users\YOUR_USER\.windows-build-tools\python27\python.exe
``` 
Note - it uses python 2.7 not 3.x as it is not supported

Create your (user) environment variable:

```sh
setx PYTHON "%USERPROFILE%\.windows-build-tools\python27\python.exe"
```

[Stackoverflow post can be found here](https://stackoverflow.com/questions/15126050/running-python-on-windows-for-node-js-dependencies/39648550#39648550)


In case your using a Linux based distro, please follow the official installation instructions linked to the distro to install Pyton.

## Build

To build the project, simply execute the normal maven commands. E.g., at the root of the project:

```sh
mvn clean install
```

This will build the project inside each of target folder of the project's modules.

## Deploy backend and frontend separately

### Backend

Navigate to the backend module and execute the following:

```sh
mvn clean package spring-boot:run
```

### Frontend

Navigate to the frontend module and execute the following to download dependencies:

```sh
yarn install
```

Navigate to the frontend module and execute the following to launch the app:

```sh
yarn run start
```

## Deploy as a packaged WAR application

### Prerequisite

- A Tomcat instance (min. version 8.x) must be installed on the machine. 
- In this README, the installation directory of the Tomcat is represented by `<tomcat_installation_dir>`
- A MySQL 5.7.x database is installed with the following properties configured:
    - `character_set_server=utf8`
    - `collation_server=utf8_general_ci`
    - `init-connect='SET collation_connection = utf8mb4_unicode_ci'`
- An Elasticsearch 6.2.2 running instance (only needed to used the statistics features, optional otherwise).

### Installation procedure

1. Unarchive the file `skpt-<skpt_version>.war` in `<tomcat_installation_dir>\webapps\skpt` (the name of the folder `skpt` can be changed) or take the built war `skpt.war` under `sources\war\target`.
2. Update the file `<tomcat_installation_dir>\webapps\skpt\WEB-INF\classes\application-<prod|staging>.properties` with the properties define in [Project properties](#Project properties).	
3. Run `<tomcat_installation_dir>\bin\startup.sh` (Linux) or `<tomcat_installation_dir>\bin\startup.bat` (Windows).
4. The application is available at `http://localhost:8080/` with default Tomcat configuration.

## Project properties

| Command | Description |
| --- | --- |
| `info.app.version` | Project version. |
| `info.app.date` | Release date. |
| `server.port` | Server HTTP port. |
| `management.endpoint.enabled-by-defaul` | Whether to enable or disable all endpoints by default. |
| `management.endpoint.info.enabled` | Used for enable or not the endpoints relatives to the info. |
| `management.endpoint.health.enabled` | Used for enable or not the endpoints relatives to the health. |
| `management.endpoint.health.cache.time-to-live` | Used to change the default cache period of 1000 milliseconds. |
| `spring.http.encoding.charset` | Charset of HTTP requests and responses. Added to the "Content-Type" header if not set explicitly. |
| `spring.http.encoding.enabled` | Whether to enable http encoding support. |
| `spring.http.encoding.force` | Whether to force the encoding to the configured charset on HTTP requests and responses. |
| `logging.level.root` | Log levels severity mapping for the root. |
| `logging.level.org.springframework` | Log levels severity mapping for the spring framework. |
| `logging.level.eu.europa.empl.skpt` | Log levels severity mapping for the skpt |
| `spring.jpa.generate-ddl` | Whether to initialize the schema on startup. |
| `spring.jpa.hibernate.ddl-auto` | DDL mode. This is actually a shortcut for the "hibernate.hbm2ddl.auto" property. Defaults to "create-drop" when using an embedded database and no schema manager was detected. Otherwise, defaults to "none". |
| `spring.jpa.show-sql` | Whether to enable logging of SQL statements. |
| `spring.flyway.enabled` | Whether to enable flyway. |
| `spring.flyway.locations` | Locations of migrations scripts. Can contain the special "{vendor}" placeholder to use vendor-specific locations. |
| `spring.flyway.cleanBeforeMigrate` | Used to clean the db before the migration. |
| `spring.cache.jcache.config` | The location of the configuration file to use to initialize the cache manager. |
| `spring.cache.type` | Cache type. By default, auto-detected according to the environment. |
| `server..servlet.session.timeout` | Session timeout. If a duration suffix is not specified, seconds will be used. |
| `spring.http.multipart.max-file-size` | Max file size. |
| `spring.http.multipart.max-request-size` | Max request size. |
| `spring.jackson.serialization.indent_output` | Jackson on/off features that affect the way Java objects are serialized. |
| `spring.jackson.serialization.WRITE_DATES_AS_TIMESTAMPS` | Jackson on/off features that affect the way Java objects are serialized. |
| `spring.jackson.serialization.WRITE_DATE_TIMESTAMPS_AS_NANOSECONDS` | Jackson on/off features that affect the way Java objects are serialized. |
| `spring.jackson.deserialization.READ_DATE_TIMESTAMPS_AS_NANOSECONDS` | Jackson on/off features that affect the way Java objects are serialized. |
| `esco.api` | Url of the esco api. |
| `elasticsearch.clustername` | Name of the elasticsearch cluster used by the mooc. |
| `elasticsearch.host` | Address of the elasticsearch used by the mooc. |
| `elasticsearch.port` | Port of the elasticsearch used by the mooc. |
| `elasticsearch.user` | User used by the mooc for the elasticsearch. |
| `elasticsearch.password` | Password used by the mooc for the elasticsearch. |
| `survey.date.start` | Start date of a survey. |
| `survey.date.end` | End date of a survey. |
| `survey.url` | Url of the survey. |
| `spring.mail.host` | SMTP server host. For instance, `smtp.example.com`. |
| `spring.mail.port` | SMTP server port. |
| `spring.mail.username` | Login user of the SMTP server. |
| `spring.mail.password` | Login password of the SMTP server. |
| `spring.mail.protocol` | Protocol used by the SMTP server. |
| `spring.mail.properties.mail.smtp.starttls.enable` | Additional JavaMail Session properties. |
| `spring.mail.properties.mail.smtp.from` | Additional JavaMail Session properties. |
| `report.mail.to` | The email address to which the reporting will be sent to. |
| `report.mail.subject` | The email subject of the reporting emails.  |
| `survey.cookieConsentKitUrl` | The cookie consent kit (CCK) URL |
| `skpt.attachment.dir` | The attachment temporary folder. |
| `skpt.attachment.accepted.media.types` | The attachments authorized types. |
| `skpt.attachment.accepted.extensions` | The attachments authorized extensions. |
| `skpt.attachment.max.size` | The attachments max size in bytes. |
| `skpt.attachment.cron` | The outdated attachments cleanup job cron expression.|
| `skpt.attachment.window` | The validity time of the attachments in ms.|
| `skpt.joinup.url` | Joinup url of the project |
| `spring.datasource.url` | JDBC URL of the database. |
| `spring.datasource.username` | Login username of the database. |
| `spring.datasource.password` | Login password of the database. |
| `spring.datasource.driver-class-name` | Fully qualified name of the JDBC driver. Auto-detected based on the URL by default. |
| `export.word.temp.dir` | Directory used to generate the word files. |
| `mooc.url` | Url link to the mooc app. |

## Maintainers

European Commission  

Contact: EMPL-E2-SKILLS-PROFILETOOL@ec.europa.eu
