/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 29/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.api;

import eu.europa.empl.skpt.api.exception.LabelIOException;
import eu.europa.empl.skpt.service.label.ILabelService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.io.ByteArrayOutputStream;
import java.io.IOException;

import static eu.europa.empl.skpt.common.Error.LABEL_IO_EXCEPTION;

// CLOVER:OFF

/**
 * Controller handling requests to retrieve labels
 *
 * @author ARHS Spikeseed
 */
@RestController
public class LabelController {

    private final ILabelService labelService;

    /**
     * Constructor
     *
     * @param labelService the label service
     */
    @Autowired
    public LabelController(ILabelService labelService) {
        this.labelService = labelService;
    }

    /**
     * Method handling requests to retrieve labels as json for 1 language
     *
     * @param lang the language to retrieve labels in
     * @return response as a byte array
     */
    @Cacheable(value = "api-labels")
    @RequestMapping(value = "/api/labels/{lang:[a-z]{2,3}}.json", produces = MediaType.APPLICATION_JSON_VALUE)
    public byte[] getAllLabels(@PathVariable("lang") String lang) {
        try (ByteArrayOutputStream os = new ByteArrayOutputStream()) {
            labelService.asJson(os, lang);
            return os.toByteArray();
        } catch (IOException e) {
            throw new LabelIOException("Error during the retrieving of the labels", LABEL_IO_EXCEPTION);
        }
    }
}
