/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 04/02/2019
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.api;

import eu.europa.empl.skpt.api.dto.ReportDto;
import eu.europa.empl.skpt.service.report.IReportService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

// CLOVER:OFF

/**
 * Controller for the reports.
 *
 * @author ARHS Spikeseed
 */
@RestController
public class ReportController {

    private IReportService reportService;

    /**
     * Constructor.
     *
     * @param reportService nace service
     */
    @Autowired
    public ReportController(IReportService reportService) {
        this.reportService = reportService;
    }

    /**
     * Send an email containing the report information.
     *
     * @param reportDto report information
     * @return a response entity
     */
    @PostMapping(value = "/api/report/sendMail", consumes = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity sendReportingMail(
            @RequestBody @Valid ReportDto reportDto) {
        try {
            this.reportService.sendReport(reportDto);
            return ResponseEntity.ok().build();
        } catch (Exception e) {
            return ResponseEntity.status(HttpStatus.INTERNAL_SERVER_ERROR).body(e.getMessage());
        }
    }

}
