/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 28/01/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.api.config;

import org.apache.commons.lang3.StringUtils;
import org.springframework.context.annotation.Profile;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.PostConstruct;
import java.util.HashMap;
import java.util.Map;

// CLOVER:OFF

/**
 * Mock controller
 *
 * @author ARHS Spikeseed
 */
@RestController
@Profile("!prod")
public class MockConfigController extends AbstractConfigController {

    private Map<String, String> properties;

    /**
     * Init the map
     */
    @PostConstruct
    public void init() {
        this.properties = new HashMap<>();
        this.properties.put("sentryDsn", this.sentryPublicDsn);
        this.properties.put("escoApiEndpoint", this.escoApiEndpoint);
        this.properties.put("moocUrl", this.moocUrl);
        this.properties.put("surveyStartDate", this.surveyStartDate);
        this.properties.put("surveyEndDate", this.surveyEndDate);
        this.properties.put("surveyUrl", this.surveyUrl);
        this.properties.put("joinupUrl", this.joinupUrl);
    }

    /**
     * Configuration request handler.
     *
     * @return The configuration parameters.
     */
    @RequestMapping("/api/config")
    public Map<String, String> getConfig() {
        Map<String, String> result = new HashMap<>();

        result.putAll(properties);

        if (!this.sentryEnable) {
            result.put("sentryDsn", StringUtils.EMPTY);
        }

        return result;
    }

    /**
     * Used to update a config property
     *
     * @param property property to set
     * @param value new value
     */
    @RequestMapping("/api/config/set")
    public void setProperty(
            @RequestParam("property") String property,
            @RequestParam("value") String value) {
        this.properties.put(property, value);
    }
}
