/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 14/4/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.api.exception;

import eu.europa.empl.skpt.common.Error;

import java.util.ArrayList;
import java.util.List;

// CLOVER:OFF

/**
 * Super class of all exceptions bound to the API.
 *
 * @author ARHS Spikeseed
 */
public abstract class ApiException extends RuntimeException {

    private final List<Error> errors;

    /**
     * Default constructor.
     */
    public ApiException() {
        this(null, null, null);
    }

    /**
     * Constructor with message argument
     *
     * @param message the message of the exception
     */
    public ApiException(String message) {
        this(message, null, null);
    }

    /**
     * Constructor with message and cause arguments
     *
     * @param message the message of the exception
     * @param cause   the cause of the exception
     */
    public ApiException(String message, Throwable cause) {
        this(message, cause, null);
    }

    /**
     * Constructor with cause argument
     *
     * @param cause the cause of the exception
     */
    public ApiException(Throwable cause) {
        this(null, cause, null);
    }

    /**
     * Constructor with message argument
     *
     * @param message the message of the exception
     * @param errors  list of potential errors to be returned to the client
     */
    public ApiException(String message, List<Error> errors) {
        this(message, null, errors);
    }

    /**
     * Constructor with cause argument
     *
     * @param cause  the cause of the exception
     * @param errors list of potential errors to be returned to the client
     */
    public ApiException(Throwable cause, List<Error> errors) {
        this(null, cause, errors);
    }

    /**
     * Constructor with message and cause arguments
     *
     * @param message the message of the exception
     * @param cause   the cause of the exception
     * @param errors  list of potential errors to be returned to the client
     */
    public ApiException(String message, Throwable cause, List<Error> errors) {
        super(message, cause);
        this.errors = errors != null ? new ArrayList<>(errors) : new ArrayList<>();
    }

    public List<Error> getErrors() {
        return errors;
    }

    /**
     * Returns {@code true} if this exception contains errors, {@code false} otherwise.
     * @return {@code true} if this exception contains errors, {@code false} otherwise
     */
    public boolean hasErrors() {
        return !errors.isEmpty();
    }
}
