/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 16/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.api.export;

import eu.europa.empl.skpt.api.exception.ImportException;
import eu.europa.empl.skpt.api.exception.ImportIOException;
import eu.europa.empl.skpt.api.exception.ImportSaxException;
import eu.europa.empl.skpt.api.exception.InternalServerErrorException;
import eu.europa.empl.skpt.common.Error;
import eu.europa.empl.skpt.service.export.model.profile.Profile;
import eu.europa.empl.skpt.service.importation.IImportService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;
import org.xml.sax.SAXException;

import java.io.IOException;
import java.util.Optional;

// CLOVER:OFF

/**
 * Controller handling import requests.
 *
 * @author ARHS Spikeseed
 */
@RestController
public class ImportController {

    @Autowired
    private IImportService importService;

    /**
     * Converts the provided XML profile to JSON.
     *
     * @param file the XML profile
     * @return the converted XML to JSON
     */
    @RequestMapping(value = "/api/import", method = RequestMethod.POST,
            consumes = MediaType.MULTIPART_FORM_DATA_VALUE, produces = MediaType.APPLICATION_JSON_VALUE)
    public Profile importXml(@RequestParam("file") MultipartFile file) {
        Optional<Profile> profile = Optional.empty();
        if (file != null) {
            try {
                profile = importService.importProfile(file.getOriginalFilename(), file.getBytes());
            } catch (IOException e) {
                throw new ImportIOException("Error IO during the Xml import", Error.IMPORT_INVALID_XML);
            } catch (SAXException e) {
                throw new ImportSaxException("Error SAX during the Xml import", Error.IMPORT_INVALID_XML);
            } catch (Exception e) {
                throw new InternalServerErrorException("Error during the Xml import");
            }
        }
        return profile.orElseThrow(() -> new ImportException("The profile should not be empty", Error.IMPORT_INVALID));
    }
}