/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 14/4/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.common;

// CLOVER:OFF

/**
 * Lists errors that can occur within the application. It is particularly meant for business or validation errors that can then be
 * propagated.
 *
 * @author ARHS Spikeseed
 */
public enum Error {

    /**
     * Error message for wrong media type
     */
    ATTACHMENT_WRONG_MEDIA_TYPE("001", "An attachment has been submitted but doesn't have a recognized media type."),
    /**
     * Error message for wrong extension
     */
    ATTACHMENT_WRONG_EXTENSION("002", "An attachment has been submitted but doesn't have a recognized extension."),
    /**
     * Error message for attachment exceeding max size
     */
    ATTACHMENT_EXCEEDS_MAX_SIZE("003", "An attachment has been submitted but exceeds the maximum allowed size."),
    /**
     * Error message for invalid XML
     */
    IMPORT_INVALID_XML("020", "The XML submitted is invalid in regard to the XSD"),
    /**
     * Error message for an empty optional profile
     */
    IMPORT_INVALID("", "The optional profile cannot be empty"),
    /**
     * Error message for file exceeding max size
     */
    FILE_EXCEEDS_MAX_SIZE("040", "A file has been submitted but exceeds the maximum allowed size."),
    /**
     * Error message for request exceeding max size
     */
    REQUEST_EXCEEDS_MAX_SIZE("041", "A request has been submitted but exceeds the maximum allowed size."),
    /**
     * Error message for IOException during the Word export
     */
    EXPORT_WORD_IO_EXCEPTION("042", "An IO Exception occured during the Word export."),
    /**
     * Error message URISyntaxException during the Word export
     */
    EXPORT_WORD_URI_SYNTAX_EXCEPTION("042", "An URI Syntax Exception occured during the Word export."),
    /**
     * Error message for IOException during the Pdf export
     */
    EXPORT_PDF_IO_EXCEPTION("042", "An IO Exception occured during the Pdf export."),
    /**
     * Error message for IOException during the Xml export
     */
    EXPORT_XML_IO_EXCEPTION("042", "An IO Exception occured during the Xml export."),
    /**
     * Error message for IOException during the Xml import
     */
    IMPORT_XML_IO_EXCEPTION("042", "An IO Exception occured during the Xml import."),
    /**
     * Error message for IOException during the upload of the attachment
     */
    ATTACHMENT_IO_EXCEPTION("042", "An IO Exception occured during the upload of the attachment."),
    /**
     * Error message for EncodingException during the retrieval of the attachment
     */
    ATTACHMENT_ENCODING_EXCEPTION("042", "An Encoding Exception occured during the retrieval of the attachment."),
    /**
     * Error message for IOException during the retrieval of the labels
     */
    LABEL_IO_EXCEPTION("042", "An IO Exception occured during the retrieval of the labals."),
    /**
     * Error message for internal server error
     */
    INTERNAL_SERVER_ERROR("042", "An internal server error occured.");

    private final String id;
    private final String description;

    /**
     * Constructor
     *
     * @param id          the unique id of the error
     * @param description the description detailing the error
     */
    Error(String id, String description) {
        this.id = id;
        this.description = description;
    }

    public String getId() {
        return id;
    }

    public String getDescription() {
        return description;
    }
}
