/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool MOOC Backend
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 19/07/2018
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.config;

import eu.europa.empl.skpt.service.export.impl.ExportService;
import org.apache.avalon.framework.configuration.ConfigurationException;
import org.apache.avalon.framework.configuration.DefaultConfigurationBuilder;
import org.apache.fop.apps.FopFactory;
import org.apache.fop.apps.FopFactoryBuilder;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.xml.sax.SAXException;

import java.io.IOException;
import java.net.URI;
import java.net.URISyntaxException;

/**
 * ExportConfiguration
 *
 * @author ARHS Spikeseed
 */
@Configuration
public class ExportConfiguration {

    private static final String FOP_CONFIGURATION_FILE = "/fop/fop.xconf";
    private static final String FOP_FOLDER = "/fop/";

    /**
     * Create an FopFactory
     *
     * @return an FopFactory
     */
    @Bean
    public FopFactory createFopFactory() {
        org.apache.avalon.framework.configuration.Configuration config;
        URI fopBaseFolder;
        try {
            config = new DefaultConfigurationBuilder().build(ExportService.class.getResourceAsStream(FOP_CONFIGURATION_FILE));
            fopBaseFolder = ExportService.class.getResource(FOP_FOLDER).toURI();

        } catch (SAXException | IOException | ConfigurationException | URISyntaxException e) {
            throw new RuntimeException(e);
        }
        return new FopFactoryBuilder(fopBaseFolder).setConfiguration(config).build();
    }
}
