package eu.europa.empl.skpt.config;

import eu.europa.empl.skpt.service.export.model.profile.Profile;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.xml.sax.SAXException;

import javax.xml.XMLConstants;
import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Marshaller;
import javax.xml.bind.Unmarshaller;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.stream.StreamSource;
import javax.xml.validation.Schema;
import javax.xml.validation.SchemaFactory;
import java.nio.charset.StandardCharsets;

/**
 * Defines configuration linked to the import/export feature
 */
@Configuration
public class ImportExportConfiguration {
    private static final String XSD_RESOURCE_PATH = "/eu/europa/empl/skpt/profile.xsd";

    /**
     * Creates unmarshaller
     * @param jaxbContext jaxb context
     * @return initialized unmarshaller
     * @throws JAXBException jaxb exception
     */
    @Bean
    public Unmarshaller unmarshaller(JAXBContext jaxbContext) throws JAXBException {
        return jaxbContext.createUnmarshaller();
    }

    /**
     * Creates jaxb context
     * @return initialized jaxb context
     * @throws JAXBException jaxb exception
     */
    @Bean
    public JAXBContext jaxbContext() throws JAXBException {
        return JAXBContext.newInstance(Profile.class);
    }

    /**
     * Creates marshaller
     * @param jaxbContext jaxb context
     * @return initialized marshaller
     * @throws JAXBException jaxb exception
     */
    @Bean
    public Marshaller marshaller(JAXBContext jaxbContext) throws JAXBException {
        Marshaller jaxbMarshaller = jaxbContext.createMarshaller();
        jaxbMarshaller.setProperty(Marshaller.JAXB_ENCODING, StandardCharsets.UTF_8.name());
        return jaxbMarshaller;
    }

    /**
     * Creates transformer factory
     * @return initialized transformer factory
     */
    @Bean
    public TransformerFactory transformerFactory() {
        return TransformerFactory.newInstance();
    }

    /**
     * Creates schema factory
     * @return initialized schema factory
     */
    @Bean
    public SchemaFactory createSchemaFactory() {
        return SchemaFactory.newInstance(XMLConstants.W3C_XML_SCHEMA_NS_URI);
    }

    /**
     * Creates the schema
     * @param schemaFactory schema factory used to create the new schema
     * @return initialized schema
     * @throws SAXException sax exception
     */
    @Bean
    public Schema createSchema(SchemaFactory schemaFactory) throws SAXException {
        StreamSource streamSource = new StreamSource(getClass().getResource(XSD_RESOURCE_PATH).toString());
        return schemaFactory.newSchema(streamSource);
    }
}
