/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 14/4/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.config;

import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.convert.ConversionService;
import org.springframework.core.convert.support.DefaultConversionService;
import org.springframework.core.convert.support.GenericConversionService;
import org.springframework.core.serializer.support.DeserializingConverter;
import org.springframework.core.serializer.support.SerializingConverter;

// CLOVER:OFF

/**
 * Other configurations that don't need a specific class.
 *
 * @author ARHS Spikeseed
 */
@Configuration
public class OtherConfiguration {

    /**
     * Registers a conversion service
     *
     * @return a conversion service
     */
    @Bean
    public ConversionService conversionService() {
        return new DefaultConversionService();
    }

    /**
     * Registers a conversion service for spring session
     *
     * @return a conversion service for spring session
     */
    @Bean
    @Qualifier("springSessionConversionService")
    public ConversionService springSessionConversionService() {
        GenericConversionService conversionService = new GenericConversionService();
        conversionService.addConverter(Object.class, byte[].class,
                new SerializingConverter());
        conversionService.addConverter(byte[].class, Object.class,
                new DeserializingConverter());
        return conversionService;
    }
}
