/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 21/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.config.converter;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.converter.xml.Jaxb2RootElementHttpMessageConverter;
import org.xml.sax.SAXException;

import javax.xml.XMLConstants;
import javax.xml.bind.Marshaller;
import javax.xml.bind.PropertyException;
import javax.xml.bind.Unmarshaller;
import javax.xml.transform.Source;
import javax.xml.validation.Schema;
import javax.xml.validation.SchemaFactory;
import java.nio.charset.StandardCharsets;

/**
 * Extension of {@link Jaxb2RootElementHttpMessageConverter} that supports defining schemas.
 *
 * @author ARHS Spikeseed
 */
public class CustomJaxb2RootElementHttpMessageConverter extends Jaxb2RootElementHttpMessageConverter {

    private static final Logger LOGGER = LoggerFactory.getLogger(CustomJaxb2RootElementHttpMessageConverter.class);

    private final Source[] schemas;

    /**
     * Constructor
     *
     * @param schemas XSD sources
     */
    public CustomJaxb2RootElementHttpMessageConverter(Source... schemas) {
        this.schemas = schemas;
    }

    @Override
    protected void customizeMarshaller(Marshaller marshaller) {
        try {
            marshaller.setProperty(Marshaller.JAXB_ENCODING, StandardCharsets.UTF_8.name());

            if (this.schemas != null && this.schemas.length > 0) {
                SchemaFactory schemaFactory = SchemaFactory.newInstance(XMLConstants.W3C_XML_SCHEMA_NS_URI);
                Schema schema = schemaFactory.newSchema(this.schemas);
                marshaller.setSchema(schema);
            }
        } catch (PropertyException | SAXException e) {
            LOGGER.error(e.getMessage());
            throw new RuntimeException(e);
        }
    }

    @Override
    protected void customizeUnmarshaller(Unmarshaller unmarshaller) {
        try {
            if (this.schemas != null && this.schemas.length > 0) {
                SchemaFactory schemaFactory = SchemaFactory.newInstance(XMLConstants.W3C_XML_SCHEMA_NS_URI);
                Schema schema = schemaFactory.newSchema(this.schemas);
                unmarshaller.setSchema(schema);
            }
        } catch (SAXException e) {
            LOGGER.error(e.getMessage());
            throw new RuntimeException(e);
        }
    }
}
