/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 28/01/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.data.domain.country;

import com.fasterxml.jackson.annotation.JsonManagedReference;
import eu.europa.empl.skpt.data.domain.AbstractEntity;
import eu.europa.empl.skpt.data.domain.IReferenceData;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Index;
import javax.persistence.MapKey;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import java.util.Collections;
import java.util.Map;

// CLOVER:OFF

/**
 * Country JPA entity.
 *
 * @author ARHS Spikeseed
 */
@Entity
@Table(
        name = "tb_rfd_country",
        indexes = {
                @Index(columnList = "alpha_code_3", unique = true)
        }
)
public class Country extends AbstractEntity implements IReferenceData<CountryValue> {

    @Column(name = "alpha_code_3", nullable = false)
    private String alphaCode3;

    @OneToMany(cascade = CascadeType.ALL, mappedBy = "country")
    @MapKey(name = "language")
    @JsonManagedReference
    private Map<String, CountryValue> values;

    public String getAlphaCode3() {
        return alphaCode3;
    }

    public void setAlphaCode3(String alphaCode3) {
        this.alphaCode3 = alphaCode3;
    }

    @Override
    public Map<String, CountryValue> getValues() {
        return (values == null) ? Collections.emptyMap() : values;
    }

    public void setValues(Map<String, CountryValue> values) {
        this.values = values;
    }
}
