/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 28/01/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.data.domain.isced;

import com.fasterxml.jackson.annotation.JsonManagedReference;
import eu.europa.empl.skpt.data.domain.AbstractEntity;
import eu.europa.empl.skpt.data.domain.IReferenceData;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Index;
import javax.persistence.MapKey;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import java.util.Collections;
import java.util.Map;

// CLOVER:OFF

/**
 * ISCED FoET 2013 JPA entity.
 *
 * @author ARHS Spikeseed
 */
@Entity
@Table(
        name = "tb_rfd_isced",
        indexes = {
                @Index(columnList = "key_value", unique = true)
        }
)
public class IscedFoet extends AbstractEntity implements IReferenceData<IscedFoetValue> {

    @Column(name = "key_value", nullable = false)
    private String key;

    @OneToMany(cascade = CascadeType.ALL, mappedBy = "iscedFoet")
    @MapKey(name = "language")
    @JsonManagedReference
    private Map<String, IscedFoetValue> values;

    public String getKey() {
        return key;
    }

    public void setKey(String key) {
        this.key = key;
    }

    @Override
    public Map<String, IscedFoetValue> getValues() {
        return (values == null) ? Collections.emptyMap() : values;
    }

    public void setValues(Map<String, IscedFoetValue> values) {
        this.values = values;
    }
}
