/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 28/01/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.data.domain.language;

import com.fasterxml.jackson.annotation.JsonManagedReference;
import eu.europa.empl.skpt.data.domain.AbstractEntity;
import eu.europa.empl.skpt.data.domain.IReferenceData;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.Index;
import javax.persistence.MapKey;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import java.util.Collections;
import java.util.Map;

// CLOVER:OFF

/**
 * Language JPA entity.
 *
 * @author ARHS Spikeseed
 */
@Entity
@Table(
        name = "tb_rfd_language",
        indexes = {
                @Index(columnList = "iso_code_1", unique = true)
        }
)
public class Language extends AbstractEntity implements IReferenceData<LanguageValue> {

    @Column(name = "iso_code_1", nullable = false)
    private String isoCode1;

    @Column(name = "iso_code_2")
    private String isoCode2;

    @Column(name = "iso_code_3")
    private String isoCode3;

    @Column(name = "native_value")
    private String nativeValue;

    @Column(name = "primary_supported")
    private Boolean primarySupported;

    @Column(name = "secondary_supported")
    private Boolean secondarySupported;

    @OneToMany(fetch = FetchType.LAZY, cascade = CascadeType.ALL, mappedBy = "lang")
    @MapKey(name = "language")
    @JsonManagedReference
    private Map<String, LanguageValue> values;

    @Column(name = "selector_order")
    private Integer selectorOrder;

    public String getIsoCode1() {
        return isoCode1;
    }

    public void setIsoCode1(String isoCode1) {
        this.isoCode1 = isoCode1;
    }

    public String getIsoCode2() {
        return isoCode2;
    }

    public void setIsoCode2(String isoCode2) {
        this.isoCode2 = isoCode2;
    }

    public String getIsoCode3() {
        return isoCode3;
    }

    public void setIsoCode3(String isoCode3) {
        this.isoCode3 = isoCode3;
    }

    public String getNativeValue() {
        return nativeValue;
    }

    public void setNativeValue(String nativeValue) {
        this.nativeValue = nativeValue;
    }

    public void setPrimarySupported(Boolean primarySupported) {
        this.primarySupported = primarySupported;
    }

    public Boolean getPrimarySupported() {
        return primarySupported;
    }

    public void setSecondarySupported(Boolean secondarySupported) {
        this.secondarySupported = secondarySupported;
    }

    public Boolean getSecondarySupported() {
        return secondarySupported;
    }

    @Override
    public Map<String, LanguageValue> getValues() {
        return (values == null) ? Collections.emptyMap() : values;
    }

    public void setValues(Map<String, LanguageValue> values) {
        this.values = values;
    }

    public Integer getSelectorOrder() {
        return selectorOrder;
    }

    public void setSelectorOrder(Integer selectorOrder) {
        this.selectorOrder = selectorOrder;
    }
}
