/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 12/4/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.data.repository.attachment;

import eu.europa.empl.skpt.data.domain.attachment.Attachment;
import org.springframework.data.jpa.repository.Lock;
import org.springframework.data.repository.PagingAndSortingRepository;

import javax.persistence.LockModeType;
import java.time.Instant;
import java.util.Optional;
import java.util.stream.Stream;

/**
 * Repository handling {@link Attachment} entities
 *
 * @author ARHS Spikeseed
 */
public interface IAttachmentRepository extends PagingAndSortingRepository<Attachment, Long> {

    /**
     * Returns the {@link Attachment} matching the unique identifier specified.
     *
     * @param id the unique identifier
     * @return an {@link Optional} of {@link Attachment}
     */
    Optional<Attachment> findById(Long id);

    /**
     * Returns the {@link Attachment} matching the unique identifier specified.
     *
     * @param id the unique identifier
     * @return an {@link Optional} of {@link Attachment}
     */
    Optional<Attachment> findByIdentifier(String id);

    /**
     * Returns attachments uploaded prior to a certain timestamp.
     * This method used the {@link LockModeType#PESSIMISTIC_WRITE} lock mode. This will block other transactional threads on
     * data access preventing double processing of attachments.
     *
     * @param uploadTimestamp used to select only attachments uploaded prior this timestamp
     * @return attachments uploaded prior to a certain timestamp
     */
    @Lock(LockModeType.PESSIMISTIC_WRITE)
    Stream<Attachment> findByUploadTimestampLessThan(Instant uploadTimestamp);

}
