/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 28/01/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.data.repository.isced;

import eu.europa.empl.skpt.data.domain.isced.IscedFoet;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.PagingAndSortingRepository;
import org.springframework.data.repository.query.Param;

import java.util.Optional;
import java.util.Set;

/**
 * Repository retrieving {@link IscedFoet} entities
 *
 * @author ARHS Spikeseed
 */
public interface IIscedFoetRepository extends PagingAndSortingRepository<IscedFoet, Long> {

    /**
     * Returns the {@link IscedFoet} mathing the unique identifier specified.
     *
     * @param id the unique identifier of an ISCED FoET 2013
     * @return an {@link Optional} of {@link IscedFoet}
     */
    Optional<IscedFoet> findById(Long id);

    /**
     * Returns a {@link Page} of {@link IscedFoet} entities meeting the paging restriction provided in the
     * {@code Pageable} object.
     *
     * @param language  the search language
     * @param pageable  the pagination parameters
     * @return a page of entities
     */
    @Query("SELECT DISTINCT if FROM IscedFoet if JOIN if.values ifv WHERE ifv.language = :language")
    Page<IscedFoet> findByLanguage(@Param("language") String language, Pageable pageable);

    /**
     * Returns a {@link Page} of {@link IscedFoet} entities meeting the paging restriction provided in the
     * {@code Pageable} object.
     *
     * @param pageable the pagination parameters
     * @param value    parameter matched against {@link eu.europa.empl.skpt.data.domain.isced.IscedFoetValue#value}
     * @return a page of entities
     */
    @Query("SELECT DISTINCT i FROM IscedFoet i JOIN i.values iv WHERE iv.value LIKE concat('%', :value, '%')")
    Page<IscedFoet> findByValueIgnoreCase(@Param("value") String value, Pageable pageable);

    /**
     * Returns a {@link Page} of {@link IscedFoet} entities meeting the paging restriction provided in the
     * {@code Pageable} object.
     *
     * @param pageable  the pagination parameters
     * @param value     parameter matched against {@link eu.europa.empl.skpt.data.domain.isced.IscedFoetValue#value}
     * @param languages the languages for which the value will be matched against
     * @return a page of entities
     */
    @Query("SELECT DISTINCT i FROM IscedFoet i JOIN i.values iv "
            + "WHERE iv.language IN :langs AND iv.value LIKE concat('%', :value, '%')")
    Page<IscedFoet> findByValueIgnoreCaseAndLanguages(@Param("langs") Set<String> languages, @Param("value") String
            value, Pageable pageable);

}
