/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 28/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.data.repository.label;

import eu.europa.empl.skpt.data.domain.label.Label;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.PagingAndSortingRepository;

import java.util.Optional;
import java.util.stream.Stream;

/**
 * Repository retrieving {@link Label} entities
 *
 * @author ARHS Spikeseed
 */
public interface ILabelRepository extends PagingAndSortingRepository<Label, Long> {

    /**
     * Find all labels and return them as a {@link Stream}. Make sure to close the stream!
     *
     * @return a stream of all labels
     */
    @Query("select l from Label l")
    Stream<Label> findAllAsStream();

    /**
     * Returns the {@link Label} matching the unique identifier specified.
     *
     * @param id the unique identifier
     * @return an {@link Optional} of {@link Label}
     */
    Optional<Label> findById(Long id);

    /**
     * Returns the {@link Label} matching the unique key.
     *
     * @param key the key of the label
     * @return an {@link Optional} of {@link Label}
     */
    Optional<Label> findByKey(String key);

}
