/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 28/01/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.data.repository.nace;

import eu.europa.empl.skpt.data.domain.nace.Nace;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.PagingAndSortingRepository;
import org.springframework.data.repository.query.Param;

import java.util.Optional;
import java.util.Set;

/**
 * Repository retrieving {@link Nace} entities
 *
 * @author ARHS Spikeseed
 */
public interface INaceRepository extends PagingAndSortingRepository<Nace, Long> {

    /**
     * Returns the {@link Nace} mathing the unique identifier specified.
     *
     * @param id the unique identifier of a NACE
     * @return an {@link Optional} of {@link Nace}
     */
    Optional<Nace> findById(Long id);

    /**
     * Returns a {@link Page} of {@link Nace} entities meeting the paging restriction provided in the
     * {@code Pageable} object.
     *
     * @param language  the search language
     * @param pageable  the pagination parameters
     * @return a page of entities
     */
    @Query("SELECT DISTINCT n FROM Nace n JOIN n.values nv WHERE nv.language = :language")
    Page<Nace> findByLanguage(@Param("language") String language, Pageable pageable);

    /**
     * Returns a {@link Page} of {@link Nace} entities meeting the paging restriction provided in the
     * {@code Pageable} object.
     *
     * @param pageable the pagination parameters
     * @param value    parameter matched against {@link eu.europa.empl.skpt.data.domain.nace.NaceValue#value}
     * @return a page of entities
     */
    @Query("SELECT DISTINCT i FROM Nace i JOIN i.values iv WHERE iv.value LIKE concat('%', :value, '%')")
    Page<Nace> findByValueIgnoreCase(@Param("value") String value, Pageable pageable);

    /**
     * Returns a {@link Page} of {@link Nace} entities meeting the paging restriction provided in the
     * {@code Pageable} object.
     *
     * @param pageable  the pagination parameters
     * @param value     parameter matched against {@link eu.europa.empl.skpt.data.domain.nace.NaceValue#value}
     * @param languages the languages for which the value will be matched against
     * @return a page of entities
     */
    @Query("SELECT DISTINCT i FROM Nace i JOIN i.values iv "
            + "WHERE iv.language IN :langs AND iv.value LIKE concat('%', :value, '%')")
    Page<Nace> findByValueIgnoreCaseAndLanguages(@Param("langs") Set<String> languages, @Param("value") String value,
                                                 Pageable pageable);

}
