/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 14/4/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.attachment;

import eu.europa.empl.skpt.common.Error;
import eu.europa.empl.skpt.data.domain.attachment.Attachment;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

// CLOVER:OFF

/**
 * Holds the result of a save attachment action.
 *
 * @author ARHS Spikeseed
 */
public class AttachmentSaveResult {

    private final Optional<Attachment> attachment;
    private final List<Error> errors;

    /**
     * Constructor
     *
     * @param attachment the attachment
     * @param errors     the list of errors if any
     */
    public AttachmentSaveResult(Attachment attachment, List<Error> errors) {
        this.attachment = attachment != null ? Optional.of(attachment) : Optional.empty();
        this.errors = errors != null ? new ArrayList<>(errors) : Collections.emptyList();
    }

    /**
     * Constructor
     *
     * @param attachment the attachment
     */
    public AttachmentSaveResult(Attachment attachment) {
        this(attachment, null);
    }

    /**
     * Constructor
     *
     * @param errors     the list of errors if any
     */
    public AttachmentSaveResult(List<Error> errors) {
        this(null, errors);
    }

    public Optional<Attachment> getAttachment() {
        return attachment;
    }

    public List<Error> getErrors() {
        return Collections.unmodifiableList(errors);
    }

    /**
     * Returns if this result contains errors.
     *
     * @return if this result contains errors
     */
    public boolean hasErrors() {
        return !errors.isEmpty();
    }
}
