/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 12/4/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.attachment;

import eu.europa.empl.skpt.data.domain.attachment.Attachment;

import java.io.InputStream;
import java.util.Optional;

/**
 * Service handling logic for attachments.
 *
 * @author ARHS Spikeseed
 */
public interface IAttachmentService {


    /**
     * Returns a {@link Attachment} entity by its unique identifier
     *
     * @param id        the unique identifier of an attachment
     * @return an {@link Optional} of {@link Attachment}
     */
    Optional<Attachment> findById(Long id);

    /**
     * Returns a {@link Attachment} entity by its unique identifier
     *
     * @param id        the unique identifier of an attachment
     * @return an {@link Optional} of {@link Attachment}
     */
    Optional<Attachment> findByIdentifier(String id);

    /**
     * Saves a new attachment
     * @param is the input stream of the file to be saved
     * @param name the name of the file
     * @param type the media type of the file
     * @param size the size of the file
     * @return an {@link Attachment} object
     */
    AttachmentSaveResult save(InputStream is, String name, String type, long size);

    /**
     * Creates an input stream
     * @param id the unique identifier of an attachment
     * @return an input stream of the underlying file
     */
    InputStream read(String id);

    /**
     * Removes/Deletes outdated attachments. Normally, this method is meant to be called by the scheduler.
     */
    void removeOutdatedAttachments();

}
