/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 28/01/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.service.country;

import eu.europa.empl.skpt.data.domain.country.Country;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;

import java.util.Optional;

/**
 * Interface for the {@link eu.europa.empl.skpt.service.country.impl.CountryService} service.
 *
 * @author ARHS Spikeseed
 */
public interface ICountryService {

    /**
     * Returns a {@link Page} of {@link Country} entities meeting the paging restriction provided in the
     * {@code Pageable} object.
     *
     * @param searchString    search string to match against {@link Country} values
     * @param resultLanguages the languages to search on
     * @param pageable        the pagination parameters
     * @return a page of entities
     */
    Page<Country> search(String searchString, String[] resultLanguages, Pageable pageable);

    /**
     * Returns a {@link Optional} of {@link Country} entities filtered by {@link Country} Alpha3 code meeting the paging
     * restriction provided in the {@code Pageable} object.
     *
     * @param code      the ISO 3166 A3 country code
     * @param languages languages to include in the result against {@link Country} values
     * @param defaultEnglish true if the method need to return the default language in english
     * @return a page of entities
     */
    Optional<Country> findByAlphaCode3(String code, String[] languages, boolean defaultEnglish);

    /**
     * Returns a {@link Optional} of {@link Country} entities filtered by {@link Country} Alpha3 code meeting the paging
     * restriction provided in the {@code Pageable} object.
     *
     * @param code      the ISO 3166 A3 country code
     * @param languages languages to include in the result against {@link Country} values
     * @return a page of entities
     */
    Optional<Country> findByAlphaCode3(String code, String[] languages);

}
