/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 28/01/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.service.country.impl;

import eu.europa.empl.skpt.data.domain.country.Country;
import eu.europa.empl.skpt.data.repository.country.ICountryRepository;
import eu.europa.empl.skpt.service.country.ICountryService;
import eu.europa.empl.skpt.service.tool.LanguageFilter;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;

import java.util.Optional;

/**
 * Implementation of the service for the {@link Country} entity.
 *
 * @author ARHS Spikeseed
 */
@Service
public class CountryService implements ICountryService {

    private final ICountryRepository countryRepository;
    private final LanguageFilter languageFilter;

    /**
     * Contructor.
     *
     * @param countryRepository     the {@link Country} repository.
     * @param languageFilter    language filter
     */
    @Autowired
    public CountryService(ICountryRepository countryRepository, LanguageFilter languageFilter) {
        this.countryRepository = countryRepository;
        this.languageFilter = languageFilter;
    }

    @Override
    public Page<Country> search(String searchString, String[] resultLanguages, Pageable pageable) {
        Page<Country> countriesPage = null;
        if (StringUtils.isNotBlank(searchString)) {
            countriesPage = this.countryRepository.findByValueIgnoreCase(searchString, pageable);
        } else {
            countriesPage = this.countryRepository.findAll(pageable);
        }

        countriesPage = (Page<Country>) languageFilter.filter(countriesPage, resultLanguages);

        return countriesPage;
    }

    @Override
    public Optional<Country> findByAlphaCode3(String code, String[] languages, boolean defaultEnglish) {
        Optional<Country> optionalCountry = this.countryRepository.findByAlphaCode3(code);

        if (optionalCountry.isPresent()) {
            Country country = (Country) languageFilter.filter(optionalCountry.get(), languages);
            if (defaultEnglish && !country.getValues().containsKey(languages[0])) { // always have only one language for this case
                country = (Country) languageFilter.filter(optionalCountry.get(), new String[]{"en"});
            }
            optionalCountry = Optional.of(country);
        }

        return optionalCountry;
    }

    @Override
    public Optional<Country> findByAlphaCode3(String code, String[] languages) {
        return findByAlphaCode3(code, languages, false);
    }
}
