/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 28/01/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.service.esco;

import eu.europa.empl.skpt.data.domain.esco.EscoClassification;
import eu.europa.empl.skpt.data.domain.esco.EscoLocalConcept;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;

import java.util.Optional;

/**
 * Interface for the {@link eu.europa.empl.skpt.service.esco.impl.EscoLocalService} service.
 *
 * @author ARHS Spikeseed
 */
public interface IEscoLocalService {

    /**
     * Returns a {@link EscoLocalConcept} entity by its unique identifier
     *
     * @param id        the unique identifier of an ESCO
     * @param languages the languages returned.
     * @return an {@link Optional} of {@link EscoLocalConcept}
     */
    Optional<EscoLocalConcept> findById(Long id, String[] languages);

    /**
     * Returns a {@link Page} of {@link EscoLocalConcept} entities filtered by {@link EscoClassification} meeting the paging
     * restriction provided in the {@code Pageable} object.
     *
     * @param classification  the ESCO classification
     * @param searchString    search string to match against ESCO values
     * @param resultLanguages the languages to search on.
     * @param pageable        the pagination parameters
     * @return a page of entities.
     */
    Page<EscoLocalConcept> search(EscoClassification classification, String searchString,
            String[] resultLanguages, Pageable pageable);

}
