/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 28/01/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.service.esco.impl;

import eu.europa.empl.skpt.data.domain.esco.EscoClassification;
import eu.europa.empl.skpt.data.domain.esco.EscoLocalConcept;
import eu.europa.empl.skpt.data.repository.esco.IEscoRepository;
import eu.europa.empl.skpt.service.esco.IEscoLocalService;
import eu.europa.empl.skpt.service.tool.LanguageFilter;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import org.springframework.util.Assert;

import java.util.Optional;

/**
 * Implementation of the service for the {@link EscoLocalConcept} entity.
 *
 * @author ARHS Spikeseed
 */
@Service
public class EscoLocalService implements IEscoLocalService {

    private final IEscoRepository escoRepository;
    private final LanguageFilter languageFilter;

    /**
     * Contructor.
     *
     * @param escoRepository the {@link EscoLocalConcept} repository.
     * @param languageFilter    language filter
     */
    @Autowired
    public EscoLocalService(IEscoRepository escoRepository, LanguageFilter languageFilter) {
        this.escoRepository = escoRepository;
        this.languageFilter = languageFilter;
    }

    @Override
    public Optional<EscoLocalConcept> findById(Long id, String[] languages) {
        Assert.notNull(id, "'id' cannot be null");
        Optional<EscoLocalConcept> optionalEscoConcept = this.escoRepository.findById(id);

        EscoLocalConcept escoLocalConcept = (EscoLocalConcept) optionalEscoConcept
                .map(esco -> languageFilter.filter(esco, languages))
                .orElse(null);

        optionalEscoConcept = Optional.ofNullable(escoLocalConcept);

        return optionalEscoConcept;
    }

    @Override
    public Page<EscoLocalConcept> search(EscoClassification classification, String searchString,
            String[] resultLanguages, Pageable pageable) {
        Page<EscoLocalConcept> escosPage = null;
        if (StringUtils.isNotBlank(searchString)) {
            escosPage = this.escoRepository.findByClassificationAndValueIgnoreCase(classification, searchString, pageable);
        } else {
            escosPage = this.escoRepository.findByClassification(classification, pageable);
        }

        escosPage = (Page<EscoLocalConcept>)  languageFilter.filter(escosPage, resultLanguages);

        return escosPage;
    }

}
