/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 26/06/2018
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.export;

import java.io.IOException;
import javax.xml.bind.JAXBException;
import javax.xml.transform.Result;
import javax.xml.transform.Source;
import javax.xml.transform.TransformerException;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;
import eu.europa.empl.skpt.service.export.model.profile.Profile;

/**
 * Service handling the transformation of the xml based on an xslt
 *
 * @author ARHS Spikeseed
 */
public interface ITransformerService {

    /**
     * Transforms the xml result based on the xslt
     *
     * @param profile     profile to transform
     * @param xslt        xslt sheet name
     * @param lang        language
     * @param prettyPrint pretty print
     * @param res         xml result
     * @throws IOException IO exception
     * @throws TransformerException TransformerException
     * @throws JAXBException JAXBException
     */
    void transform(Profile profile, Source xslt, String lang, boolean prettyPrint, Result res)
            throws IOException, TransformerException, JAXBException;

    /**
     *
     * @param streamSource Stream source containing the XML to transform
     * @param streamResult Stream result that will contain the transformation result
     * @param xsltSource XSLT sheet source
     * @throws TransformerException thrown in case an error occurs during the transformation
     */
    void transform(StreamSource streamSource, StreamResult streamResult, Source xsltSource) throws TransformerException;
}
