/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 15/06/2018
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.export.impl;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.stream.Stream;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;

/**
 * Service used to zip the content of a folder into a file
 */
@Component
public class ZipDocumentService {
    private static final Logger LOGGER = LoggerFactory.getLogger(ZipDocumentService.class);

    /**
     * Method used to zip the content of a folder into a file
     *
     * @param byteArrayOutputStream Stream used to store the docx file
     * @param folderPath            The folder whose content must be zipped
     * @throws IOException IOException thrown when accessing files
     */
    public void zipDocument(ByteArrayOutputStream byteArrayOutputStream, Path folderPath) throws IOException {

        try (ZipOutputStream zipOutputStream = new ZipOutputStream(byteArrayOutputStream);
             Stream<Path> walk = Files.walk(folderPath)) {

            walk.filter(path -> !path.toFile().isDirectory())
                    .forEach(path -> {
                        ZipEntry zipEntry = new ZipEntry(folderPath.relativize(path).toString());
                        try {
                            zipOutputStream.putNextEntry(zipEntry);
                            zipOutputStream.write(Files.readAllBytes(path));
                            zipOutputStream.closeEntry();
                        } catch (Exception e) {
                            LOGGER.error("Error when creating docx archive", e);
                        }
                    });
        }
    }
}