/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 23/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.export.model;

import eu.europa.empl.skpt.service.export.model.profile.Profile;
import org.apache.commons.lang3.StringUtils;

import java.util.Optional;

// CLOVER:OFF

/**
 * Result of the process parsing a JSON profile.
 *
 * @author ARHS Spikeseed
 */
public class ParseJsonResult {

    private final Optional<Profile> profile;
    private final Optional<String> error;

    private ParseJsonResult(Profile profile, String error) {
        this.profile = profile == null ? Optional.empty() : Optional.of(profile);
        this.error = StringUtils.isBlank(error) ? Optional.empty() : Optional.of(error);
    }

    /**
     * Constructs a new {@link ParseJsonResult} with the profile specified.
     *
     * @param profile the parsed profile
     */
    public ParseJsonResult(Profile profile) {
        this(profile, null);
    }

    /**
     * Constructs a new {@link ParseJsonResult} with the error specified.
     *
     * @param error the error that resulted of the parsing process
     */
    public ParseJsonResult(String error) {
        this(null, error);
    }

    public Optional<Profile> getProfile() {
        return profile;
    }

    public Optional<String> getError() {
        return error;
    }
}
