/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 23/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.export.model;

import eu.europa.empl.skpt.common.Error;
import eu.europa.empl.skpt.service.export.model.profile.Profile;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

// CLOVER:OFF

/**
 * Result of the process parsing a XML profile.
 *
 * @author ARHS Spikeseed
 */
public class ParseXmlResult {

    private final Optional<Profile> profile;
    private final List<Error> errors;

    private ParseXmlResult(Profile profile, List<Error> errors) {
        this.profile = profile == null ? Optional.empty() : Optional.of(profile);
        this.errors = errors != null ? new ArrayList<>(errors) : Collections.emptyList();
    }

    /**
     * Constructs a new {@link ParseXmlResult} with the profile specified.
     *
     * @param profile the parsed profile
     */
    public ParseXmlResult(Profile profile) {
        this(profile, null);
    }

    /**
     * Constructor
     *
     * @param errors     the list of errors if any
     */
    public ParseXmlResult(List<Error> errors) {
        this(null, errors);
    }

    public Optional<Profile> getProfile() {
        return profile;
    }

    public List<Error> getErrors() {
        return Collections.unmodifiableList(errors);
    }

    /**
     * Returns if this result contains errors.
     *
     * @return if this result contains errors
     */
    public boolean hasErrors() {
        return !errors.isEmpty();
    }

}
