/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 17/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.export.model.profile;

import eu.europa.empl.skpt.service.export.model.ExcelHelper;
import eu.europa.empl.skpt.service.export.model.ExcelTranslationTypesEnum;
import eu.europa.empl.skpt.service.export.model.IExcelCell;
import lombok.Getter;
import lombok.Setter;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import javax.xml.bind.annotation.XmlType;
import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

// CLOVER:OFF

/**
 * Contact info
 *
 * @author ARHS Spikeseed
 */
@XmlType(propOrder = {
        "address",
        "postalCode",
        "country",
        "phoneNumber",
        "phoneNumbers",
        "email",
        "emails"
})
@Getter
@Setter
public class ContactInfo {

    private String address;
    private String postalCode;
    private String country;
    private PrefixSuffix phoneNumber;
    private List<PrefixSuffix> phoneNumbers;
    private PrefixSuffix email;
    private List<PrefixSuffix> emails;

    public List<PrefixSuffix> getPhoneNumbers() {
        return phoneNumbers == null ? Collections.emptyList() : Collections.unmodifiableList(phoneNumbers);
    }

    public List<PrefixSuffix> getEmails() {
        return emails == null ? Collections.emptyList() : Collections.unmodifiableList(emails);
    }

    /**
     * Adapt the class to generate an excel file.
     *
     * @param excelHelper excel helper
     * @param workbook excel workbook
     * @param sectionIndex section index
     * @param sectionName section name
     * @param language language
     */
    public void toExcel(ExcelHelper excelHelper, XSSFWorkbook workbook, int sectionIndex, String sectionName, String language) {
        String subsectionName = excelHelper.getTranslation("profile.contact.section.name", language);
        XSSFSheet sheet = excelHelper.createSheet(workbook, sectionIndex, subsectionName);

        List<XSSFRow> rows = excelHelper.createRows(sheet, sectionIndex, sectionName, subsectionName);

        int columnIndex = 0;
        excelHelper.createColumn(columnIndex++, rows, language, "profile.general.contact.address",
                address);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.general.contact.postCode",
                postalCode);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.general.contact.country",
                country, ExcelTranslationTypesEnum.COUNTRY);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.general.contact.phone",
                phoneNumber.toExcelString(false), phoneNumbers.stream().map(elm -> (IExcelCell) elm).collect(Collectors.toList()));
        excelHelper.createColumn(columnIndex++, rows, language, "profile.general.contact.email",
                email.toExcelString(true), emails.stream().map(elm -> (IExcelCell) elm).collect(Collectors.toList()), true);
    }

}
