/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 20/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.export.model.profile;

import eu.europa.empl.skpt.service.export.model.ExcelHelper;
import eu.europa.empl.skpt.service.export.model.ExcelTranslationTypesEnum;
import eu.europa.empl.skpt.service.export.model.IExcelCell;
import lombok.Getter;
import lombok.Setter;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import javax.xml.bind.annotation.XmlType;
import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

// CLOVER:OFF

/**
 * Digital Skills
 *
 * @author ARHS Spikeseed
 */
@XmlType(propOrder = {
        "usingSmartphone",
        "usingLaptop",
        "managingFiles",
        "createTextDocs",
        "createSpreadsheets",
        "createPresentations",
        "useEmails",
        "findInfoOnInternet",
        "useInternetCalls",
        "purchaseOnline",
        "learningOnline",
        "makingGraphicDesigns",
        "other",
        "others"
})
@Getter
@Setter
public class DigitalSkills {

    private int usingSmartphone;
    private int usingLaptop;
    private int managingFiles;
    private int createTextDocs;
    private int createSpreadsheets;
    private int createPresentations;
    private int useEmails;
    private int findInfoOnInternet;
    private int useInternetCalls;
    private int purchaseOnline;
    private int learningOnline;
    private int makingGraphicDesigns;
    private String other;
    private List<Name> others;

    public List<Name> getOthers() {
        return others == null ? Collections.emptyList() : Collections.unmodifiableList(others);
    }

    /**
     * Adapt the class to generate an excel file.
     *
     * @param excelHelper excel helper
     * @param workbook excel workbook
     * @param sectionIndex section index
     * @param sectionName section name
     * @param language language
     */
    public void toExcel(ExcelHelper excelHelper, XSSFWorkbook workbook, int sectionIndex, String sectionName, String language) {
        String subsectionName = excelHelper.getTranslation("profile.skills_id.digital_skills.section.name", language);
        XSSFSheet sheet = excelHelper.createSheet(workbook, sectionIndex, subsectionName);

        List<XSSFRow> rows = excelHelper.createRows(sheet, sectionIndex, sectionName, subsectionName);

        int columnIndex = 0;
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.digital_skills.using_smartphone.label",
                usingSmartphone, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.digital_skills.using_laptop.label",
                usingLaptop, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.digital_skills.managing_files.label",
                managingFiles, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.digital_skills.create_text_docs.label",
                createTextDocs, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.digital_skills.create_spread_sheets.label",
                createSpreadsheets, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.digital_skills.create_presentations.label",
                createPresentations, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.digital_skills.emails.label",
                useEmails, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.digital_skills.find_info_internet.label",
                findInfoOnInternet, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.digital_skills.internet_phone.label",
                useInternetCalls, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.digital_skills.online_purchase.label",
                purchaseOnline, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.digital_skills.online_learning.label",
                learningOnline, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.digital_skills.making_graphic_designs.label",
                makingGraphicDesigns, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex, rows, language, "profile.skills_id.digital_skills.other.label",
                other, others.stream().map(elm -> (IExcelCell) elm).collect(Collectors.toList()));
    }

}
