/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 20/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.export.model.profile;

import eu.europa.empl.skpt.service.export.model.ExcelHelper;
import eu.europa.empl.skpt.service.export.model.ExcelTranslationTypesEnum;
import lombok.Getter;
import lombok.Setter;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import javax.xml.bind.annotation.XmlType;
import java.util.List;

// CLOVER:OFF

/**
 * Driving skills
 *
 * @author ARHS Spikeseed
 */
@XmlType(propOrder = {
        "carriage",
        "twoWheeled",
        "manual",
        "automatic",
        "heavyTruck",
        "bus",
        "tram",
        "train",
        "machinery",
        "vessel",
        "forkLift",
        "constructionMachinery",
        "aircraft",
        "other"
})
@Getter
@Setter
public class DrivingSkills {

    private DrivingSkill carriage;
    private DrivingSkill twoWheeled;
    private DrivingSkill manual;
    private DrivingSkill automatic;
    private DrivingSkill heavyTruck;
    private DrivingSkill bus;
    private DrivingSkill tram;
    private DrivingSkill train;
    private DrivingSkill machinery;
    private DrivingSkill vessel;
    private DrivingSkill forkLift;
    private DrivingSkill constructionMachinery;
    private DrivingSkill aircraft;
    private DrivingSkill other;

    /**
     * Adapt the class to generate an excel file.
     *
     * @param excelHelper excel helper
     * @param workbook excel workbook
     * @param sectionIndex section index
     * @param sectionName section name
     * @param language language
     */
    public void toExcel(ExcelHelper excelHelper, XSSFWorkbook workbook, int sectionIndex, String sectionName, String language) {
        String subsectionName = excelHelper.getTranslation("profile.driving.section.name", language);
        XSSFSheet sheet = excelHelper.createSheet(workbook, sectionIndex, subsectionName);

        List<XSSFRow> rows = excelHelper.createRows(sheet, sectionIndex, sectionName, subsectionName);

        int columnIndex = 0;
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.driving_skills.carriage.label",
                carriage.getSelected(), ExcelTranslationTypesEnum.YES_NO);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.driving_skills.two_wheeled.label",
                twoWheeled.getSelected(), ExcelTranslationTypesEnum.YES_NO);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.driving_skills.manual.label",
                manual.getSelected(), ExcelTranslationTypesEnum.YES_NO);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.driving_skills.automatic.label",
                automatic.getSelected(), ExcelTranslationTypesEnum.YES_NO);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.driving_skills.heavy_truck.label",
                heavyTruck.getSelected(), ExcelTranslationTypesEnum.YES_NO);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.driving_skills.bus.label",
                bus.getSelected(), ExcelTranslationTypesEnum.YES_NO);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.driving_skills.tram.label",
                tram.getSelected(), ExcelTranslationTypesEnum.YES_NO);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.driving_skills.train.label",
                train.getSelected(), ExcelTranslationTypesEnum.YES_NO);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.driving_skills.machinery.label",
                machinery.getSelected(), ExcelTranslationTypesEnum.YES_NO);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.driving_skills.vessel.label",
                vessel.getSelected(), ExcelTranslationTypesEnum.YES_NO);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.driving_skills.fork_lift.label",
                forkLift.getSelected(), ExcelTranslationTypesEnum.YES_NO);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.driving_skills.construction_machinery.label",
                constructionMachinery.getSelected(), ExcelTranslationTypesEnum.YES_NO);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.driving_skills.aircraft.label",
                aircraft.getSelected(), ExcelTranslationTypesEnum.YES_NO);
        excelHelper.createColumn(columnIndex, rows, language, "profile.skills_id.driving_skills.other.label",
                other.getName());
    }

}
