/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 2/05/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.service.export.model.profile;

// CLOVER:OFF

import eu.europa.empl.skpt.service.export.model.ExcelHelper;
import lombok.Getter;
import lombok.Setter;

import javax.xml.bind.annotation.XmlType;

/**
 * Education Type
 *
 * @author ARHS Spikeseed
 */
@XmlType(propOrder = {
        "schoolBased",
        "workBased",
        "apprenticeship",
        "internship",
})
@Getter
@Setter
public class EducationType {

    private Boolean schoolBased;
    private Boolean workBased;
    private Boolean apprenticeship;
    private Boolean internship;

    /**
     * Adapt the class to generate an excel file.
     *
     * @param excelHelper excel helper
     * @param language language
     * @return a string
     */
    public String toExcel(ExcelHelper excelHelper, String language) {
        String schoolBasedString = schoolBased != null ? excelHelper.getTranslation(
                "profile.skills_id.education_training.education_type.school_based", language) + ": "
                + excelHelper.getTranslation(schoolBased, language) + "\n" : "";
        String workBasedString = workBased != null ? excelHelper.getTranslation(
                "profile.skills_id.education_training.education_type.work_based", language) + ": "
                + excelHelper.getTranslation(workBased, language) + "\n" : "";
        String apprenticeshipString = apprenticeship != null ? excelHelper.getTranslation(
                "profile.skills_id.education_training.education_type.apprenticeship", language) + ": "
                + excelHelper.getTranslation(apprenticeship, language) + "\n" : "";
        String internshpString = internship != null ? excelHelper.getTranslation(
                "profile.skills_id.education_training.education_type.internship", language) + ": "
                + excelHelper.getTranslation(internship, language) : "";
        return schoolBasedString + workBasedString + apprenticeshipString + internshpString;
    }

}
