/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 20/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.export.model.profile;

import eu.europa.empl.skpt.service.export.model.ExcelHelper;
import eu.europa.empl.skpt.service.export.model.ExcelTranslationTypesEnum;
import eu.europa.empl.skpt.service.export.model.IExcelCell;
import lombok.Getter;
import lombok.Setter;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import javax.xml.bind.annotation.XmlType;
import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

// CLOVER:OFF

/**
 * Language
 *
 * @author ARHS Spikeseed
 */
@XmlType(propOrder = {
        "motherTongue",
        "otherMotherTongue",
        "communicateInHostCountry",
        "hostCountry",
        "preferredGeneral",
        "preferredProfessional",
        "otherLanguages"
})
@Getter
@Setter
public class LanguageSkills {

    private String motherTongue;
    private List<Name> otherMotherTongue;
    private String communicateInHostCountry;
    private LanguageSkillsDetails hostCountry;
    private LanguageSkillsDetails preferredGeneral;
    private LanguageSkillsDetails preferredProfessional;
    private List<LanguageSkillsDetails> otherLanguages;

    public List<Name> getOtherMotherTongue() {
        return otherMotherTongue == null ? Collections.emptyList() : Collections.unmodifiableList(otherMotherTongue);
    }

    public List<LanguageSkillsDetails> getOtherLanguages() {
        return otherLanguages == null ? Collections.emptyList() : Collections.unmodifiableList(otherLanguages);
    }

    /**
     * Adapt the class to generate an excel file.
     *
     * @param excelHelper excel helper
     * @param workbook excel workbook
     * @param sectionIndex section index
     * @param sectionName section name
     * @param language language
     */
    public void toExcel(ExcelHelper excelHelper, XSSFWorkbook workbook, int sectionIndex, String sectionName, String language) {
        String subsectionName = excelHelper.getTranslation("profile.skills_id.language_skills.section.name", language);
        XSSFSheet sheet = excelHelper.createSheet(workbook, sectionIndex, subsectionName);

        List<XSSFRow> rows = excelHelper.createRows(sheet, sectionIndex, sectionName, subsectionName);

        int columnIndex = 0;
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.language_skills.mother_tongue.label",
                motherTongue, otherMotherTongue.stream().map(elm -> (IExcelCell) elm).collect(Collectors.toList()),
                ExcelTranslationTypesEnum.LANGUAGE);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.language_skills.host_country.label",
                communicateInHostCountry, ExcelTranslationTypesEnum.YES_NO);
        if ("true".equals(communicateInHostCountry)) {
            excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.language_skills.level.instructions",
                    hostCountry.toExcel(excelHelper, language));
        } else if ("false".equals(communicateInHostCountry)) {
            excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.language_skills.preferred_general.label",
                    preferredGeneral.toExcel(excelHelper, language));
            excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.language_skills.preferred_professional.label",
                    preferredProfessional.toExcel(excelHelper, language));
        }
        excelHelper.createColumn(columnIndex, rows, language, "profile.skills_id.language_skills.other.instructions",
                otherLanguages.stream().map(elm -> elm.toExcel(excelHelper, language)).collect(Collectors.joining("\n")));
    }

}
