/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 20/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.export.model.profile;

import eu.europa.empl.skpt.service.export.model.ExcelHelper;
import eu.europa.empl.skpt.service.export.model.ExcelTranslationTypesEnum;
import lombok.Getter;
import lombok.Setter;

import javax.xml.bind.annotation.XmlType;

// CLOVER:OFF

/**
 * Language Skills details
 *
 * @author ARHS Spikeseed
 */
@XmlType(propOrder = {
        "code",
        "speaking",
        "listening",
        "reading",
        "writing",
        "attachment"
})
@Getter
@Setter
public class LanguageSkillsDetails {

    private String code;
    private int speaking;
    private int listening;
    private int reading;
    private int writing;
    private Attachment attachment;

    /**
     * Adapt the class to generate an excel file.
     *
     * @param excelHelper excel helper
     * @param language language
     * @return a string
     */
    public String toExcel(ExcelHelper excelHelper, String language) {
        return code == null ? "" : String.format("%s (%s: %s, %s: %s, %s: %s, %s: %s)",
                excelHelper.getTranslation(code, language, ExcelTranslationTypesEnum.LANGUAGE),
                excelHelper.getTranslation("profile.skills_id.language_skills.speaking", language),
                excelHelper.getTranslation(RatingLevel.getKeyById(speaking), language),
                excelHelper.getTranslation("profile.skills_id.language_skills.listening", language),
                excelHelper.getTranslation(RatingLevel.getKeyById(listening), language),
                excelHelper.getTranslation("profile.skills_id.language_skills.reading", language),
                excelHelper.getTranslation(RatingLevel.getKeyById(reading), language),
                excelHelper.getTranslation("profile.skills_id.language_skills.writing", language),
                excelHelper.getTranslation(RatingLevel.getKeyById(writing), language));
    }

    @Getter
    private enum RatingLevel {

        RATING_0(0,"profile.skills_id.language_skills.level.none"),
        RATING_1(1,"profile.skills_id.language_skills.level.basic"),
        RATING_2(2,"profile.skills_id.language_skills.level.sufficient"),
        RATING_3(3,"profile.skills_id.language_skills.level.good"),
        RATING_4(4,"profile.skills_id.language_skills.level.excellent");

        private int levelId;
        private String levelKey;

        RatingLevel(int levelId, String levelKey) {
            this.levelId = levelId;
            this.levelKey = levelKey;
        }

        public static String getKeyById(int levelId) {
            for(RatingLevel ratingLevel : values()) {
                if (ratingLevel.getLevelId() == levelId) {
                    return ratingLevel.getLevelKey();
                }
            }
            return String.valueOf(levelId);
        }

    }

}
