/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 20/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.export.model.profile;

import eu.europa.empl.skpt.service.export.model.ExcelHelper;
import eu.europa.empl.skpt.service.export.model.ExcelTranslationTypesEnum;
import lombok.Getter;
import lombok.Setter;
import org.apache.commons.lang3.BooleanUtils;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import javax.xml.bind.annotation.XmlType;
import java.util.List;

// CLOVER:OFF

/**
 * Literacy Skills
 *
 * @author ARHS Spikeseed
 */
@XmlType(propOrder = {
        "readRegularly",
        "readPaperMediaType",
        "otherReadPaper",
        "readLinerMediaType",
        "otherReadLinerSocial",

        "writeRegularly",
        "writeMediaType",
        "otherWriteDigital"

})
@Getter
@Setter
public class LiteracySkills {

    private Boolean readRegularly;
    private ReadPaperMediaType readPaperMediaType;
    private String otherReadPaper;
    private ReadLinerMediaType readLinerMediaType;
    private String otherReadLinerSocial;

    private Boolean writeRegularly;
    private WriteMediaType writeMediaType;
    private String otherWriteDigital;

    /**
     * Adapt the class to generate an excel file.
     *
     * @param excelHelper excel helper
     * @param workbook excel workbook
     * @param sectionIndex section index
     * @param sectionName section name
     * @param displaySection boolean used for the following condition
     *                       profile.skillsIdentification.educationTraining.attended === 'false'
     *                       || !profile.skillsIdentification.educationTraining.highestLevel
     *                       || profile.skillsIdentification.educationTraining.highestLevel == 'primary_education'
     * @param language language
     */
    public void toExcel(
            ExcelHelper excelHelper, XSSFWorkbook workbook, int sectionIndex, String sectionName, boolean displaySection, String language) {
        String subsectionName = excelHelper.getTranslation("profile.literacy.section.name", language);
        XSSFSheet sheet = excelHelper.createSheet(workbook, sectionIndex, subsectionName);

        List<XSSFRow> rows = excelHelper.createRows(sheet, sectionIndex, sectionName, subsectionName);

        int columnIndex = 0;
        if (displaySection) {
            excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.literacy_skills.read_regularly.label",
                    readRegularly, ExcelTranslationTypesEnum.YES_NO);

            columnIndex = buildReadRegularly(excelHelper, columnIndex, rows, language);

            excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.literacy_skills.write_regularly.label",
                    writeRegularly, ExcelTranslationTypesEnum.YES_NO);

            buildWriteRegularly(excelHelper, columnIndex, rows, language);
        }
    }

    private int buildReadRegularly(ExcelHelper excelHelper, int columnIndex, List<XSSFRow> rows, String language) {
        if (BooleanUtils.isTrue(readRegularly)) {
            excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.literacy_skills.read_paper_media_type.label",
                    readPaperMediaType.toExcel(excelHelper, language)
                            + (readPaperMediaType.getOther() != null && readPaperMediaType.getOther()
                            ? otherReadPaper : ""));
            excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.literacy_skills.read_liner_media_type.label",
                    readLinerMediaType.toExcel(excelHelper, language)
                            + (readLinerMediaType.getOtherSocialMedia() != null && readLinerMediaType.getOtherSocialMedia()
                            ? otherReadLinerSocial : ""));
        }
        return columnIndex;
    }

    private int buildWriteRegularly(ExcelHelper excelHelper, int columnIndex, List<XSSFRow> rows, String language) {
        if (BooleanUtils.isTrue(writeRegularly)) {
            excelHelper.createColumn(columnIndex, rows, language, "profile.skills_id.literacy_skills.write_media_type.label",
                    writeMediaType.toExcel(excelHelper, language)
                            + (writeMediaType.getOtherDigital() != null && writeMediaType.getOtherDigital()
                            ? otherWriteDigital : ""));
        }
        return columnIndex;
    }

}
