/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 20/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.export.model.profile;

import eu.europa.empl.skpt.service.export.model.ExcelHelper;
import eu.europa.empl.skpt.service.export.model.ExcelTranslationTypesEnum;
import lombok.Data;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import javax.xml.bind.annotation.XmlType;
import java.util.List;

// CLOVER:OFF

/**
 * Numeracy
 *
 * @author ARHS Spikeseed
 */
@XmlType(propOrder = {
        "measuring",
        "calculationWholeNumbers",
        "calculationFractions",
        "calculationPercentage",
        "geometry",
        "charts",
        "complex",
        "metric"
})
@Data
public class NumeracySkills {

    private NumeracySkillsDetails measuring;
    private NumeracySkillsDetails calculationWholeNumbers;
    private NumeracySkillsDetails calculationFractions;
    private NumeracySkillsDetails calculationPercentage;
    private NumeracySkillsDetails geometry;
    private Integer charts;
    private NumeracySkillsDetails complex;
    private Integer metric;

    /**
     * Adapt the class to generate an excel file.
     *
     * @param excelHelper excel helper
     * @param workbook excel workbook
     * @param sectionIndex section index
     * @param sectionName section name
     * @param language language
     */
    public void toExcel(ExcelHelper excelHelper, XSSFWorkbook workbook, int sectionIndex, String sectionName, String language) {
        String subsectionName = excelHelper.getTranslation("profile.numeracy.section.name", language);
        XSSFSheet sheet = excelHelper.createSheet(workbook, sectionIndex, subsectionName);

        List<XSSFRow> rows = excelHelper.createRows(sheet, sectionIndex, sectionName, subsectionName);

        int columnIndex = 0;
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.numeracy_skills.measuring.label",
                measuring.getRate(), ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        columnIndex = measuring.toExcel(excelHelper, columnIndex, rows, language, false, true);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.numeracy_skills.calculation.whole_numbers.label",
                calculationWholeNumbers.getRate(), ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        columnIndex = calculationWholeNumbers.toExcel(excelHelper, columnIndex, rows, language, true, true);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.numeracy_skills.calculation.factions.label",
                calculationFractions.getRate(), ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        columnIndex = calculationFractions.toExcel(excelHelper, columnIndex, rows, language, true, true);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.numeracy_skills.calculation.percentage.label",
                calculationPercentage.getRate(), ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        columnIndex = calculationPercentage.toExcel(excelHelper, columnIndex, rows, language, true, true);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.numeracy_skills.geometry.label",
                geometry.getRate(), ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        columnIndex = geometry.toExcel(excelHelper, columnIndex, rows, language, false, true);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.numeracy_skills.charts.label",
                charts, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.numeracy_skills.complex.label",
                complex.getRate(), ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        columnIndex = complex.toExcel(excelHelper, columnIndex, rows, language, true, true);
        excelHelper.createColumn(columnIndex, rows, language, "profile.skills_id.numeracy_skills.metric.label",
                metric, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
    }

}
