/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 20/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.export.model.profile;

import eu.europa.empl.skpt.service.export.model.ExcelHelper;
import lombok.Data;
import org.apache.poi.xssf.usermodel.XSSFRow;

import javax.xml.bind.annotation.XmlType;
import java.util.List;

// CLOVER:OFF

/**
 * Numeracy
 *
 * @author ARHS Spikeseed
 */
@XmlType(propOrder = {
        "rate",
        "calculator",
        "usage"
})
@Data
public class NumeracySkillsDetails {

    private Integer rate;
    private NumeracySkillsCalculator calculator;
    private NumeracySkillsUsage usage;

    /**
     * Adapt the class to generate an excel file.
     *
     * @param excelHelper excel helper
     * @param columnIndex column index
     * @param rows rows
     * @param language language
     * @param hasCalculator has calculator
     * @param hasUsage has usage
     * @return the column index
     */
    public int toExcel(
            ExcelHelper excelHelper, int columnIndex, List<XSSFRow> rows, String language, boolean hasCalculator, boolean hasUsage) {
        if (rate != null && rate > 0) {
            if (hasCalculator) {
                excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.numeracy_skills.calculator.label",
                        calculator.toExcel(excelHelper, language));
            }
            if (hasUsage) {
                excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.numeracy_skills.usage.label",
                        usage.toExcel(excelHelper, language));
            }
        }
        return columnIndex;
    }

}
