package eu.europa.empl.skpt.service.export.model.profile;

import eu.europa.empl.skpt.service.export.model.ExcelHelper;
import eu.europa.empl.skpt.service.export.model.ExcelTranslationTypesEnum;
import eu.europa.empl.skpt.service.export.model.IExcelCell;
import lombok.Getter;
import lombok.Setter;
import org.apache.poi.xssf.usermodel.XSSFRow;

import javax.xml.bind.annotation.XmlType;
import java.util.List;
import java.util.stream.Collectors;

// CLOVER:OFF

/**
 * Outcome
 *
 * @author ARHS Spikeseed
 */
@XmlType(propOrder = {
        "dateOfIssuance",
        "placeOfIssuance",
        "type",
        "otherType",
        "organisation",
        "responsibleOfficer",
        "organisationContactInfo"
})
@Getter
@Setter
public class Organisation {

    private Date dateOfIssuance;
    private String placeOfIssuance;
    private String type;
    private String otherType;
    private String organisation;
    private String responsibleOfficer;
    private OrganisationContactInfo organisationContactInfo;

    /**
     * Adapt the class to generate an excel file.
     *
     * @param excelHelper excel helper
     * @param columnIndex column index
     * @param rows rows
     * @param organisationIndex organisation index
     * @param language language
     * @return the column index
     */
    public int toExcel(ExcelHelper excelHelper, int columnIndex, List<XSSFRow> rows, int organisationIndex, String language) {
        excelHelper.createColumn(columnIndex++, rows,
                excelHelper.getTranslation("profile.outcome.organisation.sub_section_title", language) + " " + organisationIndex);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.outcome.details_issuing_organisation.data_of_issuance",
                dateOfIssuance.toExcelString(false));
        excelHelper.createColumn(columnIndex++, rows, language, "profile.outcome.details_issuing_organisation.place_of_issuance",
                placeOfIssuance);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.outcome.details_issuing_organisation.type.label",
                "other".equals(type)
                        ? excelHelper.getTranslation("profile.outcome.details_issuing_organisation.type.other", language)
                        + ": " + otherType : excelHelper.getTranslation(type, language));
        excelHelper.createColumn(columnIndex++, rows, language, "profile.outcome.organisation.label",
                organisation);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.outcome.details_issuing_organisation.responsible_officer",
                responsibleOfficer);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.general.contact.address",
                organisationContactInfo.getAddress());
        excelHelper.createColumn(columnIndex++, rows, language, "profile.general.contact.country",
                organisationContactInfo.getCountry(), ExcelTranslationTypesEnum.COUNTRY);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.general.contact.phone",
                organisationContactInfo.getPhoneNumber().toExcelString(false),
                organisationContactInfo.getPhoneNumbers().stream().map(elm -> (IExcelCell) elm).collect(Collectors.toList()));
        excelHelper.createColumn(columnIndex++, rows, language, "profile.general.contact.email",
                organisationContactInfo.getEmail().toExcelString(true));
        return columnIndex;
    }

}
