/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 20/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.export.model.profile;

import eu.europa.empl.skpt.service.export.model.ExcelHelper;
import eu.europa.empl.skpt.service.export.model.ExcelTranslationTypesEnum;
import lombok.Data;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import javax.xml.bind.annotation.XmlType;
import java.util.List;

// CLOVER:OFF

/**
 * Other Basic and Transversal Skills
 *
 * @author ARHS Spikeseed
 */
@XmlType(propOrder = {
        "workIndependently",
        "makeDecisionsIndependently",
        "workInStructuredWay",
        "solveProblems",
        "workWithOthers",
        "workWithPeople",
        "workWithCustomers",
        "workAsLeader",
        "manageProject",
        "provideService",
        "workInStressfulConditions",
        "developIdeas",
        "inspireEnthuseOthers",
        "takeResponsability"
})
@Data
public class OtherBasicTransversalSkills {

    private Integer workIndependently;
    private Integer makeDecisionsIndependently;
    private Integer workInStructuredWay;
    private Integer solveProblems;
    private Integer workWithOthers;
    private Integer workWithPeople;
    private Integer workWithCustomers;
    private Integer workAsLeader;
    private Integer manageProject;
    private Integer provideService;
    private Integer workInStressfulConditions;
    private Integer developIdeas;
    private Integer inspireEnthuseOthers;
    private Integer takeResponsability;

    /**
     * Adapt the class to generate an excel file.
     *
     * @param excelHelper excel helper
     * @param workbook excel workbook
     * @param sectionIndex section index
     * @param sectionName section name
     * @param language language
     */
    public void toExcel(ExcelHelper excelHelper, XSSFWorkbook workbook, int sectionIndex, String sectionName, String language) {
        String subsectionName = excelHelper.getTranslation("profile.skills_id.other_basic_transversal_skills.section.name", language);
        XSSFSheet sheet = excelHelper.createSheet(workbook, sectionIndex, subsectionName);

        List<XSSFRow> rows = excelHelper.createRows(sheet, sectionIndex, sectionName, subsectionName);

        int columnIndex = 0;
        excelHelper.createColumn(columnIndex++, rows, language,
                "profile.skills_id.other_basic_transversal_skills.work_independently.label",
                workIndependently, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex++, rows, language,
                "profile.skills_id.other_basic_transversal_skills.make_decisions_independently.label",
                makeDecisionsIndependently, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex++, rows, language,
                "profile.skills_id.other_basic_transversal_skills.work_in_structured_way.label",
                workInStructuredWay, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex++, rows, language,
                "profile.skills_id.other_basic_transversal_skills.solve_problems.label",
                solveProblems, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex++, rows, language,
                "profile.skills_id.other_basic_transversal_skills.work_with_others.label",
                workWithOthers, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex++, rows, language,
                "profile.skills_id.other_basic_transversal_skills.work_with_people.label",
                workWithPeople, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex++, rows, language,
                "profile.skills_id.other_basic_transversal_skills.work_with_customers.label",
                workWithCustomers, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex++, rows, language,
                "profile.skills_id.other_basic_transversal_skills.work_as_leader.label",
                workAsLeader, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex++, rows, language,
                "profile.skills_id.other_basic_transversal_skills.manage_project.label",
                manageProject, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex++, rows, language,
                "profile.skills_id.other_basic_transversal_skills.work_in_stressful_conditions.label",
                workInStressfulConditions, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex++, rows, language,
                "profile.skills_id.other_basic_transversal_skills.develop_ideas.label",
                developIdeas, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex++, rows, language,
                "profile.skills_id.other_basic_transversal_skills.inspire_enthuse_others.label",
                inspireEnthuseOthers, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        excelHelper.createColumn(columnIndex, rows, language,
                "profile.skills_id.other_basic_transversal_skills.take_responsability.label",
                takeResponsability, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
    }

}
