/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 20/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.export.model.profile;

import eu.europa.empl.skpt.service.export.model.ExcelHelper;
import lombok.Getter;
import lombok.Setter;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import javax.xml.bind.annotation.XmlType;
import java.util.Collections;
import java.util.List;

// CLOVER:OFF

/**
 * Outcome
 *
 * @author ARHS Spikeseed
 */
@XmlType(propOrder = {
        "keySkills",
        "recognitionRecommendation",
        "recognitionReferral",
        "validationRecommendation",
        "validationReferral",
        "educationOrTrainingAdvice",
        "educationOrTrainingReferral",
        "employmentBusiness",
        "guidanceOtherOrganisations",
        "furtherInformationOtherOrganisations",
        "furtherInformationOnlineSupport",
        "organisations",
        "statistics",
        "stored",
        "courses",
        "recommendations"
})
@Getter
@Setter
public class Outcome {

    private String keySkills;
    private String recognitionRecommendation;
    private String recognitionReferral;
    private String validationRecommendation;
    private String validationReferral;
    private String educationOrTrainingAdvice;
    private String educationOrTrainingReferral;
    private String employmentBusiness;
    private String guidanceOtherOrganisations;
    private String furtherInformationOtherOrganisations;
    private String furtherInformationOnlineSupport;
    private List<Organisation> organisations;
    private Boolean statistics;
    private Boolean stored;
    private Courses courses;
    private Recommendations recommendations;

    public List<Organisation> getOrganisations() {
        return organisations == null ? Collections.emptyList() : Collections.unmodifiableList(organisations);
    }

    /**
     * Adapt the class to generate an excel file.
     *
     * @param excelHelper excel helper
     * @param workbook excel workbook
     * @param sectionIndex section index
     * @param language language
     */
    public void toExcel(ExcelHelper excelHelper, XSSFWorkbook workbook, int sectionIndex, String language) {
        String sectionName = excelHelper.getTranslation("step.outcome", language);
        strengthsToExcel(excelHelper, workbook, sectionIndex, sectionName, language);
        recognitionToExcel(excelHelper, workbook, sectionIndex, sectionName, language);
        validationToExcel(excelHelper, workbook, sectionIndex, sectionName, language);
        trainingToExcel(excelHelper, workbook, sectionIndex, sectionName, language);
        workToExcel(excelHelper, workbook, sectionIndex, sectionName, language);
        guidanceToExcel(excelHelper, workbook, sectionIndex, sectionName, language);
        organisationToExcel(excelHelper, workbook, sectionIndex, sectionName, language);
    }

    private void strengthsToExcel(ExcelHelper excelHelper, XSSFWorkbook workbook, int sectionIndex, String sectionName, String language) {
        String subsectionName = excelHelper.getTranslation("profile.outcome.key_skills.title", language);
        XSSFSheet sheet = excelHelper.createSheet(workbook, sectionIndex, subsectionName);

        List<XSSFRow> rows = excelHelper.createRows(sheet, sectionIndex, sectionName, subsectionName);

        int columnIndex = 0;
        excelHelper.createColumn(columnIndex, rows, language, "profile.outcome.key_skills.label",
                keySkills);
    }

    private void recognitionToExcel(ExcelHelper excelHelper, XSSFWorkbook workbook, int sectionIndex, String sectionName, String language) {
        String subsectionName = excelHelper.getTranslation("profile.outcome.recognition.section.name", language);
        XSSFSheet sheet = excelHelper.createSheet(workbook, sectionIndex, subsectionName);

        List<XSSFRow> rows = excelHelper.createRows(sheet, sectionIndex, sectionName, subsectionName);

        int columnIndex = 0;
        excelHelper.createColumn(columnIndex++, rows, language, "profile.outcome.recognition.label_1.label",
                recognitionRecommendation);
        excelHelper.createColumn(columnIndex, rows, language, "profile.outcome.recognition.label_2.label",
                recognitionReferral);
    }

    private void validationToExcel(ExcelHelper excelHelper, XSSFWorkbook workbook, int sectionIndex, String sectionName, String language) {
        String subsectionName = excelHelper.getTranslation("profile.outcome.validation.section.name", language);
        XSSFSheet sheet = excelHelper.createSheet(workbook, sectionIndex, subsectionName);

        List<XSSFRow> rows = excelHelper.createRows(sheet, sectionIndex, sectionName, subsectionName);

        int columnIndex = 0;
        excelHelper.createColumn(columnIndex++, rows, language, "profile.outcome.validation.label_1.label",
                validationRecommendation);
        excelHelper.createColumn(columnIndex, rows, language, "profile.outcome.validation.label_2.label",
                validationReferral);
    }

    private void trainingToExcel(ExcelHelper excelHelper, XSSFWorkbook workbook, int sectionIndex, String sectionName, String language) {
        String subsectionName = excelHelper.getTranslation("profile.outcome.education-or-training.section.name", language);
        XSSFSheet sheet = excelHelper.createSheet(workbook, sectionIndex, subsectionName);

        List<XSSFRow> rows = excelHelper.createRows(sheet, sectionIndex, sectionName, subsectionName);

        int columnIndex = 0;
        excelHelper.createColumn(columnIndex++, rows, language, "profile.outcome.education_or_training.label_1.label",
                educationOrTrainingAdvice);
        excelHelper.createColumn(columnIndex, rows, language, "profile.outcome.education_or_training.label_2.label",
                educationOrTrainingReferral);
    }

    private void workToExcel(ExcelHelper excelHelper, XSSFWorkbook workbook, int sectionIndex, String sectionName, String language) {
        String subsectionName = excelHelper.getTranslation("profile.outcome.employment-business.section.name", language);
        XSSFSheet sheet = excelHelper.createSheet(workbook, sectionIndex, subsectionName);

        List<XSSFRow> rows = excelHelper.createRows(sheet, sectionIndex, sectionName, subsectionName);

        int columnIndex = 0;
        excelHelper.createColumn(columnIndex, rows, language, "profile.outcome.employment_business.label",
                employmentBusiness);
    }

    private void guidanceToExcel(ExcelHelper excelHelper, XSSFWorkbook workbook, int sectionIndex, String sectionName, String language) {
        String subsectionName = excelHelper.getTranslation("profile.outcome.further-information.section.name", language);
        XSSFSheet sheet = excelHelper.createSheet(workbook, sectionIndex, subsectionName);

        List<XSSFRow> rows = excelHelper.createRows(sheet, sectionIndex, sectionName, subsectionName);

        int columnIndex = 0;
        excelHelper.createColumn(columnIndex, rows, language, "profile.outcome.guidance.other_organisation.label",
                guidanceOtherOrganisations);
    }

    private void organisationToExcel(
            ExcelHelper excelHelper, XSSFWorkbook workbook, int sectionIndex, String sectionName, String language) {
        String subsectionName = excelHelper.getTranslation("profile.outcome.details_issuing_organisation.title", language);
        XSSFSheet sheet = excelHelper.createSheet(workbook, sectionIndex, subsectionName);

        List<XSSFRow> rows = excelHelper.createRows(sheet, sectionIndex, sectionName, subsectionName);

        int columnIndex = 0;
        for (int i = 0; i < organisations.size(); i++) {
            columnIndex = organisations.get(i).toExcel(excelHelper, columnIndex, rows, i + 1, language);
        }
    }

}
