/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 20/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.export.model.profile;

import eu.europa.empl.skpt.service.export.model.ExcelHelper;
import lombok.Data;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import javax.xml.bind.annotation.XmlType;
import java.util.List;

// CLOVER:OFF

/**
 * Outside Skills
 *
 * @author ARHS Spikeseed
 */
@XmlType(propOrder = {
        "caringChildren",
        "caringElderlyPeople",
        "caringSickPeople",
        "makingClothing",
        "preparingMeals",
        "cultivatingCrops",
        "livestock",
        "makingPottery",
        "sellingTradingProducts",
        "makingFurniture",
        "houseConstruction",
        "coachingTeaching"
})
@Data
public class OutsideSkills {

    private OutsideSkillsCaring caringChildren;
    private OutsideSkillsCaring caringElderlyPeople;
    private OutsideSkillsCaring caringSickPeople;
    private OutsideSkillsMakingClothing makingClothing;
    private OutsideSkillsPreparingMeals preparingMeals;
    private OutsideSkillsOther cultivatingCrops;
    private OutsideSkillsCaring livestock;
    private OutsideSkillsOther makingPottery;
    private OutsideSkillsOther sellingTradingProducts;
    private OutsideSkillsOther makingFurniture;
    private OutsideSkillsOther houseConstruction;
    private OutsideSkillsOther coachingTeaching;

    /**
     * Adapt the class to generate an excel file.
     *
     * @param excelHelper excel helper
     * @param workbook excel workbook
     * @param sectionIndex section index
     * @param sectionName section name
     * @param language language
     */
    public void toExcel(ExcelHelper excelHelper, XSSFWorkbook workbook, int sectionIndex, String sectionName, String language) {
        String subsectionName = excelHelper.getTranslation("profile.skills_id.outside_skills.section.name", language);
        XSSFSheet sheet = excelHelper.createSheet(workbook, sectionIndex, subsectionName);

        List<XSSFRow> rows = excelHelper.createRows(sheet, sectionIndex, sectionName, subsectionName);

        int columnIndex = 0;
        columnIndex = caringChildren.toExcel(excelHelper, columnIndex, rows,
                "profile.skills_id.outside_skills.caring_children.label", language);
        columnIndex = caringElderlyPeople.toExcel(excelHelper, columnIndex, rows,
                "profile.skills_id.outside_skills.caring_elderly_people.label", language);
        columnIndex = caringSickPeople.toExcel(excelHelper, columnIndex, rows,
                "profile.skills_id.outside_skills.caring_sick_people.label", language);
        columnIndex = makingClothing.toExcel(excelHelper, columnIndex, rows,
                "profile.skills_id.outside_skills.making_clothing.label", language);
        columnIndex = preparingMeals.toExcel(excelHelper, columnIndex, rows,
                "profile.skills_id.outside_skills.preparing_meals.label", language);
        columnIndex = cultivatingCrops.toExcel(excelHelper, columnIndex, rows,
                "profile.skills_id.outside_skills.cultivating_crops.label", language);
        columnIndex = livestock.toExcel(excelHelper, columnIndex, rows,
                "profile.skills_id.outside_skills.livestock.label", language);
        columnIndex = makingPottery.toExcel(excelHelper, columnIndex, rows,
                "profile.skills_id.outside_skills.making_pottery.label", language);
        columnIndex = sellingTradingProducts.toExcel(excelHelper, columnIndex, rows,
                "profile.skills_id.outside_skills.selling_trading_products.label", language);
        columnIndex = makingFurniture.toExcel(excelHelper, columnIndex, rows,
                "profile.skills_id.outside_skills.making_furniture.label", language);
        columnIndex = houseConstruction.toExcel(excelHelper, columnIndex, rows,
                "profile.skills_id.outside_skills.house_construction.label", language);
        coachingTeaching.toExcel(excelHelper, columnIndex, rows,
                "profile.skills_id.outside_skills.coaching_teaching.label", language);
    }

}
