/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 20/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.export.model.profile;

import eu.europa.empl.skpt.service.export.model.ExcelHelper;
import eu.europa.empl.skpt.service.export.model.ExcelTranslationTypesEnum;
import lombok.Data;
import org.apache.poi.xssf.usermodel.XSSFRow;

import javax.xml.bind.annotation.XmlType;
import java.util.List;

// CLOVER:OFF

/**
 * Outside Skills
 *
 * @author ARHS Spikeseed
 */
@XmlType(propOrder = {
        "rate",
        "total",
        "durationMonth",
        "durationYear",
        "frequency"
})
@Data
public class OutsideSkillsCaring {

    private Integer rate;
    private int total;
    private int durationMonth;
    private int durationYear;
    private String frequency;

    /**
     * Adapt the class to generate an excel file.
     *
     * @param excelHelper excel helper
     * @param columnIndex column index
     * @param rows rows
     * @param headerKey key value of the header of the first column
     * @param language language
     * @return the column index
     */
    public int toExcel(ExcelHelper excelHelper, int columnIndex, List<XSSFRow> rows, String headerKey, String language) {
        excelHelper.createColumn(columnIndex++, rows, language, headerKey, rate, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        if (rate != null && rate > 0) {
            excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.outside_skills.how_many.label",
                    total);
            excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.outside_skills.how_often.label",
                    "profile.skills_id.outside_skills.making_clothing.frequency." + frequency);
            String monthsTranslation = excelHelper.getTranslation(
                    "profile.skills_id.professional_skills.professional_experience.duration.month", language);
            String yearsTranslation = excelHelper.getTranslation(
                    "profile.skills_id.professional_skills.professional_experience.duration.year", language);
            String duration = durationMonth + " " + monthsTranslation + " " + durationYear + " " + yearsTranslation;
            excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.outside_skills.how_long.label",
                    duration);
        }
        return columnIndex;
    }

}
