/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 20/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.export.model.profile;

import eu.europa.empl.skpt.service.export.model.ExcelHelper;
import eu.europa.empl.skpt.service.export.model.ExcelTranslationTypesEnum;
import lombok.Data;
import lombok.Getter;
import org.apache.poi.xssf.usermodel.XSSFRow;

import javax.xml.bind.annotation.XmlType;
import java.util.List;

// CLOVER:OFF

/**
 * Outside Skills
 *
 * @author ARHS Spikeseed
 */
@XmlType(propOrder = {
        "rate",
        "people",
        "durationMonth",
        "durationYear",
        "frequency"
})
@Data
public class OutsideSkillsPreparingMeals {

    private Integer rate;
    private String people;
    private int durationMonth;
    private int durationYear;
    private String frequency;

    /**
     * Adapt the class to generate an excel file.
     *
     * @param excelHelper excel helper
     * @param columnIndex column index
     * @param rows rows
     * @param header value of the header of the first column
     * @param language language
     * @return the column index
     */
    public int toExcel(ExcelHelper excelHelper, int columnIndex, List<XSSFRow> rows, String header, String language) {
        excelHelper.createColumn(columnIndex++, rows, language, header, rate, ExcelTranslationTypesEnum.LEVEL_DIGITAL);
        if (rate != null && rate > 0) {
            excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.outside_skills.preparing_meals.people.label",
                    PeopleNumber.getKeyById(people));
            excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.outside_skills.how_often.label",
                    "profile.skills_id.outside_skills.preparing_meals.frequency." + frequency);
            String monthsTranslation = excelHelper.getTranslation(
                    "profile.skills_id.professional_skills.professional_experience.duration.month", language);
            String yearsTranslation = excelHelper.getTranslation(
                    "profile.skills_id.professional_skills.professional_experience.duration.year", language);
            String duration = durationMonth + " " + monthsTranslation + " " + durationYear + " " + yearsTranslation;
            excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.outside_skills.how_long.label",
                    duration);
        }
        return columnIndex;
    }

    @Getter
    private enum PeopleNumber {

        FIVE("five","profile.skills_id.outside_skills.preparing_meals.people.five"),
        TEN("ten","profile.skills_id.outside_skills.preparing_meals.people.ten"),
        TWENTY("twenty","profile.skills_id.outside_skills.preparing_meals.people.twenty"),
        MORE("more","profile.skills_id.outside_skills.preparing_meals.people.more");

        private String numberId;
        private String numberKey;

        PeopleNumber(String numberId, String numberKey) {
            this.numberId = numberId;
            this.numberKey = numberKey;
        }

        public static String getKeyById(String numberId) {
            for(OutsideSkillsPreparingMeals.PeopleNumber peopleNumber : values()) {
                if (peopleNumber.getNumberId().equals(numberId)) {
                    return peopleNumber.getNumberKey();
                }
            }
            return numberId;
        }

    }

}
