/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 17/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.export.model.profile;

import eu.europa.empl.skpt.service.export.model.ExcelHelper;
import eu.europa.empl.skpt.service.export.model.ExcelTranslationTypesEnum;
import lombok.Getter;
import lombok.Setter;
import org.apache.poi.xssf.usermodel.XSSFRow;

import javax.xml.bind.annotation.XmlType;
import java.util.List;

// CLOVER:OFF

/**
 * Personal Info
 *
 * @author ARHS Spikeseed
 */
@XmlType(propOrder = {
        "name",
        "type",
        "number",
        "country",
        "expirationDate",
        "attachment",
})
@Getter
@Setter
public class PersonalIdentificationDocument {

    private String name;
    private String type;
    private String number;
    private String country;
    private Date expirationDate;
    private Attachment attachment;

    /**
     * Adapt the class to generate an excel file.
     *
     * @param excelHelper excel helper
     * @param columnIndex column index
     * @param rows rows
     * @param identificationDocumentIndex identification document index
     * @param language language
     * @return the column index
     */
    public int toExcel(ExcelHelper excelHelper, int columnIndex, List<XSSFRow> rows, int identificationDocumentIndex, String language) {
        excelHelper.createColumn(columnIndex++, rows,
                excelHelper.getTranslation("profile.personal.general.identification.document.sub_section_title", language)
                        + " " + identificationDocumentIndex);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.personal.general.identification.document.choose",
                "profile.personal.general.identification.document." + name);

        if ("other".equals(type)) {
            excelHelper.createColumn(columnIndex++, rows, language, "profile.personal.general.identification.document.type",
                    type);
        }

        excelHelper.createColumn(columnIndex++, rows, language, "profile.personal.general.identification.document.number",
                number);
        excelHelper.createColumn(columnIndex++, rows, language, "profile.personal.general.identification.document.country",
                country, ExcelTranslationTypesEnum.COUNTRY);

        return columnIndex;
    }

}