/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 17/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.export.model.profile;

import eu.europa.empl.skpt.service.export.model.ExcelHelper;
import eu.europa.empl.skpt.service.export.model.ExcelTranslationTypesEnum;
import eu.europa.empl.skpt.service.export.model.IExcelCell;
import lombok.Getter;
import lombok.Setter;
import org.apache.poi.xssf.usermodel.XSSFRow;

import javax.xml.bind.annotation.XmlType;
import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

// CLOVER:OFF

/**
 * Professional experience
 *
 * @author ARHS Spikeseed
 */
@XmlType(propOrder = {
        "nature",
        "durationWeek",
        "durationMonth",
        "durationYear",
        "country",
        "language",
        "otherLanguages",
        "occupation",
        "skill",
        "otherSkills",
        "organisationSize",
        "workplaceSize",
        "proof",
        "attachment"
})
@Getter
@Setter
public class ProfessionalExperience {

    private String nature;
    private int durationWeek;
    private int durationMonth;
    private int durationYear;
    private String country;
    private String language;
    private List<Name> otherLanguages;
    private String occupation;
    private String skill;
    private List<Name> otherSkills;
    private String organisationSize;
    private String workplaceSize;
    private Boolean proof;
    private Attachment attachment;

    public List<Name> getOtherLanguages() {
        return otherLanguages == null ? Collections.emptyList() : Collections.unmodifiableList(otherLanguages);
    }

    public List<Name> getOtherSkills() {
        return otherSkills == null ? Collections.emptyList() : Collections.unmodifiableList(otherSkills);
    }

    /**
     * Adapt the class to generate an excel file.
     *
     * @param excelHelper excel helper
     * @param columnIndex column index
     * @param rows rows
     * @param professionalExperienceIndex professional experience index
     * @param language language
     * @return the column index
     */
    public int toExcel(ExcelHelper excelHelper, int columnIndex, List<XSSFRow> rows, int professionalExperienceIndex, String language) {
        excelHelper.createColumn(columnIndex++, rows,
                excelHelper.getTranslation(
                        "profile.skills_id.professional_skills.professional_experience.history.section.name", language)
                        + " " + professionalExperienceIndex);
        excelHelper.createColumn(columnIndex++, rows, language,
                "profile.skills_id.professional_skills.professional_experience.history.nature.label",
                nature != null && !nature.isEmpty() ? "profile.skills_id.professional_skills.professional_experience.history.nature."
                        + nature : "");
        String weeksTranslation = excelHelper.getTranslation(
                "profile.skills_id.professional_skills.professional_experience.duration.week", language);
        String monthsTranslation = excelHelper.getTranslation(
                "profile.skills_id.professional_skills.professional_experience.duration.month", language);
        String yearsTranslation = excelHelper.getTranslation(
                "profile.skills_id.professional_skills.professional_experience.duration.year", language);
        String experienceDuration = durationWeek + " " + weeksTranslation + " " + durationMonth + " " + monthsTranslation + " "
                + durationYear + " " + yearsTranslation;
        excelHelper.createColumn(columnIndex++, rows, language,
                "profile.skills_id.professional_skills.professional_experience.history.duration.label",
                experienceDuration);
        excelHelper.createColumn(columnIndex++, rows, language,
                "profile.skills_id.professional_skills.professional_experience.history.country.label",
                country, ExcelTranslationTypesEnum.COUNTRY);
        excelHelper.createColumn(columnIndex++, rows, language,
                "profile.skills_id.professional_skills.professional_experience.history.language.label",
                this.language, otherLanguages.stream().map(elm -> (IExcelCell) elm).collect(Collectors.toList()),
                ExcelTranslationTypesEnum.LANGUAGE);
        excelHelper.createColumn(columnIndex++, rows, language,
                "profile.skills_id.professional_skills.professional_experience.history.occupation.label",
                occupation, ExcelTranslationTypesEnum.ESCO_OCCUPATION);
        excelHelper.createColumn(columnIndex++, rows, language,
                "profile.skills_id.professional_skills.professional_experience.history.skill.label",
                skill, otherSkills.stream().map(elm -> (IExcelCell) elm).collect(Collectors.toList()),
                ExcelTranslationTypesEnum.ESCO_SKILL);
        excelHelper.createColumn(columnIndex++, rows, language,
                "profile.skills_id.professional_skills.professional_experience.history.organisation.size.label",
                organisationSize != null && !organisationSize.isEmpty()
                        ? "profile.skills_id.professional_skills.professional_experience.history.size." + organisationSize : "");
        excelHelper.createColumn(columnIndex++, rows, language,
                "profile.skills_id.professional_skills.professional_experience.history.workplace.size.label",
                workplaceSize != null && !workplaceSize.isEmpty()
                        ? "profile.skills_id.professional_skills.professional_experience.history.size." + workplaceSize : "");
        excelHelper.createColumn(columnIndex++, rows, language,
                "profile.skills_id.professional_skills.professional_experience.history.proof.label",
                proof, ExcelTranslationTypesEnum.YES_NO);

        return columnIndex;
    }

}