/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 20/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.export.model.profile;

import eu.europa.empl.skpt.service.export.model.ExcelHelper;
import eu.europa.empl.skpt.service.export.model.ExcelTranslationTypesEnum;
import lombok.Getter;
import lombok.Setter;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import javax.xml.bind.annotation.XmlType;
import java.util.Collections;
import java.util.List;

// CLOVER:OFF

/**
 * Literacy Skills
 *
 * @author ARHS Spikeseed
 */
@XmlType(propOrder = {
        "experience",
        "durationWeek",
        "durationMonth",
        "durationYear",
        "last",
        "experiences"
})
@Getter
@Setter
public class ProfessionalSkills {

    private Boolean experience;
    private int durationWeek;
    private int durationMonth;
    private int durationYear;
    private String last;
    private List<ProfessionalExperience> experiences;

    public List<ProfessionalExperience> getExperiences() {
        return experiences == null ? Collections.emptyList() : Collections.unmodifiableList(experiences);
    }

    /**
     * Adapt the class to generate an excel file.
     *
     * @param excelHelper excel helper
     * @param workbook excel workbook
     * @param sectionIndex section index
     * @param sectionName section name
     * @param language language
     */
    public void toExcel(ExcelHelper excelHelper, XSSFWorkbook workbook, int sectionIndex, String sectionName, String language) {
        String subsectionName = excelHelper.getTranslation("profile.skills_id.professional_skills.section.name", language);
        XSSFSheet sheet = excelHelper.createSheet(workbook, sectionIndex, subsectionName);

        List<XSSFRow> rows = excelHelper.createRows(sheet, sectionIndex, sectionName, subsectionName);

        int columnIndex = 0;
        excelHelper.createColumn(columnIndex++, rows, language, "profile.skills_id.professional_skills.professional_experience.label",
                experience, ExcelTranslationTypesEnum.YES_NO);

        if (experience != null && experience) {
            String weeksTranslation = excelHelper.getTranslation(
                    "profile.skills_id.professional_skills.professional_experience.duration.week", language);
            String monthsTranslation = excelHelper.getTranslation(
                    "profile.skills_id.professional_skills.professional_experience.duration.month", language);
            String yearsTranslation = excelHelper.getTranslation(
                    "profile.skills_id.professional_skills.professional_experience.duration.year", language);
            String duration = durationWeek + " " + weeksTranslation + " " + durationMonth + " " + monthsTranslation + " "
                    + durationYear + " " + yearsTranslation;
            excelHelper.createColumn(columnIndex++, rows, language,
                    "profile.skills_id.professional_skills.professional_experience.duration.label",
                    duration);
            excelHelper.createColumn(columnIndex++, rows, language,
                    "profile.skills_id.professional_skills.professional_experience_last.label",
                    last);

            if (experiences != null) {
                for (int i = 0; i < experiences.size(); i++) {
                    columnIndex = experiences.get(i).toExcel(excelHelper, columnIndex, rows, i + 1, language);
                }
            }
        }
    }

}
