/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 20/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.export.model.profile;

import eu.europa.empl.skpt.service.export.model.ExcelHelper;
import lombok.Getter;
import lombok.Setter;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import java.util.Collections;
import java.util.List;

// CLOVER:OFF

/**
 * Profile.
 *
 * @author ARHS Spikeseed
 */
@XmlRootElement(name = "profile")
@XmlType(propOrder = {
        "personalInfo",
        "expectations",
        "skillsIdentification",
        "outcome"
})
@Getter
@Setter
public class Profile {

    private PersonalInfo personalInfo;
    private List<Expectation> expectations;
    private SkillsIdentification skillsIdentification;
    private Outcome outcome;

    public List<Expectation> getExpectations() {
        return expectations == null ? Collections.emptyList() : Collections.unmodifiableList(expectations);
    }

    /**
     * Adapt the class to generate an excel file.
     *
     * @param excelHelper excel helper
     * @param workbook excel workbook
     * @param language language
     * @return a workbook
     */
    public XSSFWorkbook toExcel(ExcelHelper excelHelper, XSSFWorkbook workbook, String language) {
        int sectionIndex = 1;
        personalInfo.toExcel(excelHelper, workbook, sectionIndex++, language);
        expectationsToExcel(excelHelper, workbook, sectionIndex++, language);
        skillsIdentification.toExcel(excelHelper, workbook, sectionIndex++, language);
        outcome.toExcel(excelHelper, workbook, sectionIndex, language);
        return workbook;
    }

    private void expectationsToExcel(ExcelHelper excelHelper, XSSFWorkbook workbook, int sectionIndex, String language) {
        String sectionName = excelHelper.getTranslation("step.expectations", language);
        XSSFSheet sheet = excelHelper.createSheet(workbook, sectionIndex, sectionName);

        List<XSSFRow> rows = excelHelper.createRows(sheet, sectionIndex, sectionName);

        int columnIndex = 0;
        for (int i = 0; i < expectations.size(); i++) {
            columnIndex = expectations.get(i).toExcel(excelHelper, columnIndex, rows, (i + 1), language);
        }
    }

}
