/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 24/04/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.service.export.model.profile;

import eu.europa.empl.skpt.service.export.model.ExcelHelper;
import lombok.Getter;
import lombok.Setter;

import javax.xml.bind.annotation.XmlType;

// CLOVER:OFF

/**
 * Read liner media type
 *
 * @author ARHS Spikeseed
 */
@XmlType(propOrder = {
        "facebook",
        "linkedin",
        "whatsapp",
        "twitter",
        "otherSocialMedia",
        "newspapers"
})
@Getter
@Setter
public class ReadLinerMediaType {

    private Boolean facebook;
    private Boolean linkedin;
    private Boolean whatsapp;
    private Boolean twitter;
    private Boolean otherSocialMedia;
    private Boolean newspapers;

    /**
     * Adapt the class to generate an excel file.
     *
     * @param excelHelper excel helper
     * @param language language
     * @return a string
     */
    public String toExcel(ExcelHelper excelHelper, String language) {
        StringBuilder stringBuilder = new StringBuilder();
        if (facebook != null && facebook) {
            stringBuilder.append(
                    excelHelper.getTranslation("profile.skills_id.literacy_skills.social.facebook", language)).append("\n");
        }
        if (linkedin != null && linkedin) {
            stringBuilder.append(
                    excelHelper.getTranslation("profile.skills_id.literacy_skills.social.linkedin", language)).append("\n");
        }
        if (whatsapp != null && whatsapp) {
            stringBuilder.append(
                    excelHelper.getTranslation("profile.skills_id.literacy_skills.social.whatsapp", language)).append("\n");
        }
        if (twitter != null && twitter) {
            stringBuilder.append(
                    excelHelper.getTranslation("profile.skills_id.literacy_skills.social.twitter", language)).append("\n");
        }
        if (newspapers != null && newspapers) {
            stringBuilder.append(
                    excelHelper.getTranslation("profile.skills_id.literacy_skills.digital.newspapers", language)).append("\n");
        }
        return stringBuilder.toString();
    }

}
