/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 24/04/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.service.export.model.profile;

import eu.europa.empl.skpt.service.export.model.ExcelHelper;
import lombok.Getter;
import lombok.Setter;

import javax.xml.bind.annotation.XmlType;

// CLOVER:OFF

/**
 * Read paper media type
 *
 * @author ARHS Spikeseed
 */
@XmlType(propOrder = {
        "letters",
        "magazines",
        "newspapers",
        "booksLeisure",
        "booksStudy",
        "other"
})
@Getter
@Setter
public class ReadPaperMediaType {

    private Boolean letters;
    private Boolean magazines;
    private Boolean newspapers;
    private Boolean booksLeisure;
    private Boolean booksStudy;
    private Boolean other;

    /**
     * Adapt the class to generate an excel file.
     *
     * @param excelHelper excel helper
     * @param language language
     * @return a string
     */
    public String toExcel(ExcelHelper excelHelper, String language) {
        StringBuilder stringBuilder = new StringBuilder();
        if (letters != null && letters) {
            stringBuilder.append(
                    excelHelper.getTranslation("profile.skills_id.literacy_skills.paper.letters", language)).append("\n");
        }
        if (magazines != null && magazines) {
            stringBuilder.append(
                    excelHelper.getTranslation("profile.skills_id.literacy_skills.paper.magazines", language)).append("\n");
        }
        if (newspapers != null && newspapers) {
            stringBuilder.append(
                    excelHelper.getTranslation("profile.skills_id.literacy_skills.paper.newspapers", language)).append("\n");
        }
        if (booksLeisure != null && booksLeisure) {
            stringBuilder.append(
                    excelHelper.getTranslation("profile.skills_id.literacy_skills.paper.books.leisure", language)).append("\n");
        }
        if (booksStudy != null && booksStudy) {
            stringBuilder.append(
                    excelHelper.getTranslation("profile.skills_id.literacy_skills.paper.books.study", language)).append("\n");
        }
        return stringBuilder.toString();
    }

}
