/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 20/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.export.model.profile;

import eu.europa.empl.skpt.service.export.model.ExcelHelper;
import lombok.Getter;
import lombok.Setter;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import javax.xml.bind.annotation.XmlType;
import java.util.ArrayList;
import java.util.List;

// CLOVER:OFF

/**
 * Skills identification
 *
 * @author ARHS Spikeseed
 */
@XmlType(propOrder = {
        "languageSkills",
        "educationTraining",
        "literacySkills",
        "numeracySkills",
        "otherBasicTransversalSkills",
        "digitalSkills",
        "professionalSkills",
        "outsideSkills",
        "drivingSkills",
        "otherSkills"
})
@Getter
@Setter
public class SkillsIdentification {

    private LanguageSkills languageSkills;
    private EducationTraining educationTraining;
    private LiteracySkills literacySkills;
    private NumeracySkills numeracySkills;
    private OtherBasicTransversalSkills otherBasicTransversalSkills;
    private DigitalSkills digitalSkills;
    private ProfessionalSkills professionalSkills;
    private OutsideSkills outsideSkills;
    private DrivingSkills drivingSkills;
    private List<OtherSkills> otherSkills;

    public void setOtherSkills(List<OtherSkills> otherSkills) {
        this.otherSkills = otherSkills == null ? new ArrayList<>() : new ArrayList<>(otherSkills);
    }

    /**
     * Adapt the class to generate an excel file.
     *
     * @param excelHelper excel helper
     * @param workbook excel workbook
     * @param sectionIndex section index
     * @param language language
     */
    public void toExcel(ExcelHelper excelHelper, XSSFWorkbook workbook, int sectionIndex, String language) {
        String sectionName = excelHelper.getTranslation("step.skills", language);
        languageSkills.toExcel(excelHelper, workbook, sectionIndex, sectionName, language);
        boolean displayLiteracySkills = educationTraining.toExcel(excelHelper, workbook, sectionIndex, sectionName, language);
        literacySkills.toExcel(excelHelper, workbook, sectionIndex, sectionName, displayLiteracySkills, language);
        numeracySkills.toExcel(excelHelper, workbook, sectionIndex, sectionName, language);
        digitalSkills.toExcel(excelHelper, workbook, sectionIndex, sectionName, language);
        professionalSkills.toExcel(excelHelper, workbook, sectionIndex, sectionName, language);
        outsideSkills.toExcel(excelHelper, workbook, sectionIndex, sectionName, language);
        otherBasicTransversalSkills.toExcel(excelHelper, workbook, sectionIndex, sectionName, language);
        drivingSkills.toExcel(excelHelper, workbook, sectionIndex, sectionName, language);
    }

}
