/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 24/04/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.service.export.model.profile;

import eu.europa.empl.skpt.service.export.model.ExcelHelper;
import lombok.Getter;
import lombok.Setter;

import javax.xml.bind.annotation.XmlType;

// CLOVER:OFF

/**
 * Read paper media type
 *
 * @author ARHS Spikeseed
 */
@XmlType(propOrder = {
        "socialMedia",
        "mails",
        "reports",
        "memos",
        "forms",
        "otherDigital"
})
@Getter
@Setter
public class WriteMediaType {

    private Boolean socialMedia;
    private Boolean mails;
    private Boolean reports;
    private Boolean memos;
    private Boolean forms;
    private Boolean otherDigital;

    /**
     * Adapt the class to generate an excel file.
     *
     * @param excelHelper excel helper
     * @param language language
     * @return a string
     */
    public String toExcel(ExcelHelper excelHelper, String language) {
        StringBuilder stringBuilder = new StringBuilder();
        if (socialMedia != null && socialMedia) {
            stringBuilder.append(
                    excelHelper.getTranslation("profile.skills_id.literacy_skills.digital.social_media", language)).append("\n");
        }
        if (mails != null && mails) {
            stringBuilder.append(
                    excelHelper.getTranslation("profile.skills_id.literacy_skills.digital.mails", language)).append("\n");
        }
        if (reports != null && reports) {
            stringBuilder.append(
                    excelHelper.getTranslation("profile.skills_id.literacy_skills.digital.reports", language)).append("\n");
        }
        if (memos != null && memos) {
            stringBuilder.append(
                    excelHelper.getTranslation("profile.skills_id.literacy_skills.digital.memos", language)).append("\n");
        }
        if (forms != null && forms) {
            stringBuilder.append(
                    excelHelper.getTranslation("profile.skills_id.literacy_skills.digital.forms", language)).append("\n");
        }
        return stringBuilder.toString();
    }

}
