/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 29/06/2018
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.importation;

import java.io.IOException;
import javax.xml.bind.JAXBException;
import javax.xml.transform.TransformerException;
import eu.europa.empl.skpt.service.export.model.ParseXmlResult;

/**
 * Service handling logic for the xml parsing.
 *
 * @author ARHS Spikeseed
 */
public interface IXmlParserService {

    /**
     * Parse the XML profile file in paramater to a {@link ParseXmlResult}.
     * In case the profile XML file contains attachments, they are parsed and saved in the system.
     *
     * @param xmlFileData The  byte array representation of the XML file that contains the profile to parse
     * @return OutputStreamToInputStream
     * @throws IOException IOException thrown in case an error occurs while parsing the attachments
     * @throws TransformerException TransformerException is thrown in case an error occurs while parsing the attachments
     * @throws JAXBException JAXBException TransformerException is thrown in case an error while unmarshalling the profile.
     */
     ParseXmlResult parseXmlProfile(byte[] xmlFileData) throws IOException, TransformerException, JAXBException;
}
