/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 19/06/2018
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.importation.impl;

import eu.europa.empl.skpt.api.exception.BadRequestException;
import eu.europa.empl.skpt.service.export.model.ParseXmlResult;
import eu.europa.empl.skpt.service.export.model.profile.Profile;
import eu.europa.empl.skpt.service.importation.IImportService;
import eu.europa.empl.skpt.service.importation.IXmlParserService;
import eu.europa.empl.skpt.service.importation.IXmlValidationService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Optional;
import java.util.regex.Pattern;

/**
 * Default implementation of {@link IImportService}
 *
 * @author ARHS Spikeseed
 */
@Service
public class ImportService implements IImportService {
    private final IXmlValidationService xmlValidationService;
    private final IXmlParserService xmlParserService;

    /**
     * Constructor
     *
     * @param xmlValidationService xml validation service
     * @param xmlParserService     xml parsing service
     */
    @Autowired
    public ImportService(IXmlValidationService xmlValidationService, IXmlParserService xmlParserService) {
        this.xmlValidationService = xmlValidationService;
        this.xmlParserService = xmlParserService;
    }

    @Override
    public Optional<Profile> importProfile(String xmlProfileFileName, byte[] xmlProfileFileContent) throws Exception {
        xmlProfileFileContent = updateOldProfile(xmlProfileFileContent);
        xmlValidationService.validateXml(xmlProfileFileContent);
        ParseXmlResult parseXmlResult = xmlParserService.parseXmlProfile(xmlProfileFileContent);

        if (parseXmlResult.hasErrors()) {
            throw new BadRequestException("Unable to import file.", parseXmlResult.getErrors());
        }
        return parseXmlResult.getProfile();
    }

    private byte[] updateOldProfile(byte[] oldProfileByteArray) {
        String xmlProfile = new String(oldProfileByteArray);

        xmlProfile = replaceSectionResponsesInRating(xmlProfile);

        return xmlProfile.getBytes();
    }

    private String replaceSectionResponsesInRating(String xmlProfile) {
        xmlProfile = Pattern.compile("<numeracySkills>.*<selected>.*</numeracySkills>", Pattern.DOTALL)
                .matcher(xmlProfile)
                .replaceFirst("<numeracySkills/>");

        xmlProfile = Pattern.compile("<outsideSkills>.*<selected>.*</outsideSkills>", Pattern.DOTALL)
                .matcher(xmlProfile)
                .replaceFirst("<outsideSkills/>");

        xmlProfile = Pattern.compile("<otherBasicTransversalSkills>.*(false|true).*</otherBasicTransversalSkills>", Pattern.DOTALL)
                .matcher(xmlProfile)
                .replaceFirst("<otherBasicTransversalSkills/>");

        return xmlProfile;
    }

}
