/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 29/06/2018
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.importation.impl;

import java.io.*;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Unmarshaller;
import javax.xml.transform.Source;
import javax.xml.transform.TransformerException;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;
import org.apache.commons.io.IOUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import eu.europa.empl.skpt.service.export.impl.TransformerService;
import eu.europa.empl.skpt.service.export.model.ParseXmlResult;
import eu.europa.empl.skpt.service.export.model.profile.Profile;
import eu.europa.empl.skpt.service.importation.IXmlParserService;

/**
 * Default implementation of {@link IXmlParserService}
 *
 * @author ARHS Spikeseed
 */
@Service
public class XmlParserService implements IXmlParserService {
    private static final String XSL_PARSE_ATTACHMENT_RESOURCE_PATH = "/eu/europa/empl/skpt/parse-attachment.xsl";

    private final Unmarshaller unmarshaller;
    private final TransformerService transformerService;

    /**
     * Constructor
     *
     * @param unmarshaller       unmarshaller
     * @param transformerService xml transformerService
     */
    @Autowired
    public XmlParserService(Unmarshaller unmarshaller, TransformerService transformerService) {
        this.unmarshaller = unmarshaller;
        this.transformerService = transformerService;
    }

    @Override
    public ParseXmlResult parseXmlProfile(byte[] xmlFileData) throws IOException, TransformerException, JAXBException {
        ParseXmlResult parseXmlResult;
        try (OutputStream osProfile = new ByteArrayOutputStream()) {
            parseAttachments(xmlFileData, osProfile);
            try (InputStream xmlFileStream = new ByteArrayInputStream(((ByteArrayOutputStream) osProfile).toByteArray())) {
                Profile profile = (Profile) unmarshaller.unmarshal(xmlFileStream);
                parseXmlResult = new ParseXmlResult(profile);
            }
        }
        return parseXmlResult;
    }

    private void parseAttachments(byte[] xmlFileData, OutputStream osProfile) throws TransformerException, IOException {
        // 2. parse XML to remove attachments from it and create them in the system
        try (InputStream xmlFileStream = new ByteArrayInputStream(xmlFileData)) {
            Source xslt = new StreamSource(getClass().getResource(XSL_PARSE_ATTACHMENT_RESOURCE_PATH).toString());
            transformerService.transform(new StreamSource(xmlFileStream), new StreamResult(osProfile), xslt);
        } finally {
            IOUtils.closeQuietly(osProfile);
        }
    }
}
