/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 29/06/2018
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.importation.impl;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.transform.dom.DOMSource;
import javax.xml.validation.Schema;
import javax.xml.validation.Validator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.w3c.dom.Document;
import org.xml.sax.SAXException;
import eu.europa.empl.skpt.api.exception.XMLValidationException;
import eu.europa.empl.skpt.service.importation.IXmlValidationService;
import lombok.extern.slf4j.Slf4j;

/**
 * Default implementation of {@link IXmlValidationService}
 *
 * @author ARHS Spikeseed
 */
@Service
@Slf4j
public class XmlValidationService implements IXmlValidationService {
    private final Schema schema;
    private final CustomErrorHandler errorHandler = new CustomErrorHandler();

    /**
     * Constructor
     *
     * @param schema schema
     */
    @Autowired
    public XmlValidationService(Schema schema) {
        this.schema = schema;
    }

    @Override
    public void validateXml(byte[] xmlFileData) throws XMLValidationException {
        DocumentBuilder parser;
        DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
        documentBuilderFactory.setNamespaceAware(true);
        try (InputStream xmlFileStream = new ByteArrayInputStream(xmlFileData)) {
            parser = documentBuilderFactory.newDocumentBuilder();
            Document document = parser.parse(xmlFileStream);
            Validator validator = schema.newValidator();
            validator.setErrorHandler(errorHandler);
            validator.validate(new DOMSource(document), null);
        } catch (ParserConfigurationException | IOException | SAXException e) {
            log.error(e.getMessage());
            throw new XMLValidationException(e.getMessage(), e.getCause());

        }
    }
}
