/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 28/01/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.service.isced;

import eu.europa.empl.skpt.data.domain.isced.IscedFoet;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;

import java.util.Optional;

/**
 * Interface for the {@link IscedFoetService} service.
 *
 * @author ARHS Spikeseed
 */
public interface IIscedFoetService {

    /**
     * Returns a {@link IscedFoet} entity by its unique identifier
     *
     * @param id        the unique identifier of an ISCED FoET 2013
     * @param languages the languages returned.
     * @param defaultEnglish true if the method need to return the default language in english
     * @return An {@link Optional} of {@link IscedFoet}
     */
    Optional<IscedFoet> findById(Long id, String[] languages, boolean defaultEnglish);

    /**
     * Returns a {@link IscedFoet} entity by its unique identifier
     *
     * @param id        the unique identifier of an ISCED FoET 2013
     * @param languages the languages returned.
     * @return An {@link Optional} of {@link IscedFoet}
     */
    Optional<IscedFoet> findById(Long id, String[] languages);

    /**
     * Returns a {@link Page} of {@link IscedFoet} entities meeting the paging restriction provided in the
     * {@code Pageable} object.
     *
     * @param searchString    search string to match against ISCED FoET 2013 values
     * @param resultLanguages the languages to search on
     * @param pageable        the pagination parameters
     * @return A page of entities
     */
    Page<IscedFoet> search(String searchString, String[] resultLanguages, Pageable pageable);

}
