/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 28/01/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.service.isced.impl;

import eu.europa.empl.skpt.data.domain.isced.IscedFoet;
import eu.europa.empl.skpt.data.repository.isced.IIscedFoetRepository;
import eu.europa.empl.skpt.service.isced.IIscedFoetService;
import eu.europa.empl.skpt.service.tool.LanguageFilter;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import org.springframework.util.Assert;

import java.util.Optional;

/**
 * Implementation of the service for the {@link IscedFoet} entity.
 *
 * @author ARHS Spikeseed
 */
@Service
public class IscedFoetService implements IIscedFoetService {

    private final IIscedFoetRepository iscedFoetRepository;
    private final LanguageFilter languageFilter;

    /**
     * Contructor.
     *
     * @param iscedFoetRepository the {@link IscedFoet} repository.
     * @param languageFilter    language filter
     */
    @Autowired
    public IscedFoetService(IIscedFoetRepository iscedFoetRepository, LanguageFilter languageFilter) {
        this.iscedFoetRepository = iscedFoetRepository;
        this.languageFilter = languageFilter;
    }

    @Override
    public Optional<IscedFoet> findById(Long id, String[] languages, boolean defaultEnglish) {
        Assert.notNull(id, "'id' cannot be null");
        Optional<IscedFoet> optionalIscedFoet = this.iscedFoetRepository.findById(id);

        if (optionalIscedFoet.isPresent()) {
            IscedFoet iscedFoet = (IscedFoet) languageFilter.filter(optionalIscedFoet.get(), languages);
            if (defaultEnglish && !iscedFoet.getValues().containsKey(languages[0])) { // always have only one language for this case
                iscedFoet = (IscedFoet) languageFilter.filter(optionalIscedFoet.get(), new String[]{"en"});
            }
            optionalIscedFoet = Optional.of(iscedFoet);
        }

        return optionalIscedFoet;
    }

    @Override
    public Optional<IscedFoet> findById(Long id, String[] languages) {
        return findById(id, languages, false);
    }

    @Override
    public Page<IscedFoet> search(String searchString, String[] resultLanguages, Pageable pageable) {
        Page<IscedFoet> iscedFoetPage = null;
        if (StringUtils.isNotBlank(searchString)) {
            iscedFoetPage = this.iscedFoetRepository.findByValueIgnoreCase(searchString, pageable);
        } else {
            iscedFoetPage = this.iscedFoetRepository.findAll(pageable);
        }

        iscedFoetPage = (Page<IscedFoet>) languageFilter.filter(iscedFoetPage, resultLanguages);

        return iscedFoetPage;
    }
}
