/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 28/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.label;

import java.io.OutputStream;
import java.util.Optional;

/**
 * Service handling label related logic.
 *
 * @author ARHS Spikeseed
 */
public interface ILabelService {

    /**
     * Returns all labels in JSON for a specific language.
     *
     * @param os   the output stream to write to
     * @param lang the language of the labels to return
     */
    void asJson(OutputStream os, String lang);

    /**
     * Returns the translation identified by the specified key and in the language specified if it exists.
     *
     * @param key  the key identifying the label
     * @param lang the language to return the translation in
     * @param defaultEnglish true if the method need to return the default language in english
     * @return the translation identified by the specified key and in the language specified if it exists
     */
    Optional<String> getLabelTranslationByKey(String key, String lang, boolean defaultEnglish);

    /**
     * Returns the translation identified by the specified key and in the language specified if it exists.
     *
     * @param key  the key identifying the label
     * @param lang the language to return the translation in
     * @return the translation identified by the specified key and in the language specified if it exists
     */
    Optional<String> getLabelTranslationByKey(String key, String lang);
}
