/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 28/01/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.service.language;

import eu.europa.empl.skpt.data.domain.language.Language;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;

import java.util.Optional;
import java.util.Set;

/**
 * Interface for the {@link eu.europa.empl.skpt.service.language.impl.LanguageService} service.
 *
 * @author ARHS Spikeseed
 */
public interface ILanguageService {

    /**
     * Returns a {@link Page} of {@link Language} entities meeting the paging restriction provided in the
     * {@code Pageable} object.
     *
     * @param searchString    search string to match against {@link Language} values
     * @param searchLanguages the languages to search on
     * @param resultLanguages languages to include in the result against {@link Language} values
     * @param pageable        the pagination parameters
     * @return a page of entities
     */
    Page<Language> search(String searchString, Set<String> searchLanguages, String[] resultLanguages, Pageable pageable);

    /**
     * Returns a {@link Page} of {@link Language} entities filtered by {@link Language} ISO 639-1 code meeting the
     * paging restriction provided in the {@code Pageable} object.
     *
     * @param code      the ISO 639-1 language code
     * @param languages languages to include in the result against {@link Language} values
     * @param defaultEnglish true if the method need to return the default language in english
     * @return a page of entities
     */
    Optional<Language> findByIsoCode1(String code, String[] languages, boolean defaultEnglish);

    /**
     * Returns a {@link Page} of {@link Language} entities filtered by {@link Language} ISO 639-1 code meeting the
     * paging restriction provided in the {@code Pageable} object.
     *
     * @param code      the ISO 639-1 language code
     * @param languages languages to include in the result against {@link Language} values
     * @return a page of entities
     */
    Optional<Language> findByIsoCode1(String code, String[] languages);

        /**
         * Return the primary supported languages
         * @param pageable the pagination parameters
         * @return a page of entities
         */
    Page<Language> findByPrimarySupported(Pageable pageable);

    /**
     * Return the secondary supported languages
     * @param pageable the pagination parameters
     * @return a page of entities
     */
    Page<Language> findBySecondarySupported(Pageable pageable);
}
