/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 28/01/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.service.nace;

import eu.europa.empl.skpt.data.domain.nace.Nace;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;

import java.util.Optional;

/**
 * Interface for the {@link NaceService} service.
 *
 * @author ARHS Spikeseed
 */
public interface INaceService {

    /**
     * Returns a {@link Nace} entity by its unique identifier
     *
     * @param id        the unique identifier of an ISCED FoET 2013
     * @param languages the languages returned.
     * @param defaultEnglish true if the method need to return the default language in english
     * @return an {@link Optional} of {@link Nace}
     */
    Optional<Nace> findById(Long id, String[] languages, boolean defaultEnglish);

    /**
     * Returns a {@link Nace} entity by its unique identifier
     *
     * @param id        the unique identifier of an ISCED FoET 2013
     * @param languages the languages returned.
     * @return an {@link Optional} of {@link Nace}
     */
    Optional<Nace> findById(Long id, String[] languages);

    /**
     * Returns a {@link Page} of {@link Nace} entities meeting the paging restriction provided in the
     * {@code Pageable} object.
     *
     * @param searchString    search string to match against NACE values
     * @param resultLanguages the languages of the results.
     * @param pageable        the pagination parameters
     * @return a page of entities
     */
    Page<Nace> search(String searchString, String[] resultLanguages, Pageable pageable);

}
