/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 28/01/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.service.nace.impl;

import eu.europa.empl.skpt.data.domain.nace.Nace;
import eu.europa.empl.skpt.data.repository.nace.INaceRepository;
import eu.europa.empl.skpt.service.nace.INaceService;
import eu.europa.empl.skpt.service.tool.LanguageFilter;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import org.springframework.util.Assert;

import java.util.Optional;

/**
 * Implementation of the service for the {@link Nace} entity.
 *
 * @author ARHS Spikeseed
 */
@Service
public class NaceService implements INaceService {

    private final INaceRepository naceRepository;
    private final LanguageFilter languageFilter;

    /**
     * Contructor.
     *
     * @param naceRepository    the {@link Nace} repository.
     * @param languageFilter    language filter
     */
    @Autowired
    public NaceService(INaceRepository naceRepository, LanguageFilter languageFilter) {
        this.naceRepository = naceRepository;
        this.languageFilter = languageFilter;
    }

    @Override
    public Optional<Nace> findById(Long id, String[] languages, boolean defaultEnglish) {
        Assert.notNull(id, "'id' cannot be null");
        Optional<Nace> optionalNace = this.naceRepository.findById(id);

        if (optionalNace.isPresent()) {
            Nace nace = (Nace) languageFilter.filter(optionalNace.get(), languages);
            if (defaultEnglish && !nace.getValues().containsKey(languages[0])) { // always have only one language for this case
                nace = (Nace) languageFilter.filter(optionalNace.get(), new String[]{"en"});
            }
            optionalNace = Optional.of(nace);
        }

        return optionalNace;
    }

    @Override
    public Optional<Nace> findById(Long id, String[] languages) {
        return findById(id, languages, false);
    }

    @Override
    public Page<Nace> search(String searchString, String[] resultLanguages, Pageable pageable) {
        Page<Nace> nacePage = null;
        if (StringUtils.isNotBlank(searchString)) {
            nacePage = this.naceRepository.findByValueIgnoreCase(searchString, pageable);
        } else {
            nacePage = this.naceRepository.findAll(pageable);
        }

        nacePage = (Page<Nace>) languageFilter.filter(nacePage, resultLanguages);

        return nacePage;
    }
}
