package eu.europa.empl.skpt.service.report.impl;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import eu.europa.empl.skpt.api.dto.ReportDto;
import eu.europa.empl.skpt.service.mail.IMailService;
import eu.europa.empl.skpt.service.report.IReportService;

/**
 * Report service
 *
 * @author ARHS Spikeseed
 */
@Service
public class ReportService implements IReportService {

    private static final Logger LOGGER = LoggerFactory.getLogger(ReportService.class);

    private final ReportMailTemplateBuilder reportMailTemplateBuilder;

    @Value("${report.mail.to}")
    private String mailTo;

    @Value("${report.mail.subject}")
    private String mailSubject;

    private IMailService mailService;

    /**
     * Constructor
     *
     * @param reportMailTemplateBuilder template of the mail
     * @param mailService mail service
     */
    @Autowired
    public ReportService(ReportMailTemplateBuilder reportMailTemplateBuilder, IMailService mailService) {
        this.reportMailTemplateBuilder = reportMailTemplateBuilder;
        this.mailService = mailService;
    }

    @Override
    public void sendReport(ReportDto reportDto) {
        String htmlContent = reportMailTemplateBuilder.build(reportDto);
        mailService.sendMail(mailTo, mailSubject, htmlContent, reportDto.getAttachments());
    }

}
