package eu.europa.empl.skpt.service.stats.impl;

import com.fasterxml.jackson.databind.ObjectMapper;
import eu.europa.empl.skpt.data.domain.stats.ProfileStatistic;
import eu.europa.empl.skpt.service.stats.IProfileStatisticService;
import org.elasticsearch.action.index.IndexRequest;
import org.elasticsearch.action.index.IndexResponse;
import org.elasticsearch.client.RequestOptions;
import org.elasticsearch.client.RestHighLevelClient;
import org.elasticsearch.common.xcontent.XContentType;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.IOException;

/**
 * The profile statistics service.
 *
 * @author ARHS Spikeseed.
 */
@Service
public class ProfileStatisticService implements IProfileStatisticService {

    private static final String PROFILES = "profiles";
    private static final String PROFILE = "profile";
    private static final Logger LOGGER = LoggerFactory.getLogger(ProfileStatisticService.class);

    private ObjectMapper objectMapper;
    private RestHighLevelClient restHighLevelClient;

    /**
     * Contructor.
     *
     * @param objectMapper          object mapper
     * @param restHighLevelClient   rest high level client
     */
    @Autowired
    public ProfileStatisticService(ObjectMapper objectMapper, RestHighLevelClient restHighLevelClient) {
        this.objectMapper = objectMapper;
        this.restHighLevelClient = restHighLevelClient;
    }

    @Override
    public ProfileStatistic sendStatistics(String profile) {
        ProfileStatistic profileStatistic = null;
        try {
            LOGGER.debug("Profile for statistics:\n{}", profile);
            profileStatistic = objectMapper.readValue(profile, ProfileStatistic.class);
            LOGGER.info("Sending profile statistic to Elasticsearch ...");
            String message = objectMapper.writeValueAsString(profileStatistic);
            LOGGER.debug("ProfileStatistic: {}", message);
            sendToElasticSearch(profileStatistic);
        } catch (Exception e) {
            // CLOVER:OFF
            LOGGER.error("An error occur while sending statistic:\n{}", e.getMessage());
            throw new RuntimeException(e);
            // CLOVER:ON
        }
        return profileStatistic;
    }

    @Override
    public IndexResponse sendToElasticSearch(ProfileStatistic profileStatistic) throws IOException {
        IndexRequest indexRequest = new IndexRequest(PROFILES, PROFILE);
        indexRequest.source(objectMapper.writeValueAsString(profileStatistic), XContentType.JSON);
        indexRequest.timeout("1s");
        IndexResponse response = restHighLevelClient.index(indexRequest, RequestOptions.DEFAULT);
        LOGGER.info("Profile sent to Elasticsearch for statistic!");
        return response;
    }

}
