/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool MOOC Backend
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 18/07/2018
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.service.tool;

import eu.europa.empl.skpt.data.domain.IReferenceData;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Component;

import java.util.Arrays;

/**
 * LanguageFilter
 *
 * @author ARHS Spikeseed
 */
@Component
public class LanguageFilter {

    /**
     * Modify the set of languages returned within the reference data.
     *
     * @param entity        the reference data entity
     * @param languages     the list of languages to keep for the reference data
     * @return IReferenceData
     */
    public IReferenceData filter(IReferenceData entity, String[] languages) {
        if (entity != null && languages != null && languages.length > 0) {
            entity.getValues().keySet().removeIf(key -> !Arrays.asList(languages).contains(key));
        }
        return entity;
    }

    /**
     * Modify the set of languages returned within the reference data.
     *
     * @param page          the list of reference data
     * @param languages     the list of languages to keep for the reference data
     * @return page of language
     */
    // Sonar ignored for the next line: the "?" is needed, more than one type is used
    public Page<? extends IReferenceData> filter(Page<? extends IReferenceData> page, String[] languages) { //NOSONAR
        if (page.getSize() > 0 && languages != null && languages.length > 0) {
            page.getContent().forEach(entity -> filter(entity, languages));
        }
        return page;
    }

}
