/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 08/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.user;

import eu.europa.empl.skpt.data.domain.user.User;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;

import java.util.Optional;

/**
 * User service
 *
 * @author ARHS Spikeseed
 */
public interface IUserService {
    /**
     * Returns the user identified by the specified id.
     * @param id the unique identifier of the user to return
     * @return the user identified by the specified id
     */
    Optional<User> getUserById(Long id);

    /**
     * All users paginated.
     *
     * @param pageable the pagination params
     * @return all users paginated
     */
    Page<User>  getUsers(Pageable pageable);

    /**
     * Save user.
     *
     * @param user the user to save
     * @return the saved user identified by an id
     * @throws Exception exception
     */
    User saveUser(User user) throws Exception;

    /**
     * Delete user.
     *
     * @param id the unique identifier of the user to delete
     */
    void deleteUser(Long id);

}
