/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 08/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.user.impl;

import eu.europa.empl.skpt.data.domain.user.Role;
import eu.europa.empl.skpt.data.domain.user.User;
import eu.europa.empl.skpt.data.repository.role.IRoleRepository;
import eu.europa.empl.skpt.data.repository.user.IUserRepository;
import eu.europa.empl.skpt.service.user.IUserService;
import java.time.Instant;
import java.util.Optional;
import java.util.Set;
import java.util.stream.Collectors;
import java.util.stream.StreamSupport;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import org.springframework.util.Assert;

/**
 * User service
 *
 * @author ARHS Spikeseed
 */
@Service
public class UserService implements IUserService {

    private IUserRepository userRepository;
    private IRoleRepository roleRepository;

    /**
     * Constructor
     *
     * @param userRepository the user repository
     * @param roleRepository the role repository
     */
    @Autowired
    public UserService(IUserRepository userRepository, IRoleRepository roleRepository) {
        this.userRepository = userRepository;
        this.roleRepository = roleRepository;
    }

    // CLOVER:OFF

    @Override
    public Optional<User> getUserById(Long id) {
        Assert.notNull(id, "'id' cannot be null");
        return userRepository.findById(id);
    }

    // CLOVER:ON

    @Override
    public Page<User> getUsers(Pageable pageable) {
        Assert.notNull(pageable, "'pageable' cannot be null");
        return userRepository.findAll(pageable);
    }

    @Override
    public User saveUser(User user) throws Exception {
        Assert.notNull(user, "'user' cannot be null");

        if (user.getRoles().isEmpty()) {
            throw new Exception("At least one role required");
        }

        // Fetch available roles
        Set<Role> roles = StreamSupport.stream(this.roleRepository.findAll().spliterator(), false)
                .filter(role -> user.getRoles().stream()
                        .anyMatch(r -> r.getRole() == role.getRole()))
                .collect(Collectors.toSet());

        user.setRoles(roles);

        if (user.getId() == null) {
            user.setCreatedDate(Instant.now());
        }

        user.setModifiedDate(Instant.now());
        return userRepository.save(user);
    }

    @Override
    public void deleteUser(Long id) {
        Assert.notNull(id, "'id' cannot be null");
        userRepository.deleteById(id);
    }
}
