create table tb_attachment (
    id bigint generated by default as identity (start with 1),
    created_date timestamp not null,
    modified_date timestamp,
    identifier varchar(255) not null,
    media_type varchar(255) not null,
    name varchar(1000) not null,
    path varchar(4000) not null,
    size bigint not null,
    upload_timestamp timestamp not null,
    primary key (id)
);

create table tb_rfd_country (
    id bigint generated by default as identity (start with 1),
    created_date timestamp not null,
    modified_date timestamp,
    alpha_code_3 varchar(255) not null,
    primary key (id)
);

create table tb_rfd_country_value (
    id bigint generated by default as identity (start with 1),
    created_date timestamp not null,
    modified_date timestamp,
    language varchar(2) not null,
    value varchar(255) not null,
    country_id bigint,
    primary key (id)
);

create table tb_rfd_esco_concept (
    id bigint generated by default as identity (start with 1),
    created_date timestamp not null,
    modified_date timestamp,
    classification varchar(255) not null,
    esco_id varchar(255) not null,
    primary key (id)
);

create table tb_rfd_esco_value (
    id bigint generated by default as identity (start with 1),
    created_date timestamp not null,
    modified_date timestamp,
    language varchar(2) not null,
    value varchar(1000) not null,
    concept_id bigint,
    primary key (id)
);

create table tb_rfd_isced (
    id bigint generated by default as identity (start with 1),
    created_date timestamp not null,
    modified_date timestamp,
    key_value varchar(255) not null,
    primary key (id)
);

create table tb_rfd_isced_value (
    id bigint generated by default as identity (start with 1),
    created_date timestamp not null,
    modified_date timestamp,
    language varchar(3) not null,
    value varchar(255) not null,
    isced_id bigint,
    primary key (id)
);

create table tb_rfd_label (
    id bigint generated by default as identity (start with 1),
    created_date timestamp not null,
    modified_date timestamp,
    key_value varchar(255) not null,
    primary key (id)
);

create table tb_rfd_label_value (
    id bigint generated by default as identity (start with 1),
    created_date timestamp not null,
    modified_date timestamp,
    language varchar(3) not null,
    translation varchar(2048) not null,
    label_id bigint,
    primary key (id)
);

create table tb_rfd_language (
    id bigint generated by default as identity (start with 1),
    created_date timestamp not null,
    modified_date timestamp,
    iso_code_1 varchar(255) not null,
    iso_code_2 varchar(255),
    iso_code_3 varchar(255),
    native_value varchar(255),
    primary_supported boolean default false,
    secondary_supported boolean default false,
    primary key (id)
);

create table tb_rfd_language_value (
    id bigint generated by default as identity (start with 1),
    created_date timestamp not null,
    modified_date timestamp,
    language varchar(2) not null,
    value varchar(255) not null,
    language_id bigint,
    primary key (id)
);

create table tb_rfd_nace (
    id bigint generated by default as identity (start with 1),
    created_date timestamp not null,
    modified_date timestamp,
    key_value varchar(255) not null,
    primary key (id)
);

create table tb_rfd_nace_value (
    id bigint generated by default as identity (start with 1),
    created_date timestamp not null,
    modified_date timestamp,
    language varchar(3) not null,
    value varchar(255) not null,
    nace_id bigint,
    primary key (id)
);

create table tb_role (
    id bigint generated by default as identity (start with 1),
    created_date timestamp not null,
    modified_date timestamp,
    role varchar(255) not null,
    primary key (id)
);

create table tb_user (
    id bigint generated by default as identity (start with 1),
    created_date timestamp not null,
    modified_date timestamp,
    first_name varchar(255),
    last_name varchar(255),
    username varchar(255) not null,
    primary key (id)
);

create table tb_user_role (
    user_id bigint not null,
    role_id bigint not null,
    primary key (user_id, role_id)
);

alter table tb_attachment
    add constraint UKgcpcsb9jw6stoxi3smopan4xw unique (identifier);

alter table tb_rfd_country
    add constraint UK45n5d2yl7df7kfpoprrifva55 unique (alpha_code_3);

create index IDXffjf8u7go14orqbfeatlug2sh on tb_rfd_country_value (value);

alter table tb_rfd_isced
    add constraint UKrw744k82s8vywenj2ut6c2vwg unique (key_value);

create index IDXtmfec139icxlmt01mkl4vahnq on tb_rfd_isced_value (value);

alter table tb_rfd_label
    add constraint UKff7cf1ypr2q944ditis7awh2 unique (key_value);

alter table tb_rfd_language
    add constraint UKrux995l0mlnv2yb2n1mhguwj unique (iso_code_1);

create index IDXb0gkbb20sfbw1ffebdmq7vkvj on tb_rfd_language_value (value);

alter table tb_rfd_nace
    add constraint UK5a1ix3fhcc851um3ocyf2q2s9 unique (key_value);

create index IDXimchdrw2inm09to5ugicf37cv on tb_rfd_nace_value (value);

alter table tb_role
    add constraint UK6mj2wbjfvldae39hp1efh2hqd unique (role);

alter table tb_user
    add constraint UK4wv83hfajry5tdoamn8wsqa6x unique (username);

alter table tb_rfd_country_value
    add constraint FKk8d7nmdhmd91vesfdqcswt65f
foreign key (country_id)
references tb_rfd_country;

alter table tb_rfd_esco_value
    add constraint FKn6su2ygbp3ssfi6gmqsieytmd
foreign key (concept_id)
references tb_rfd_esco_concept;

alter table tb_rfd_isced_value
    add constraint FKmymkyu3ad6mosux3f65bx864e
foreign key (isced_id)
references tb_rfd_isced;

alter table tb_rfd_label_value
    add constraint FKtbv3eoafdsgpdgb2qgmbddx67
foreign key (label_id)
references tb_rfd_label;

alter table tb_rfd_language_value
    add constraint FKbiv9wl799r4i4egc2wh41kce
foreign key (language_id)
references tb_rfd_language;

alter table tb_rfd_nace_value
    add constraint FKhmx1lwqdmopqrctxes71416q2
foreign key (nace_id)
references tb_rfd_nace;

alter table tb_user_role
    add constraint FKea2ootw6b6bb0xt3ptl28bymv
foreign key (role_id)
references tb_role;

alter table tb_user_role
    add constraint FK7vn3h53d0tqdimm8cp45gc0kl
foreign key (user_id)
references tb_user;

-- **************************
-- Spring Session DDL
-- **************************

CREATE TABLE SPRING_SESSION (
	PRIMARY_ID CHAR(36) NOT NULL,
	SESSION_ID CHAR(36) NOT NULL,
	CREATION_TIME BIGINT NOT NULL,
	LAST_ACCESS_TIME BIGINT NOT NULL,
	MAX_INACTIVE_INTERVAL INT NOT NULL,
	EXPIRY_TIME BIGINT NOT NULL,
	PRINCIPAL_NAME VARCHAR(100),
	CONSTRAINT SPRING_SESSION_PK PRIMARY KEY (PRIMARY_ID)
);

CREATE UNIQUE INDEX SPRING_SESSION_IX1 ON SPRING_SESSION (SESSION_ID);
CREATE INDEX SPRING_SESSION_IX2 ON SPRING_SESSION (EXPIRY_TIME);
CREATE INDEX SPRING_SESSION_IX3 ON SPRING_SESSION (PRINCIPAL_NAME);

CREATE TABLE SPRING_SESSION_ATTRIBUTES (
	SESSION_PRIMARY_ID CHAR(36) NOT NULL,
	ATTRIBUTE_NAME VARCHAR(200) NOT NULL,
	ATTRIBUTE_BYTES LONGVARBINARY NOT NULL,
	CONSTRAINT SPRING_SESSION_ATTRIBUTES_PK PRIMARY KEY (SESSION_PRIMARY_ID, ATTRIBUTE_NAME),
	CONSTRAINT SPRING_SESSION_ATTRIBUTES_FK FOREIGN KEY (SESSION_PRIMARY_ID) REFERENCES SPRING_SESSION(PRIMARY_ID) ON DELETE CASCADE
);

