<?xml version="1.0" encoding="UTF-8"?>
<stylesheet
        version="1.0"
        xmlns="http://www.w3.org/1999/XSL/Transform"
        xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
        xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main"
        xmlns:fo="http://www.w3.org/1999/XSL/Format"
        xmlns:skpt="http://skpt.europa.eu"
        xmlns:data="xalan://eu.europa.empl.skpt.service.export.XslDataService"
        extension-element-prefixes="data"
        exclude-result-prefixes="w fo">

    <template name="displayValue">
        <param name="type"/>
        <param name="classification"/>
        <param name="value"/>

        <choose>
            <when test="$type = 'label'">
                <value-of select="data:getLabel($dataService, $value, $lang)"/>
            </when>
            <when test="$type = 'language'">
                <value-of select="data:getLanguageLabel($dataService, $value, $lang)"/>
            </when>
            <when test="$type = 'country'">
                <value-of select="data:getCountryLabel($dataService, $value, $lang)"/>
            </when>
            <when test="$type = 'date'">
                <if test="$value/skpt:day/text() != '0' or $value/skpt:month/text() !=  '0'  or $value/skpt:year/text() !=  '0'">
                    <value-of select="$value/skpt:day/text()"/>/<value-of
                        select="$value/skpt:month/text()"/>/<value-of select="$value/skpt:year/text()"/>
                </if>
            </when>
            <when test="$type = 'phone'">
                <value-of select="$value/skpt:prefix/text()"/>
                <value-of select="$value/skpt:suffix/text()"/>
            </when>
            <when test="$type = 'mail'">
                <value-of select="$value/skpt:prefix/text()"/>@<value-of select="$value/skpt:suffix/text()"/>
            </when>
            <when test="$type = 'isced'">
                <value-of select="data:getIscedFoetLabel($dataService, $value, $lang)"/>
            </when>
            <when test="$type = 'nace'">
                <value-of select="data:getNaceLabel($dataService, $value, $lang)"/>
            </when>
            <when test="$type = 'esco'">
                <value-of select="data:getEscoLabel($dataService, $value, $classification, $lang)"/>
            </when>
            <when test="$type = 'languageRating'">
                <variable name="baseLabelKey">profile.skills_id.language_skills.level.</variable>
                <choose>
                    <when test="$value = '0'">
                        <call-template name="displayValue">
                            <with-param name="type">label</with-param>
                            <with-param name="value" select="concat($baseLabelKey,'none')"/>
                        </call-template>
                    </when>
                    <when test="$value = '1'">
                        <call-template name="displayValue">
                            <with-param name="type">label</with-param>
                            <with-param name="value" select="concat($baseLabelKey,'basic')"/>
                        </call-template>
                    </when>
                    <when test="$value = '2'">
                        <call-template name="displayValue">
                            <with-param name="type">label</with-param>
                            <with-param name="value" select="concat($baseLabelKey,'sufficient')"/>
                        </call-template>

                    </when>
                    <when test="$value = '3'">
                        <call-template name="displayValue">
                            <with-param name="type">label</with-param>
                            <with-param name="value" select="concat($baseLabelKey,'good')"/>
                        </call-template>

                    </when>
                    <when test="$value = '4'">
                        <call-template name="displayValue">
                            <with-param name="type">label</with-param>
                            <with-param name="value" select="concat($baseLabelKey,'excellent')"/>
                        </call-template>

                    </when>
                </choose>
            </when>
            <when test="$type = 'digitalRating'">
                <variable name="baseLabelKey">profile.skills_id.digital_skills.rating.</variable>
                <choose>
                    <when test="$value = '0'">
                        <call-template name="displayValue">
                            <with-param name="type">label</with-param>
                            <with-param name="value" select="concat($baseLabelKey,'none')"/>
                        </call-template>
                    </when>
                    <when test="$value = '1'">
                        <call-template name="displayValue">
                            <with-param name="type">label</with-param>
                            <with-param name="value" select="concat($baseLabelKey,'guidance')"/>
                        </call-template>
                    </when>
                    <when test="$value = '2'">
                        <call-template name="displayValue">
                            <with-param name="type">label</with-param>
                            <with-param name="value" select="concat($baseLabelKey,'beginner')"/>
                        </call-template>

                    </when>
                    <when test="$value = '3'">
                        <call-template name="displayValue">
                            <with-param name="type">label</with-param>
                            <with-param name="value" select="concat($baseLabelKey,'intermediate')"/>
                        </call-template>

                    </when>
                    <when test="$value = '4'">
                        <call-template name="displayValue">
                            <with-param name="type">label</with-param>
                            <with-param name="value" select="concat($baseLabelKey,'expert')"/>
                        </call-template>

                    </when>
                </choose>
            </when>
            <when test="$value = 'true'">
                <value-of select="data:getLabel($dataService,'common.yes', $lang)"/>
            </when>
            <when test="$value='false'">
                <!--When value is 'false', nothing needs to be displayed-->
            </when>
            <otherwise>
                <value-of select="$value"/>
            </otherwise>
        </choose>

    </template>

    <template name="subSection">
        <param name="sectionName"/>
        <call-template name="section">
            <with-param name="sectionName" select="$sectionName"/>
            <with-param name="fontSize">28</with-param>
            <with-param name="backgroundColor">8AB2E2</with-param>
        </call-template>
    </template>

    <template name="mainSection">
        <param name="sectionName"/>
        <call-template name="section">
            <with-param name="sectionName" select="$sectionName"/>
            <with-param name="fontSize">32</with-param>
            <with-param name="backgroundColor">4483D2</with-param>
        </call-template>
    </template>

    <template name="section">
        <param name="sectionName"/>
        <param name="fontSize"/>
        <param name="backgroundColor"/>
        <if test="$globalExportFormat = 'pdf'">
            <fo:block font-size="14pt" font-weight="bold" font-family="Helvetica,Arial,Nyala" padding="2.5mm"
                      background-color="(#4483d2)" color="(#ffffff)">
                <value-of select="$sectionName"/>
            </fo:block>
        </if>
        <if test="$globalExportFormat = 'word'">
            <w:tr>
                <w:tc>
                    <w:tcPr>
                        <w:tcW w:w="9242" w:type="dxa"/>
                        <w:gridSpan w:val="2"/>
                        <w:tcBorders>
                            <w:top w:val="nil"/>
                            <w:left w:val="single" w:sz="36" w:space="0">
                                <attribute name="w:color">
                                    <value-of select="$backgroundColor"/>
                                </attribute>
                            </w:left>
                            <w:bottom w:val="nil"/>
                            <w:right w:val="single" w:sz="36" w:space="0">
                                <attribute name="w:color">
                                    <value-of select="$backgroundColor"/>
                                </attribute>
                            </w:right>
                        </w:tcBorders>
                        <w:shd w:val="clear" w:color="auto">
                            <attribute name="w:fill">
                                <value-of select="$backgroundColor"/>
                            </attribute>
                        </w:shd>
                    </w:tcPr>
                    <w:p>
                        <w:pPr>
                            <w:spacing w:before="120" w:line="360" w:lineRule="auto"/>
                            <w:rPr>
                                <w:rFonts w:ascii="Arial" w:hAnsi="Arial" w:cs="Arial"/>
                                <w:b/>
                                <w:sz>
                                    <attribute name="w:val">
                                        <value-of select="$fontSize"/>
                                    </attribute>
                                </w:sz>
                                <w:szCs w:val="$fontSize">
                                    <attribute name="w:val">
                                        <value-of select="$fontSize"/>
                                    </attribute>
                                </w:szCs>
                            </w:rPr>
                        </w:pPr>
                        <w:r>
                            <w:rPr>
                                <w:rFonts w:ascii="Arial" w:hAnsi="Arial" w:cs="Arial"/>
                                <w:b/>
                                <w:color w:val="FFFFFF" w:themeColor="background1"/>
                                <w:sz w:val="$fontSize">
                                    <attribute name="w:val">
                                        <value-of select="$fontSize"/>
                                    </attribute>
                                </w:sz>
                                <w:szCs w:val="$fontSize">
                                    <attribute name="w:val">
                                        <value-of select="$fontSize"/>
                                    </attribute>
                                </w:szCs>
                            </w:rPr>
                            <w:t>
                                <value-of select="$sectionName"/>
                            </w:t>
                        </w:r>
                    </w:p>
                </w:tc>
            </w:tr>
        </if>
    </template>

    <attribute-set name="tableCell">
        <attribute name="border-bottom-color">(#c0c0c0)</attribute>
        <attribute name="border-bottom-width">0.5mm</attribute>
        <attribute name="border-bottom-style">solid</attribute>
        <attribute name="padding">2.5mm</attribute>
    </attribute-set>

    <attribute-set name="tableCellLabel">
        <attribute name="border-bottom-color">(#c0c0c0)</attribute>
        <attribute name="border-bottom-width">0.5mm</attribute>
        <attribute name="border-bottom-style">solid</attribute>
        <attribute name="padding">2.5mm</attribute>
        <attribute name="font-weight">bold</attribute>
    </attribute-set>

    <template name="displayTable">
        <param name="labelKey"/>
        <param name="body"/>
        <param name="sectionIndex"/>

        <if test="$body and $body != ''">
            <variable name="labelText">
                <if test="$labelKey and $labelKey != '' and $sectionIndex != ''">
                    <value-of select="concat(data:getLabel($dataService, $labelKey, $lang), ' ', $sectionIndex)"/>
                </if>
                <if test="$labelKey and $labelKey != '' and not($sectionIndex)">
                    <value-of select="data:getLabel($dataService, $labelKey, $lang)"/>
                </if>
            </variable>

            <call-template name="subSection">
                <with-param name="sectionName">
                    <value-of select="$labelText"/>
                </with-param>
            </call-template>

            <if test="$globalExportFormat = 'pdf'">
                <fo:block font-size="10pt" font-family="Helvetica,Arial,Nyala" padding="2.5mm" padding-top="0"
                          background-color="(#c0c0c0)" color="(#000000)">
                    <fo:table table-layout="fixed" width="100%" border-collapse="separate" background-color="#ffffff">
                        <fo:table-column column-width="25%"/>
                        <fo:table-column column-width="25%"/>
                        <fo:table-column column-width="25%"/>
                        <fo:table-column column-width="25%"/>
                        <fo:table-body>
                            <copy-of select="$body"/>
                        </fo:table-body>

                    </fo:table>
                </fo:block>
            </if>
            <if test="$globalExportFormat = 'word'">
                <copy-of select="$body"/>
            </if>
        </if>
    </template>

    <template name="displayRow">
        <param name="labelKey"/>
        <param name="type">text</param>
        <param name="classification"/>
        <param name="value"/>
        <param name="otherValues"/>
        <param name="other"/>
        <param name="fullLine" select="false()"/>


        <if test="($value != 'false' and $value != '0' and $value != '000' and $value != '') or $other ">
            <if test="$globalExportFormat = 'pdf'">
                <fo:table-row>
                    <fo:table-cell xsl:use-attribute-sets="tableCellLabel">
                        <fo:block>
                            <value-of select="data:getLabel($dataService, $labelKey, $lang)"/>
                        </fo:block>
                    </fo:table-cell>
                    <fo:table-cell number-columns-spanned="3" xsl:use-attribute-sets="tableCell">
                        <choose>
                            <when test="($value and $value != '') or $otherValues or $other">
                                <if test="$value and $value != ''">
                                    <fo:block>
                                        <call-template name="displayValue">
                                            <with-param name="value" select="$value"/>
                                            <with-param name="type" select="$type"/>
                                            <with-param name="classification" select="$classification"/>
                                        </call-template>
                                    </fo:block>
                                </if>
                                <if test="$otherValues">
                                    <for-each select="$otherValues">
                                        <fo:block>
                                            <call-template name="displayValue">
                                                <with-param name="value" select="."/>
                                                <with-param name="type" select="$type"/>
                                                <with-param name="classification" select="$classification"/>
                                            </call-template>
                                        </fo:block>
                                    </for-each>
                                </if>
                                <if test="$other">
                                    <for-each select="$other">
                                        <variable name="valueLabel">
                                            <choose>
                                                <when test="./skpt:name/text()">
                                                    <value-of select="./skpt:name/text()"/>
                                                </when>
                                                <otherwise>
                                                    <value-of select="."/>
                                                </otherwise>
                                            </choose>
                                        </variable>
                                        <fo:block>
                                            <call-template name="displayValue">
                                                <with-param name="value" select="$valueLabel"/>
                                            </call-template>
                                        </fo:block>
                                    </for-each>
                                </if>
                            </when>
                            <otherwise>
                                <fo:block/>
                            </otherwise>
                        </choose>
                    </fo:table-cell>
                </fo:table-row>
            </if>
            <if test="$globalExportFormat = 'word'">
                <w:tr>
                    <w:tc>
                        <w:tcPr>
                            <w:tcW w:w="3085" w:type="dxa"/>
                            <w:tcBorders>
                                <w:top w:val="nil"/>
                                <w:left w:val="single" w:sz="36" w:space="0" w:color="BFBFBF" w:themeColor="background1" w:themeShade="BF"/>
                                <w:bottom w:val="single" w:sz="12" w:space="0" w:color="BFBFBF" w:themeColor="background1" w:themeShade="BF"/>
                                <w:right w:val="nil"/>
                            </w:tcBorders>
                        </w:tcPr>
                        <call-template name="displayWordParagraph">
                            <with-param name="isQuestion">true</with-param>
                            <with-param name="text">
                                <value-of select="data:getLabel($dataService, $labelKey, $lang)"/>
                            </with-param>
                        </call-template>
                    </w:tc>
                    <w:tc>
                        <w:tcPr>
                            <w:tcW w:w="6157" w:type="dxa"/>
                            <w:tcBorders>
                                <w:top w:val="nil"/>
                                <w:left w:val="nil"/>
                                <w:bottom w:val="single" w:sz="12" w:space="0" w:color="BFBFBF" w:themeColor="background1" w:themeShade="BF"/>
                                <w:right w:val="single" w:sz="36" w:space="0" w:color="BFBFBF" w:themeColor="background1" w:themeShade="BF"/>
                            </w:tcBorders>
                        </w:tcPr>

                        <choose>
                            <when test="($value and $value != '') or $otherValues or $other">
                                <if test="$value and $value != ''">
                                    <call-template name="displayWordParagraph">
                                        <with-param name="text">
                                            <call-template name="displayValue">
                                                <with-param name="value" select="$value"/>
                                                <with-param name="type" select="$type"/>
                                                <with-param name="classification" select="$classification"/>
                                            </call-template>
                                        </with-param>
                                    </call-template>
                                </if>
                                <if test="$otherValues">
                                    <for-each select="$otherValues">
                                        <call-template name="displayWordParagraph">
                                            <with-param name="text">
                                                <call-template name="displayValue">
                                                    <with-param name="value" select="."/>
                                                    <with-param name="type" select="$type"/>
                                                    <with-param name="classification" select="$classification"/>
                                                </call-template>
                                            </with-param>
                                        </call-template>
                                    </for-each>
                                </if>
                                <if test="$other">
                                    <for-each select="$other">
                                        <variable name="valueLabel">
                                            <choose>
                                                <when test="./skpt:name/text()">
                                                    <value-of select="./skpt:name/text()"/>
                                                </when>
                                                <otherwise>
                                                    <value-of select="."/>
                                                </otherwise>
                                            </choose>
                                        </variable>
                                        <call-template name="displayWordParagraph">
                                            <with-param name="text">
                                                <call-template name="displayValue">
                                                    <with-param name="value" select="$valueLabel"/>
                                                </call-template>
                                            </with-param>
                                        </call-template>
                                    </for-each>
                                </if>
                            </when>
                            <otherwise>
                            </otherwise>
                        </choose>
                    </w:tc>
                </w:tr>
            </if>
        </if>
    </template>

    <template name="displayLabelRow">
        <param name="labelKey"/>
        <param name="value"/>
        <param name="prefix"/>
        <param name="suffix"/>
        <param name="other"/>

        <if test="$value">

            <variable name="label">
                <if test="$value and $value != ''">
                    <value-of select="concat($prefix, $value, $suffix)"/>
                </if>
            </variable>

            <choose>
                <when test="$value = 'other'">
                    <call-template name="displayRow">
                        <with-param name="labelKey" select="$labelKey"/>
                        <with-param name="value" select="$label"/>
                        <with-param name="other" select="$other"/>
                        <with-param name="type">label</with-param>
                    </call-template>
                </when>
                <otherwise>
                    <call-template name="displayRow">
                        <with-param name="labelKey" select="$labelKey"/>
                        <with-param name="value" select="$label"/>
                        <with-param name="type">label</with-param>
                    </call-template>
                </otherwise>
            </choose>
        </if>
    </template>

    <template name="displayTimeDuration">
        <param name="labelKey"/>
        <param name="week"/>
        <param name="month"/>
        <param name="year"/>

        <variable name="data">
            <if test="$week and $week != '0'">
                <call-template name="displayParagraph">
                    <with-param name="text">
                        <value-of select="concat($week, ' ')"/>
                        <value-of
                                select="data:getLabel($dataService, 'profile.skills_id.professional_skills.professional_experience.duration.week', $lang)"/>
                    </with-param>
                </call-template>
            </if>
            <if test="$month and $month != '0'">
                <call-template name="displayParagraph">
                    <with-param name="text">
                        <value-of select="concat($month, ' ')"/>
                        <value-of
                                select="data:getLabel($dataService, 'profile.skills_id.professional_skills.professional_experience.duration.month', $lang)"/>
                    </with-param>
                </call-template>
            </if>
            <if test="$year and $year != '0'">
                <call-template name="displayParagraph">
                    <with-param name="text">
                        <value-of select="concat($year, ' ')"/>
                        <value-of
                                select="data:getLabel($dataService, 'profile.skills_id.professional_skills.professional_experience.duration.year', $lang)"/>
                    </with-param>
                </call-template>
            </if>
        </variable>

        <if test="$data and $data != ''">
            <if test="$globalExportFormat = 'pdf'">
                <fo:table-row>
                    <if test="$labelKey">
                        <fo:table-cell xsl:use-attribute-sets="tableCellLabel">
                            <fo:block>
                                <value-of select="data:getLabel($dataService, $labelKey, $lang)"/>
                            </fo:block>
                        </fo:table-cell>
                    </if>
                    <fo:table-cell number-columns-spanned="3" xsl:use-attribute-sets="tableCell">
                        <copy-of select="$data"/>
                    </fo:table-cell>
                </fo:table-row>
            </if>
            <if test="$globalExportFormat = 'word'">
                <w:tr>
                    <w:tc>
                        <w:tcPr>
                            <w:tcW w:w="3085" w:type="dxa"/>
                            <w:tcBorders>
                                <w:top w:val="nil"/>
                                <w:left w:val="single" w:sz="36" w:space="0" w:color="BFBFBF" w:themeColor="background1" w:themeShade="BF"/>
                                <w:bottom w:val="single" w:sz="12" w:space="0" w:color="BFBFBF" w:themeColor="background1" w:themeShade="BF"/>
                                <w:right w:val="nil"/>
                            </w:tcBorders>
                        </w:tcPr>
                        <call-template name="displayWordParagraph">
                            <with-param name="isQuestion">true</with-param>
                            <with-param name="text">
                                <value-of select="data:getLabel($dataService, $labelKey, $lang)"/>
                            </with-param>
                        </call-template>
                    </w:tc>
                    <w:tc>
                        <w:tcPr>
                            <w:tcW w:w="6157" w:type="dxa"/>
                            <w:tcBorders>
                                <w:top w:val="nil"/>
                                <w:left w:val="nil"/>
                                <w:bottom w:val="single" w:sz="12" w:space="0" w:color="BFBFBF" w:themeColor="background1" w:themeShade="BF"/>
                                <w:right w:val="single" w:sz="36" w:space="0" w:color="BFBFBF" w:themeColor="background1" w:themeShade="BF"/>
                            </w:tcBorders>
                        </w:tcPr>
                        <copy-of select="$data"/>
                    </w:tc>
                </w:tr>
            </if>
        </if>
    </template>


    <template name="displayParagraph">
        <param name="text"/>
        <if test="$globalExportFormat = 'pdf'">
            <call-template name="displayPDFParagraph">
                <with-param name="text" select="$text"/>
            </call-template>
        </if>
        <if test="$globalExportFormat = 'word'">
            <call-template name="displayWordParagraph">
                <with-param name="text" select="$text"/>
            </call-template>
        </if>
    </template>

    <template name="displayWordParagraph">
        <param name="text"/>
        <param name="isQuestion"/>
        <w:p>
            <w:pPr>
                <w:spacing w:before="120" w:line="360" w:lineRule="auto"/>
                <w:rPr>
                    <w:rFonts w:ascii="Arial" w:hAnsi="Arial" w:cs="Arial"/>
                </w:rPr>
            </w:pPr>
            <w:r>
                <w:rPr>
                    <w:rFonts w:ascii="Arial" w:hAnsi="Arial" w:cs="Arial"/>
                    <if test="$isQuestion and $isQuestion = 'true'">
                        <w:b/>
                    </if>
                </w:rPr>
                <w:t>
                    <value-of select="$text"/>
                </w:t>
            </w:r>
        </w:p>
    </template>

    <template name="displayPDFParagraph">
        <param name="text"/>
        <fo:block>
            <value-of select="$text"/>
        </fo:block>
    </template>

</stylesheet>