<?xml version="1.0" encoding="UTF-8"?>
<stylesheet
        version="1.0"
        xmlns="http://www.w3.org/1999/XSL/Transform"
        xmlns:fo="http://www.w3.org/1999/XSL/Format"
        xmlns:skpt="http://skpt.europa.eu"
        xmlns:data="xalan://eu.europa.empl.skpt.service.export.XslDataService"
        extension-element-prefixes="data">

    <variable name="globalExportFormat" select="'pdf'"/>

    <include href="commons.xsl"/>

    <param name="dataService"></param>
    <param name="lang"></param>

    <template match="skpt:profile">
        <fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format">
            <!--  defines the layout master  -->
            <fo:layout-master-set>
                <fo:simple-page-master master-name="simpleA4" page-height="29.7cm" page-width="21cm" margin-top="1.5cm"
                                       margin-bottom="1.5cm"
                                       margin-left="2cm" margin-right="2cm">
                    <fo:region-body margin-top="0cm"/>
                    <fo:region-before extent="0cm"/>
                    <fo:region-after region-name="footer" precedence="true"></fo:region-after>
                </fo:simple-page-master>
            </fo:layout-master-set>

            <fo:page-sequence master-reference="simpleA4">
                <fo:static-content flow-name="footer">
                    <fo:block text-align="right"><fo:page-number/>/
                        <fo:page-number-citation
                                ref-id="last-page"/>
                    </fo:block>
                </fo:static-content>

                <fo:flow flow-name="xsl-region-body">
                    <call-template name="header"/>
                    <apply-templates select="*"/>
                    <fo:block id="last-page" line-height="0"/>
                </fo:flow>
            </fo:page-sequence>
        </fo:root>
    </template>

    <template name="header">

        <fo:block font-size="16pt"
                  font-weight="bold"
                  font-family="Helvetica,Arial,Nyala"
                  color="white"
                  padding="2.5mm"
                  padding-before="2mm"
                  padding-after="2mm"
                  background-color="(#074a8b)"
                  text-align="center">
            <value-of select="data:getLabel($dataService, 'skills.profile.tool.label', $lang)"/>
        </fo:block>
        <fo:block font-size="16pt"
                  font-weight="bold"
                  font-family="Helvetica,Arial,Nyala"
                  padding="2.5mm"
                  padding-before="5mm"
                  padding-after="5mm"
                  background-color="(#f4f4f4)">
            <call-template name="displayValue">
                <with-param name="value" select="skpt:personalInfo/skpt:familyName/text()"/>
            </call-template>
            <text> </text>
            <call-template name="displayValue">
                <with-param name="value" select="skpt:personalInfo/skpt:firstName/text()"/>
            </call-template>
            <if test="skpt:personalInfo/skpt:attachment">
                <call-template name="profilePicture"/>
            </if>
        </fo:block>
    </template>

    <template name="profilePicture">
        <variable name="type" select="skpt:personalInfo/skpt:attachment/skpt:type"/>
        <variable name="id" select="skpt:personalInfo/skpt:attachment/skpt:id"/>
        <fo:block>
            <fo:external-graphic content-width="scale-to-fit"
                                 height="100px"
                                 scaling="uniform">
                <attribute name="src">
                    <text>url('data:</text>
                    <value-of select="$type"/>
                    <text>;base64,</text>
                    <value-of disable-output-escaping="yes" select="data:getAttachmentAsBase64($dataService, $id)"/>
                    <text>')</text>
                </attribute>
            </fo:external-graphic>
        </fo:block>
    </template>

    <include href="fragments/personalInfo.xsl"/>

    <include href="fragments/expectations.xsl"/>

    <include href="fragments/skillsIdentification.xsl"/>

    <include href="fragments/languageSkills.xsl"/>

    <include href="fragments/educationTraining.xsl"/>

    <include href="fragments/certificates.xsl"/>

    <include href="fragments/literacySkills.xsl"/>

    <include href="fragments/numeracySkills.xsl"/>

    <include href="fragments/digitalSkills.xsl"/>

    <include href="fragments/professionalSkills.xsl"/>

    <include href="fragments/experiences.xsl"/>

    <include href="fragments/outsideSkills.xsl"/>

    <include href="fragments/otherBasicTransversalSkills.xsl"/>

    <include href="fragments/drivingSkills.xsl"/>

    <include href="fragments/outcome.xsl"/>

    <include href="fragments/organisations.xsl"/>

</stylesheet>