/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 28/4/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.data.repository.attachment;

import eu.europa.empl.skpt.data.domain.attachment.Attachment;
import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.orm.jpa.DataJpaTest;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.test.context.jdbc.Sql;
import org.springframework.test.context.junit4.SpringRunner;
import org.springframework.transaction.TransactionStatus;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.support.TransactionCallback;
import org.springframework.transaction.support.TransactionTemplate;

import java.time.Instant;
import java.util.List;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * Test class for {@link IAttachmentRepository}.
 *
 * @author ARHS Spikeseed
 */
@RunWith(SpringRunner.class)
@DataJpaTest
@ActiveProfiles("unitTest")
@Sql(value = "attachment-repository-test.sql")
public class AttachmentRepositoryTest {

    @Autowired
    private TransactionTemplate transactionTemplate;

    @Autowired
    private IAttachmentRepository attachmentRepository;

    @Test
    @Transactional(propagation = Propagation.NOT_SUPPORTED)
    public void findByUploadTimestampLessThan() throws Exception {

        Callable<Long> t1 = createCallable();
        Callable<Long> t2 = createCallable();

        ExecutorService executorService = Executors.newFixedThreadPool(2);
        Future<Long> f1 = executorService.submit(t1);
        Future<Long> f2 = executorService.submit(t2);

        Long count1 = f1.get();
        Long count2 = f2.get();

        Assert.assertTrue((5L == count1 && 0L == count2) || (0L == count1 && 5L == count2));

    }

    private Callable<Long> createCallable() {
        return new Callable<Long>() {
            @Override
            public Long call() throws Exception {
                return transactionTemplate.execute(new TransactionCallback<Long>() {
                    @Override
                    public Long doInTransaction(TransactionStatus status) {
                        Stream<Attachment> attachments = attachmentRepository.findByUploadTimestampLessThan(Instant.now());
                        List<Attachment> attachmentList = attachments.collect(Collectors.toList());
                        attachmentList.forEach(attachment -> attachmentRepository.delete(attachment));
                        return (long) attachmentList.size();
                    }
                });
            }
        };
    }

}
