/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 29/12/2016
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.data.repository.country;

import eu.europa.empl.skpt.data.domain.country.Country;
import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.orm.jpa.DataJpaTest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.test.context.jdbc.Sql;
import org.springframework.test.context.junit4.SpringRunner;

import java.util.HashSet;
import java.util.Optional;
import java.util.Set;

/**
 * Test class for {@link ICountryRepository}.
 *
 * @author ARHS Spikeseed
 */
@RunWith(SpringRunner.class)
@DataJpaTest
@ActiveProfiles("unitTest")
@Sql(value = "country-repository-test.sql")
public class CountryRepositoryTest {

    @Autowired
    private ICountryRepository countryRepository;

    @Test
    public void findAll() {
        Page<Country> countryPage = this.countryRepository.findAll(PageRequest.of(0, 5));
        Assert.assertNotNull(countryPage);
        Assert.assertEquals(8, countryPage.getTotalElements());
    }

    @Test
    public void findByValueIgnoreCase() {
        Page<Country> countryPage = this.countryRepository.findByValueIgnoreCase("alba", PageRequest.of(0, 10, Sort
                .Direction.ASC, "id"));
        Assert.assertNotNull(countryPage);
        Assert.assertEquals(1, countryPage.getContent().size());

        countryPage = this.countryRepository.findByValueIgnoreCase("ANG", PageRequest.of(0, 10));
        Assert.assertNotNull(countryPage);
        Assert.assertEquals(2, countryPage.getContent().size());
    }

    @Test
    public void findByValueIgnoreCaseAndLanguages() {

        String searchLanguage = "fr";
        Set<String> mySet = new HashSet<>();
        mySet.add("belgium");
        Set<String> mySecondSet = new HashSet<>();
        mySecondSet.add("belgique");
        Page<Country> countryPage = this.countryRepository.findByValueIgnoreCaseAndLanguages(mySet,
                searchLanguage, PageRequest.of(0, 10, Sort.Direction.ASC, "id"));
        Assert.assertNotNull(countryPage);
        Assert.assertEquals(0, countryPage.getContent().size());

        countryPage = this.countryRepository.findByValueIgnoreCaseAndLanguages(mySecondSet, searchLanguage,
                PageRequest.of(0, 10));
        Assert.assertNotNull(countryPage);
        Assert.assertEquals(0, countryPage.getContent().size());
    }

    @Test
    public void findByAlphaCode3() {
        Optional<Country> country = this.countryRepository.findByAlphaCode3("ALB");
        Assert.assertNotNull(country);
        Assert.assertTrue(country.isPresent());
        Assert.assertEquals("ALB", country.get().getAlphaCode3());
    }

}
