/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 29/12/2016
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.data.repository.isced;

import eu.europa.empl.skpt.data.domain.isced.IscedFoet;
import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.orm.jpa.DataJpaTest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.test.context.jdbc.Sql;
import org.springframework.test.context.junit4.SpringRunner;

import java.util.HashSet;
import java.util.Optional;
import java.util.Set;

/**
 * Test class for {@link IIscedFoetRepository}.
 *
 * @author ARHS Spikeseed
 */
@RunWith(SpringRunner.class)
@DataJpaTest
@ActiveProfiles("unitTest")
@Sql("isced-repository-test.sql")
public class IscedFoetRepositoryTest {

    @Autowired
    private IIscedFoetRepository iscedFoetRepository;

    @Test
    public void findById() {
        Optional<IscedFoet> optionalIscedFoet = this.iscedFoetRepository.findById(1L);
        Assert.assertNotNull(optionalIscedFoet);
        Assert.assertTrue(optionalIscedFoet.isPresent());
        Assert.assertEquals(1L, optionalIscedFoet.get().getId().longValue());
    }

    @Test
    public void findAll() {
        Page<IscedFoet> iscedFoetPage = this.iscedFoetRepository.findAll(PageRequest.of(0, 10));
        Assert.assertNotNull(iscedFoetPage);
        Assert.assertEquals(5, iscedFoetPage.getTotalElements());
    }

    @Test
    public void findByValueIgnoreCase() {
        Page<IscedFoet> iscedFoetPage = this.iscedFoetRepository.findByValueIgnoreCase("skill", PageRequest.of(0,
                10, Sort.Direction.ASC, "id"));
        Assert.assertNotNull(iscedFoetPage);
        Assert.assertEquals(2, iscedFoetPage.getContent().size());

        iscedFoetPage = this.iscedFoetRepository.findByValueIgnoreCase("numeracy", PageRequest.of(0, 10));
        Assert.assertNotNull(iscedFoetPage);
        Assert.assertEquals(1, iscedFoetPage.getContent().size());
    }

    @Test
    public void findByValueIgnoreCaseAndLanguage() {

        String searchLanguage = "en";
        Set<String> mySet = new HashSet<>();
        mySet.add("literacy");
        Page<IscedFoet> iscedFoetPage = this.iscedFoetRepository.findByValueIgnoreCaseAndLanguages(mySet,
                searchLanguage, PageRequest.of(0, 10, Sort.Direction.ASC, "id"));
        Assert.assertNotNull(iscedFoetPage);
        Assert.assertEquals(0, iscedFoetPage.getContent().size());

        Set<String> mySecondSet = new HashSet<>();
        mySecondSet.add("alphabétisation");
        iscedFoetPage = this.iscedFoetRepository.findByValueIgnoreCaseAndLanguages(mySecondSet,
                searchLanguage, PageRequest.of(0, 10));
        Assert.assertNotNull(iscedFoetPage);
        Assert.assertEquals(0, iscedFoetPage.getContent().size());
    }

}
