/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 28/3/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.data.repository.label;

import eu.europa.empl.skpt.data.domain.label.Label;
import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.orm.jpa.DataJpaTest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.test.context.jdbc.Sql;
import org.springframework.test.context.junit4.SpringRunner;

import java.util.Optional;
import java.util.stream.Stream;

/**
 * Test class for {@link ILabelRepository}.
 *
 * @author ARHS Spikeseed
 */
@RunWith(SpringRunner.class)
@DataJpaTest
@ActiveProfiles("unitTest")
@Sql(value = "label-repository-test.sql")
public class LabelRepositoryTest {

    @Autowired
    private ILabelRepository labelRepository;

    @Test
    public void findAll() {
        Page<Label> labelPage = this.labelRepository.findAll(PageRequest.of(0, 10));
        Assert.assertNotNull(labelPage);
        Assert.assertEquals(5, labelPage.getTotalElements());
    }

    @Test
    public void findAllAsStream() {
        Stream<Label> labelStream = this.labelRepository.findAllAsStream();
        Assert.assertNotNull(labelStream);
        Assert.assertEquals(5, labelStream.count());
    }

    @Test
    public void findById() {
        Optional<Label> label = this.labelRepository.findById(4L);
        Assert.assertNotNull(label);
        Assert.assertTrue(label.isPresent());
        Assert.assertEquals("common.no", label.get().getKey());
    }

    @Test
    public void findByKey() {
        Optional<Label> label = this.labelRepository.findByKey("common.no");
        Assert.assertNotNull(label);
        Assert.assertTrue(label.isPresent());
        Assert.assertEquals(Long.valueOf(4), label.get().getId());
    }

}
