/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 29/12/2016
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.data.repository.language;

import eu.europa.empl.skpt.data.domain.language.Language;
import eu.europa.empl.skpt.data.repository.country.ICountryRepository;
import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.orm.jpa.DataJpaTest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.test.context.jdbc.Sql;
import org.springframework.test.context.junit4.SpringRunner;

import java.util.HashSet;
import java.util.Optional;
import java.util.Set;

/**
 * Test class for {@link ICountryRepository}.
 *
 * @author ARHS Spikeseed
 */
@RunWith(SpringRunner.class)
@DataJpaTest
@ActiveProfiles("unitTest")
@Sql("language-repository-test.sql")
public class LanguageRepositoryTest {

    @Autowired
    private ILanguageRepository languageRepository;

    @Test
    public void findAll() {
        Page<Language> languagePage = this.languageRepository.findAll(PageRequest.of(0, 10));
        Assert.assertNotNull(languagePage);
        Assert.assertEquals(192, languagePage.getTotalElements());
    }

    @Test
    public void findByValueIgnoreCase() {
        Page<Language> languagePage = this.languageRepository
                .findByValueIgnoreCase("fra", PageRequest.of(0, 10, Sort.Direction.ASC, "id"));
        Assert.assertNotNull(languagePage);
        Assert.assertEquals(1, languagePage.getContent().size());

        languagePage = this.languageRepository.findByValueIgnoreCase("BEL", PageRequest.of(0, 10));
        Assert.assertNotNull(languagePage);
        Assert.assertEquals(3, languagePage.getContent().size());
    }

    @Test
    public void findByValueIgnoreCaseAndLanguages() {

        String searchLanguage = "fr";
        Set<String> mySet = new HashSet<>();
        mySet.add("French");
        Set<String> mySecondSet = new HashSet<>();
        mySecondSet.add("Français");
        Page<Language> languagePage = this.languageRepository
                .findByValueIgnoreCaseAndLanguages(mySet, searchLanguage,
                        PageRequest.of(0, 10, Sort.Direction.ASC, "id"));
        Assert.assertNotNull(languagePage);
        Assert.assertEquals(0, languagePage.getContent().size());

        languagePage = this.languageRepository.findByValueIgnoreCaseAndLanguages(mySecondSet, searchLanguage,
                PageRequest.of(0, 10));
        Assert.assertNotNull(languagePage);
        Assert.assertEquals(0, languagePage.getContent().size());
    }

    @Test
    public void findByIsoCode1() {
        Optional<Language> language = this.languageRepository.findByIsoCode1("be");
        Assert.assertNotNull(language);
        Assert.assertTrue(language.isPresent());
        Assert.assertEquals("be", language.get().getIsoCode1());
    }

    @Test
    public void findAllApplicationLanguages() {
        Page<Language> languagePage = this.languageRepository.findByPrimarySupported(true, PageRequest.of(0, 10));
        Assert.assertNotNull(languagePage);
        Assert.assertEquals(5, languagePage.getTotalElements());
    }
}
