/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 * 
 *  CREATED BY : ARHS Spikeseed
 *          ON : 22/2/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.data.repository.nace;

import eu.europa.empl.skpt.data.domain.nace.Nace;
import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.orm.jpa.DataJpaTest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Sort;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.test.context.jdbc.Sql;
import org.springframework.test.context.junit4.SpringRunner;

import java.util.HashSet;
import java.util.Optional;
import java.util.Set;

/**
 * Test class for {@link INaceRepository}
 *
 * @author ARHS Spikeseed
 */
@RunWith(SpringRunner.class)
@DataJpaTest
@ActiveProfiles("unitTest")
@Sql("nace-repository-test.sql")
public class NaceRepositoryTest {

    @Autowired
    private INaceRepository naceRepository;

    @Test
    public void findAll() {
        Page<Nace> nacePage = this.naceRepository.findAll(PageRequest.of(0, 10));
        Assert.assertNotNull(nacePage);
        Assert.assertEquals(3, nacePage.getTotalElements());
    }

    @Test
    public void findByValueIgnoreCase() {
        Page<Nace> nacePage = this.naceRepository.findByValueIgnoreCase("Manufacturing", PageRequest.of(0, 10, Sort.Direction.ASC, "id"));
        Assert.assertNotNull(nacePage);
        Assert.assertEquals(0, nacePage.getContent().size());

        nacePage = this.naceRepository.findByValueIgnoreCase("СЕЛСКО, ГОРСКО И РИБНО СТОПАНСТВО", PageRequest.of(0, 10));
        Assert.assertNotNull(nacePage);
        Assert.assertEquals(1, nacePage.getContent().size());

        nacePage = this.naceRepository.findByValueIgnoreCase("TARIM, ORMANCILIK VE BALIKÇILIK", PageRequest.of(0,
                10));
        Assert.assertNotNull(nacePage);
        Assert.assertEquals(1, nacePage.getContent().size());
    }

    @Test
    public void findByValueIgnoreCaseAndLanguages() {

        String searchLanguage = "hu";
        Set<String> mySet = new HashSet<>();
        mySet.add("Manufacturing");
        Page<Nace> nacePage = this.naceRepository
                .findByValueIgnoreCaseAndLanguages(mySet, searchLanguage,
                        PageRequest.of(0, 10, Sort.Direction.ASC, "id"));
        Assert.assertNotNull(nacePage);
        Assert.assertEquals(0, nacePage.getContent().size());

        Set<String> mySecondSet = new HashSet<>();
        mySecondSet.add("MEZŐGAZDASÁG, ERDŐGAZDÁLKODÁS, HALÁSZAT");
        nacePage = this.naceRepository.findByValueIgnoreCaseAndLanguages(mySecondSet,
                searchLanguage, PageRequest.of(0, 10));
        Assert.assertNotNull(nacePage);
        Assert.assertEquals(0, nacePage.getContent().size());

    }

    @Test
    public void findById() {
        Optional<Nace> optionalNace = this.naceRepository.findById(1L);
        Assert.assertNotNull(optionalNace);
        Assert.assertTrue(optionalNace.isPresent());
        Assert.assertEquals(1L, optionalNace.get().getId().longValue());
    }

}
