/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 28/01/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.service.esco.impl;

import eu.europa.empl.skpt.data.domain.IReferenceData;
import eu.europa.empl.skpt.data.domain.esco.EscoClassification;
import eu.europa.empl.skpt.data.domain.esco.EscoLocalConcept;
import eu.europa.empl.skpt.data.repository.esco.IEscoRepository;
import eu.europa.empl.skpt.service.tool.LanguageFilter;
import eu.europa.empl.skpt.tool.EscoGenerator;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.Mock;
import org.mockito.Mockito;
import org.mockito.junit.MockitoJUnitRunner;
import org.springframework.data.domain.*;

import java.util.List;
import java.util.Optional;

import static org.junit.Assert.*;
import static org.mockito.ArgumentMatchers.any;
import static org.mockito.Mockito.eq;
import static org.mockito.Mockito.when;

/**
 * Test class for the {@link EscoLocalService} service.
 *
 * @author ARHS Spikeseed
 */
@RunWith(MockitoJUnitRunner.class)
public class EscoServiceTest {

    @Mock
    private IEscoRepository escoRepository;
    @Mock
    private LanguageFilter languageFilter;

    private EscoLocalService escoLocalService;

    private List<EscoLocalConcept> allEsco;
    private List<EscoLocalConcept> allEscoOccupations;
    private List<EscoLocalConcept> allEscoContainsWorkersWord;
    private EscoLocalConcept aquacultureEsco;
    private Pageable pageable;

    @Before
    public void setUp() {
        escoLocalService = new EscoLocalService(
                escoRepository, languageFilter);

        allEsco = EscoGenerator.generateAllEscoList();
        allEscoOccupations = EscoGenerator.generateAllEscoOccupationsList();
        allEscoContainsWorkersWord = EscoGenerator.generateAllEscoContainsWorkersWordList();

        aquacultureEsco = allEsco.get(0);

        pageable = PageRequest.of(0, 20, Sort.Direction.ASC, "id");

        when(escoRepository.findById(0L))
                .thenReturn(Optional.of(aquacultureEsco));

        when(escoRepository.findByClassification(EscoClassification.OCCUPATIONS, pageable))
                .thenReturn(new PageImpl<>(allEscoOccupations));

        when(escoRepository.findByClassificationAndValueIgnoreCase(EscoClassification.OCCUPATIONS, "workers", pageable))
                .thenReturn(new PageImpl<>(allEscoContainsWorkersWord));

        when(languageFilter.filter(eq(aquacultureEsco), any()))
                .thenReturn(allEsco.get(0));

        Mockito.<Page<? extends IReferenceData>>
                when(languageFilter.filter(new PageImpl<>(allEscoOccupations), new String[0]))
                .thenReturn(new PageImpl<>(allEscoOccupations));

        Mockito.<Page<? extends IReferenceData>>
                when(languageFilter.filter(new PageImpl<>(allEscoContainsWorkersWord), new String[0]))
                .thenReturn(new PageImpl<>(allEscoContainsWorkersWord));
    }

    @Test
    public void findById() {
        Optional<EscoLocalConcept> escoLocal = this.escoLocalService
                .findById(0L, null);

        assertNotNull(escoLocal);
        assertTrue(escoLocal.isPresent());
        assertEquals(aquacultureEsco, escoLocal.get());
    }

    @Test
    public void findByClassificationWithBlankSearchString() {
        String searchString = null;
        String[] resultLanguages = {};
        List<EscoLocalConcept> escos = this.escoLocalService
                .search(EscoClassification.OCCUPATIONS, searchString, resultLanguages, pageable)
                .getContent();

        assertNotNull(escos);
        assertEquals(allEscoOccupations, escos);
    }

    @Test
    public void findByClassification() {
        String searchString = "workers";
        String[] resultLanguages = {};
        List<EscoLocalConcept> escos = this.escoLocalService
                .search(EscoClassification.OCCUPATIONS, searchString, resultLanguages, pageable)
                .getContent();

        assertNotNull(escos);
        assertEquals(allEscoContainsWorkersWord, escos);
    }

}
