package eu.europa.empl.skpt.service.export.impl;

import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.List;
import java.util.Optional;
import org.junit.Assert;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.test.context.junit4.SpringRunner;
import eu.europa.empl.skpt.service.export.model.profile.*;
import eu.europa.empl.skpt.service.importation.impl.ImportService;
import static java.util.Arrays.asList;
import static org.hamcrest.Matchers.contains;
import static org.junit.Assert.*;

@RunWith(SpringRunner.class)
@SpringBootTest
@ActiveProfiles("integrationTest")
public class ImportServiceIntegrationTest {
    @Autowired
    private ImportService importService;
    private static final String BASE_FOLDER= "src/test/resources/eu/europa/empl/skpt/service/export/impl/";

    @Test
    public void importProfileWithCourseSelected() throws Exception {
        Path profileFile = Paths.get(BASE_FOLDER+"profile_course_selected.xml");
        byte[] profileContent = Files.readAllBytes(profileFile);
        Optional<Profile> profileOptional = importService.importProfile("profile_course_selected.xml", profileContent);
        Assert.assertTrue(profileOptional.isPresent());

        Profile profile = profileOptional.get();
        Courses courses = profile.getOutcome().getCourses();
        assertNotNull(courses);
        List<Course> selectedCourses = courses.getSelectedCourses();
        assertNotNull(selectedCourses);

        assertEquals("http://data.europa.eu/lo/course/105", selectedCourses.get(0).getUri());
        assertEquals("http://data.europa.eu/lo/course/116", selectedCourses.get(1).getUri());
        assertEquals("http://data.europa.eu/lo/course/119", selectedCourses.get(2).getUri());

        Recommendations recommendations = profile.getOutcome().getRecommendations();
        List<CourseRecommendation> courseRecommendationList = recommendations.getCourseRecommendations();
        assertEquals(2, courseRecommendationList.size());

        selectedCourses = courseRecommendationList.get(0).getSelectedCourses();
        assertEquals("http://data.europa.eu/lo/course/119", selectedCourses.get(0).getUri());

        selectedCourses = courseRecommendationList.get(1).getSelectedCourses();
        assertEquals("http://data.europa.eu/lo/course/126", selectedCourses.get(0).getUri());
        assertEquals("http://data.europa.eu/lo/course/144", selectedCourses.get(1).getUri());

    }

    @Test
    public void importProfileWithCourseFilters() throws Exception {
        Path profileFile = Paths.get(BASE_FOLDER+"profile_course_filters.xml");
        byte[] profileContent = Files.readAllBytes(profileFile);
        Optional<Profile> profileOptional = importService.importProfile("profile_course_filters.xml", profileContent);

        Assert.assertTrue(profileOptional.isPresent());

        Profile profile = profileOptional.get();
        Courses courses = profile.getOutcome().getCourses();
        assertNotNull(courses);
        Filters filters = courses.getFilters();
        assertNotNull(filters);

        assertEquals("marketing", filters.getText());
        assertEquals("http://data.europa.eu/esco/ConceptScheme/at-topics/digital-skills", filters.getTopic()[0]);
        assertThat(asList(filters.getLanguages()), contains("http://publications.europa.eu/resource/authority/language/ENG",
                "http://publications.europa.eu/resource/authority/language/FRA"));
        assertThat(asList(filters.getSubtitles()), contains("http://publications.europa.eu/resource/authority/language/FRA",
                "http://publications.europa.eu/resource/authority/language/POL"));
        assertEquals("http://data.europa.eu/esco/isced-f/023", filters.getIsceds()[0]);
        assertEquals("https://www.edx.org/", filters.getProvider()[0]);

    }

    @Test
    public void importOldProfile() throws Exception {
        Path oldProfileFile = Paths.get(BASE_FOLDER + "old_profile.xml");
        byte[] profileContent = Files.readAllBytes(oldProfileFile);
        Optional<Profile> profileOptional = importService.importProfile("old_profile.xml", profileContent);

        assertTrue(profileOptional.isPresent());
    }
}
