/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 19/06/2018
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2015 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */
package eu.europa.empl.skpt.service.export.impl;

import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import eu.europa.empl.skpt.service.export.IJsonParserService;
import eu.europa.empl.skpt.service.export.model.ParseJsonResult;
import eu.europa.empl.skpt.service.export.model.profile.Filters;
import eu.europa.empl.skpt.service.export.model.profile.Profile;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.test.context.junit4.SpringRunner;

import java.io.IOException;
import java.util.Optional;

import static org.apache.commons.lang3.StringUtils.isBlank;
import static org.junit.Assert.*;

@RunWith(SpringRunner.class)
@SpringBootTest
@ActiveProfiles("integrationTest")
public class JsonParserServiceTest {

    @Autowired
    private ObjectMapper objectMapper;

    @Autowired
    private IJsonParserService jsonParserService;

    @Test
    public void generateProfileFromJson() throws IOException {
        JsonNode profileJson = objectMapper.readTree(getClass().getResource("skpt-valid-search.json"));

        ParseJsonResult parseJsonResult = jsonParserService.parseJson(profileJson.toString());
        Optional<Profile> profileOptional = parseJsonResult.getProfile();

        Profile profile = profileOptional.get();
        assertNotNull(profile);

        Filters filters = profile.getOutcome().getCourses().getFilters();

        assertArrayEquals(new String[]{"http://data.europa.eu/esco/ConceptScheme/at-ed-level/isced-7"}, filters.getEducationLevel());
        assertArrayEquals(new String[]{"http://data.europa.eu/esco/isced-f/06"}, filters.getIsceds());
        assertArrayEquals(new String[]{"http://publications.europa.eu/resource/authority/language/ENG"}, filters.getLanguages());
        assertArrayEquals(new String[]{"http://online.stanford.edu/"}, filters.getProvider());
        assertEquals(0, filters.getSubtitles().length);
        assertEquals("networking", filters.getText());
        assertArrayEquals(new String[]{"http://data.europa.eu/esco/ConceptScheme/at-topics/digital-skills"}, filters.getTopic());
    }

    @Test
    public void generateXmlWithIncorrectJSON() throws Exception {
        JsonNode profileJson = objectMapper.readTree(getClass().getResource("skpt-invalid.json"));

        ParseJsonResult res = jsonParserService.parseJson(profileJson.toString());
        Optional<Profile> profileOptional = res.getProfile();

        Profile profile = profileOptional.get();
        assertTrue("Consent questions are not answered", profile.getOutcome().getStored() == null);
    }

    @Test
    public void generateXmlWithCorrectJSON() throws Exception {
        JsonNode profileJson = objectMapper.readTree(ExportServiceTest.class.getResource("skpt-valid.json"));
        ParseJsonResult res = jsonParserService.parseJson(profileJson.toString());

        Optional<Profile> profileOptional = res.getProfile();
        assertTrue("Profile is absent", profileOptional.isPresent());

        Profile profile = profileOptional.get();
        assertFalse("The family name is missing", isBlank(profile.getPersonalInfo().getFamilyName()));
        assertFalse("The first name is missing", isBlank(profile.getPersonalInfo().getFirstName()));
        assertFalse("Consent questions are not answered",
                profile.getOutcome().getStatistics() == null
                        || profile.getOutcome().getStored() == null);
    }
}