/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 28/01/2017
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.service.isced.impl;

import eu.europa.empl.skpt.data.domain.IReferenceData;
import eu.europa.empl.skpt.data.domain.isced.IscedFoet;
import eu.europa.empl.skpt.data.repository.isced.IIscedFoetRepository;
import eu.europa.empl.skpt.service.country.impl.CountryService;
import eu.europa.empl.skpt.service.tool.LanguageFilter;
import eu.europa.empl.skpt.tool.IscedFoetGenerator;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.Mock;
import org.mockito.Mockito;
import org.mockito.junit.MockitoJUnitRunner;
import org.springframework.data.domain.*;

import java.util.List;
import java.util.Optional;

import static org.junit.Assert.*;
import static org.mockito.ArgumentMatchers.any;
import static org.mockito.Mockito.eq;
import static org.mockito.Mockito.when;

/**
 * Test class for the {@link CountryService} service.
 *
 * @author ARHS Spikeseed
 */
@RunWith(MockitoJUnitRunner.class)
public class IscedFoetServiceTest {

    @Mock
    private IIscedFoetRepository iscedFoetRepository;
    @Mock
    private LanguageFilter languageFilter;

    private IscedFoetService iscedFoetService;

    private List<IscedFoet> allIscedFoet;
    private List<IscedFoet> allIscedFoetWontainsArtWord;
    private IscedFoet educationIscedFoet;
    private Pageable pageable;

    @Before
    public void setUp() {
        iscedFoetService = new IscedFoetService(
                iscedFoetRepository, languageFilter);

        allIscedFoet = IscedFoetGenerator.generateAllIscedFoetList();
        allIscedFoetWontainsArtWord = IscedFoetGenerator.generateIscedFoetContainsArtWordList();

        educationIscedFoet = allIscedFoet.get(0);

        pageable = PageRequest.of(0, 20, Sort.Direction.ASC, "id");

        when(iscedFoetRepository.findById(0L))
                .thenReturn(Optional.of(educationIscedFoet));

        when(iscedFoetRepository.findAll(pageable))
                .thenReturn(new PageImpl<>(allIscedFoet));

        when(iscedFoetRepository.findByValueIgnoreCase("art", pageable))
                .thenReturn(new PageImpl<>(allIscedFoetWontainsArtWord));

        when(languageFilter.filter(eq(educationIscedFoet), any()))
                .thenReturn(educationIscedFoet);

        Mockito.<Page<? extends IReferenceData>>
                when(languageFilter.filter(new PageImpl<>(allIscedFoet), new String[0]))
                .thenReturn(new PageImpl<>(allIscedFoet));

        Mockito.<Page<? extends IReferenceData>>
                when(languageFilter.filter(new PageImpl<>(allIscedFoetWontainsArtWord), new String[0]))
                .thenReturn(new PageImpl<>(allIscedFoetWontainsArtWord));
    }

    @Test
    public void findById() {
        Optional<IscedFoet> iscedFoet = this.iscedFoetService
                .findById(0L, null);

        assertNotNull(iscedFoet);
        assertTrue(iscedFoet.isPresent());
        assertEquals(educationIscedFoet, iscedFoet.get());
    }

    @Test
    public void findAllWithBlankSearchString() {
        String searchString = null;
        String[] resultLanguages = {};
        List<IscedFoet> iscedFoets = this.iscedFoetService
                .search(searchString, resultLanguages, pageable)
                .getContent();

        assertNotNull(iscedFoets);
        assertEquals(allIscedFoet, iscedFoets);
    }

    @Test
    public void findAllWithNotBlankSearchString() {
        String searchString = "art";
        String[] resultLanguages = {};
        List<IscedFoet> iscedFoets = this.iscedFoetService
                .search(searchString, resultLanguages, pageable)
                .getContent();

        assertNotNull(iscedFoets);
        assertEquals(allIscedFoetWontainsArtWord, iscedFoets);
    }
}
