/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool MOOC Backend
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 17/07/2018
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.service.nace.impl;

import eu.europa.empl.skpt.data.domain.IReferenceData;
import eu.europa.empl.skpt.data.domain.nace.Nace;
import eu.europa.empl.skpt.data.repository.nace.INaceRepository;
import eu.europa.empl.skpt.service.tool.LanguageFilter;
import eu.europa.empl.skpt.tool.NaceGenerator;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.Mock;
import org.mockito.Mockito;
import org.mockito.junit.MockitoJUnitRunner;
import org.springframework.data.domain.*;

import java.util.Arrays;
import java.util.List;
import java.util.Optional;

import static org.junit.Assert.*;
import static org.mockito.ArgumentMatchers.any;
import static org.mockito.Mockito.eq;
import static org.mockito.Mockito.when;

/**
 * NaceServiceTest
 *
 * @author ARHS Spikeseed
 */
@RunWith(MockitoJUnitRunner.class)
public class NaceServiceTest {

    @Mock
    private INaceRepository naceRepository;
    @Mock
    private LanguageFilter languageFilter;

    private NaceService naceService;

    private List<Nace> allNace;
    private Pageable pageable;

    @Before
    public void init() {
        naceService = new NaceService(
                naceRepository, languageFilter);

        allNace = NaceGenerator.generateNaceList();

        pageable = PageRequest.of(0, 20, Sort.Direction.ASC, "id");

        when(naceRepository.findById(0L))
                .thenReturn(Optional.of(allNace.get(0)));

        when(naceRepository.findAll(pageable))
                .thenReturn(new PageImpl<>(allNace));

        when(naceRepository.findByValueIgnoreCase("2 en", pageable))
                .thenReturn(new PageImpl<>(Arrays.asList(allNace.get(2))));

        when(languageFilter.filter(eq(allNace.get(0)), any()))
                .thenReturn(allNace.get(0));

        Mockito.<Page<? extends IReferenceData>>
                when(languageFilter.filter(new PageImpl<>(allNace), new String[0]))
                .thenReturn(new PageImpl<>(allNace));

        Mockito.<Page<? extends IReferenceData>>
                when(languageFilter.filter(new PageImpl<>(Arrays.asList(allNace.get(2))), new String[0]))
                .thenReturn(new PageImpl<>(Arrays.asList(allNace.get(2))));
    }

    @Test
    public void findById() {
        Optional<Nace> nace = this.naceService
                .findById(0L, null);

        assertNotNull(nace);
        assertTrue(nace.isPresent());
        assertEquals(allNace.get(0), nace.get());
    }

    @Test
    public void findAll() {
        String searchString = null;
        String[] resultLanguages = {};
        List<Nace> nacesResult = naceService
                .search(searchString, resultLanguages, pageable)
                .getContent();

        assertNotNull(nacesResult);
        assertEquals(allNace, nacesResult);
    }

    @Test
    public void findAllByValue() {
        String searchString = "2 en";
        String[] resultLanguages = {};
        List<Nace> nacesResult = naceService
                .search(searchString, resultLanguages, pageable)
                .getContent();

        assertNotNull(nacesResult);
        assertEquals(Arrays.asList(allNace.get(2)), nacesResult);
    }

}
