package eu.europa.empl.skpt.service.statistics;

import com.fasterxml.jackson.databind.ObjectMapper;
import eu.europa.empl.skpt.data.domain.stats.ProfileStatistic;
import eu.europa.empl.skpt.service.stats.impl.ProfileStatisticService;
import org.elasticsearch.action.index.IndexRequest;
import org.elasticsearch.action.index.IndexResponse;
import org.elasticsearch.client.RequestOptions;
import org.elasticsearch.client.RestHighLevelClient;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.Mock;
import org.mockito.junit.MockitoJUnitRunner;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Paths;

import static org.junit.Assert.assertEquals;
import static org.mockito.ArgumentMatchers.any;
import static org.mockito.ArgumentMatchers.eq;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

@RunWith(MockitoJUnitRunner.class)
public class ProfileStatisticServiceTest {

    @Mock
    private ObjectMapper objectMapper;
    @Mock
    private RestHighLevelClient restHighLevelClient;

    private ProfileStatisticService profileStatisticService;

    private ProfileStatistic profileStatistic;

    @Before
    public void init() throws IOException {
        profileStatisticService = new ProfileStatisticService(objectMapper, restHighLevelClient);

        profileStatistic = ProfileStatistic.builder().build();

        when(objectMapper.readValue("{theProfile}", ProfileStatistic.class))
                .thenReturn(profileStatistic);

        String profile = new String(
                Files.readAllBytes(
                        Paths.get("./src/test/resources/eu/europa/empl/skpt/service/statistics/profile.json")));
        when(objectMapper.writeValueAsString(any()))
                .thenReturn(profile);

        when(restHighLevelClient.index(any(IndexRequest.class), eq(RequestOptions.DEFAULT)))
                .thenReturn(mock(IndexResponse.class));
    }

    @Test
    public void sendStatistics() {
        ProfileStatistic profile = profileStatisticService.sendStatistics("{theProfile}");

        assertEquals(profileStatistic, profile);
    }

}

