/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool MOOC Backend
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 23/07/2018
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.service.tool;

import eu.europa.empl.skpt.data.domain.language.Language;
import eu.europa.empl.skpt.data.domain.language.LanguageValue;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.InjectMocks;
import org.mockito.junit.MockitoJUnitRunner;
import org.springframework.data.domain.*;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import static org.junit.Assert.assertEquals;

/**
 * LanguageFilterTest
 *
 * @author ARHS Spikeseed
 */
@RunWith(MockitoJUnitRunner.class)
public class LanguageFilterTest {

    @InjectMocks
    private LanguageFilter languageFilter;

    private List<Language> allLanguages;

    @Before
    public void init() {
        allLanguages = generateListAllLanguages();
    }

    private List<Language> generateListAllLanguages() {
        Language afrikaansLanguage = new Language();
        afrikaansLanguage.setIsoCode1("af");
        afrikaansLanguage.setIsoCode2("afr");
        afrikaansLanguage.setIsoCode3("afr");
        Map<String, LanguageValue> afrikaansLanguageValues = new HashMap<>();
        afrikaansLanguageValues.put("en", createLanguageValue("en", "Afrikaans"));
        afrikaansLanguageValues.put("fr", createLanguageValue("fr", "Afrikaans"));
        afrikaansLanguage.setValues(afrikaansLanguageValues);

        Language tibetanLanguage = new Language();
        tibetanLanguage.setIsoCode1("bo");
        tibetanLanguage.setIsoCode2("bod");
        tibetanLanguage.setIsoCode3("bod");
        Map<String, LanguageValue> tibetanLanguageValues = new HashMap<>();
        tibetanLanguageValues.put("en", createLanguageValue("en", "Tibetan"));
        tibetanLanguageValues.put("fr", createLanguageValue("fr", "Tibétain"));
        tibetanLanguage.setValues(tibetanLanguageValues);

        return Arrays.asList(afrikaansLanguage, tibetanLanguage);
    }

    private LanguageValue createLanguageValue(String language, String value) {
        LanguageValue languageValue = new LanguageValue();
        languageValue.setLanguage(language);
        languageValue.setValue(value);
        return languageValue;
    }

    @Test
    public void filter() {
        Pageable pageable = PageRequest.of(0, 20, Sort.Direction.ASC, "id");
        Page<Language> page = new PageImpl<>(allLanguages, pageable, 2);
        languageFilter.filter(page, new String[]{"en"});

        assertEquals(2, page.getContent().size());
        for (Language language : page.getContent()) {
            assertEquals(1, language.getValues().size());
            for(Map.Entry<String, LanguageValue> entry : language.getValues().entrySet()) {
                assertEquals("en", entry.getKey());
            }

        }
    }

}
