/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool MOOC Backend
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 24/07/2018
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.tool;

import eu.europa.empl.skpt.data.domain.country.Country;
import eu.europa.empl.skpt.data.domain.country.CountryValue;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * CountryGenerator
 *
 * @author ARHS Spikeseed
 */
public class CountryGenerator {

    public static List<Country> generateAllCountryList() {
        Country luxembourgCountry = createCountry(
                "LUX", createCountryValue("en", "Luxembourg"), createCountryValue("fr", "Luxembourg"));

        Country macaoCountry = createCountry(
                "MAC", createCountryValue("en", "Macao"), createCountryValue("fr", "Macao"));

        Country laoCountry = createCountry(
                "LAO", createCountryValue("en", "Lao People's Democratic Republic (the)"), createCountryValue("fr", "Lao, République démocratique populaire"));

        return Arrays.asList(luxembourgCountry, macaoCountry, laoCountry);
    }

    public static List<Country> generateAllCountryContainsLuxWordList() {
        Country luxembourgCountry = createCountry(
                "LUX", createCountryValue("en", "Luxembourg"), createCountryValue("fr", "Luxembourg"));

        return Arrays.asList(luxembourgCountry);
    }

    private static Country createCountry(String alphaCode3, CountryValue countryValueEn, CountryValue countryValueFr) {
        Country country = new Country();
        country.setAlphaCode3(alphaCode3);

        Map<String, CountryValue> languageValues = new HashMap<>();
        if (countryValueEn != null) {
            languageValues.put("en", countryValueEn);
        }
        if (countryValueFr != null) {
            languageValues.put("fr", countryValueFr);
        }
        country.setValues(languageValues);

        return country;
    }

    private static CountryValue createCountryValue(String language, String value) {
        CountryValue countryValue = new CountryValue();
        countryValue.setLanguage(language);
        countryValue.setValue(value);
        return countryValue;
    }

}
