/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool MOOC Backend
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 24/07/2018
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.tool;

import eu.europa.empl.skpt.data.domain.esco.EscoClassification;
import eu.europa.empl.skpt.data.domain.esco.EscoLocalConcept;
import eu.europa.empl.skpt.data.domain.esco.EscoValue;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * EscoGenerator
 *
 * @author ARHS Spikeseed
 */
public class EscoGenerator {

    public static List<EscoLocalConcept> generateAllEscoList() {
        EscoLocalConcept aquacultureEsco = createEsco(
                "0", EscoClassification.OCCUPATIONS, createEscoValue("en", "Aquaculture workers"), createEscoValue("fr", "Travailleurs de l'aquaculture"));

        EscoLocalConcept healthEsco = createEsco(
                "1", EscoClassification.OCCUPATIONS, createEscoValue("en", "Health services managers"), createEscoValue("fr", "Gestionnaires des services de santé"));

        EscoLocalConcept economistEsco = createEsco(
                "2", EscoClassification.OCCUPATIONS, createEscoValue("en", "Economists"), createEscoValue("fr", "Économistes"));

        EscoLocalConcept printerEsco = createEsco(
                "3", EscoClassification.OCCUPATIONS, null, createEscoValue("fr", "Imprimeur"));

        EscoLocalConcept skillEsco = createEsco(
                "4", EscoClassification.SKILLS, createEscoValue("en", "Skills"), createEscoValue("fr", "Compétence"));

        return Arrays.asList(aquacultureEsco, healthEsco, economistEsco, printerEsco, skillEsco);
    }

    public static List<EscoLocalConcept> generateAllEscoOccupationsList() {
        EscoLocalConcept aquacultureEsco = createEsco(
                "0", EscoClassification.OCCUPATIONS, createEscoValue("en", "Aquaculture workers"), createEscoValue("fr", "Travailleurs de l'aquaculture"));

        EscoLocalConcept healthEsco = createEsco(
                "1", EscoClassification.OCCUPATIONS, createEscoValue("en", "Health services managers"), createEscoValue("fr", "Gestionnaires des services de santé"));

        EscoLocalConcept economistEsco = createEsco(
                "2", EscoClassification.OCCUPATIONS, createEscoValue("en", "Economists"), createEscoValue("fr", "Économistes"));

        EscoLocalConcept printerEsco = createEsco(
                "3", EscoClassification.OCCUPATIONS, null, createEscoValue("fr", "Imprimeur"));

        return Arrays.asList(aquacultureEsco, healthEsco, economistEsco, printerEsco);
    }

    public static List<EscoLocalConcept> generateAllEscoContainsWorkersWordList() {
        EscoLocalConcept aquacultureEsco = createEsco(
                "0", EscoClassification.OCCUPATIONS, createEscoValue("en", "Aquaculture workers"), createEscoValue("fr", "Travailleurs de l'aquaculture"));

        return Arrays.asList(aquacultureEsco);
    }

    private static EscoLocalConcept createEsco(String id, EscoClassification classification, EscoValue escoValueEn, EscoValue escoValueFr) {
        EscoLocalConcept esco = new EscoLocalConcept();
        esco.setEscoId(id);
        esco.setClassification(classification);

        Map<String, EscoValue> values = new HashMap<>();
        if (escoValueEn != null) {
            values.put("en", escoValueEn);
        }
        if (escoValueFr != null) {
            values.put("fr", escoValueFr);
        }
        esco.setValues(values);

        return esco;
    }

    private static EscoValue createEscoValue(String language, String sentence) {
        EscoValue escoValue = new EscoValue();
        escoValue.setLanguage(language);
        escoValue.setValue(sentence);
        return escoValue;
    }

}
