/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool MOOC Backend
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 24/07/2018
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.tool;

import eu.europa.empl.skpt.data.domain.isced.IscedFoet;
import eu.europa.empl.skpt.data.domain.isced.IscedFoetValue;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * IscedGenerator
 *
 * @author ARHS Spikeseed
 */
public class IscedFoetGenerator {

    public static List<IscedFoet> generateAllIscedFoetList() {
        IscedFoet educationIscedFoet = createIscedFoet(
                0L, createIscedFoetValue("en", "Education"), createIscedFoetValue("fr", "Education"));

        IscedFoet artIscedFoet = createIscedFoet(
                1L, createIscedFoetValue("en", "Arts"), createIscedFoetValue("fr", "Arts"));

        return Arrays.asList(educationIscedFoet, artIscedFoet);
    }

    public static List<IscedFoet> generateIscedFoetContainsArtWordList() {
        IscedFoet artIscedFoet = createIscedFoet(
                1L, createIscedFoetValue("en", "Arts"), createIscedFoetValue("fr", "Arts"));

        return Arrays.asList(artIscedFoet);
    }

    private static IscedFoet createIscedFoet(Long id, IscedFoetValue iscedFoetValueEn, IscedFoetValue iscedFoetValueFr) {
        IscedFoet iscedFoet = new IscedFoet();
        iscedFoet.setId(id);

        Map<String, IscedFoetValue> values = new HashMap<>();
        if (iscedFoetValueEn != null) {
            values.put("en", iscedFoetValueEn);
        }
        if (iscedFoetValueFr != null) {
            values.put("fr", iscedFoetValueFr);
        }
        iscedFoet.setValues(values);

        return iscedFoet;
    }

    private static IscedFoetValue createIscedFoetValue(String language, String sentence) {
        IscedFoetValue iscedFoetValue = new IscedFoetValue();
        iscedFoetValue.setLanguage(language);
        iscedFoetValue.setValue(sentence);
        return iscedFoetValue;
    }

}
