/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool MOOC Backend
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 24/07/2018
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.tool;

import eu.europa.empl.skpt.data.domain.country.Country;
import eu.europa.empl.skpt.data.domain.country.CountryValue;
import eu.europa.empl.skpt.data.domain.label.Label;
import eu.europa.empl.skpt.data.domain.label.LabelValue;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * LabelGenerator
 *
 * @author ARHS Spikeseed
 */
public class LabelGenerator {

    public static List<Label> generateAllLabelList() {
        Label label1 = createLabel(
                1L, "common.yes", createLabelValue(1L, "fr", "Oui"), createLabelValue(2L, "en", "Yes"));

        Label label2 = createLabel(
                2L, "common.no", createLabelValue(3L, "fr", "Non"), createLabelValue(4L, "en", "No"));

        Label label3 = createLabel(
                3L, "common.nested.deep.apple", createLabelValue(5L, "fr", "Pomme"), createLabelValue(6L, "en", "Apple"));

        Label label4 = createLabel(
                4L, "common.nested.deep.pineapple", createLabelValue(7L, "fr", "Ananas"), createLabelValue(8L, "en", "Pineapple"));

        Label labelNullValue = createLabel(
                5L, "common.nullValueFr", createLabelValue(9L, "fr", "nullValue"), createLabelValue(10L, "en", "nullValue"));
        labelNullValue.getValues().put("fr", null);

        Label labelNullKey = createLabel(
                6L, null, createLabelValue(9L, "fr", "nullKey"), createLabelValue(10L, "en", "nullKey"));


        return Arrays.asList(label1, label2, label3, label4, labelNullValue, labelNullKey);
    }

    public static List<Label> generateLabelListWithPathProblem() {
        Label label1 = createLabel(
                1L, "common.yes", createLabelValue(1L, "fr", "Oui"), createLabelValue(2L, "en", "Yes"));

        Label label2 = createLabel(
                2L, "common", createLabelValue(1L, "fr", "Commun"), createLabelValue(2L, "en", "Common"));

        return Arrays.asList(label1, label2);
    }

    private static Label createLabel(Long id, String key, LabelValue... labelValue) {
        Label label = new Label();
        label.setId(id);
        label.setKey(key);

        Map<String, LabelValue> values = new HashMap<>();
        for (int i = 0; i < labelValue.length; i++) {
            LabelValue value = labelValue[i];
            value.setLabel(label);
            values.put(value.getLanguage(), value);
        }
        label.setValues(values);

        return label;
    }

    private static LabelValue createLabelValue(Long id, String lang, String translation) {
        LabelValue labelValue = new LabelValue();
        labelValue.setId(id);
        labelValue.setLanguage(lang);
        labelValue.setTranslation(translation);
        return labelValue;
    }

}
