/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool MOOC Backend
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 24/07/2018
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.tool;

import eu.europa.empl.skpt.data.domain.language.Language;
import eu.europa.empl.skpt.data.domain.language.LanguageValue;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * LanguageGenerator
 *
 * @author ARHS Spikeseed
 */
public class LanguageGenerator {

    public static List<Language> generateAllLanguagesList() {
        Language afrikaansLanguage = createLanguage(
                "af", "afr", "afr", createLanguageValue("en", "Afrikaans"), createLanguageValue("fr", "Afrikaans"));

        Language tibetanLanguage = createLanguage(
                "bo", "bod", "bod", createLanguageValue("en", "Tibetan"), createLanguageValue("fr", "Tibétain"));

        Language frenchLanguage = createLanguage(
                "fr", "fra", "fra", createLanguageValue("en", "French"), createLanguageValue("fr", "Français"));

        return Arrays.asList(afrikaansLanguage, tibetanLanguage, frenchLanguage);
    }

    public static List<Language> generateAllLanguagesInEnglishList() {
        Language afrikaansLanguageInEnglish = createLanguage(
                "af", "afr", "afr", createLanguageValue("en", "Afrikaans"), null);

        Language tibetanLanguageInEnglish = createLanguage(
                "bo", "bod", "bod", createLanguageValue("en", "Tibetan"), null);

        Language frenchLanguage = createLanguage(
                "fr", "fra", "fra", createLanguageValue("en", "French"), null);

        return Arrays.asList(afrikaansLanguageInEnglish, tibetanLanguageInEnglish, frenchLanguage);
    }

    private static Language createLanguage(String code1, String code2, String code3, LanguageValue languageValueEn, LanguageValue languageValueFr) {
        Language language = new Language();

        language.setIsoCode1(code1);
        language.setIsoCode2(code2);
        language.setIsoCode3(code3);
        Map<String, LanguageValue> languageValues = new HashMap<>();
        if (languageValueEn != null) {
            languageValues.put("en", languageValueEn);
        }
        if (languageValueFr != null) {
            languageValues.put("fr", languageValueFr);
        }
        language.setValues(languageValues);

        return language;
    }

    private static LanguageValue createLanguageValue(String language, String value) {
        LanguageValue languageValue = new LanguageValue();
        languageValue.setLanguage(language);
        languageValue.setValue(value);
        return languageValue;
    }

}
