/* ----------------------------------------------------------------------------
 *     PROJECT : Skills Profile Tool MOOC Backend
 *
 *  CREATED BY : ARHS Spikeseed
 *          ON : 24/07/2018
 *
 * ----------------------------------------------------------------------------
 * Copyright (c) 2016 European Commission – DG Employment, Social Affairs & Inclusion
 * ----------------------------------------------------------------------------
 */

package eu.europa.empl.skpt.tool;

import eu.europa.empl.skpt.data.domain.nace.Nace;
import eu.europa.empl.skpt.data.domain.nace.NaceValue;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * NaceGenerator
 *
 * @author ARHS Spikeseed
 */
public class NaceGenerator {

    public static List<Nace> generateNaceList() {
        List<Nace> naces = new ArrayList<>();

        for (int i = 0; i < 5; i++) {
            naces.add(
                    NaceGenerator.createNace(
                            String.valueOf(i),
                            new String[]{"en", "fr", "de"},
                            NaceGenerator.createNaceValue("en", "Sentence " + i + " in English"),
                            NaceGenerator.createNaceValue("fr", "Phrase " + i + " en anglais"),
                            NaceGenerator.createNaceValue("de", "Satz " + i + " auf Englisch")));
        }

        return naces;
    }

    private static Nace createNace(String key, String[] languages, NaceValue... naceValues) {
        Nace nace = new Nace();
        nace.setKey(key);

        Map<String, NaceValue> values = new HashMap<>();
        for (int i = 0; i < languages.length && i < naceValues.length; i++) {
            naceValues[i].setNace(nace);
            values.put(languages[i], naceValues[i]);
        }
        nace.setValues(values);

        return nace;
    }

    private static NaceValue createNaceValue(String language, String sentence) {
        NaceValue naceValue = new NaceValue();
        naceValue.setLanguage(language);
        naceValue.setValue(sentence);
        return naceValue;
    }

}
