import {ConfigurationPage} from '../pages/configuration.po';
import {HeaderPage} from '../pages/header.po';
import {HomePage} from '../pages/home.po';
import {PersonalInfoContactPage} from '../pages/personal-info.contact.po';
import {PersonalInfoGeneralPage} from '../pages/personal-info.general.po';
import {browser} from 'protractor';
import {EclFooterPage} from '../pages/ecl-footer.po';
import {summary} from '../../src/app/component/profile/summary/summary.component';
import {SummaryPage} from '../pages/summary/summary.po';
import {OutcomeIssuingOrganisationPage} from '../pages/outcome.issuing-organisation.po';

describe('A user on the configuration page', function() {
  let headerPage: HeaderPage;
  let homePage: HomePage;
  let configurationPage: ConfigurationPage;
  let personalInfoContactPage: PersonalInfoContactPage;
  let personalInfoGeneralPage: PersonalInfoGeneralPage;
  let outcomeIssuingOrganisationPage: OutcomeIssuingOrganisationPage;
  let summaryPage: SummaryPage;
  let eclFooterPage: EclFooterPage;

  // SECTION NAME                             SWITCH ID                         MENU ID                     IS MANDATORY    IS MAIN MENU    MENU TO IGNORE
  let sections = [
    ['Personal information',                          'personalInfo-switch',            'personal-info',            'true',         'true',         'true',       'step.personal'],
    ['General information',                           'generalInfo-switch',             'general',                  'true',         'false',        'false',      'step.personal'],
    ['Contact information',                           'contactInfo-switch',             'contact',                  'false',        'false',        'false',      'step.personal'],
    ['Migration information',                         'migrationInfo-switch',           'migration',                'false',        'false',        'false',      'step.personal'],
    ['Expectations',                                  'expectations-switch',            'expectations',             'false',        'true',         'false',      'step.expectations'],
    ['Skills identification',                         'skillsIdentification-switch',    'skills-identification',    'false',        'true',         'true',       'step.skills'],
    ['Language',                                      'language-switch',                'languages',                'false',        'false',        'false',      'step.skills'],
    ['Education and Training',                        'educationAndTraining-switch',    'education-and-training',   'false',        'false',        'false',      'step.skills'],
    ['Literacy Skills',                               'literacySkills-switch',          'literacy',                 'false',        'false',        'false',      'step.skills'],
    ['Numeracy Skills',                               'numeracySkills-switch',          'numeracy',                 'false',        'false',        'false',      'step.skills'],
    ['Digital skills',                                'digitalSkills-switch',           'digital',                  'false',        'false',        'false',      'step.skills'],
    ['Professional skills',                           'professionalSkills-switch',      'professional',             'false',        'false',        'false',      'step.skills'],
    ['Skills acquired outside the workplace',         'outsideSkills-switch',           'acquired-outside',         'false',        'false',        'false',      'step.skills'],
    ['Other basic and transversal skills',            'otherTransversalSkills-switch',  'other-basic-transversal',  'false',        'false',        'false',      'step.skills'],
    ['Driving Skills',                                'drivingSkills-switch',           'driving',                  'false',        'false',        'false',      'step.skills'],
    ['Overall appraisal and recommended next steps',  'outcome-switch',                 'outcome',                  'false',        'true',         'true',       'step.outcome'],
    ['Strengths',                                     'strengths-switch',               'key-skills',               'false',        'false',        'false',      'step.outcome'],
    ['Recognition',                                   'recognition-switch',             'recognition',              'false',        'false',        'false',      'step.outcome'],
    ['Validation',                                    'validationSection-switch',       'validation',               'false',        'false',        'false',      'step.outcome'],
    ['Training',                                      'training-switch',                'education-or-training',    'false',        'false',        'false',      'step.outcome'],
    ['Work',                                          'work-switch',                    'employment-business',      'false',        'false',        'false',      'step.outcome'],
    ['Guidance',                                      'guidance-switch',                'further-information',      'false',        'false',        'false',      'step.outcome'],
    ['Organisation',                                  'organisation-switch',            'issuing-organisation',     'false',        'false',        'false',      'step.outcome'],
    ['Courses',                                       'courses-switch',                 'mooc-search',              'false',        'false',        'false',      'step.outcome'],
    ['Recommendations',                               'recommendation-switch',          'mooc-recommended',         'false',        'false',        'false',      'step.outcome'],
    ['Summary',                                       'summary-switch',                 'summary',                  'false',        'true',         'false',      'step.summary']
  ];

  beforeAll(() => {
    headerPage = new HeaderPage();
    homePage = new HomePage();
    configurationPage = new ConfigurationPage();
    personalInfoContactPage = new PersonalInfoContactPage();
    personalInfoGeneralPage = new PersonalInfoGeneralPage();
    outcomeIssuingOrganisationPage = new OutcomeIssuingOrganisationPage();
    summaryPage = new SummaryPage();
    eclFooterPage = new EclFooterPage();

    configurationPage.navigateTo();
  });

  describe('must not be able to go on a hidden section', () => {

    let sectionsToHide = [
      [
        {sectionName : 'personal-info', isHidden: false}, {sectionName : 'general', isHidden: false}, {sectionName : 'contact', isHidden: false}, {sectionName : 'migration', isHidden: false},
        {sectionName : 'expectations', isHidden: false},
        {sectionName : 'skills-identification', isHidden: true}, {sectionName : 'languages', isHidden: true}, {sectionName : 'education-and-training', isHidden: true}, {sectionName : 'literacy', isHidden: true}, {sectionName : 'numeracy', isHidden: true}, {sectionName : 'digital', isHidden: true}, {sectionName : 'professional', isHidden: true}, {sectionName : 'acquired-outside', isHidden: true}, {sectionName : 'other-basic-transversal', isHidden: true}, {sectionName : 'driving', isHidden: true},
        {sectionName : 'outcome', isHidden: false}, {sectionName : 'key-skills', isHidden: false}, {sectionName : 'recognition', isHidden: false}, {sectionName : 'validation', isHidden: false}, {sectionName : 'education-or-training', isHidden: false}, {sectionName : 'employment-business', isHidden: false}, {sectionName : 'further-information', isHidden: false}, {sectionName : 'issuing-organisation', isHidden: false}, {sectionName : 'mooc-search', isHidden: false}, {sectionName : 'mooc-recommended', isHidden: false},
        {sectionName : 'summary', isHidden: true}
      ],
      [
        {sectionName : 'personal-info', isHidden: false}, {sectionName : 'general', isHidden: false}, {sectionName : 'contact', isHidden: true}, {sectionName : 'migration', isHidden: false},
        {sectionName : 'expectations', isHidden: true},
        {sectionName : 'skills-identification', isHidden: false}, {sectionName : 'languages', isHidden: false}, {sectionName : 'education-and-training', isHidden: true}, {sectionName : 'literacy', isHidden: false}, {sectionName : 'numeracy', isHidden: true}, {sectionName : 'digital', isHidden: true}, {sectionName : 'professional', isHidden: false}, {sectionName : 'acquired-outside', isHidden: false}, {sectionName : 'other-basic-transversal', isHidden: true}, {sectionName : 'driving', isHidden: true},
        {sectionName : 'outcome', isHidden: false}, {sectionName : 'key-skills', isHidden: true}, {sectionName : 'recognition', isHidden: true}, {sectionName : 'validation', isHidden: true}, {sectionName : 'education-or-training', isHidden: false}, {sectionName : 'employment-business', isHidden: false}, {sectionName : 'further-information', isHidden: false}, {sectionName : 'issuing-organisation', isHidden: false}, {sectionName : 'mooc-search', isHidden: false}, {sectionName : 'mooc-recommended', isHidden: false},
        {sectionName : 'summary', isHidden: false}
      ]
    ];

    afterEach(() => {
      configurationPage.navigateTo();
    });

    sectionsToHide.forEach((hidingArray, index) => {
      it('with the next button on the header action bar. (' + (index + 1) + ')', () => {
        let array = hideSections(hidingArray);

        // go to the first available page
        headerPage.getPersonalInformationButton().click();

        // check the sections
        checkSections(array, headerPage.getNextButton());

        expect(headerPage.isNextButtonPresent())
          .toBe(false,
            'The Next button need to be hidden.');
      });
    });

    sectionsToHide.forEach((hidingArray, index) => {
      it('with the next button on the footer. (' + (index + 1) + ')', () => {
        let array = hideSections(hidingArray);

        // go to the first available page
        headerPage.getPersonalInformationButton().click();

        // check the sections
        checkSections(array, eclFooterPage.getNextButton());

        expect(eclFooterPage.isNextButtonPresent())
          .toBe(false,
            'The Next button need to be hidden.');
      });
    });

    sectionsToHide.forEach((hidingArray, index) => {
      it('with the previous button on the header action bar. (' + (index + 1) + ')', () => {
        let array = hideSections(hidingArray).reverse();

        // go to the first available page
        // [sectionName, switchId, menuId, isMandatory, isMainMenu, menuToIgnore, isHidden]
        let i = 0;
        while (i !== array.length && array[i][6] !== 'false') {
          i++;
        }
        if (i < array.length) {
          goToSection(array[i][2] as string);
          goToSubSection(array[i][2] as string);

          // check the sections
          checkSections(array, headerPage.getPreviousButton());

          expect(headerPage.isPreviousButtonPresent())
            .toBe(false,
              'The Next button need to be hidden.');
        }
      });
    });

    sectionsToHide.forEach((hidingArray, index) => {
      it('with the previous button on the footer. (' + (index + 1) + ')', () => {
        let array = hideSections(hidingArray).reverse();

        // go to the first available page
        // [sectionName, switchId, menuId, isMandatory, isMainMenu, menuToIgnore, isHidden]
        let i = 0;
        while (i !== array.length && array[i][6] !== 'false') {
          i++;
        }
        if (i < array.length) {
          goToSection(array[i][2] as string);
          goToSubSection(array[i][2] as string);

          // check the sections
          checkSections(array, eclFooterPage.getPreviousButton());

          expect(eclFooterPage.isPreviousButtonPresent())
            .toBe(false,
              'The Next button need to be hidden.');
        }
      });
    });

    function hideSections(hidingArray): Array<Array<String>> {
      let sectionsToTests = [];

      let ignoreUntilNextMainMenu = false;
      for (let i = 0; i < sections.length; i++) {
        let [sectionName, switchId, menuId, isMandatory, isMainMenu, menuToIgnore, parentMenu] = sections[i];

        if (ignoreUntilNextMainMenu && isMainMenu === 'true') {
          ignoreUntilNextMainMenu = false;
        }

        let hide = hidingArray[i].isHidden;
        if (!ignoreUntilNextMainMenu && hide) {
          // hide the section
          configurationPage.getMenu(parentMenu).click();
          configurationPage.getToggleButton(switchId).click();

          if (isMainMenu === 'true') {
            ignoreUntilNextMainMenu = true;
          }
        }

        sectionsToTests.push([sectionName, switchId, menuId, isMandatory, isMainMenu, menuToIgnore].concat(hide + '').concat(parentMenu));
      }

      return sectionsToTests;
    }

    function checkSections(array, button) {
      array.forEach(([sectionName, switchId, menuId, isMandatory, isMainMenu, menuToIgnore, isHidden, parentMenu]) => {
        if (menuToIgnore === 'false') {
          browser.getCurrentUrl().then(function (currentUrl: string) {
            expect(currentUrl.indexOf(menuId as string) > 0)
              .toBe(isHidden === 'false',
                'Problem on the section "' + menuId + '". Current url : ' + currentUrl);

            if (isHidden === 'false' && menuToIgnore === 'false' && hasNextSection(sectionName, array)) {
              button.click();
            }
          });
        }
      });
    }

    function hasNextSection(currentSectionName, array) {
      let currentSectionFound = false;
      for (let i = 0; i < array.length; i++) {
        // [sectionName, switchId, menuId, isMandatory, isMainMenu, menuToIgnore, isHidden]
        if (currentSectionFound && array[i][5] === 'false' && array[i][6] === 'false') {
          return true;
        }
        if (currentSectionName === array[i][0]) {
          currentSectionFound = true;
        }
      }
      return false;
    }

  });


  sections.forEach(([sectionName, switchId, menuId, isMandatory, isMainMenu, menuToIgnore, parentMenu]) => {
    it('must be able to enable and disable the sections ' + sectionName, () => {

      // check if the section is displayed
      checkSection(menuId, true, isMandatory, isMainMenu, 'The menu of id "' + menuId + '" is not displayed. (1)');

      // hide it
      configurationPage.getMenu(parentMenu).click();
      configurationPage.getToggleButton(switchId).click();

      // check if the section is not displayed
      checkSection(menuId, isMandatory === 'true', isMandatory, isMainMenu, 'The menu of id "' + menuId + '" id displayed.');

      // unhide it
      configurationPage.getMenu(parentMenu).click();
      configurationPage.getToggleButton(switchId).click();

      // check if the section is displayed
      checkSection(menuId, true, isMandatory, isMainMenu, 'The menu of id "' + menuId + '" is not displayed. (2)');
    });
  });

  sections.filter(section => section[0] !== 'Courses' && section[0] !== 'Recommendations' && section[0] !== 'Summary' && section[0] !== 'Organisation')
    .forEach(([sectionName, switchId, menuId, isMandatory, isMainMenu, menuToIgnore, parentMenu]) => {
      it('must be able to remove and add the section ' + sectionName + ' in the summary', () => {
        // check if the section is displayed
        checkSectionInSummary(sectionName, true);

        // hide it
        configurationPage.getMenu(parentMenu).click();
        configurationPage.getToggleButton(switchId).click();

        // check if the section is not displayed
        checkSectionInSummary(sectionName, isMandatory === 'true');

        // unhide it
        configurationPage.getMenu(parentMenu).click();
        configurationPage.getToggleButton(switchId).click();

        // check if the section is displayed
        checkSectionInSummary(sectionName, true);
      });
    });

  /**
   * Test used only for the section Organisation of the summary
   */
  sections.filter(section => section[0] === 'Organisation')
    .forEach(([sectionName, switchId, menuId, isMandatory, isMainMenu, menuToIgnore, parentMenu]) => {
      it('must be able to remove and add the section ' + sectionName + ' in the summary', () => {
        // add an organisation
        goToSection('outcome');
        goToSubSection('issuing-organisation');
        outcomeIssuingOrganisationPage.getPlaceOfIssuanceInput().sendKeys('Place of issuance');

        // check if the section is displayed
        checkSectionInSummary(sectionName, true);

        // hide it
        configurationPage.getMenu(parentMenu).click();
        configurationPage.getToggleButton(switchId).click();

        // check if the section is not displayed
        checkSectionInSummary(sectionName, isMandatory === 'true');

        // unhide it
        configurationPage.getMenu(parentMenu).click();
        configurationPage.getToggleButton(switchId).click();

        // check if the section is displayed
        checkSectionInSummary(sectionName, true);
      });
    });

  function checkSectionInSummary(sectionName: string, isDisplayed: boolean) {
    goToSection('summary');
    if (isDisplayed) {
      expect(summaryPage.getAllSectionTitle().getText()).toContain(sectionName);
    } else {
      expect(summaryPage.getAllSectionTitle().getText()).not.toContain(sectionName);
    }
    headerPage.getConfigurationButton().click();
  }

  function checkSection(menuId: string, isDisplayed: boolean, isMandatory: string, isMainMenu: string, errorMessage: string) {
    if (isMainMenu === 'false') {
      goToSection(menuId);
    }
    expect(headerPage.isPresent(menuId)).toBe(isDisplayed, errorMessage);
    headerPage.getConfigurationButton().click();
  }

  function goToSection(section: string) {
    switch (section) {
      case 'personal-info':
      case 'general':
      case 'contact':
      case 'migration':
        headerPage.getPersonalInformationButton().click();
        break;
      case 'expectations':
        headerPage.getExpectationsButton().click();
        break;
      case 'skills-identification':
      case 'languages':
      case 'education-and-training':
      case 'literacy':
      case 'numeracy':
      case 'digital':
      case 'professional':
      case 'acquired-outside':
      case 'other-basic-transversal':
      case 'driving':
        headerPage.getSkillsIdentificationButton().click();
        break;
      case 'outcome':
      case 'key-skills':
      case 'recognition':
      case 'validation':
      case 'education-or-training':
      case 'employment-business':
      case 'further-information':
      case 'issuing-organisation':
      case 'mooc-search':
      case 'mooc-recommended':
        headerPage.getOutcomeButton().click();
        break;
      case 'summary':
        headerPage.getSummaryButton().click();
        break;
    }
  }

  function goToSubSection(subSection: string) {
    switch (subSection) {
      case 'general':
        headerPage.getGeneralInformationTabButton().click();
        break;
      case 'contact':
        headerPage.getContactInformationTabButton().click();
        break;
      case 'migration':
        headerPage.getMigrationTabButton().click();
        break;
      case 'languages':
        headerPage.getLanguagesTabButton().click();
        break;
      case 'education-and-training':
        headerPage.getEducationAndTrainingTabButton().click();
        break;
      case 'literacy':
        headerPage.getLiteracySkillsTabButton().click();
        break;
      case 'numeracy':
        headerPage.getNumeracySkillsTabButton().click();
        break;
      case 'digital':
        headerPage.getDigitalSkillsTabButton().click();
        break;
      case 'professional':
        headerPage.getProfessionalSkillsTabButton().click();
        break;
      case 'acquired-outside':
        headerPage.getSkillsAcquiredOutsideTabButton().click();
        break;
      case 'other-basic-transversal':
        headerPage.getOtherBasicAndTransversalSkillsTabButton().click();
        break;
      case 'driving':
        headerPage.getDrivingSkillsTabButton().click();
        break;
      case 'key-skills':
        headerPage.getStrengthsTabButton().click();
        break;
      case 'recognition':
        headerPage.getRecognitionTabButton().click();
        break;
      case 'validation':
        headerPage.getValidationTabButton().click();
        break;
      case 'education-or-training':
        headerPage.getTrainingTabButton().click();
        break;
      case 'employment-business':
        headerPage.getWorkTabButton().click();
        break;
      case 'further-information':
        headerPage.getGuidanceTabButton().click();
        break;
      case 'issuing-organisation':
        headerPage.getOrganisationTabButton().click();
        break;
      case 'mooc-search':
        headerPage.getCoursesTabButton().click();
        break;
      case 'mooc-recommended':
        headerPage.getRecommendationsTabButton().click();
        break;
    }
  }

});
