import {ConfigurationPage} from '../pages/configuration.po';
import {HeaderPage} from '../pages/header.po';

describe('Configure images in Other basic and transversal skills', function () {
  let headerPage: HeaderPage;
  let configurationPage: ConfigurationPage;

  let questions = {
    'Other basic and transversal skills': {
      'profile.skills_id.other_basic_transversal_skills.work_independently.label': {
        elementId: 'other-transversal-work-independently'
      },
      'profile.skills_id.other_basic_transversal_skills.make_decisions_independently.label': {
        elementId: 'other-transversal-make-decision-independently'
      },
      'profile.skills_id.other_basic_transversal_skills.work_in_structured_way.label': {
        elementId: 'other-transversal-work-structured-way'
      },
      'profile.skills_id.other_basic_transversal_skills.solve_problems.label': {
        elementId: 'other-transversal-solve-problems'
      },
      'profile.skills_id.other_basic_transversal_skills.work_with_others.label': {
        elementId: 'other-transversal-work-with-others'
      },
      'profile.skills_id.other_basic_transversal_skills.work_with_people.label': {
        elementId: 'other-transversal-work-with-people'
      },
      'profile.skills_id.other_basic_transversal_skills.work_with_customers.label': {
        elementId: 'other-transversal-work-with-customers'
      },
      'profile.skills_id.other_basic_transversal_skills.work_as_leader.label': {
        elementId: 'other-transversal-work-as-leader'
      },
      'profile.skills_id.other_basic_transversal_skills.manage_project.label': {
        elementId: 'other-transversal-manage-projects'
      },
      'profile.skills_id.other_basic_transversal_skills.work_in_stressful_conditions.label': {
        elementId: 'work-stressful-conditions'
      },
      'profile.skills_id.other_basic_transversal_skills.develop_ideas.label': {
        elementId: 'develop-new-ideas'
      },
      'profile.skills_id.other_basic_transversal_skills.inspire_enthuse_others.label': {
        elementId: 'inspire-enthuse-others'
      },
      'profile.skills_id.other_basic_transversal_skills.take_responsability.label': {
        elementId: 'take-responsibility'
      },
    }
  };
  beforeAll(() => {
    headerPage = new HeaderPage();
    configurationPage = new ConfigurationPage();
    configurationPage.navigateTo();
  });


  Object.keys(questions['Other basic and transversal skills']).forEach(questionLabelKey => {

    it('must be able to remove and add the image for ' + questionLabelKey + ' from section Other basic and transversal skills', () => {
      let questionId = questions['Other basic and transversal skills'][questionLabelKey].elementId;
      let parentMenu = 'step.skills';
      let imageId = questionId + '-img';

      let imageSwitchId = 'otherTransversalSkills_'.concat(questionLabelKey, 'image-switch');

      checkImage('other-basic-transversal', true, 'The image with id "' + imageId + '" is not displayed. (1)', imageId);

      // // hide it
      configurationPage.getMenu(parentMenu).click();
      configurationPage.getToggleButton(imageSwitchId).click();

      // check if the section is not displayed
      checkImage('other-basic-transversal', false, 'The image with id "' + imageId + '" id displayed.', imageId);

      // // unhide it
      configurationPage.getMenu(parentMenu).click();
      configurationPage.getToggleButton(imageSwitchId).click();

      // check if the section is displayed
      checkImage('other-basic-transversal', true, 'The image with id "' + imageId + '" is not displayed. (2)', imageId);
    });
  });

  function checkImage(menuId: string, isDisplayed: boolean, errorMessage: string, imageId: string) {
    headerPage.getSkillsIdentificationButton().click();
    headerPage.getOtherBasicAndTransversalSkillsTabButton().click();

    expect(headerPage.isPresent(imageId)).toBe(isDisplayed, errorMessage);
    headerPage.getConfigurationButton().click();
  }
});
