import {ConfigurationPage} from '../pages/configuration.po';
import {HeaderPage} from '../pages/header.po';
import {HomePage} from '../pages/home.po';
import {PersonalInfoContactPage} from '../pages/personal-info.contact.po';
import {PersonalInfoGeneralPage} from '../pages/personal-info.general.po';
import {EclFooterPage} from '../pages/ecl-footer.po';
import {summary} from '../../src/app/component/profile/summary/summary.component';
import {SummaryPage} from '../pages/summary/summary.po';
import {OutcomeIssuingOrganisationPage} from '../pages/outcome.issuing-organisation.po';
import * as path from 'path';
import {browser} from 'protractor';

describe('Configure conditional question', function () {
  let headerPage: HeaderPage;
  let homePage: HomePage;
  let configurationPage: ConfigurationPage;
  let personalInfoContactPage: PersonalInfoContactPage;
  let personalInfoGeneralPage: PersonalInfoGeneralPage;
  let outcomeIssuingOrganisationPage: OutcomeIssuingOrganisationPage;
  let summaryPage: SummaryPage;
  let eclFooterPage: EclFooterPage;

  // SECTION NAME                             SWITCH ID                         MENU ID                     IS MANDATORY    IS MAIN MENU    MENU TO IGNORE           PARENT MENU ID
  let sections = [
    ['General information', 'generalInfo-switch', 'general', 'true', 'false', 'false', 'step.personal'],
    ['Education and Training', 'educationAndTraining-switch', 'education-and-training', 'false', 'false', 'false', 'step.skills'],
    ['Professional skills', 'professionalSkills-switch', 'professional', 'false', 'false', 'false', 'step.skills'],
  ];

  let sectionsPrimary = [
    ['Literacy Skills', 'literacySkills-switch', 'literacy', 'false', 'false', 'false', 'step.skills'],
  ];

  let questions = {
    'General information': {
      'profile.personal.general.identification.document.choose': {
        elementId: 'personal-identification-document-0'
      },
      'profile.personal.general.identification.document.type': {
        elementId: 'document-type-0'
      },
      'profile.personal.general.identification.document.number': {
        elementId: 'document-number-0'
      },
      'profile.personal.general.identification.document.country': {
        elementId: 'document-country-of-issue-0'
      },
      'profile.personal.general.identification.document.valid': {
        elementId: 'document-validity-date-picker-0'
      }
    },
    'Education and Training': {
      'profile.skills_id.education_training.study_field.label': {
        elementId: 'education-training-study-field-area'
      },
      'profile.skills_id.education_training.education_type.label': {
        elementId: 'education-training-seducation-type'
      },
      'profile.skills_id.education_training.prior_learning.label': {
        elementId: 'education-training-prior-learning'
      },
      'profile.skills_id.education_training.certificate.label': {
        elementId: 'education-training-certificate'
      },
      'profile.skills_id.education_training.last.label': {
        elementId: 'education-training-last'
      },
      'profile.skills_id.education_training.full_time.label': {
        elementId: 'education-training-full-time-week'
      },
      'profile.skills_id.education_training.part_time.label': {
        elementId: 'education-training-part-time-week'
      },
      'profile.skills_id.education_training.highest_level.label': {
        elementId: 'education-training-level'
      },
      'profile.skills_id.education_training.certificate.upload.label': {
        elementId: 'education-training-certificate-upload0file-reader'
      },
      'profile.skills_id.education_training.certificate.title.label': {
        elementId: 'education-training-certificate-title0'
      },
      'profile.skills_id.education_training.certificate.name.label': {
        elementId: 'education-training-certificate-name0'
      },
      'profile.skills_id.education_training.certificate.country.label': {
        elementId: 'education-training-certificate-country-0'
      },
      'profile.skills_id.education_training.certificate.year.label': {
        elementId: 'education-training-certificate-year0'
      },
    },
    'Professional skills': {
      'profile.skills_id.professional_skills.professional_experience.duration.label': {
        elementId: 'professional-experience-duration-week'
      },
      'profile.skills_id.professional_skills.professional_experience_last.label': {
        elementId: 'professional-experience-last'
      },
      'profile.skills_id.professional_skills.professional_experience.history.nature.label': {
        elementId: 'professional-experience-nature0'
      },
      'profile.skills_id.professional_skills.professional_experience.history.duration.label': {
        elementId: 'professional-experience-history-duration-week0'
      },
      'profile.skills_id.professional_skills.professional_experience.history.country.label': {
        elementId: 'professional-experience-history-country0'
      },
      'profile.skills_id.professional_skills.professional_experience.history.language.label': {
        elementId: 'professional-experience-history-language0'
      },
      'profile.skills_id.professional_skills.professional_experience.history.occupation.label': {
        elementId: 'professional-experience-history-occupation0'
      },
      'profile.skills_id.professional_skills.professional_experience.history.skill.label': {
        elementId: 'professional-experience-history-skill0'
      },
      'profile.skills_id.professional_skills.professional_experience.history.organisation.size.label': {
        elementId: 'professional-experience-history-organisation-size0'
      },
      'profile.skills_id.professional_skills.professional_experience.history.workplace.size.label': {
        elementId: 'professional-experience-history-workplace-size0'
      },
      'profile.skills_id.professional_skills.professional_experience.history.proof.label': {
        elementId: 'professional-experience-history-proof0'
      },
    }
  };

  let questionsPrimary = {
    'Literacy Skills': {
      'profile.skills_id.literacy_skills.read_paper_media_type.label': {
        elementId: 'paper-read-media-type'
      },
      'profile.skills_id.literacy_skills.read_liner_media_type.label': {
        elementId: 'paper-read-liner-media-type'
      },
      'profile.skills_id.literacy_skills.write_media_type.label': {
        elementId: 'paper-write-media-type'
      }
    }
  };

  beforeAll(() => {
    headerPage = new HeaderPage();
    homePage = new HomePage();
    configurationPage = new ConfigurationPage();
    personalInfoContactPage = new PersonalInfoContactPage();
    personalInfoGeneralPage = new PersonalInfoGeneralPage();
    outcomeIssuingOrganisationPage = new OutcomeIssuingOrganisationPage();
    summaryPage = new SummaryPage();
    eclFooterPage = new EclFooterPage();

    configurationPage.navigateTo();
  });

  sections.forEach(([sectionName, switchId, menuId, isMandatory, isMainMenu, menuToIgnore, parentMenu]) => {

    Object.keys(questions[sectionName]).forEach(questionLabelKey => {
      it('must be able to remove and add the question ' + questionLabelKey + ' from section ' + sectionName + ' higher', () => {
        homePage.navigateTo();
        // path of the file
        const fileToUpload = '../resources/profile-higher.xml';
        const absolutePath = path.resolve(__dirname, fileToUpload);

        // unhide input (not working in firefox otherwise)
        browser.executeScript(
          'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
        );

        homePage.getFileReaderInput().sendKeys(absolutePath);


        let menuSwitchPrefix = switchId.substr(0, switchId.indexOf('-switch'));
        let questionSwitchId = menuSwitchPrefix.concat('_', questionLabelKey, '-switch');
        let questionId = questions[sectionName][questionLabelKey].elementId;
        let isQuestionMandatory = questions[sectionName][questionLabelKey].mandatory;
        checkQuestion(menuId, true, isMandatory, isMainMenu, 'The question with id "' + questionId + '" is displayed. (1)', questionId);

        // // hide it
        configurationPage.getMenu(parentMenu).click();
        configurationPage.getToggleButton(questionSwitchId).click();

        // check if the section is not displayed
        checkQuestion(menuId, isQuestionMandatory === undefined ? false : isQuestionMandatory, isMandatory, isMainMenu, 'The question with id "' + questionId + '" is not displayed.', questionId);

        // // unhide it
        configurationPage.getMenu(parentMenu).click();
        configurationPage.getToggleButton(questionSwitchId).click();

        // check if the section is displayed
        checkQuestion(menuId, true, isMandatory, isMainMenu, 'The question with id "' + questionId + '" is displayed. (2)', questionId);
      });
    });

  });

  sectionsPrimary.forEach(([sectionName, switchId, menuId, isMandatory, isMainMenu, menuToIgnore, parentMenu]) => {
    Object.keys(questionsPrimary[sectionName]).forEach(questionLabelKey => {
      it('must be able to remove and add the question ' + questionLabelKey + ' from section ' + sectionName + ' primary', () => {
        homePage.navigateTo();
        // path of the file
        const fileToUpload = '../resources/profile-primary.xml';
        const absolutePath = path.resolve(__dirname, fileToUpload);

        // unhide input (not working in firefox otherwise)
        browser.executeScript(
          'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
        );

        homePage.getFileReaderInput().sendKeys(absolutePath);


        let menuSwitchPrefix = switchId.substr(0, switchId.indexOf('-switch'));
        let questionSwitchId = menuSwitchPrefix.concat('_', questionLabelKey, '-switch');
        let questionId = questionsPrimary[sectionName][questionLabelKey].elementId;

        checkQuestion(menuId, true, isMandatory, isMainMenu, 'The question with id "' + questionId + '" is displayed. (1)', questionId);

        // // hide it
        configurationPage.getMenu(parentMenu).click();
        configurationPage.getToggleButton(questionSwitchId).click();

        // check if the section is not displayed
        checkQuestion(menuId, isMandatory === 'true', isMandatory, isMainMenu, 'The question with id "' + questionId + '" is not displayed.', questionId);

        // // unhide it
        configurationPage.getMenu(parentMenu).click();
        configurationPage.getToggleButton(questionSwitchId).click();

        // check if the section is displayed
        checkQuestion(menuId, true, isMandatory, isMainMenu, 'The question with id "' + questionId + '" is displayed. (2)', questionId);
      });
    });

  });

  function checkQuestion(menuId: string, isDisplayed: boolean, isMandatory: string, isMainMenu: string, errorMessage: string, questionId: string) {
    if (isMainMenu === 'false') {
      goToSection(menuId);
      goToSubSection(menuId);
    }

    expect(headerPage.isPresent(questionId)).toBe(isDisplayed, errorMessage);
    headerPage.getConfigurationButton().click();
  }

  function goToSection(section: string) {
    switch (section) {
      case 'personal-info':
      case 'general':
      case 'contact':
      case 'migration':
        headerPage.getPersonalInformationButton().click();
        break;
      case 'expectations':
        headerPage.getExpectationsButton().click();
        break;
      case 'skills-identification':
      case 'languages':
      case 'education-and-training':
      case 'literacy':
      case 'numeracy':
      case 'digital':
      case 'professional':
      case 'acquired-outside':
      case 'other-basic-transversal':
      case 'driving':
        headerPage.getSkillsIdentificationButton().click();
        break;
      case 'outcome':
      case 'key-skills':
      case 'recognition':
      case 'validation':
      case 'education-or-training':
      case 'employment-business':
      case 'further-information':
      case 'issuing-organisation':
      case 'mooc-search':
      case 'mooc-recommended':
        headerPage.getOutcomeButton().click();
        break;
      case 'summary':
        headerPage.getSummaryButton().click();
        break;
    }
  }

  function goToSubSection(subSection: string) {
    switch (subSection) {
      case 'general':
        headerPage.getGeneralInformationTabButton().click();
        break;
      case 'contact':
        headerPage.getContactInformationTabButton().click();
        break;
      case 'migration':
        headerPage.getMigrationTabButton().click();
        break;
      case 'languages':
        headerPage.getLanguagesTabButton().click();
        break;
      case 'education-and-training':
        headerPage.getEducationAndTrainingTabButton().click();
        break;
      case 'literacy':
        headerPage.getLiteracySkillsTabButton().click();
        break;
      case 'numeracy':
        headerPage.getNumeracySkillsTabButton().click();
        break;
      case 'digital':
        headerPage.getDigitalSkillsTabButton().click();
        break;
      case 'professional':
        headerPage.getProfessionalSkillsTabButton().click();
        break;
      case 'acquired-outside':
        headerPage.getSkillsAcquiredOutsideTabButton().click();
        break;
      case 'other-basic-transversal':
        headerPage.getOtherBasicAndTransversalSkillsTabButton().click();
        break;
      case 'driving':
        headerPage.getDrivingSkillsTabButton().click();
        break;
      case 'key-skills':
        headerPage.getStrengthsTabButton().click();
        break;
      case 'recognition':
        headerPage.getRecognitionTabButton().click();
        break;
      case 'validation':
        headerPage.getValidationTabButton().click();
        break;
      case 'education-or-training':
        headerPage.getTrainingTabButton().click();
        break;
      case 'employment-business':
        headerPage.getWorkTabButton().click();
        break;
      case 'further-information':
        headerPage.getGuidanceTabButton().click();
        break;
      case 'issuing-organisation':
        headerPage.getOrganisationTabButton().click();
        break;
      case 'mooc-search':
        headerPage.getCoursesTabButton().click();
        break;
      case 'mooc-recommended':
        headerPage.getRecommendationsTabButton().click();
        break;
    }
  }
});
