import {ConfigurationPage} from '../pages/configuration.po';
import {HeaderPage} from '../pages/header.po';
import {HomePage} from '../pages/home.po';
import {PersonalInfoContactPage} from '../pages/personal-info.contact.po';
import {PersonalInfoGeneralPage} from '../pages/personal-info.general.po';
import {EclFooterPage} from '../pages/ecl-footer.po';
import {summary} from '../../src/app/component/profile/summary/summary.component';
import {SummaryPage} from '../pages/summary/summary.po';
import {OutcomeIssuingOrganisationPage} from '../pages/outcome.issuing-organisation.po';

describe('Configure question', function () {
  let headerPage: HeaderPage;
  let homePage: HomePage;
  let configurationPage: ConfigurationPage;
  let personalInfoContactPage: PersonalInfoContactPage;
  let personalInfoGeneralPage: PersonalInfoGeneralPage;
  let outcomeIssuingOrganisationPage: OutcomeIssuingOrganisationPage;
  let summaryPage: SummaryPage;
  let eclFooterPage: EclFooterPage;

  // SECTION NAME                             SWITCH ID                         MENU ID                     IS MANDATORY    IS MAIN MENU    MENU TO IGNORE           PARENT MENU ID
  let sections = [
    ['General information', 'generalInfo-switch', 'general', 'true', 'false', 'false', 'step.personal'],
    ['Contact information', 'contactInfo-switch', 'contact', 'false', 'false', 'false', 'step.personal'],
    ['Migration information', 'migrationInfo-switch', 'migration', 'false', 'false', 'false', 'step.personal'],
    ['Language', 'language-switch', 'languages', 'false', 'false', 'false', 'step.skills'],
    ['Education and Training', 'educationAndTraining-switch', 'education-and-training', 'false', 'false', 'false', 'step.skills'],
    ['Literacy Skills', 'literacySkills-switch', 'literacy', 'false', 'false', 'false', 'step.skills'],
    ['Numeracy Skills', 'numeracySkills-switch', 'numeracy', 'false', 'false', 'false', 'step.skills'],
    ['Digital skills', 'digitalSkills-switch', 'digital', 'false', 'false', 'false', 'step.skills'],
    ['Professional skills', 'professionalSkills-switch', 'professional', 'false', 'false', 'false', 'step.skills'],
    ['Skills acquired outside the workplace', 'outsideSkills-switch', 'acquired-outside', 'false', 'false', 'false', 'step.skills'],
    ['Other basic and transversal skills', 'otherTransversalSkills-switch', 'other-basic-transversal', 'false', 'false', 'false', 'step.skills'],
    ['Recognition', 'recognition-switch', 'recognition', 'false', 'false', 'false', 'step.outcome'],
    ['Validation', 'validationSection-switch', 'validation', 'false', 'false', 'false', 'step.outcome'],
    ['Training', 'training-switch', 'education-or-training', 'false', 'false', 'false', 'step.outcome'],
    ['Organisation', 'organisation-switch', 'issuing-organisation', 'false', 'false', 'false', 'step.outcome'],
  ];

  let questions = {
    'General information': {
      'profile.general.name.family': {
        elementId: 'family-name',
        mandatory: true
      },
      'profile.general.name.first': {
        elementId: 'first-name',
        mandatory: true
      },
      'profile.general.gender.label': {
        elementId: 'gender'
      },
      'profile.general.birth.date': {
        elementId: 'birth-date-picker'
      },
      'profile.general.birth.country': {
        elementId: 'birth-country'

      },
      'profile.general.nationality': {
        elementId: 'nationality'

      },
      'profile.general.marital.status': {
        elementId: 'marital-status'
      }
    },
    'Contact information': {
      'profile.general.contact.address': {
        elementId: 'contact-info-address'
      },
      'profile.general.contact.postCode': {
        elementId: 'contact-info-post-code'
      },
      'profile.general.contact.country': {
        elementId: 'contact-info-country'
      },
      'profile.general.contact.phone': {
        elementId: 'contact-info-phone'
      },
      'profile.general.contact.email': {
        elementId: 'contact-info-email'
      },
    },
    'Migration information': {
      'profile.general.country.reception_arrival_date': {
        elementId: 'date-of-arrival-date-picker'
      },
      'profile.general.residence.status': {
        elementId: 'residence-status'
      },
      'profile.general.work.permit.label': {
        elementId: 'work-permit-status'
      },
      'profile.personal.migration.travelling.label': {
        elementId: 'travelling-with-dependants'
      },
      'profile.personal.migration.travelling.minor_15': {
        elementId: 'minor-15-or-under-travelling'
      },
      'profile.personal.migration.travelling.minor_16_to_18': {
        elementId: 'minor-16-to-18-travelling'
      },
      'profile.personal.migration.travelling.adult': {
        elementId: 'adult-travelling'
      },
      'profile.personal.migration.travelling.elderly': {
        elementId: 'elderly-travelling'
      },
      'profile.personal.migration.travelling.sick': {
        elementId: 'sick-travelling'
      }
    },
    'Expectations': {
      'profile.expectations.do_next.label': {
        elementId: 'expectation-do-next-'
      },
      'profile.expectations.instructions': {
        elementId: 'key-skills'
      },
      'profile.expectations.improve_language.rowLabel': {
        elementId: 'expectation-language-'
      },
      'profile.expectations.undertake_education.time_commitment.label': {
        elementId: 'expectation-time-commitment-'
      },
      'profile.expectations.undertake_education.education_type.label': {
        elementId: 'expectation-education-type-'
      },
      'profile.expectations.undertake_education.study_field.label': {
        elementId: 'expectation-study-field-'
      },
      'profile.expectations.other.label': {
        elementId: 'expectation-find-work-other-'
      },
      'profile.expectations.find_work.rowLabel': {
        elementId: 'expectation-find-work-other-'
      }
    },
    'Language': {
      'profile.skills_id.language_skills.mother_tongue.label': {
        elementId: 'language-skills-mother-tongue'
      },
      'profile.skills_id.language_skills.host_country.label': {
        elementId: 'language-skills-host-country'
      },
    },
    'Education and Training': {
      'profile.skills_id.education_training.attended.label': {
        elementId: 'education-training-attended'
      },
    },
    'Literacy Skills': {
      'profile.skills_id.literacy_skills.read_regularly.label': {
        elementId: 'read-regularly'
      },
      'profile.skills_id.literacy_skills.write_regularly.label': {
        elementId: 'write-regularly'
      },
    },
    'Numeracy Skills': {
      'profile.skills_id.numeracy_skills.measuring.label': {
        elementId: 'numeracy-skills-measuring'
      },
      'profile.skills_id.numeracy_skills.calculation.whole_numbers.label': {
        elementId: 'numeracy-skills-calculation-whole-numbers'
      },
      'profile.skills_id.numeracy_skills.calculation.factions.label': {
        elementId: 'numeracy-skills-calculation-fractions'
      },
      'profile.skills_id.numeracy_skills.calculation.percentage.label': {
        elementId: 'numeracy-skills-calculation-percentage'
      },
      'profile.skills_id.numeracy_skills.geometry.label': {
        elementId: 'numeracy-skills-geometry'
      },
      'profile.skills_id.numeracy_skills.charts.label': {
        elementId: 'numeracy-skills-charts'
      },
      'profile.skills_id.numeracy_skills.complex.label': {
        elementId: 'numeracy-skills-complex'
      },
      'profile.skills_id.numeracy_skills.metric.label': {
        elementId: 'numeracy-skills-metric'
      },
    },
    'Digital skills': {
      'profile.skills_id.digital_skills.using_smartphone.label': {
        elementId: 'using-smartphone'
      },
      'profile.skills_id.digital_skills.using_laptop.label': {
        elementId: 'using-laptop'
      },
      'profile.skills_id.digital_skills.managing_files.label': {
        elementId: 'managing-files'
      },
      'profile.skills_id.digital_skills.create_text_docs.label': {
        elementId: 'create-text-docs'
      },
      'profile.skills_id.digital_skills.create_spread_sheets.label': {
        elementId: 'create-spread-sheets'
      },
      'profile.skills_id.digital_skills.create_presentations.label': {
        elementId: 'create-presentations'
      },
      'profile.skills_id.digital_skills.emails.label': {
        elementId: 'emails'
      },
      'profile.skills_id.digital_skills.find_info_internet.label': {
        elementId: 'find-info-internet'
      },
      'profile.skills_id.digital_skills.internet_phone.label': {
        elementId: 'internet-phone'
      },
      'profile.skills_id.digital_skills.online_purchase.label': {
        elementId: 'online-purchase'
      },
      'profile.skills_id.digital_skills.online_learning.label': {
        elementId: 'online-learning'
      },
      'profile.skills_id.digital_skills.making_graphic_designs.label': {
        elementId: 'making-graphic-designs'
      },
      'profile.skills_id.digital_skills.other.label': {
        elementId: 'other-digital-skills'
      },
    },
    'Professional skills': {
      'profile.skills_id.professional_skills.professional_experience.label': {
        elementId: 'professional-experience'
      },
    },
    'Skills acquired outside the workplace': {
      'profile.skills_id.outside_skills.caring_children.label': {
        elementId: 'outside-skills-caring-children'
      },
      'profile.skills_id.outside_skills.caring_elderly_people.label': {
        elementId: 'outside-skills-caring-elderly-people'
      },
      'profile.skills_id.outside_skills.caring_sick_people.label': {
        elementId: 'outside-skills-caring-sick-people'
      },
      'profile.skills_id.outside_skills.making_clothing.label': {
        elementId: 'outside-skills-making-clothing'
      },
      'profile.skills_id.outside_skills.preparing_meals.label': {
        elementId: 'outside-skills-preparing-meals'
      },
      'profile.skills_id.outside_skills.cultivating_crops.label': {
        elementId: 'outside-skills-cultivating-crops'
      },
      'profile.skills_id.outside_skills.livestock.label': {
        elementId: 'outside-skills-livestock'
      },
      'profile.skills_id.outside_skills.making_pottery.label': {
        elementId: 'outside-skills-making-pottery'
      },
      'profile.skills_id.outside_skills.selling_trading_products.label': {
        elementId: 'outside-skills-selling-products'
      },
      'profile.skills_id.outside_skills.making_furniture.label': {
        elementId: 'outside-skills-making-furniture'
      },
      'profile.skills_id.outside_skills.house_construction.label': {
        elementId: 'outside-skills-house-construction'
      },
      'profile.skills_id.outside_skills.coaching_teaching.label': {
        elementId: 'outside-skills-coaching-teaching'
      },
    },
    'Other basic and transversal skills': {
      'profile.skills_id.other_basic_transversal_skills.work_independently.label': {
        elementId: 'other-transversal-work-independently'
      },
      'profile.skills_id.other_basic_transversal_skills.make_decisions_independently.label': {
        elementId: 'other-transversal-make-decision-independently'
      },
      'profile.skills_id.other_basic_transversal_skills.work_in_structured_way.label': {
        elementId: 'other-transversal-work-structured-way'
      },
      'profile.skills_id.other_basic_transversal_skills.solve_problems.label': {
        elementId: 'other-transversal-solve-problems'
      },
      'profile.skills_id.other_basic_transversal_skills.work_with_others.label': {
        elementId: 'other-transversal-work-with-others'
      },
      'profile.skills_id.other_basic_transversal_skills.work_with_people.label': {
        elementId: 'other-transversal-work-with-people'
      },
      'profile.skills_id.other_basic_transversal_skills.work_with_customers.label': {
        elementId: 'other-transversal-work-with-customers'
      },
      'profile.skills_id.other_basic_transversal_skills.work_as_leader.label': {
        elementId: 'other-transversal-work-as-leader'
      },
      'profile.skills_id.other_basic_transversal_skills.manage_project.label': {
        elementId: 'other-transversal-manage-projects'
      },
      'profile.skills_id.other_basic_transversal_skills.work_in_stressful_conditions.label': {
        elementId: 'work-stressful-conditions'
      },
      'profile.skills_id.other_basic_transversal_skills.develop_ideas.label': {
        elementId: 'develop-new-ideas'
      },
      'profile.skills_id.other_basic_transversal_skills.inspire_enthuse_others.label': {
        elementId: 'inspire-enthuse-others'
      },
      'profile.skills_id.other_basic_transversal_skills.take_responsability.label': {
        elementId: 'take-responsibility'
      },
    },
    'Recognition': {
      'profile.outcome.recognition.label_1.label': {
        elementId: 'app-recognition-qualifications-recommendation'
      },
      'profile.outcome.recognition.label_2.label': {
        elementId: 'app-recognition-qualifications-referral'
      },
    },
    'Validation': {
      'profile.outcome.validation.label_1.label': {
        elementId: 'app-validation-learning-recommendation'
      },
      'profile.outcome.validation.label_2.label': {
        elementId: 'app-validation-learning-referral'
      },
    },
    'Training': {
      'profile.outcome.education_or_training.label_1.label': {
        elementId: 'app-education-or-training-advice'
      },
      'profile.outcome.education_or_training.label_2.label': {
        elementId: 'app-education-or-training-referral'
      },
    },
    'Organisation': {
      'profile.outcome.details_issuing_organisation.data_of_issuance': {
        elementId: 'organisation-date-picker0'
      },
      'profile.outcome.details_issuing_organisation.place_of_issuance': {
        elementId: 'place-of-issuance'
      },
      'profile.outcome.details_issuing_organisation.type.label': {
        elementId: 'organisation-type'
      },
      'profile.outcome.organisation.label': {
        elementId: 'organisation'
      },
      'profile.outcome.details_issuing_organisation.responsible_officer': {
        elementId: 'responsible-officer'
      },
      'profile.general.contact.address': {
        elementId: 'organisation-contact-info-address'
      },
      'profile.general.contact.country': {
        elementId: 'organisation-contact-info-country'
      },
      'profile.general.contact.phone': {
        elementId: 'organisation-contact-info-phone'
      },
      'profile.general.contact.email': {
        elementId: 'organisation-contact-info-email'
      },
    },
  };

  beforeAll(() => {
    headerPage = new HeaderPage();
    homePage = new HomePage();
    configurationPage = new ConfigurationPage();
    personalInfoContactPage = new PersonalInfoContactPage();
    personalInfoGeneralPage = new PersonalInfoGeneralPage();
    outcomeIssuingOrganisationPage = new OutcomeIssuingOrganisationPage();
    summaryPage = new SummaryPage();
    eclFooterPage = new EclFooterPage();

    configurationPage.navigateTo();
  });

  sections.forEach(([sectionName, switchId, menuId, isMandatory, isMainMenu, menuToIgnore, parentMenu]) => {
    // sections.forEach(([sectionName, switchId, menuId, isMandatory, isMainMenu]) => {

    Object.keys(questions[sectionName]).forEach(questionLabelKey => {
      it('must be able to remove and add the question ' + questionLabelKey + ' from section ' + sectionName, () => {

        let menuSwitchPrefix = switchId.substr(0, switchId.indexOf('-switch'));
        let questionSwitchId = menuSwitchPrefix.concat('_', questionLabelKey, '-switch');
        let questionId = questions[sectionName][questionLabelKey].elementId;
        let isQuestionMandatory = questions[sectionName][questionLabelKey].mandatory;
        checkQuestion(menuId, true, isMandatory, isMainMenu, 'The question with id "' + questionId + '" is displayed. (1)', questionId);

        // // hide it
        configurationPage.getMenu(parentMenu).click();
        configurationPage.getToggleButton(questionSwitchId).click();

        // check if the section is not displayed
        checkQuestion(menuId, isQuestionMandatory === undefined ? false : isQuestionMandatory, isMandatory, isMainMenu, 'The question with id "' + questionId + '" is not displayed.', questionId);

        // // unhide it
        configurationPage.getMenu(parentMenu).click();
        configurationPage.getToggleButton(questionSwitchId).click();

        // check if the section is displayed
        checkQuestion(menuId, true, isMandatory, isMainMenu, 'The question with id "' + questionId + '" is displayed. (2)', questionId);
      });
    });

  });

  function checkQuestion(menuId: string, isDisplayed: boolean, isMandatory: string, isMainMenu: string, errorMessage: string, questionId: string) {
    if (isMainMenu === 'false') {
      goToSection(menuId);
      goToSubSection(menuId);
    }

    expect(headerPage.isPresent(questionId)).toBe(isDisplayed, errorMessage);
    headerPage.getConfigurationButton().click();
  }

  function goToSection(section: string) {
    switch (section) {
      case 'personal-info':
      case 'general':
      case 'contact':
      case 'migration':
        headerPage.getPersonalInformationButton().click();
        break;
      case 'expectations':
        headerPage.getExpectationsButton().click();
        break;
      case 'skills-identification':
      case 'languages':
      case 'education-and-training':
      case 'literacy':
      case 'numeracy':
      case 'digital':
      case 'professional':
      case 'acquired-outside':
      case 'other-basic-transversal':
      case 'driving':
        headerPage.getSkillsIdentificationButton().click();
        break;
      case 'outcome':
      case 'key-skills':
      case 'recognition':
      case 'validation':
      case 'education-or-training':
      case 'employment-business':
      case 'further-information':
      case 'issuing-organisation':
      case 'mooc-search':
      case 'mooc-recommended':
        headerPage.getOutcomeButton().click();
        break;
      case 'summary':
        headerPage.getSummaryButton().click();
        break;
    }
  }

  function goToSubSection(subSection: string) {
    switch (subSection) {
      case 'general':
        headerPage.getGeneralInformationTabButton().click();
        break;
      case 'contact':
        headerPage.getContactInformationTabButton().click();
        break;
      case 'migration':
        headerPage.getMigrationTabButton().click();
        break;
      case 'languages':
        headerPage.getLanguagesTabButton().click();
        break;
      case 'education-and-training':
        headerPage.getEducationAndTrainingTabButton().click();
        break;
      case 'literacy':
        headerPage.getLiteracySkillsTabButton().click();
        break;
      case 'numeracy':
        headerPage.getNumeracySkillsTabButton().click();
        break;
      case 'digital':
        headerPage.getDigitalSkillsTabButton().click();
        break;
      case 'professional':
        headerPage.getProfessionalSkillsTabButton().click();
        break;
      case 'acquired-outside':
        headerPage.getSkillsAcquiredOutsideTabButton().click();
        break;
      case 'other-basic-transversal':
        headerPage.getOtherBasicAndTransversalSkillsTabButton().click();
        break;
      case 'driving':
        headerPage.getDrivingSkillsTabButton().click();
        break;
      case 'key-skills':
        headerPage.getStrengthsTabButton().click();
        break;
      case 'recognition':
        headerPage.getRecognitionTabButton().click();
        break;
      case 'validation':
        headerPage.getValidationTabButton().click();
        break;
      case 'education-or-training':
        headerPage.getTrainingTabButton().click();
        break;
      case 'employment-business':
        headerPage.getWorkTabButton().click();
        break;
      case 'further-information':
        headerPage.getGuidanceTabButton().click();
        break;
      case 'issuing-organisation':
        headerPage.getOrganisationTabButton().click();
        break;
      case 'mooc-search':
        headerPage.getCoursesTabButton().click();
        break;
      case 'mooc-recommended':
        headerPage.getRecommendationsTabButton().click();
        break;
    }
  }
});
