import {HomePage} from '../pages/home.po';
import * as path from 'path';
import {browser, element, ExpectedConditions, protractor} from 'protractor';
import {PersonalInfoGeneralPage} from '../pages/personal-info.general.po';
import {HeaderPage} from '../pages/header.po';
import {LanguageSelectorPage} from '../pages/language-selector.po';
import * as http from 'http';

describe('A user on the home page', function() {
  let homePage: HomePage;
  let headerPage: HeaderPage;
  let languageSelectorPage: LanguageSelectorPage;
  let personalInfoGeneralPage: PersonalInfoGeneralPage;

  beforeAll(() => {
    homePage = new HomePage();
    headerPage = new HeaderPage();
    languageSelectorPage = new LanguageSelectorPage();
    personalInfoGeneralPage = new PersonalInfoGeneralPage();

    homePage.navigateTo();
  });

  describe('must be able to change the current language', () => {

    afterAll(() => {
      headerPage.getLanguageDropDownOption('en').click();
    });

    [
      ['bg', 'български'],
      ['es', 'Español'],
      ['cs', 'Čeština'],
      ['da', 'Dansk'],
      ['de', 'Deutsch'],
      ['et', 'Eesti keel'],
      ['el', 'ελληνικά'],
      ['en', 'English'],
      ['fr', 'Français'],
      ['hr', 'Hrvatski'],
      ['it', 'Italiano'],
      ['lv', 'Latviešu valoda'],
      ['lt', 'Lietuvių kalba'],
      ['hu', 'Magyar'],
      ['mt', 'Malti'],
      ['nl', 'Nederlands'],
      ['pl', 'Polski'],
      ['pt', 'Português'],
      ['ro', 'Română'],
      ['sk', 'Slovenčina'],
      ['sl', 'Slovenščina'],
      ['fi', 'Suomi'],
      ['sv', 'Svenska'],
      ['ar', 'العربية'],
      ['fa', 'فارسی'],
      ['ku', 'سۆرانی، کوردیی ناوەندی'],
      ['so', 'اف سومالى'],
      ['ti', 'ትግርኛ'],
      ['tr', 'Türkçe'],
      ['ps', 'پښتو']
    ].forEach(([languageCode, translation]) => {
      it('to ' + languageCode, () => {
        headerPage.getChangeLanguageButton().click();
        languageSelectorPage.getLanguageButton(languageCode).click();
        expect(headerPage.getChangeLanguageButton().getText()).toEqual(translation + '\n' + languageCode.toUpperCase());
      });
    });
  });

  it('must be able to create a new profile', () => {
    homePage.navigateTo();
    homePage.getCreateProfileButton().click();
    expect(browser.getCurrentUrl()).toEqual(homePage.getFirstSection());
    expect(personalInfoGeneralPage.getFamilyAndFirstName().getText())
      .toEqual(' \n ', 'Error on the family and first name');
    expect(personalInfoGeneralPage.getFamilyNameInput().getText())
      .toEqual('', 'Error on the family name input');
    expect(personalInfoGeneralPage.getFirstNameInput().getText())
      .toEqual('', 'Error on the first name input');
  });

  it('must be able to load a profile', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../resources/profile.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(homePage.getFirstSection());
    expect(personalInfoGeneralPage.getFamilyAndFirstName().getText())
      .toEqual('Doe \nJohn ', 'Error on the family and first name');
    expect(personalInfoGeneralPage.getFamilyNameInput().getAttribute('value'))
      .toEqual('Doe', 'Error on the family name input');
    expect(personalInfoGeneralPage.getFirstNameInput().getAttribute('value'))
      .toEqual('John', 'Error on the first name input');
  });

  it('must be able to load an empty profile with some fields developed but empty', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../resources/super_empty.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(homePage.getFirstSection());
    expect(personalInfoGeneralPage.getFamilyAndFirstName().getText())
      .toEqual('Doe \nJohn ', 'Error on the family and first name');
    expect(personalInfoGeneralPage.getFamilyNameInput().getAttribute('value'))
      .toEqual('Doe', 'Error on the family name input');
    expect(personalInfoGeneralPage.getFirstNameInput().getAttribute('value'))
      .toEqual('John', 'Error on the first name input');
  });

  it('must be able to see the banner', () => {
    homePage.navigateTo();
    expect(homePage.isBackgroundImagePresent()).toBe(true);
  });

  // Survey tests

  describe('during a survey plan', () => {

    let startSurvey = '2018-06-01';
    let endSurvey = '2050-06-01';

    beforeAll(() => {
      setSurveyValues(startSurvey, endSurvey, false);
      homePage.navigateTo();
    });

    afterAll(() => {
      setSurveyValues('', '', true);
    });

    it('must be able to see a survey modal, cancel it, reload the page and see again the modal', () => {
      expect(homePage.isSurveyModalPresent())
        .toBe(true, 'Survey modal need to be present. (1)');
      expect(homePage.isSurveyModalAcceptCookiesButtonPresent())
        .toBe(true, 'Accept cookies button need to be present. (1)');

      homePage.getSurveyModalCancelButton().click();

      expect(homePage.isSurveyModalPresent())
        .toBe(false, 'Survey modal should not be displayed.');

      homePage.navigateTo();
      expect(homePage.isSurveyModalPresent())
        .toBe(true, 'Survey modal need to be present. (2)');
      expect(homePage.isSurveyModalAcceptCookiesButtonPresent())
        .toBe(true, 'Accept cookies button need to be present. (2)');

    });

    it('must be able to see a survey modal, give feedback it, reload the homepage and see again the modal', () => {
      expect(homePage.isSurveyModalPresent())
        .toBe(true, 'Survey modal need to be present. (1)');
      expect(homePage.isSurveyModalAcceptCookiesButtonPresent())
        .toBe(true, 'Accept cookies button need to be present. (1)');

      homePage.getSurveyModalGiveFeedbackButton().click();

      browser.sleep(300);
      browser.getAllWindowHandles().then((handles) => {
        browser.waitForAngularEnabled(false);

        browser.driver.switchTo().window(handles[1]);
        expect(browser.getCurrentUrl())
          .toEqual('https://www.google.com/', 'Wrong url. (1)');

        browser.driver.switchTo().window(handles[0]);
        expect(browser.getCurrentUrl())
          .toEqual(browser.baseUrl + homePage.url(), 'Wrong url. (2)');

        browser.waitForAngularEnabled(true);

        homePage.navigateTo();
        expect(homePage.isSurveyModalPresent())
          .toBe(true, 'Survey modal need to be present. (2)');
        expect(homePage.isSurveyModalAcceptCookiesButtonPresent())
          .toBe(true, 'Accept cookies button need to be present. (2)');
      });
    });

    it('must be able to see a survey modal with cookie alert, accept it, cancel the modal, reload the page and not see again the modal', () => {
      expect(homePage.isSurveyModalPresent())
        .toBe(true, 'Survey modal need to be present. (1)');
      expect(homePage.isSurveyModalAcceptCookiesButtonPresent())
        .toBe(true, 'Accept cookies button need to be present. (1)');

      homePage.getSurveyModalAcceptCookiesButton().click();
      browser.sleep(5000);

      expect(homePage.isSurveyModalPresent())
        .toBe(true, 'Survey modal need to be present. (2)');
      expect(homePage.isSurveyModalAcceptCookiesButtonPresent())
        .toBe(false, 'Accept cookies button should not be displayed. (2)');

      homePage.getSurveyModalCancelButton().click();

      // check the end of the cookie
      browser.manage().getCookies().then(function(cookies) {
        let isCookiePresent = false;
        for (let cookie of cookies as Array<any>) {
          if (cookie.name === 'skpt_survey') {
            isCookiePresent = true;
            expect(cookie.expiry * 1000) // need to multiply to have the same number length
              .toBe(new Date(endSurvey).getTime(), 'Bad cookie expiration date.');
          }
        };
        expect(isCookiePresent)
          .toBe(true, 'skpt_survey cookie need to be present.');
      });

      expect(homePage.isSurveyModalPresent())
        .toBe(false, 'Survey modal should not be displayed (1)');

      homePage.navigateTo();
      expect(homePage.isSurveyModalPresent())
        .toBe(false, 'Survey modal should not be displayed. (2)');

      browser.restartSync();
      homePage.navigateTo();
    });

    it('must be able to see a survey modal with cookie alert, refuse it, cancel the modal, reload the page and not see again the modal', () => {
      expect(homePage.isSurveyModalPresent())
        .toBe(true, 'Survey modal need to be present. (1)');
      expect(homePage.isSurveyModalAcceptCookiesButtonPresent())
        .toBe(true, 'Accept cookies button need to be present. (1)');

      homePage.getSurveyModalRefuseCookiesButton().click();
      browser.sleep(10000);

      expect(homePage.isSurveyModalPresent())
        .toBe(true, 'Survey modal need to be present. (2)');

      homePage.getSurveyModalCancelButton().click();
      expect(homePage.isSurveyModalPresent())
        .toBe(false, 'Survey modal should not be displayed.');

      homePage.navigateTo();
      expect(homePage.isSurveyModalPresent())
        .toBe(true, 'Survey modal need to be present. (3)');
      expect(homePage.isSurveyModalAcceptCookiesButtonPresent())
        .toBe(true, 'Accept cookies button need to be present. (3)');

      browser.restartSync();
      homePage.navigateTo();
    });
  });

  describe('outside a survey timeframe', () => {

    it('must not see a survey if the end date is passed', () => {
      setSurveyValues('2017-06-01', '2018-06-01', true);
      homePage.navigateTo();

      expect(homePage.isSurveyModalPresent()).toBe(false);

      setSurveyValues('', '', true);
    });

    it('must see a survey if no survey properties are filled', () => {
      homePage.navigateTo();

      expect(homePage.isSurveyModalPresent()).toBe(false);
    });

  });

  function setSurveyValues(start: string, end: string, urlEmpty: boolean) {
    let backendUrl = 'http://localhost:8585';
    http.get(backendUrl + '/api/config/set?property=surveyStartDate&value=' + start);
    http.get(backendUrl + '/api/config/set?property=surveyEndDate&value=' + end);
    if (urlEmpty) {
      http.get(backendUrl + '/api/config/set?property=surveyUrl&value=');
    } else {
      http.get(backendUrl + '/api/config/set?property=surveyUrl&value=https%3A%2F%2Fwww.google.com');
    }
  }

});
