import {HomePage} from '../pages/home.po';
import {PersonalInfoContactPage} from '../pages/personal-info.contact.po';
import {OutcomeCoursesPage} from '../pages/outcome.courses.po';
import {HeaderPage} from '../pages/header.po';
import {browser, protractor} from 'protractor';
import {Key} from 'selenium-webdriver';
import * as path from 'path';
import {ConsentPage} from '../pages/consent.po';


describe('A user on the search courses page', function() {

  let headerPage: HeaderPage;
  let homePage: HomePage;
  let consentPage: ConsentPage;
  let personalInfoContactPage: PersonalInfoContactPage;
  let outcomeCoursesPage: OutcomeCoursesPage;

  beforeAll(() => {
    headerPage = new HeaderPage();
    homePage = new HomePage();
    outcomeCoursesPage = new OutcomeCoursesPage();
    consentPage = new ConsentPage();
    personalInfoContactPage = new PersonalInfoContactPage();

    homePage.navigateTo();
    homePage.getCreateProfileButton().click();
    headerPage.getOutcomeButton().click();
    headerPage.getCoursesTabButton().click();
  });

  afterAll(() => {
    homePage.navigateTo();
    browser.switchTo().alert().accept();
  });

  it('must be able to load some filter from a loaded profile', () => {
    homePage.navigateTo();

    // path of the file
    const fileToUpload = '../resources/profile-outcome.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(outcomeCoursesPage.getFirstSection());

    // outcomeCoursesPage.navigateTo();
    headerPage.getOutcomeButton().click();
    headerPage.getCoursesTabButton().click();

    expect(outcomeCoursesPage.getLanguagesChoice().getAttribute('title')).toEqual('Arabic');
    expect(outcomeCoursesPage.getSubtitlesChoice().getAttribute('title')).toEqual('Bulgarian');
    expect(outcomeCoursesPage.getFieldOfStudyChoice().getAttribute('title')).toEqual('Basic programmes and qualifications');
    expect(outcomeCoursesPage.getEducationLevelChoice().getAttribute('title')).toEqual('ISCED-1 - Primary education');
    expect(outcomeCoursesPage.getCourseTopicChoice().getAttribute('title')).toEqual('Integration into the labour market');
    expect(outcomeCoursesPage.getProviderChoice().getAttribute('title')).toEqual('https://www.rwaq.org');
    expect(outcomeCoursesPage.getAllFilterTags().count()).toBe(7);

    homePage.navigateTo();
    homePage.getCreateProfileButton().click();
    headerPage.getOutcomeButton().click();
    headerPage.getCoursesTabButton().click();
  });

  it('must be able to see her email address if it is filled and delete it', () => {
    // see the email field empty
    expect(outcomeCoursesPage.getTagsEmailsSelect(0).count()).toBe(0);

    const emailPrefix = 'John.Doe';
    const emailSuffix = 'gmail.com';

    // fill the email field(s)
    headerPage.getPersonalInformationButton().click();
    headerPage.getContactInformationTabButton().click();
    personalInfoContactPage.getPrincipalEmailPrefixInput().sendKeys(emailPrefix);
    personalInfoContactPage.getPrincipalEmailSuffixInput().sendKeys(emailSuffix);

    // check if they appear
    headerPage.getOutcomeButton().click();
    headerPage.getCoursesTabButton().click();
    expect(outcomeCoursesPage.getTagsEmailsSelect(0).count()).toBe(1);
    expect(outcomeCoursesPage.getTagsEmailsSelect(0).first().getText()).toBe(emailPrefix + '@' + emailSuffix);

    headerPage.getPersonalInformationButton().click();
    headerPage.getContactInformationTabButton().click();

    personalInfoContactPage.getPrincipalEmailPrefixInput().click();
    for (let i = 0; i < emailPrefix.length; i++) {
      personalInfoContactPage.getPrincipalEmailPrefixInput().sendKeys(protractor.Key.BACK_SPACE);
    }

    personalInfoContactPage.getPrincipalEmailSuffixInput().click();
    for (let i = 0; i < emailSuffix.length; i++) {
      personalInfoContactPage.getPrincipalEmailSuffixInput().sendKeys(protractor.Key.BACK_SPACE);
    }

    expect(personalInfoContactPage.getPrincipalEmailSuffixInput().getAttribute('value')).toEqual('');
    expect(personalInfoContactPage.getPrincipalEmailSuffixInput().getAttribute('value')).toEqual('');

    headerPage.getOutcomeButton().click();
    headerPage.getCoursesTabButton().click();
    expect(outcomeCoursesPage.getTagsEmailsSelect(0).count()).toBe(0);
  });

  it('must be able to clear all filters', () => {
    // Select filters in the courses view.
    outcomeCoursesPage.getLanguagesOfTheTrainingFilterInput().sendKeys('English', Key.ENTER);
    outcomeCoursesPage.getFieldsOfStudyFilterInput().sendKeys('French', Key.ENTER);
    expect(outcomeCoursesPage.getAllFilterTags().count()).toBe(2);

    // Click on the clear button.
    outcomeCoursesPage.getRefreshFiltersButton().click();
    expect(outcomeCoursesPage.getAllFilterTags().count()).toBe(0);

    // Go to another section and come back to the Courses one.
    headerPage.getOrganisationTabButton().click();
    headerPage.getCoursesTabButton().click();

    // => The view is displayed.
    expect(outcomeCoursesPage.getLanguagesOfTheTrainingFilterInput()).toBeTruthy();
  });

  // Emails tests

  it('must be able to encode his email', () => {
    const index = 0;

    expect(outcomeCoursesPage.getTagsEmailsSelect(index).count()).toBe(0, 'Wrong number of emails. (1)');

    let emailsInput = outcomeCoursesPage.getEmailsInput(index);
    emailsInput.click();
    emailsInput.sendKeys('jeandidier@gmail.com ');

    browser.driver.sleep(3000);
    expect(outcomeCoursesPage.getTagsEmailsSelect(index).count()).toBe(1, 'Wrong number of emails. (2)');
    expect(outcomeCoursesPage.getTagsEmailsSelect(index).first().getText()).toEqual('jeandidier@gmail.com');

    outcomeCoursesPage.getFirstRemoveTagEmailSelect().click();
    expect(outcomeCoursesPage.getTagsEmailsSelect(index).count()).toBe(0, 'Wrong number of emails. (3)');
  });

  it('must be able to encode his email and click outside the input', () => {
    const index = 0;

    expect(outcomeCoursesPage.getTagsEmailsSelect(index).count()).toBe(0, 'Wrong number of emails. (1)');

    let emailsInput = outcomeCoursesPage.getEmailsInput(index);
    emailsInput.click();
    emailsInput.sendKeys('jeandidier@gmail.com');

    outcomeCoursesPage.getLanguagesOfTheTrainingFilterInput().click();

    expect(outcomeCoursesPage.getTagsEmailsSelect(index).count()).toBe(1, 'Wrong number of emails. (2)');
    expect(outcomeCoursesPage.getTagsEmailsSelect(index).first().getText()).toEqual('jeandidier@gmail.com');

    outcomeCoursesPage.getFirstRemoveTagEmailSelect().click();
    expect(outcomeCoursesPage.getTagsEmailsSelect(index).count()).toBe(0, 'Wrong number of emails. (3)');
  });

  it('must be able to modify his email by double clicking it', () => {
    const index = 0;

    expect(outcomeCoursesPage.getTagsEmailsSelect(index).count()).toBe(0, 'Wrong number of emails. (1)');

    let emailsInput = outcomeCoursesPage.getEmailsInput(index);
    emailsInput.click();
    emailsInput.sendKeys('jeandidier@gmail.com ');

    expect(outcomeCoursesPage.getTagsEmailsSelect(index).count()).toBe(1, 'Wrong number of emails. (2)');
    expect(outcomeCoursesPage.getTagsEmailsSelect(index).first().getText())
      .toEqual('jeandidier@gmail.com');

    outcomeCoursesPage.getEmailsInput(index);

    let emailLabel = outcomeCoursesPage.getTagsEmailsSelectByName('jeandidier@gmail.com');
    browser.actions().doubleClick(emailLabel).perform();

    emailsInput = outcomeCoursesPage.getEmailsInput(index);
    emailsInput.sendKeys('test ');

    expect(outcomeCoursesPage.getTagsEmailsSelect(index).first().getText())
      .toEqual('jeandidier@gmail.comtest');

    outcomeCoursesPage.getFirstRemoveTagEmailSelect().click();
    expect(outcomeCoursesPage.getTagsEmailsSelect(index).count()).toBe(0, 'Wrong number of emails. (3)');
  });

  it('must be able to encode large email', () => {
    const index = 0;

    expect(outcomeCoursesPage.getTagsEmailsSelect(index).count()).toBe(0, 'Wrong number of emails. (1)');

    let emailsInput = outcomeCoursesPage.getEmailsInput(index);
    emailsInput.click();

    let email = 'azertyuiopqsdfghhjklmwxcvbnazertyuiopqsdfghjklmwxcvbnazertyuiopqsdfghhjklmwxcvbnazertyuiop@gmail.com';
    emailsInput.sendKeys(email + ' ');

    browser.driver.sleep(3000);
    expect(outcomeCoursesPage.getTagsEmailsSelect(index).count()).toBe(1, 'Wrong number of emails. (2)');
    expect(outcomeCoursesPage.getTagsEmailsSelect(index).first().getText()).toEqual(email);

    outcomeCoursesPage.getFirstRemoveTagEmailSelect().click();
    expect(outcomeCoursesPage.getTagsEmailsSelect(index).count()).toBe(0, 'Wrong number of emails. (3)');
  });

  it('must be able to delete large email using the x in the label', () => {
    const index = 0;

    expect(outcomeCoursesPage.getTagsEmailsSelect(index).count()).toBe(0, 'Wrong number of emails. (1)');

    let emailsInput = outcomeCoursesPage.getEmailsInput(index);
    emailsInput.click();

    let email = 'azertyuiopqsdfghhjklmwxcvbnazertyuiopqsdfghjklmwxcvbnazertyuiopqsdfghhjklmwxcvbnazertyuiop@gmail.com';
    emailsInput.sendKeys(email + ' ');

    browser.driver.sleep(3000);
    expect(outcomeCoursesPage.getTagsEmailsSelect(index).count()).toBe(1, 'Wrong number of emails. (2)');
    expect(outcomeCoursesPage.getTagsEmailsSelect(index).first().getText()).toEqual(email);

    outcomeCoursesPage.getFirstRemoveTagEmailSelect().click();
    expect(outcomeCoursesPage.getTagsEmailsSelect(index).count()).toBe(0, 'Wrong number of emails. (3)');
  });

  it('must be able to encode multiple emails', () => {
    const index = 0;

    expect(outcomeCoursesPage.getTagsEmailsSelect(index).count()).toBe(0, 'Wrong number of emails. (1)');

    let emailsInput = outcomeCoursesPage.getEmailsInput(index);
    emailsInput.click();
    emailsInput.sendKeys('jeandidier@gmail.com ');
    emailsInput.sendKeys('jeanpascal@gmail.com ');
    emailsInput.sendKeys('jeankevin@gmail.com ');


    const emailsSelectOptions = outcomeCoursesPage.getTagsEmailsSelect(index);
    expect(emailsSelectOptions.count()).toBe(3, 'Wrong number of emails. (2)');
    expect(emailsSelectOptions.first().getText()).toEqual('jeandidier@gmail.com');
    expect(emailsSelectOptions.get(1).getText()).toEqual('jeanpascal@gmail.com');
    expect(emailsSelectOptions.get(2).getText()).toEqual('jeankevin@gmail.com');

    outcomeCoursesPage.getFirstRemoveTagEmailSelect().click();
    outcomeCoursesPage.getFirstRemoveTagEmailSelect().click();
    outcomeCoursesPage.getFirstRemoveTagEmailSelect().click();
    expect(outcomeCoursesPage.getTagsEmailsSelect(index).count()).toBe(0, 'Wrong number of emails. (3)');
  });

  it('must be able to delete email using the x in the label', () => {
    const index = 0;

    let emailsSelectOptions = outcomeCoursesPage.getTagsEmailsSelect(index);
    expect(emailsSelectOptions.count()).toBe(0, 'Wrong number of emails. (1)');

    let emailsInput = outcomeCoursesPage.getEmailsInput(index);
    emailsInput.click();
    emailsInput.sendKeys('jeandidier@gmail.com ');

    browser.driver.sleep(3000);
    emailsSelectOptions = outcomeCoursesPage.getTagsEmailsSelect(index);
    expect(emailsSelectOptions.count()).toBe(1, 'Wrong number of emails. (2)');
    expect(emailsSelectOptions.first().getText()).toEqual('jeandidier@gmail.com');

    outcomeCoursesPage.getFirstRemoveTagEmailSelect().click();
    expect(outcomeCoursesPage.getTagsEmailsSelect(index).count()).toBe(0, 'Wrong number of emails. (3)');
  });

  it('must not be able to add a space char into an email', () => {
    const index = 0;

    let emailsSelectOptions = outcomeCoursesPage.getTagsEmailsSelect(index);
    expect(emailsSelectOptions.count()).toBe(0, 'Wrong number of emails. (1)');

    let emailsInput = outcomeCoursesPage.getEmailsInput(index);
    emailsInput.click();
    emailsInput.sendKeys('jeandidier@gmail.com');

    browser.driver.sleep(3000);
    emailsSelectOptions = outcomeCoursesPage.getTagsEmailsSelect(index);
    expect(emailsSelectOptions.count()).toBe(0, 'Wrong number of emails. (2)');

    emailsInput.click();
    for (let i = 0; i < 12; i++) {
      emailsInput.sendKeys(protractor.Key.ARROW_LEFT);
    }
    emailsInput.sendKeys(' ');

    browser.driver.sleep(3000);
    expect(outcomeCoursesPage.getTagsEmailsSelect(index).count()).toBe(0, 'Wrong number of emails. (3)');
  });

});
