import {HeaderPage} from '../pages/header.po';
import {HomePage} from '../pages/home.po';
import {PersonalInfoContactPage} from '../pages/personal-info.contact.po';
import {SummaryContactInformationPage} from '../pages/summary/personal-info/summary-contact-information.po';
import {ClearPage} from '../pages/clear.po';

describe('A user on the contact information page', function() {
  let headerPage: HeaderPage;
  let homePage: HomePage;
  let clearPage: ClearPage;
  let personalInfoContactPage: PersonalInfoContactPage;
  let summaryContactInformationPage: SummaryContactInformationPage;

  beforeEach(() => {
    headerPage = new HeaderPage();
    homePage = new HomePage();
    clearPage = new ClearPage();
    personalInfoContactPage = new PersonalInfoContactPage();
    summaryContactInformationPage = new SummaryContactInformationPage();

    homePage.navigateTo();
    homePage.getCreateProfileButton().click();
    headerPage.getContactInformationTabButton().click();
  });

  afterEach(() => {
    headerPage.getClearProfileButton().click();
    clearPage.getValidationButton().click();
  });

  it('must be able to add a wrong email and see that it wrong', () => {
    personalInfoContactPage.getPrincipalEmailPrefixInput().sendKeys('/');
    expect(personalInfoContactPage.getAllPrefixMailErrorLabel().count()).toBe(1);
    personalInfoContactPage.getPrincipalEmailSuffixInput().sendKeys('/');
    expect(personalInfoContactPage.getAllSuffixMailErrorLabel().count()).toBe(1);

    personalInfoContactPage.getAddMailButton().click();
    personalInfoContactPage.getAllMultiMailPrefixInput().get(0).sendKeys('/');
    expect(personalInfoContactPage.getAllPrefixMailErrorLabel().count()).toBe(2);
    personalInfoContactPage.getAllMultiMailSuffixInput().get(0).sendKeys('/');
    expect(personalInfoContactPage.getAllSuffixMailErrorLabel().count()).toBe(2);

    personalInfoContactPage.getAddMailButton().click();
    expect(personalInfoContactPage.getAllPrefixMailErrorLabel().count()).toBe(2);
    expect(personalInfoContactPage.getAllSuffixMailErrorLabel().count()).toBe(2);
  });

  it('must be able to add a secondary email, see it in the summary, remove it and can\'t see anymore the secondary email row', () => {
    personalInfoContactPage.getAddMailButton().click();

    personalInfoContactPage.getAllMultiMailPrefixInput().get(0).sendKeys('john.doe');
    personalInfoContactPage.getAllMultiMailSuffixInput().get(0).sendKeys('gmail.com');

    headerPage.getSummaryButton().click();

    expect(summaryContactInformationPage.isOtherEmailAddressTitlePresent())
      .toBe(true);
    expect(summaryContactInformationPage.getOtherEmailAddress(0).get(0).getText())
      .toBe('john.doe@gmail.com');

    headerPage.getPersonalInformationButton().click();
    headerPage.getContactInformationTabButton().click();

    personalInfoContactPage.getRemoveMailButton(0).click();

    headerPage.getSummaryButton().click();

    expect(summaryContactInformationPage.isOtherEmailAddressTitlePresent())
      .toBe(false);
  });

});
