import {PersonalInfoGeneralPage} from '../pages/personal-info.general.po';
import {HeaderPage} from '../pages/header.po';
import {HomePage} from '../pages/home.po';
import {SummaryGeneralInformationPage} from '../pages/summary/personal-info/summary-general-information.po';
import {browser, protractor} from 'protractor';
import {SummaryPage} from '../pages/summary/summary.po';
import * as path from 'path';
import {PhotoProfilePage} from '../pages/photo-profile.po';

describe('A user on the general information page', function() {
  let headerPage: HeaderPage;
  let homePage: HomePage;
  let photoProfilePage: PhotoProfilePage;
  let personalInfoGeneralPage: PersonalInfoGeneralPage;
  let summaryPage: SummaryPage;
  let summaryGeneralInfoPage: SummaryGeneralInformationPage;

  beforeAll(() => {
    headerPage = new HeaderPage();
    homePage = new HomePage();
    photoProfilePage = new PhotoProfilePage();
    personalInfoGeneralPage = new PersonalInfoGeneralPage();
    summaryPage = new SummaryPage();
    summaryGeneralInfoPage = new SummaryGeneralInformationPage();

    homePage.navigateTo();
    homePage.getCreateProfileButton().click();
  });

  afterAll(() => {
    homePage.navigateTo();
    browser.switchTo().alert().accept();
  });

  it('must be able to add a profile image', () => {
    headerPage.getUploadProfilePhotoButton().click();

    // path of the file
    const fileToUpload = '../resources/profile_picture.jpg';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("image-reader").style.visibility = "visible"; document.getElementById("image-reader").style.display = "inline"'
    );

    photoProfilePage.getImageReaderInput().sendKeys(absolutePath);
    photoProfilePage.getValidModalButton().click();

    expect(headerPage.getImageProfile().getAttribute('src'))
      .not.toBe('assets/images/no_picture_placeholder.png');
  });

  it('must be able to fill all basic fields', () => {
    personalInfoGeneralPage.getFamilyNameInput().sendKeys('Bean');
    personalInfoGeneralPage.getFirstNameInput().sendKeys('Mr.');
    personalInfoGeneralPage.getRadioGenderInput().get(1).click();
    personalInfoGeneralPage.getBirthDateDatePickerInput().sendKeys('28/06/1995', protractor.Key.ENTER);
    personalInfoGeneralPage.getCountryOfBirthDropDown().click();
    personalInfoGeneralPage.getCountryInput().sendKeys('Japan');
    personalInfoGeneralPage.getCountryInput().sendKeys(protractor.Key.ENTER);
    personalInfoGeneralPage.getCountryOfNationalityDropDown().click();
    personalInfoGeneralPage.getCountryInput().sendKeys('Brazil');
    personalInfoGeneralPage.getCountryInput().sendKeys(protractor.Key.ENTER);
    personalInfoGeneralPage.getMaritalStatusDropDownOption('married').click();

    headerPage.getSummaryButton().click();

    expect(summaryGeneralInfoPage.getFamilyName().getText()).toEqual('Bean');
    expect(summaryGeneralInfoPage.getFirstName().getText()).toEqual('Mr.');
    expect(summaryGeneralInfoPage.getGender().getText()).toEqual('Male');
    expect(summaryGeneralInfoPage.getDateOfBirth().getText()).toEqual('28/6/1995');
    expect(summaryGeneralInfoPage.getCountryOfBirth().getText()).toEqual('Japan');
    expect(summaryGeneralInfoPage.getCountryOfNationality().getText()).toEqual('Brazil');
    expect(summaryGeneralInfoPage.getMaritalStatus().getText()).toEqual('Married');

    headerPage.getPersonalInformationButton().click();
  });

  describe('must be able to add a personal identification document :', function () {

    it('Passport', () => {
      personalInfoGeneralPage.getAddIdentificationDocumentButton().click();

      personalInfoGeneralPage.getPersonalIdendificationDropDown(0, 'passport').click();
      personalInfoGeneralPage.getDocumentNumberInput(0).sendKeys('123456789');
      personalInfoGeneralPage.getCountryOfIssue0DropDown().click();
      personalInfoGeneralPage.getCountryInput().sendKeys('France');
      personalInfoGeneralPage.getCountryInput().sendKeys(protractor.Key.ENTER);
      personalInfoGeneralPage.getDocumentValidityDatePickerInput(0).sendKeys('6/1/2042', protractor.Key.ENTER);

      headerPage.getSummaryButton().click();

      expect(summaryGeneralInfoPage.getType().getText()).toEqual('Passport');
      expect(summaryGeneralInfoPage.getNumber().getText()).toEqual('123456789');
      expect(summaryGeneralInfoPage.getCountryOfIssue().getText()).toEqual('France');
      expect(summaryGeneralInfoPage.getExpirationDate().getText()).toEqual('6/1/2042');

      headerPage.getPersonalInformationButton().click();
      personalInfoGeneralPage.getRemoveIdentificationDocumentButton(0).click();
    });

    it('Identity Card', () => {
      personalInfoGeneralPage.getAddIdentificationDocumentButton().click();

      personalInfoGeneralPage.getPersonalIdendificationDropDown(0, 'identityCard').click();
      personalInfoGeneralPage.getDocumentNumberInput(0).sendKeys('147258369');
      personalInfoGeneralPage.getCountryOfIssue0DropDown().click();
      personalInfoGeneralPage.getCountryInput().sendKeys('Madagascar');
      personalInfoGeneralPage.getCountryInput().sendKeys(protractor.Key.ENTER);
      personalInfoGeneralPage.getDocumentValidityDatePickerInput(0).sendKeys('7/8/2029', protractor.Key.ENTER);

      headerPage.getSummaryButton().click();

      expect(summaryGeneralInfoPage.getType().getText()).toEqual('Identity card');
      expect(summaryGeneralInfoPage.getNumber().getText()).toEqual('147258369');
      expect(summaryGeneralInfoPage.getCountryOfIssue().getText()).toEqual('Madagascar');
      expect(summaryGeneralInfoPage.getExpirationDate().getText()).toEqual('7/8/2029');

      headerPage.getPersonalInformationButton().click();
      personalInfoGeneralPage.getRemoveIdentificationDocumentButton(0).click();
    });

    it('Other', () => {
      personalInfoGeneralPage.getAddIdentificationDocumentButton().click();

      personalInfoGeneralPage.getPersonalIdendificationDropDown(0, 'other').click();
      personalInfoGeneralPage.getDocumentTypeInput(0).sendKeys('card');
      personalInfoGeneralPage.getDocumentNumberInput(0).sendKeys('987654321');
      personalInfoGeneralPage.getCountryOfIssue0DropDown().click();
      personalInfoGeneralPage.getCountryInput().sendKeys('Canada');
      personalInfoGeneralPage.getCountryInput().sendKeys(protractor.Key.ENTER);
      personalInfoGeneralPage.getDocumentValidityDatePickerInput(0).sendKeys('5/5/2055', protractor.Key.ENTER);

      headerPage.getSummaryButton().click();

      expect(summaryGeneralInfoPage.getType().getText()).toEqual('Other');
      expect(summaryGeneralInfoPage.getIdentificationDocumentOtherType().getText()).toEqual('card');
      expect(summaryGeneralInfoPage.getNumber().getText()).toEqual('987654321');
      expect(summaryGeneralInfoPage.getCountryOfIssue().getText()).toEqual('Canada');
      expect(summaryGeneralInfoPage.getExpirationDate().getText()).toEqual('5/5/2055');

      headerPage.getPersonalInformationButton().click();
      personalInfoGeneralPage.getRemoveIdentificationDocumentButton(0).click();
    });

  });

  it('must be able to upload a file on an identification document', () => {
    personalInfoGeneralPage.getAddIdentificationDocumentButton().click();

    personalInfoGeneralPage.getPersonalIdendificationDropDown(0, 'passport').click();

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("personal-identification-document-attachment-0-file-reader").style.visibility = "visible";'
      + 'document.getElementById("personal-identification-document-attachment-0-file-reader").style.display = "inline"'
    );

    personalInfoGeneralPage.getDocumentAttachmentFileReaderImput();

    const fileToUpload = '../resources/profile.pdf';
    const absolutePath = path.resolve(__dirname, fileToUpload);
    personalInfoGeneralPage.getDocumentAttachmentFileReaderImput().sendKeys(absolutePath);

    expect(personalInfoGeneralPage.isDocumentAttachmentFilePresent(0))
      .toBe(true,
        'Cannot upload the document.');
  });

});
