import {HomePage} from '../pages/home.po';
import {browser} from 'protractor';
import {FooterPage} from '../pages/footer.po';
import * as fs from 'fs';
import {HeaderPage} from '../pages/header.po';
import {SummaryPage} from '../pages/summary/summary.po';
import * as AdmZip from 'adm-zip';
import * as PDFParser from 'pdf2json';
import * as path from 'path';
import {Labels} from '../labels/labels';
import * as xml2js from 'xml2js';
import {ConsentPage} from '../pages/consent.po';

let labels: Labels = new Labels();

describe('A user must be able to to see the same data from', function() {
  let headerPage: HeaderPage;
  let footerPage: FooterPage;
  let homePage: HomePage;
  let summaryPage: SummaryPage;
  let consentPage: ConsentPage;

  beforeAll(() => {
    headerPage = new HeaderPage();
    footerPage = new FooterPage();
    homePage = new HomePage();
    summaryPage = new SummaryPage();
    consentPage = new ConsentPage();

    homePage.navigateTo();
  });

  afterEach(() => {
    homePage.navigateTo();
  });

  it('his docx profile and the summary', () => {
    // path of the file
    const fileToUpload = '../resources/profile.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    checkInfosBetweenDocxAndSummary(
      './e2e/downloads/Doe_John_' + getDateAsYYYYMMDD() + '.docx');
  });

  it('his docx profile 2 and the summary', () => {
    // path of the file
    const fileToUpload = '../resources/profile_2.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    checkInfosBetweenDocxAndSummary(
      './e2e/downloads/Doe_John_' + getDateAsYYYYMMDD() + '.docx');
  });

  it('his pdf profile and the summary', () => {
    // path of the file
    const fileToUpload = '../resources/profile.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    checkInfosBetweenPdfAndSummary(
      './e2e/downloads/Doe_John_' + getDateAsYYYYMMDD() + '.pdf');
  });

  it('his xml profile and the summary', () => {
    // path of the file
    const fileToUpload = '../resources/profile.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    checkInfosBetweenXmlAndSummary(
      './e2e/downloads/Doe_John_' + getDateAsYYYYMMDD() + '.xml');
  });

  it('his xml profile 2 and the summary', () => {
    // path of the file
    const fileToUpload = '../resources/profile_2.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    checkInfosBetweenXmlAndSummary(
      './e2e/downloads/Doe_John_' + getDateAsYYYYMMDD() + '.xml');
  });

  function checkInfosBetweenDocxAndSummary(docxPath: string) {
    checkFileExistence(docxPath);

    // download the profile as a docx file
    footerPage.getExportButton().click();
    footerPage.getExportAsWordButton().click();

    browser.driver.wait(function() {
      // Wait until the file has been downloaded.
      return fs.existsSync(docxPath);
    }, 60000).then(function() {

      let docxLines = parseDocxFile(docxPath);

      // search all question/answer of the summary
      headerPage.getSummaryButton().click();

      let summaryLines = [];
      let removeNextEmailLabel = false;
      let removeNextOtherDigitalSkillsLabel = false;
      summaryPage.getAllQuestionAndResponseLabel()
        .each(function(element) {
          element.getText().then((text) => {
            let result = formatSummaryLine(text, removeNextEmailLabel, removeNextOtherDigitalSkillsLabel);
            if (result.addText) {
              summaryLines.push(result.text);
            }
            if (result.removeLast) {
              summaryLines.pop();
            }
            removeNextEmailLabel = result.removeNextEmailLabel;
            removeNextOtherDigitalSkillsLabel = result.removeNextOtherDigitalSkillsLabel;
          });
        })
        .then(() => {
          // remove the specials strings
          docxLines = docxLines.slice(3);

          let result = compareDownloadedFileAndSummary(docxLines, summaryLines);
          docxLines = result.document;
          summaryLines = result.summary;

          docxLines = removeUnusedStrings(docxLines);

          expect(summaryLines.length).toBe(0,
            'Some fields are not found for the summary : ' + summaryLines);
          expect(docxLines.length).toBe(0,
            'Some fields are not found for the docx file : ' + docxLines);

          fs.unlinkSync(docxPath);
        });

    });

  }

  function checkInfosBetweenPdfAndSummary(pdfPath: string) {
    checkFileExistence(pdfPath);

    footerPage.getExportButton().click();
    footerPage.getExportAsPdfButton().click();

    // download the pdf
    browser.driver.wait(function() {
      // Wait until the file has been downloaded.
      return fs.existsSync(pdfPath);
    }, 60000).then(function() {

      headerPage.getSummaryButton().click();

      // search all question/answer of the summary
      let summaryLines = [];
      let removeNextEmailLabel = false;
      let removeNextOtherDigitalSkillsLabel = false;
      summaryPage.getAllQuestionAndResponseLabel()
        .each(function(element) {
          element.getText().then((text) => {
            let result = formatSummaryLine(text, removeNextEmailLabel, removeNextOtherDigitalSkillsLabel);
            if (result.addText) {
              summaryLines.push(result.text);
            }
            if (result.removeLast) {
              summaryLines.pop();
            }
            removeNextEmailLabel = result.removeNextEmailLabel;
            removeNextOtherDigitalSkillsLabel = result.removeNextOtherDigitalSkillsLabel;
          });
        })
        .then(() => {

          let parseFinished = false;
          let pdfStrings: Array<string> = [];

          let pdfParser = new PDFParser();

          pdfParser.on('pdfParser_dataError', errData => console.error(errData.parserError) );
          pdfParser.on('pdfParser_dataReady', pdfData => {
            pdfStrings = getPdfLeafs(pdfData, 'T', pdfStrings);
            parseFinished = true;
          });

          pdfParser.loadPDF(pdfPath);

          browser.driver.wait(function () {
            return parseFinished;
          }).then(function () {

            pdfStrings = parsePdfFile(pdfStrings);

            // remove the specials strings
            pdfStrings = pdfStrings.slice(3);

            let result = compareDownloadedFileAndSummary(pdfStrings, summaryLines);
            pdfStrings = result.document;
            summaryLines = result.summary;

            pdfStrings = removeUnusedStrings(pdfStrings);

            expect(summaryLines.length).toBe(0,
              'Some fields are not found for the summary : ' + summaryLines);
            expect(pdfStrings.length).toBe(0,
              'Some fields are not found for the pdf file : ' + pdfStrings);

            fs.unlinkSync(pdfPath);
          });

        });

    });

  }

  function checkInfosBetweenXmlAndSummary(xmlPath: string) {
    checkFileExistence(xmlPath);

    footerPage.getExportButton().click();
    footerPage.getExportAsXmlButton().click();

    // download the xml
    browser.driver.wait(function() {
      // Wait until the file has been downloaded.
      return fs.existsSync(xmlPath);
    }, 30000).then(function() {

      headerPage.getSummaryButton().click();

      // search all question/answer of the summary
      let summaryLines = [];
      let removeNextEmailLabel = false;
      let removeNextOtherDigitalSkillsLabel = false;
      summaryPage.getAllQuestionAndResponseLabel()
        .each(function(element) {
          element.getText().then((text) => {
            let result = formatSummaryLineForXml(text, removeNextEmailLabel, removeNextOtherDigitalSkillsLabel);
            if (result.addText) {
              summaryLines.push(result.text);
            }
            if (result.removeLast) {
              summaryLines.pop();
            }
            removeNextEmailLabel = result.removeNextEmailLabel;
            removeNextOtherDigitalSkillsLabel = result.removeNextOtherDigitalSkillsLabel;
          });
        })
        .then(() => {

          const parser = new xml2js.Parser({explicitArray: false});
          parser.parseString(fs.readFileSync(xmlPath, 'utf8'), function (err, jsonXml) {

            let xmlLines = getAllLeafOfJsonObject(jsonXml['profile'], 'profile', [])
              .filter(line =>
                line.indexOf('Other first name(s)') === -1
                && line.indexOf('Other nationalities') === -1
                && line.indexOf('Other telephone number(s)') === -1)
              .map(line => checkLabels(line))
              .map(line => line
                .replace(/ /g, '')
                .replace(/Certificate\/Diploma[0-9]+/g, 'Certificate/Diploma')
                .replace(/Personalidentificationdocument[0-9]+/g, 'Personalidentificationdocument')
                .replace(/otherlanguage/g, ''));

            const result = compareDownloadedFileAndSummary(xmlLines, summaryLines);
            xmlLines = result.document;
            summaryLines = result.summary;

            expect(summaryLines.length).toBe(0,
              'Some fields are not found for the summary : ' + summaryLines);
            expect(xmlLines.length).toBe(0,
              'Some fields are not found for the xml file : ' + xmlLines);

            fs.unlinkSync(xmlPath);
          });

        });

    });

  }

});

function getDateAsYYYYMMDD() {
  const date = new Date();
  return [
    date.getFullYear(),
    ((date.getMonth() + 1) > 9 ? '' : '0') + (date.getMonth() + 1),
    (date.getDate() > 9 ? '' : '0') + date.getDate()
  ].join('');
}

function checkFileExistence(filePath: string) {
  // check if the file already exists
  if (fs.existsSync(filePath)) {
    fs.unlinkSync(filePath);
  }
}

function formatSummaryLine(text, removeNextEmailLabel: boolean, removeNextOtherDigitalSkillsLabel: boolean) {
  let addText = false;
  let removeLast = false;
  text = text.replace(/ |\r\n|\r|\n/g, '');

  // used to remove unused the label "Email address" on the pdf from the summary
  if (removeNextEmailLabel === false && text.indexOf('Emailaddress') !== -1) {
    removeNextEmailLabel = true;
  } else if (removeNextEmailLabel === true && text.indexOf('Emailaddress') !== -1) {
    text = text.replace(/Emailaddress/g, '');
  } else if (removeNextEmailLabel === true && text.indexOf('Emailaddress') === -1) {
    removeNextEmailLabel = null;
  }

  // used to remove unused the label "Other digital skills" on the pdf from the summary
  if (removeNextOtherDigitalSkillsLabel === false && text.indexOf('Otherdigitalskills') !== -1) {
    removeNextOtherDigitalSkillsLabel = true;
  } else if (removeNextOtherDigitalSkillsLabel === true && text.indexOf('Otherdigitalskills') !== -1) {
    text = text.replace(/Otherdigitalskills/, '');
  } else if (removeNextOtherDigitalSkillsLabel === true && text.indexOf('Otherdigitalskills') === -1) {
    removeNextOtherDigitalSkillsLabel = null;
  }

  if (text === 'No') {
    removeLast = true;
  } else if (((text.indexOf('Indicatehowyoucandothis?') !== -1 && text.indexOf('calculator') !== -1)
    || text.indexOf('Indicatehowyoucandothis?') === -1)
    && text.indexOf('No') === -1) {
    text = text
      .replace(/☆|★|Otherfirstname\(s\)|Othernationalities|Otherlanguage|Othertelephonenumber\(s\)|0Week\(s\)|0Month\(s\)|0Year\(s\)/g, '')
      .replace(/Personalidentificationdocument[0-9]/g, 'Personalidentificationdocument')
      .replace(/Certificate\/Diploma[0-9]/g, 'Certificate/Diploma');
    addText = true;
  }

  return {
    text: text,
    removeNextEmailLabel: removeNextEmailLabel,
    removeNextOtherDigitalSkillsLabel : removeNextOtherDigitalSkillsLabel,
    addText: addText,
    removeLast: removeLast
  };
}

function parseDocxFile(zipPath: string): Array<string> {
  let zip = new AdmZip(zipPath);
  let downloadedDocument = zip.readAsText('word' + path.sep + 'document.xml');
  return downloadedDocument
    // create an array for each lines of the document.xml
    .split(/\r\n|\n|\r/)
    // get only the text lines
    .filter(line => line.indexOf('<w:t>') !== -1)
    // remove the tags
    .map(line => line.replace(/ |<\/?w:t>/g, ''));
}

/**
 * Get all leafs of the xml corresponding to the labels of the pdf.
 *
 * @param {JSON} xml
 * @param {string} tag
 * @param {Array<string>} leafs
 * @returns {Array<string>}
 */
function getPdfLeafs(xml: JSON, tag: string, leafs: Array<string>): Array<string> {
  if (xml['T'] !== undefined && xml['TS'] !== undefined && xml['TS'][1] !== 15) {
    leafs.push(xml['T']);
  }

  for (let element in xml) {
    if (typeof xml === 'object') {
      leafs = getPdfLeafs(xml[element], tag, leafs);
    }
  }
  return leafs;
}

/**
 * Change all encoded chars for all string from the pdf.
 *
 * @param {Array<string>} pdfStrings
 * @returns {Array<string>}
 */
function parsePdfFile(pdfStrings: Array<string>): Array<string> {
  return pdfStrings.map(string => {
    if (string.indexOf('%20') !== -1) {
      string = string.replace(/%20/g, '');
    }
    if (string.indexOf('%2F') !== -1) {
      string = string.replace(/%2F/g, '/');
    }
    if (string.indexOf('%2B') !== -1) {
      string = string.replace(/%2B/g, '+');
    }
    if (string.indexOf('%40') !== -1) {
      string = string.replace(/%40/g, '@');
    }
    if (string.indexOf('%3F') !== -1) {
      string = string.replace(/%3F/g, '?');
    }
    if (string.indexOf('%2C') !== -1) {
      string = string.replace(/%2C/g, ',');
    }
    if (string.indexOf('%C3%85') !== -1) {
      string = string.replace(/%C3%85/g, 'Å');
    }
    return string;
  });
}

function compareDownloadedFileAndSummary(downloadedDocumentLines: Array<string>, summaryLines: Array<string>) {
  let indexSummary = 0;
  let indexDocument = 0;
  while (indexSummary < summaryLines.length && summaryLines.length !== 0
  && indexDocument < downloadedDocumentLines.length && downloadedDocumentLines.length !== 0) {

    let summaryLine: string = summaryLines[indexSummary];
    let documentLine: string = downloadedDocumentLines[indexDocument];

    if (summaryLine.replace(documentLine, '') === '') {
      // case 1 summary line = 1 pdf string
      summaryLines.splice(indexSummary, 1);
      downloadedDocumentLines.splice(indexDocument, 1);
      indexDocument = 0;
    } else if (summaryLine.indexOf(documentLine) !== -1) {
      // part of string find in the line
      summaryLines[indexSummary] = summaryLine.replace(documentLine, '');
      downloadedDocumentLines.splice(indexDocument, 1);
      indexDocument = 0;
    } else {
      indexDocument++;
    }

  }

  return {
    document: downloadedDocumentLines,
    summary: summaryLines
  };
}

/**
 * Remove the unused strings find in the summary but not int the downloaded document.
 *
 * @param {Array<string>} downloadedDocumentLines
 * @returns {Array<string>}
 */
function removeUnusedStrings(downloadedDocumentLines: Array<string>): Array<string> {
  return downloadedDocumentLines.filter(string =>
    string.indexOf('Personalinformation') === -1
    && string.indexOf('Expectations') === -1
    && string.indexOf('Skillsidentification') === -1
    && string.indexOf('Overallappraisalandrecommendednextsteps') === -1
    && string.indexOf('Otherfieldofstudy') === -1
    && string.indexOf('Doyouspeakotherlanguages?') === -1 // for docx
    && string.indexOf('Pleaseindicateyourfield(s)ofstudyandforhowlong.') === -1 // for docx
    && string.indexOf('Doyouspeakother') === -1 && string.indexOf('languages?') === -1 // for pdf
    && string.indexOf('Pleaseindicateyour') === -1 && string.indexOf('field(s)ofstudyand') === -1 // for pdf
    && string.indexOf('forhowlong.') === -1 // for pdf
  );
}

// xml functions

function formatSummaryLineForXml(text, removeNextEmailLabel: boolean, removeNextOtherDigitalSkillsLabel: boolean) {
  let addText = false;
  let removeLast = false;
  text = text.replace(/\r\n|\r|\n/g, '');

  // used to remove unused the label "Email address" on the pdf from the summary
  if (removeNextEmailLabel === false && text.indexOf('Email address') !== -1) {
    removeNextEmailLabel = true;
  } else if (removeNextEmailLabel === true && text.indexOf('Email address') !== -1) {
    text = text.replace(/Email address/g, '');
  } else if (removeNextEmailLabel === true && text.indexOf('Email address') === -1) {
    removeNextEmailLabel = null;
  }

  // used to remove unused the label "Other digital skills" on the pdf from the summary
  if (removeNextOtherDigitalSkillsLabel === false && text.indexOf('Other digital skills') !== -1) {
    removeNextOtherDigitalSkillsLabel = true;
  } else if (removeNextOtherDigitalSkillsLabel === true && text.indexOf('Other digital skills') !== -1) {
    text = text.replace(/Other digital skills/, '');
  } else if (removeNextOtherDigitalSkillsLabel === true && text.indexOf('Other digital skills') === -1) {
    removeNextOtherDigitalSkillsLabel = null;
  }

  if (text === 'No') {
    removeLast = true;
  } else if (text !== 'General information' && text !== 'Contact information' && text !== 'Migration information' && text !== 'Language'
    && text !== 'Education and Training' && text !== 'Numeracy Skills' && text !== 'Digital skills' && text !== 'Professional skills'
    && text !== 'Skills acquired outside the workplace' && text !== 'Other basic and transversal skills' && text !== 'Driving Skills'
    && text !== 'Strengths' && text !== 'Recognition' && text !== 'Validation' && text !== 'Training' && text !== 'Work'
    && text !== 'Guidance' && text !== ' Organisation' && text !== 'Literacy Skills'
    && ((text.indexOf('Indicate how you can do this?') !== -1 && text.indexOf('calculator') !== -1)
      || text.indexOf('Indicate how you can do this?') === -1)
    && text.indexOf('No') === -1) {
    text = text
      .replace(/☆|★|Other first name\(s\)|Other nationalities|Other language|Other telephone number\(s\)|0 Week\(s\)|0 Month\(s\)|0 Year\(s\)/g, '')
      .replace(/Personal identification document [0-9]/g, 'Personal identification document')
      .replace(/Certificate \/ Diploma [0-9]/g, 'Certificate / Diploma');

    text = checkLabels(text);

    addText = true;
  }

  text = text.replace(/ /g, '');

  return {
    text: text,
    removeNextEmailLabel: removeNextEmailLabel,
    removeNextOtherDigitalSkillsLabel : removeNextOtherDigitalSkillsLabel,
    addText: addText,
    removeLast: removeLast
  };
}

function checkLabels(text: string): string {

  for (let key in labels.countries) {
    if (text.indexOf(labels.countries[key]) !== -1) {
      text = text.replace(new RegExp(labels.countries[key], 'g'), key);
    }
  }
  for (let key in labels.maritalStatus) {
    if (text.indexOf(labels.maritalStatus[key]) !== -1) {
      text = text.replace(new RegExp(labels.maritalStatus[key], 'g'), key);
    }
  }
  for (let key in labels.genderCodes) {
    if (text.indexOf(labels.genderCodes[key]) !== -1) {
      text = text.replace(new RegExp(labels.genderCodes[key], 'g'), key);
    }
  }
  for (let key in labels.documentTypes) {
    if (text.indexOf(labels.documentTypes[key]) !== -1) {
      text = text.replace(new RegExp(labels.documentTypes[key], 'g'), key);
    }
  }
  for (let key in labels.residentialStatuses) {
    if (text.indexOf(labels.residentialStatuses[key]) !== -1) {
      text = text.replace(new RegExp(labels.residentialStatuses[key], 'g'), key);
    }
  }
  for (let key in labels.workPermitStatuses) {
    if (text.indexOf(labels.workPermitStatuses[key]) !== -1) {
      text = text.replace(new RegExp(labels.workPermitStatuses[key], 'g'), key);
    }
  }
  for (let key in labels.booleanTranslation) {
    if (text.indexOf(labels.booleanTranslation[key]) !== -1) {
      text = text.replace(new RegExp(labels.booleanTranslation[key], 'g'), key);
    }
  }
  for (let key in labels.languageTypes) {
    if (text.indexOf(labels.languageTypes[key]) !== -1) {
      text = text.replace(new RegExp(labels.languageTypes[key], 'g'), key);
    }
  }
  for (let key in labels.expectationTypes) {
    if (text.indexOf(labels.expectationTypes[key]) !== -1) {
      text = text.replace(new RegExp(labels.expectationTypes[key], 'g'), key);
    }
  }
  for (let key in labels.educationTypes) {
    if (text.indexOf(labels.educationTypes[key]) !== -1) {
      text = text.replace(new RegExp(labels.educationTypes[key], 'g'), key);
    }
  }
  for (let key in labels.studyFieldTypes) {
    if (text.indexOf(labels.studyFieldTypes[key]) !== -1) {
      text = text.replace(new RegExp(labels.studyFieldTypes[key], 'g'), key);
    }
  }
  for (let key in labels.commitmentTimes) {
    if (text.indexOf(labels.commitmentTimes[key]) !== -1) {
      text = text.replace(new RegExp(labels.commitmentTimes[key], 'g'), key);
    }
  }
  for (let key in labels.workTypes) {
    if (text.indexOf(labels.workTypes[key]) !== -1) {
      text = text.replace(new RegExp(labels.workTypes[key], 'g'), key);
    }
  }
  for (let key in labels.fieldOfActivityTypes) {
    if (text.indexOf(labels.fieldOfActivityTypes[key]) !== -1) {
      text = text.replace(new RegExp(labels.fieldOfActivityTypes[key], 'g'), key);
    }
  }
  for (let key in labels.occupationTypes) {
    if (text.indexOf(labels.occupationTypes[key]) !== -1) {
      text = text.replace(new RegExp(labels.occupationTypes[key], 'g'), key);
    }
  }
  for (let key in labels.educationLevels) {
    if (text.indexOf(labels.educationLevels[key]) !== -1) {
      text = text.replace(new RegExp(labels.educationLevels[key], 'g'), key);
    }
  }
  for (let key in labels.capacityTypes) {
    if (text.indexOf(labels.capacityTypes[key]) !== -1) {
      text = text.replace(new RegExp(labels.capacityTypes[key], 'g'), key);
    }
  }
  for (let key in labels.ratingTypes) {
    if (text.indexOf(labels.ratingTypes[key]) !== -1) {
      text = text.replace(new RegExp(labels.ratingTypes[key], 'g'), key);
    }
  }
  for (let key in labels.professionalExperienceTypes) {
    if (text.indexOf(labels.professionalExperienceTypes[key]) !== -1) {
      text = text.replace(new RegExp(labels.professionalExperienceTypes[key], 'g'), key);
    }
  }
  for (let key in labels.skillTypes) {
    if (text.indexOf(labels.skillTypes[key]) !== -1) {
      text = text.replace(new RegExp(labels.skillTypes[key], 'g'), key);
    }
  }
  for (let key in labels.sizeTypes) {
    if (text.indexOf(labels.sizeTypes[key]) !== -1) {
      text = text.replace(new RegExp(labels.sizeTypes[key].replace(/\+/g, '\\+'), 'g'), key);
    }
  }
  for (let key in labels.frequencyTypes) {
    if (text.indexOf(labels.frequencyTypes[key]) !== -1) {
      text = text.replace(new RegExp(labels.frequencyTypes[key], 'g'), key);
    }
  }
  for (let key in labels.organisationTypes) {
    if (text.indexOf(labels.organisationTypes[key]) !== -1) {
      text = text.replace(new RegExp(labels.organisationTypes[key], 'g'), key);
    }
  }
  for (let key in labels.educationOrTrainingTypes) {
    if (text.indexOf(labels.educationOrTrainingTypes[key]) !== -1) {
      text = text.replace(new RegExp(labels.educationOrTrainingTypes[key], 'g'), key);
    }
  }

  return text;
}

let profile_skillsIdentification_educationTraining_highestLevel = null;
let profile_skillsIdentification_languageSkills_hostCountry = null;
function getAllLeafOfJsonObject(xml: JSON, path: string, leafs: Array<string>): Array<string> {
  for (let element in xml) {
    // condition used to remove the unused first element
    if (element !== '$'
      && path + '.' + element !== 'profile.outcome.statistics' && path + '.' + element !== 'profile.outcome.stored'
      && path + '.' + element !== 'profile.outcome.courses' && path + '.' + element !== 'profile.outcome.recommendations') {

      if (path + '.' + element === 'profile.skillsIdentification.educationTraining.highestLevel') {
        profile_skillsIdentification_educationTraining_highestLevel = xml[element];
      }
      if (path + '.' + element === 'profile.skillsIdentification.languageSkills.communicateInHostCountry') {
        profile_skillsIdentification_languageSkills_hostCountry = xml[element];
      }

      if (path + '.' + element === 'profile.skillsIdentification.educationTraining.fullTimeWeek') {
        leafs.push(buildDuration(xml['fullTimeWeek'], xml['fullTimeMonth'], xml['fullTimeYear'], path + '.' + element));
      } else if (path + '.' + element === 'profile.skillsIdentification.educationTraining.partTimeWeek') {
        leafs.push(buildDuration(xml['partTimeWeek'], xml['partTimeMonth'], xml['partTimeYear'], path + '.' + element));
      } else if (path + '.' + element === 'profile.skillsIdentification.educationTraining.studyFieldWeek'
        && (profile_skillsIdentification_educationTraining_highestLevel === 'other'
          || profile_skillsIdentification_educationTraining_highestLevel === 'higher_education')) {
        leafs.push(buildDuration(xml['studyFieldWeek'], xml['studyFieldMonth'], xml['studyFieldYear'], ''));
      } else if (path + '.' + element === 'profile.skillsIdentification.professionalSkills.durationWeek') {
        leafs.push(buildDuration(xml['durationWeek'], xml['durationMonth'], xml['durationYear'], path + '.' + element));
      } else if (path + '.' + element === 'profile.skillsIdentification.digitalSkills.other') {
        leafs.push('Other digital skills');
        leafs.push(xml[element]);
      } else if ( // elements to ignore
        path + '.' + element !== 'profile.skillsIdentification.educationTraining.fullTimeMonth'
        && path + '.' + element !== 'profile.skillsIdentification.educationTraining.fullTimeYear'
        && path + '.' + element !== 'profile.skillsIdentification.educationTraining.partTimeMonth'
        && path + '.' + element !== 'profile.skillsIdentification.educationTraining.partTimeYear'
        && path + '.' + element !== 'profile.skillsIdentification.educationTraining.otherField'
        && path + '.' + element !== 'profile.skillsIdentification.educationTraining.studyFieldWeek'
        && path + '.' + element !== 'profile.skillsIdentification.educationTraining.studyFieldMonth'
        && path + '.' + element !== 'profile.skillsIdentification.educationTraining.studyFieldYear'
        && path + '.' + element !== 'profile.skillsIdentification.professionalSkills.durationMonth'
        && path + '.' + element !== 'profile.skillsIdentification.professionalSkills.durationYear'
        && (path + '.' + element !== 'profile.skillsIdentification.literacySkills'
        || profile_skillsIdentification_educationTraining_highestLevel === null
        || profile_skillsIdentification_educationTraining_highestLevel === 'primary_education')
        && (path + '.' + element !== 'profile.skillsIdentification.educationTraining.otherExplanation'
        || profile_skillsIdentification_educationTraining_highestLevel === 'other')
        && (path + '.' + element !== 'profile.skillsIdentification.educationTraining.studyField'
        || profile_skillsIdentification_educationTraining_highestLevel === 'other'
        || profile_skillsIdentification_educationTraining_highestLevel === 'higher_education')
        && (path + '.' + element !== 'profile.skillsIdentification.educationTraining.studyFields'
        || profile_skillsIdentification_educationTraining_highestLevel === 'other'
        || profile_skillsIdentification_educationTraining_highestLevel === 'higher_education')
        && (path + '.' + element !== 'profile.skillsIdentification.educationTraining.otherField'
        || profile_skillsIdentification_educationTraining_highestLevel === 'other'
        || profile_skillsIdentification_educationTraining_highestLevel === 'higher_education')
        && (path + '.' + element !== 'profile.skillsIdentification.educationTraining.otherStudyFields'
        || profile_skillsIdentification_educationTraining_highestLevel === 'other'
        || profile_skillsIdentification_educationTraining_highestLevel === 'higher_education')
        && (path + '.' + element !== 'profile.skillsIdentification.educationTraining.educationType'
        || profile_skillsIdentification_educationTraining_highestLevel === 'other'
        || profile_skillsIdentification_educationTraining_highestLevel === 'higher_education')
        && (path + '.' + element !== 'profile.skillsIdentification.educationTraining.priorLearning'
        || profile_skillsIdentification_educationTraining_highestLevel === 'other'
        || profile_skillsIdentification_educationTraining_highestLevel === 'higher_education')
        && (path + '.' + element !== 'profile.skillsIdentification.languageSkills.communicateInHostCountry'
        || xml['communicateInHostCountry'] === 'true')
        && (path + '.' + element !== 'profile.skillsIdentification.educationTraining.certificate' ||
        (xml['certificate'] === 'true' && profile_skillsIdentification_educationTraining_highestLevel !== 'primary_education'))) {

        if (path + '.' + element === 'profile.personalInfo.firstNames') {
          leafs = extractSimpleArrayInformations('Other first name(s)', xml[element], leafs, false, false, false);
        } else if (path + '.' + element === 'profile.personalInfo.nationalities') {
          leafs = extractSimpleArrayInformations('Other nationalities', xml[element], leafs, false, false, false);
        } else if (path + '.' + element === 'profile.personalInfo.otherMaritalStatuses') {
          leafs = extractSimpleArrayInformations('Other marital statuses', xml[element], leafs, false, false, false);
        } else if (path + '.' + element === 'profile.personalInfo.contactInfo.phoneNumbers'
          || path + '.' + element === 'profile.outcome.organisations.organisationContactInfo.phoneNumbers') {
          leafs = extractSimpleArrayInformations('Other telephone number(s)', xml[element], leafs, false, false, false);
        } else if (path + '.' + element === 'profile.personalInfo.contactInfo.emails') {
          leafs = extractSimpleArrayInformations('', xml[element], leafs, false, true, false);
        } else if (path + '.' + element === 'profile.skillsIdentification.educationTraining.educationType') {
          leafs = extractSimpleArrayInformations('Please indicate the type(s) of education and/ or training you attended.',
            xml[element], leafs, true, false, false);
        } else if (path + '.' + element === 'profile.skillsIdentification.languageSkills.otherMotherTongue'
          || path + '.' + element === 'profile.skillsIdentification.educationTraining.studyFields'
          || path + '.' + element === 'profile.skillsIdentification.educationTraining.otherStudyFields'
          || path + '.' + element === 'profile.skillsIdentification.digitalSkills.others') {
          leafs = extractSimpleArrayInformations('', xml[element], leafs, false, false, false);
        } else if (path + '.' + element === 'profile.personalInfo.identificationDocuments') {
          leafs = buildIdentificationDocuments(xml[element], path + '.' + element, leafs);
        } else if (path + '.' + element === 'profile.expectations') {
          leafs = buildExpectations(xml[element], path + '.' + element, leafs);
        } else if (path + '.' + element === 'profile.skillsIdentification.languageSkills.hostCountry'
          || path + '.' + element === 'profile.skillsIdentification.languageSkills.preferredGeneral'
          || path + '.' + element === 'profile.skillsIdentification.languageSkills.preferredProfessional'
          || path + '.' + element === 'profile.skillsIdentification.languageSkills.otherLanguages') {
          leafs = buildLanguage(xml[element], path + '.' + element, leafs);
        } else if (path + '.' + element === 'profile.skillsIdentification.educationTraining.certificates') {
          leafs = buildCertificate(xml[element], path + '.' + element, leafs);
        } else if (path + '.' + element === 'profile.skillsIdentification.numeracySkills') {
          leafs = buildNumeracySkills(xml[element], path + '.' + element, leafs);
        } else if (path + '.' + element === 'profile.skillsIdentification.professionalSkills.experiences') {
          leafs = buildExperience(xml[element], path + '.' + element, leafs);
        } else if (path + '.' + element === 'profile.skillsIdentification.outsideSkills') {
          leafs = buildOutsideSkills(xml[element], path + '.' + element, leafs);
        } else if (path + '.' + element === 'profile.outcome.organisations') {
          leafs = buildOrganisations(xml[element], path + '.' + element, leafs);
        } else if (path + '.' + element === 'profile.skillsIdentification.literacySkills') {
          leafs = buildLiteracySkills(xml[element], path + '.' + element, leafs);
        } else if (path + '.' + element === 'profile.skillsIdentification.otherBasicTransversalSkills') {
          leafs = buildOtherBasicTransversalSkills(xml[element], path + '.' + element, leafs);
        } else if (typeof xml[element] !== 'object') {
          // if it's a leaf
          leafs.push(formatLabel(path + '.' + element, xml[element]));
        } else if (xml[element]['day'] !== undefined) {
          // if it's a date
          leafs.push(formatLabel(path + '.' + element, formatDate(xml[element])));
        } else if (xml[element]['prefix']) {
          // if it's a tel number or email
          leafs.push(formatLabel(path + '.' + element, formatNumberOrEmail(xml[element], element.indexOf('email') !== -1)));
        } else {
          leafs = getAllLeafOfJsonObject(xml[element], path + '.' + element, leafs);
        }

      }

    }
  }
  return leafs;
}

function buildLiteracySkills(xml: JSON, path: string, leafs: Array<string>): Array<string> {
  for (let element in xml) {
    if (xml[element] === 'true') {
      // is leaf
      leafs.push(formatLabel(path + '.' + element, xml[element]));
    } else {
      leafs = extractSimpleArrayInformations(labels.tags[path + '.' + element], xml[element], leafs, true, false, true);
    }
  }
  return leafs;
}

function buildOtherBasicTransversalSkills(xml: JSON, path: string, leafs: Array<string>): Array<string> {
  for (let element in xml) {
    if (xml.hasOwnProperty(element)) {
      leafs.push(formatLabel(path + '.' + element, labels.ratingTypes[xml[element]]));
    }
  }
  return leafs;
}

function buildOrganisations(xml: JSON, path: string, leafs: Array<string>): Array<string> {
  for (let index in xml) {
    if (xml.hasOwnProperty(index)) {
      leafs.push('Organisation');

      for (let element in xml[index]) {

        if (path + '.' + element === 'profile.outcome.organisations.dateOfIssuance') {
          leafs.push(
            formatLabel('profile.outcome.organisations.dateOfIssuance',
              xml[index][element]['day'] + '/' + xml[index][element]['month'] + '/' + xml[index][element]['year']));
        } else if (path + '.' + element === 'profile.outcome.organisations.organisationContactInfo') {
          leafs = getAllLeafOfJsonObject(xml[index][element], path + '.' + element, leafs);
        } else {
          leafs.push(formatLabel(path + '.' + element, xml[index][element]));
        }

      }

    }
  }
  return leafs;
}

function buildOutsideSkills(xml: JSON, path: string, leafs: Array<string>): Array<string> {
  for (let outsideSkill in xml) {
    if (xml.hasOwnProperty(outsideSkill)) {

      for (let element in xml[outsideSkill]) {
        if (path + '.' + element === 'profile.skillsIdentification.outsideSkills.rate' && xml[outsideSkill][element] > 0) {
          leafs.push(formatLabel(path + '.' + outsideSkill, labels.ratingTypes[xml[outsideSkill][element]]));
        } else if (element === 'durationMonth') {
          leafs.push(buildDuration('0', xml[outsideSkill]['durationMonth'], xml[outsideSkill]['durationYear'], path + '.' + element));
        } else if (element !== 'durationYear') {
          leafs.push(formatLabel(path + '.' + element, xml[outsideSkill][element]));
        }

      }

    }
  }
  return leafs;
}

function buildExperience(xml: JSON, path: string, leafs: Array<string>): Array<string> {
  for (let index in xml) {
    if (xml.hasOwnProperty(index)) {
      leafs.push('Experience ' + (Number(index) + 1));

      for (let element in xml[index]) {
        if (path + '.' + element === 'profile.skillsIdentification.professionalSkills.experiences.durationWeek') {
          leafs.push(
            buildDuration(xml[index]['durationWeek'], xml[index]['durationMonth'], xml[index]['durationYear'], path + '.' + element));
        } else if (path + '.' + element !== 'profile.skillsIdentification.professionalSkills.experiences.durationMonth'
          && path + '.' + element !== 'profile.skillsIdentification.professionalSkills.experiences.durationYear') {

          if (path + '.' + element === 'profile.skillsIdentification.professionalSkills.experiences.otherLanguages'
            || path + '.' + element === 'profile.skillsIdentification.professionalSkills.experiences.otherSkills') {
            leafs = extractSimpleArrayInformations('', xml[index][element], leafs, false, false, false);
          } else {
            leafs.push(formatLabel(path + '.' + element, xml[index][element]));
          }

        }

      }
    }
  }
  return leafs;
}

function buildNumeracySkills(xml: JSON, path: string, leafs: Array<string>): Array<string> {
  for (let numeracySkill in xml) {

    if (path + '.' + numeracySkill === 'profile.skillsIdentification.numeracySkills.charts' && xml[numeracySkill] > '0'
      || path + '.' + numeracySkill === 'profile.skillsIdentification.numeracySkills.metric' && xml[numeracySkill] > '0') {
      leafs.push(formatLabel(path + '.' + numeracySkill, labels.ratingTypes[xml[numeracySkill]]));
    } else {
      for (let element in xml[numeracySkill]) {
        if (path + '.' + element === 'profile.skillsIdentification.numeracySkills.rate' && xml[numeracySkill][element] > '0') {
          leafs.push(formatLabel(path + '.' + numeracySkill, labels.ratingTypes[xml[numeracySkill][element]]));
        } else if (path + '.' + element === 'profile.skillsIdentification.numeracySkills.calculator'
          && xml[numeracySkill][element] !== '') {
          leafs.push('Indicate how you can do this?');
          for (let useCalculator in xml[numeracySkill][element]) {
            if (xml[numeracySkill][element].hasOwnProperty(useCalculator)) {
              leafs.push(formatLabel(path + '.' + element + '.' + useCalculator, ''));
            }
          }
        } else if (path + '.' + element === 'profile.skillsIdentification.numeracySkills.usage' && xml[numeracySkill][element] !== '') {
          leafs.push('Indicate the area in which you do this?');
          for (let usage in xml[numeracySkill][element]) {
            if (xml[numeracySkill][element].hasOwnProperty(usage)) {
              leafs.push(formatLabel(path + '.' + element + '.' + usage, ''));
            }
          }
        }
      }
    }

  }
  return leafs;
}

function buildCertificate(xml: JSON, path: string, leafs: Array<string>): Array<string> {
  for (let index in xml) {
    if (xml.hasOwnProperty(index)) {
      leafs.push('Certificate / Diploma ' + (Number(index) + 1));
      for (let certificateElement in xml[index]) {
        if (xml[index].hasOwnProperty(certificateElement)) {
          leafs.push(formatLabel(path + '.' + certificateElement, xml[index][certificateElement]));
        }
      }
    }
  }
  return leafs;
}

function buildDuration(weeks: string, months: string, years: string, path: string): string {
  let result = '';
  if (path !== '') {
    result += labels.tags[path];
  }
  if (weeks !== '0') {
    result += (' ' + weeks + ' Week(s) ');
  }
  if (months !== '0') {
    result += (' ' + months + ' Month(s) ');
  }
  if (years !== '0') {
    result += (' ' + years + ' Year(s)');
  }
  return result;
}

function buildLanguage(xml: JSON, path: string, leafs: Array<string>): Array<string> {
  if (xml['speaking'] !== '0' && xml['listening'] !== '0' && xml['reading'] !== '0' && xml['writing'] !== '0'
    && ((path === 'profile.skillsIdentification.languageSkills.hostCountry'
      && profile_skillsIdentification_languageSkills_hostCountry === 'true')
      || path !== 'profile.skillsIdentification.languageSkills.hostCountry')) {
    for (let element in xml) {
      if (xml.hasOwnProperty(element)) {
        leafs.push(formatLabel(path + '.' + element, xml[element]));
      }
    }
  }
  return leafs;
}

function buildExpectations(xml: JSON, path: string, leafs: Array<string>): Array<string> {
  for (let index in xml) {
    if (xml.hasOwnProperty(index)) {
      leafs.push('Expectation ' + (Number(index) + 1));
      for (let expectationElement in xml[index]) {
        if (path + '.' + expectationElement === 'profile.expectations.otherImproveLanguage'
          || path + '.' + expectationElement === 'profile.expectations.otherUndertakeEducationStudyFields'
          || path + '.' + expectationElement === 'profile.expectations.otherExpectedStudyFields'
          || path + '.' + expectationElement === 'profile.expectations.otherActivityFields'
          || path + '.' + expectationElement === 'profile.expectations.otherOccupations') {
          leafs = extractSimpleArrayInformations('', xml[index][expectationElement], leafs, false, false, false);
        } else if (path + '.' + expectationElement === 'profile.expectations.otherStudyField'
          && xml[index][expectationElement] === 'true') {
          leafs.push('Other field of study');
        } else {
          leafs.push(formatLabel(path + '.' + expectationElement, xml[index][expectationElement]));
        }
      }
    }
  }
  return leafs;
}

function buildIdentificationDocuments(xml: JSON, path: string, leafs: Array<string>): Array<string> {
  for (let index in xml) {
    if (xml.hasOwnProperty(index)) {
      leafs.push('Personal identification document ' + (Number(index) + 1));
      for (let identificationDocumentElement in xml[index]) {
        if (identificationDocumentElement === 'expirationDate') {
          // if it's a date
          leafs.push(formatLabel(path + '.' + identificationDocumentElement, formatDate(xml[index][identificationDocumentElement])));
        } else {
          leafs.push(formatLabel(path + '.' + identificationDocumentElement, xml[index][identificationDocumentElement]));
        }
      }
    }
  }
  return leafs;
}

function extractSimpleArrayInformations(
  label: string, xml, leafs: Array<string>, displayKeyValue: boolean, isEmail: boolean, isLiteracySkills: boolean): Array<string> {
  if (label !== '') {
    leafs.push(label);
  }
  if (displayKeyValue) {
    for (let key in xml) {
      if (xml[key] === 'true') {
        // only for this label, we need to use the value and not the key due to some special cases
        if (isLiteracySkills) {
          leafs.push(labels.mediaTypes[key]);
        } else {
          leafs.push(key);
        }
      }
    }
  } else {
    if (xml['name'] !== undefined) {
      leafs.push(formatLabel('', xml['name']));
    } else if (xml['prefix'] !== undefined) {
      leafs.push(formatNumberOrEmail(xml, isEmail));
    } else {
      for (let value of xml) {
        if (value['name'] !== undefined) {
          leafs.push(formatLabel('', value['name']));
        } else if (value['prefix'] !== undefined) {
          leafs.push(formatNumberOrEmail(value, isEmail));
        }
      }
    }
  }
  return leafs;
}

function formatLabel(path: string, value: string): string {
  if (path === '') {
    return value;
  }
  if (labels.tags[path] === undefined) {
    return path + '#' + value;
  }
  return labels.tags[path] + value;
}

function formatDate(xml: JSON): string {
  return xml['day'] + '/' + xml['month'] + '/' + xml['year'];
}

function formatNumberOrEmail(xml: JSON, isEmail: boolean): string {
  if (isEmail) {
    return xml['prefix'] + '@' + xml['suffix'];
  }
  return xml['prefix'] + xml['suffix'];
}
