import {Labels} from '../../labels/labels';

export class AbstractValidator {

  private labels: Labels = new Labels();

  getValue(jsonInformation: any, propertyName: string): string {
    if (!jsonInformation[propertyName] && jsonInformation[propertyName] !== false) {
      return '';
    }
    return jsonInformation[propertyName];
  }

  testMultipleElements(array1: any, array2: any, errorMessage: string) {
    array1.map(function (element) {
      return element.getText();
    }).then(function (elements) {
      for (let element of elements) {
        if (element !== '') {
          expect(array2.some(elm => elm === element))
            .toBe(true, errorMessage + element);
        }
      }
    });
  }



  formatPhoneNumber(prefix: string, suffix: string) {
    if (prefix && suffix) {
      return prefix + suffix;
    }
    return '';
  }

  formatEmail(prefix: string, suffix: string) {
    if (prefix && suffix) {
      return prefix + '@' + suffix;
    }
    return '';
  }



  getJsonDateToString(jsonDate: any): string {
    if (this.isEmptyJsonObject(jsonDate)) {
      return '';
    }
    let day = jsonDate['day'];
    let month = jsonDate['month'];
    let year = jsonDate['year'];

    if (day === 0 || month === 0 || year === 0) {
      return '';
    }

    return day + '/' + month + '/' + year;

  }

  isDateValid(jsonDate: any): boolean {
    if (this.isEmptyJsonObject(jsonDate)) {
      return false;
    }

    if (!jsonDate['day'] || !jsonDate['month'] || !jsonDate['year']) {
      return false;
    }

    return true;
  }

  isEmptyJsonObject(jsonObject: any) {
    return Object.keys(jsonObject).length === 0 && jsonObject.constructor === Object;
  }

  getCountryTranslation(countryCode: string) {
    if (!countryCode) {
      return '';
    }
    return this.labels.countries[countryCode];
  }

  getMaritalStatusTranslation(maritalStatusCode: string) {
    if (!maritalStatusCode) {
      return '';
    }
    return this.labels.maritalStatus[maritalStatusCode];
  }

  getGenderTranslation(genderCode: string) {
    if (!genderCode) {
      return '';
    }
    return this.labels.genderCodes[genderCode];
  }

  getDocumentTypeTranslation(documentType: string) {
    if (!documentType) {
      return '';
    }
    return this.labels.documentTypes[documentType];
  }

  getResidentialStatusTranslation(residentialStatusCode: string) {
    if (!residentialStatusCode) {
      return '';
    }
    return this.labels.residentialStatuses[residentialStatusCode];
  }

  getWorkPermitStatusTranslation(workPermitStatusCode: string) {
    if (!workPermitStatusCode) {
      return '';
    }
    return this.labels.workPermitStatuses[workPermitStatusCode];
  }

  getBooleanTranslation(booleanAsString: string) {
    if (booleanAsString === undefined || booleanAsString === null || booleanAsString === '') {
      return '';
    }
    return this.labels.booleanTranslation[booleanAsString];
  }


  getLanguageTranslation(languageType: string) {
    if (!languageType) {
      return '';
    }
    return this.labels.languageTypes[languageType];
  }

  getExpectationTranslation(expectationType: string) {
    if (!expectationType) {
      return '';
    }
    return this.labels.expectationTypes[expectationType];
  }

  getEducationTypeTranslation(educationType: string) {
    if (!educationType) {
      return '';
    }
    return this.labels.educationTypes[educationType];
  }

  getStudyFieldTranslation(studyFieldType: string) {
    if (!studyFieldType) {
      return '';
    }
    return this.labels.studyFieldTypes[studyFieldType];
  }

  getTimeCommitmentTranslation(commitmentTime: string) {
    if (!commitmentTime) {
      return '';
    }
    return this.labels.commitmentTimes[commitmentTime];
  }

  getWorkTranslation(workType: string) {
    if (!workType) {
      return '';
    }
    return this.labels.workTypes[workType];
  }

  getFieldOfStudyTranslation(fieldOfStudyType: string) {
    if (!fieldOfStudyType) {
      return '';
    }
    return this.labels.fieldOfActivityTypes[fieldOfStudyType];
  }

  getOccupationTranslation(occupationType: string) {
    if (!occupationType) {
      return '';
    }
    return this.labels.occupationTypes[occupationType];
  }

  getDuration(duration: number) {
    if (!duration && duration !== 0) {
      return '';
    }
    return duration + ' ';
  }

  getEducationLevel(level: string) {
    if (!level) {
      return '';
    }
    return this.labels.educationLevels[level];
  }

  getMediaTypeTranslation(media: string) {
    if (!media) {
      return '';
    }
    return this.labels.mediaTypes[media];
  }

  getCapacitiesTranslation(capacity: number) {
    return this.labels.capacityTypes[capacity];
  }

  getRatingTranslation(digitalSkill: number) {
    return this.labels.ratingTypes[digitalSkill];
  }

  getOrganisationTypeTranslation(organisationType: string) {
    if (!organisationType) {
      return '';
    }
    return this.labels.organisationTypes[organisationType];
  }

  getFrequencyTranslation(frequency: string) {
    if (!frequency) {
      return '';
    }
    return this.labels.frequencyTypes[frequency];
  }

  getProfessionalExperienceTranslation(professionalExperience: string) {
    if (!professionalExperience) {
      return '';
    }
    return this.labels.professionalExperienceTypes[professionalExperience];
  }

  getSkillTranslation(skill: string) {
    if (!skill) {
      return '';
    }
    return this.labels.skillTypes[skill];
  }

  getSizeTranslation(size: string) {
    if (!size) {
      return '';
    }
    return this.labels.sizeTypes[size];
  }

}
