import * as path from 'path';
import {HeaderPage} from '../../../pages/header.po';
import {HomePage} from '../../../pages/home.po';
import {SummaryPage} from '../../../pages/summary/summary.po';
import {ExpectationsData} from '../../../data/expectations-data';
import {ExpectationsValidator} from './validator/summary-expectations-validator';
import {browser} from 'protractor';
import {ExpectationsPage} from '../../../pages/expectations.po';
import {SummaryExpectationsPage} from '../../../pages/summary/expectations/summary-expectations.po';

describe('A user on the expectations part of the summary page', function () {
  let headerPage: HeaderPage;
  let homePage: HomePage;
  let expectationsPage: ExpectationsPage;
  let summaryPage: SummaryPage;
  let summaryExpectationsPage: SummaryExpectationsPage;

  let expectationsData: ExpectationsData;

  let expectations_validator: ExpectationsValidator;

  beforeAll(() => {
    headerPage = new HeaderPage();
    homePage = new HomePage();
    expectationsPage = new ExpectationsPage();
    summaryPage = new SummaryPage();
    summaryExpectationsPage = new SummaryExpectationsPage();

    expectationsData = new ExpectationsData();

    expectations_validator = new ExpectationsValidator();
  });

  it('must be able to hide all empty expectations', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/empty.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    expectations_validator.checkExpectations(expectationsData.emptyExpectations);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isExpectationsExpended())
      .toBe(true, 'The section need to be expended');

    expectations_validator.checkExpectationsPresent(expectationsData.emptyExpectations);
  });

  it('must be able to not hide filled expectations', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/profile.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    expectations_validator.checkExpectations(expectationsData.fullExpectations);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isExpectationsExpended())
      .toBe(true, 'The section need to be expended');

    expectations_validator.checkExpectationsPresent(expectationsData.fullExpectations);
  });

  it('should not be able to see the line other field of study of the expectation `Undertake education` in the summary when the other field of study checkbox is uncheck', () => {
    homePage.navigateTo();
    homePage.getCreateProfileButton().click();

    headerPage.getExpectationsButton().click();
    expectationsPage.getAddExpectationButton().click();
    expectationsPage.getUndertakeEducationRadioButton(0).click();
    expectationsPage.getOtherFieldOfStudyCheckbox().click();
    expectationsPage.getOtherFieldOfStudyInput(0).sendKeys('other field of study');
    headerPage.getSummaryButton().click();
    expect(summaryExpectationsPage.getOtherFieldsOfStudy(0).get(0).getText())
      .toBe('other field of study');

    headerPage.getExpectationsButton().click();
    expectationsPage.getOtherFieldOfStudyCheckbox().click();
    headerPage.getSummaryButton().click();
    expect(summaryExpectationsPage.isOtherFieldsOfStudyTitlePresent())
      .toBe(false);
  });


});
