import {AbstractValidator} from '../../abstract-validator';
import {SummaryExpectationsPage} from '../../../../pages/summary/expectations/summary-expectations.po';

export class ExpectationsValidator extends AbstractValidator {

  private expectationsPage: SummaryExpectationsPage = new SummaryExpectationsPage();

  checkExpectations(expectations: any) {
    this.checkExpectationImproveLanguageSkills(0, expectations[0]);
    this.checkExpectationFollowIntegrationCourses(1, expectations[1]);
    this.checkExpectationUndertakeEducationAndTraining(2, expectations[2]);
    this.checkExpectationFindWork(3, expectations[3]);
  }

  private checkExpectationImproveLanguageSkills(index: number, expectation: any) {
    expect(this.expectationsPage.getDoNext(index).getText())
      .toBe(this.getExpectationTranslation(expectation['doNext']),
        'Error on the content of the DoNext element n°' + index);

    let improveLanguageSkills = this.getValue(expectation, 'language') === '' ?
      [] : [this.getLanguageTranslation(expectation['language'])];
    improveLanguageSkills = improveLanguageSkills.concat(expectation['otherImproveLanguage'].map(
      element => this.getLanguageTranslation(element['name'])
    ));
    this.testMultipleElements(
      this.expectationsPage.getImproveLanguageSkills(),
      improveLanguageSkills,
      'Error on the content of the improve language skills : ');
  }

  private checkExpectationFollowIntegrationCourses(index: number, expectation: any) {
    expect(this.expectationsPage.getDoNext(index).getText())
      .toBe(this.getExpectationTranslation(expectation['doNext']),
        'Error on the content of the DoNext element n°' + index);
  }

  private checkExpectationUndertakeEducationAndTraining(index: number, expectation: any) {
    expect(this.expectationsPage.getDoNext(index).getText())
      .toBe(this.getExpectationTranslation(expectation['doNext']),
        'Error on the content of the DoNext element n°' + index);

    expect(this.expectationsPage.getTypeOfEducation(index).getText())
      .toBe(this.getEducationTypeTranslation(expectation['educationType']),
        'Error on the content of the education type n°' + index);

    expect(this.expectationsPage.getTimeCommitment(index).getText())
      .toBe(this.getTimeCommitmentTranslation(expectation['undertakeEducationTimeCommitment']),
        'error on the content of the time commitment n°' + index);

    let fieldOfStudy = this.getValue(expectation, 'undertakeEducationStudyField') === '' ?
      [] : [this.getStudyFieldTranslation(expectation['undertakeEducationStudyField'])];
    fieldOfStudy = fieldOfStudy.concat(expectation['otherUndertakeEducationStudyFields'].map(
      element => this.getStudyFieldTranslation(element['name'])
    ));
    this.testMultipleElements(
      this.expectationsPage.getFieldsOfStudy(),
      fieldOfStudy,
      'Error on the content of the field of study : ');

    let otherFieldOfStudy = fieldOfStudy.concat(expectation['otherExpectedStudyFields'].map(
      element => element['name']
    ));
    this.testMultipleElements(
      this.expectationsPage.getOtherFieldsOfStudy(0),
      otherFieldOfStudy,
      'Error on the content of the other field of study : ');
  }

  private checkExpectationFindWork(index: number, expectation: any) {
    expect(this.expectationsPage.getDoNext(index).getText())
      .toBe(this.getExpectationTranslation(expectation['doNext']),
        'Error on the content of the DoNext element n°' + index);

    expect(this.expectationsPage.getFindWork(index).getText())
      .toBe(this.getWorkTranslation(expectation['findWork']),
        'Error on the content of the find work.');

    expect(this.expectationsPage.getFindWorkTime(index).getText())
      .toBe(this.getTimeCommitmentTranslation(expectation['findWorkTimeCommitment']),
        'Error on the content of the find work time.');

    let workFieldOfStudy = this.getValue(expectation, 'activityField') === '' ?
      [] : [this.getFieldOfStudyTranslation(expectation['activityField'])];
    workFieldOfStudy = workFieldOfStudy.concat(expectation['otherActivityFields'].map(
      element => this.getFieldOfStudyTranslation(element['name'])
    ));
    this.testMultipleElements(
      this.expectationsPage.getBestFittingActivity(index),
      workFieldOfStudy,
      'Error on the content of the work field of activity : ');

    let occupation = this.getValue(expectation, 'occupation') === '' ?
      [] : [this.getOccupationTranslation(expectation['occupation'])];
    occupation = occupation.concat(expectation['otherOccupations'].map(
      element => this.getOccupationTranslation(element['name'])
    ));
    this.testMultipleElements(
      this.expectationsPage.getBestFittingOccupation(index),
      occupation,
      'Error on the content of the work occupation : ');
  }

  checkExpectationsPresent(expectations: any) {
    this.checkExpectationImproveLanguageSkillsPresent(0, expectations[0]);
    this.checkExpectationFollowIntegrationCoursesPresent(1, expectations[1]);
    this.checkExpectationUndertakeEducationAndTrainingPresent(2, expectations[2]);
    this.checkExpectationFindWorkPresent(3, expectations[3]);
  }

  private checkExpectationImproveLanguageSkillsPresent(index: number, expectation: any) {
    expect(this.expectationsPage.isDoNextPresent(index))
      .toBe(this.getValue(expectation, 'doNext') !== '',
        'Error on the presence of doNext n°' + index);

    let improveLanguageSkills = this.getValue(expectation, 'language') === '' ?
      [] : [this.getLanguageTranslation(expectation['language'])];
    improveLanguageSkills = improveLanguageSkills.concat(expectation['otherImproveLanguage'].map(
      element => this.getLanguageTranslation(element['name'])
    ));
    expect(this.expectationsPage.isImproveLanguageSkillsPresent())
      .toBe(improveLanguageSkills.length !== 0,
        'Error on the presence of the improve language skills');
  }

  private checkExpectationFollowIntegrationCoursesPresent(index: number, expectation: any) {
    expect(this.expectationsPage.isDoNextPresent(index))
      .toBe(this.getValue(expectation, 'doNext') !== '',
        'Error on the presence of doNext n°' + index);
  }

  private checkExpectationUndertakeEducationAndTrainingPresent(index: number, expectation: any) {
    expect(this.expectationsPage.isDoNextPresent(index))
      .toBe(this.getValue(expectation, 'doNext') !== '',
        'Error on the presence of doNext n°' + index);

    expect(this.expectationsPage.isTypeOfEducationPresent(index))
      .toBe(this.getValue(expectation, 'educationType') !== '',
        'Error on the presence of educationType n°' + index);

    expect(this.expectationsPage.isTimeCommitmentPresent(index))
      .toBe(this.getValue(expectation, 'undertakeEducationTimeCommitment') !== '',
        'Error on the presence of time commitment');

    let fieldOfStudy = this.getValue(expectation, 'undertakeEducationStudyField') === '' ?
      [] : [this.getStudyFieldTranslation(expectation['undertakeEducationStudyField'])];
    fieldOfStudy = fieldOfStudy.concat(expectation['otherUndertakeEducationStudyFields'].map(
      element => this.getStudyFieldTranslation(element['name'])
    ));
    expect(this.expectationsPage.isFieldsOfStudyPresent())
      .toBe(fieldOfStudy.length !== 0,
        'Error on the presence of the fields of study');

    let otherFieldOfStudy = fieldOfStudy.concat(expectation['otherExpectedStudyFields'].map(
      element => element['name']
    ));
    expect(this.expectationsPage.isOtherFieldsOfStudyPresent(0))
      .toBe(otherFieldOfStudy.length !== 0,
        'Error on the presence of the other fields of study');
  }

  private checkExpectationFindWorkPresent(index: number, expectation: any) {
    expect(this.expectationsPage.isDoNextPresent(index))
      .toBe(this.getValue(expectation, 'doNext') !== '',
        'Error on the presence of doNext n°' + index);

    expect(this.expectationsPage.isFindWorkPresent(index))
      .toBe(this.getValue(expectation, 'findWork') !== '',
        'Error on the presence of the find work');

    expect(this.expectationsPage.isFindWorkTimePresent(index))
      .toBe(this.getValue(expectation, 'findWorkTimeCommitment') !== '',
        'Error on the presence of the find work time');

    let workFieldOfStudy = this.getValue(expectation, 'activityField') === '' ?
      [] : [this.getFieldOfStudyTranslation(expectation['activityField'])];
    workFieldOfStudy = workFieldOfStudy.concat(expectation['otherActivityFields'].map(
      element => this.getFieldOfStudyTranslation(element['name'])
    ));
    expect(this.expectationsPage.isBestFittingActivityPresent(index))
      .toBe(workFieldOfStudy.length !== 0,
        'Error on the presence of the best fitting activity');

    let occupation = this.getValue(expectation, 'occupation') === '' ?
      [] : [this.getOccupationTranslation(expectation['occupation'])];
    occupation = occupation.concat(expectation['otherOccupations'].map(
      element => this.getOccupationTranslation(element['name'])
    ));
    expect(this.expectationsPage.isBestFittingOccupationPresent(index))
      .toBe(occupation.length !== 0,
        'Error on the presence of the best fitting occupation');
  }

}
