import {HeaderPage} from '../../../pages/header.po';
import {HomePage} from '../../../pages/home.po';
import {SummaryPage} from '../../../pages/summary/summary.po';
import * as path from 'path';
import {OutcomeData} from '../../../data/outcome-data';
import {OrganisationValidator} from './validator/summary-organisation-validator';
import {browser} from 'protractor';
import {OutcomeIssuingOrganisationPage} from '../../../pages/outcome.issuing-organisation.po';
import {SummaryOrganisationPage} from '../../../pages/summary/outcome/summary-organisation.po';

describe('A user on the guidance part of the summary page', function () {
  let headerPage: HeaderPage;
  let homePage: HomePage;
  let outcomeIssuingOrganisationPage: OutcomeIssuingOrganisationPage;
  let summaryPage: SummaryPage;
  let summaryOrganisationPage: SummaryOrganisationPage;

  let data: OutcomeData;

  let summaryOrganisationValidator: OrganisationValidator;

  beforeAll(() => {
    headerPage = new HeaderPage();
    homePage = new HomePage();
    outcomeIssuingOrganisationPage = new OutcomeIssuingOrganisationPage();
    summaryPage = new SummaryPage();
    summaryOrganisationPage = new SummaryOrganisationPage();

    data = new OutcomeData();

    summaryOrganisationValidator = new OrganisationValidator();
  });

  it('must be able to hide empty organisation', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/empty.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    summaryOrganisationValidator.checkOrganisations(data.emptyOutcome['organisations']);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isOutcomeExpended())
      .toBe(false, 'The section need to be collapsed');
    summaryPage.getOutcomeButton().click();

    summaryOrganisationValidator.checkOrganisationsPresent(data.emptyOutcome['organisations']);
  });

  it('must be able to not hide filled organisation', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/profile.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    summaryOrganisationValidator.checkOrganisations(data.fullOutcome['organisations']);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isOutcomeExpended())
      .toBe(true, 'The section need to be expended');

    summaryOrganisationValidator.checkOrganisationsPresent(data.fullOutcome['organisations']);
  });

  it('must be able to hide \'No\' labels', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/profile_full_of_no.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    summaryOrganisationValidator.checkOrganisations(data.profileFullOfNo['organisations']);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isOutcomeExpended())
      .toBe(true, 'The section need to be expended');

    summaryOrganisationValidator.checkOrganisationsPresent(data.profileFullOfNo['organisations']);
  });

  it('should not be able to see the line other phone numbers in the summary when the list is empty', () => {
    homePage.navigateTo();
    homePage.getCreateProfileButton().click();

    headerPage.getOutcomeButton().click();
    headerPage.getOrganisationTabButton().click();
    outcomeIssuingOrganisationPage.getAddPhoneNumberButton().click();
    outcomeIssuingOrganisationPage.getMultiPhoneNumberPrefixInput(0).sendKeys('01');
    outcomeIssuingOrganisationPage.getMultiPhoneNumberSuffixInput(0).sendKeys('23456789');
    headerPage.getSummaryButton().click();
    expect(summaryOrganisationPage.getOtherTelephoneNumber(0, 0).getText())
      .toBe('0123456789');

    headerPage.getOutcomeButton().click();
    headerPage.getOrganisationTabButton().click();
    outcomeIssuingOrganisationPage.getRemovePhoneNumberButton(0).click();
    headerPage.getSummaryButton().click();
    expect(summaryOrganisationPage.isOtherTelephoneNumberTitlePresent())
      .toBe(false);
  });

});
