import {SummaryPage} from '../../../pages/summary/summary.po';
import {HeaderPage} from '../../../pages/header.po';
import {HomePage} from '../../../pages/home.po';
import {SummaryOutcomeValidator} from './validator/summary-outcome-validator';
import * as path from 'path';
import {OutcomeData} from '../../../data/outcome-data';
import {browser} from 'protractor';

describe('A user on the strengths, recognition, validation, training and work parts of the summary page', function () {
  let headerPage: HeaderPage;
  let homePage: HomePage;
  let summaryPage: SummaryPage;

  let overallData: OutcomeData;

  let summaryOverralValidator: SummaryOutcomeValidator;

  beforeAll(() => {
    headerPage = new HeaderPage();
    homePage = new HomePage();
    summaryPage = new SummaryPage();

    overallData = new OutcomeData();

    summaryOverralValidator = new SummaryOutcomeValidator();
  });

  it('must be able to hide empty outcome information', () => {
    homePage.navigateTo();
    homePage.getCreateProfileButton().click();

    headerPage.getSummaryButton().click();
    summaryOverralValidator.checkOutcome(overallData.emptyOutcome);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isOutcomeExpended())
      .toBe(false, 'The section need to be collapsed');
    summaryPage.getOutcomeButton().click();

    summaryOverralValidator.isOutcomePresent(overallData.emptyOutcome);
  });

  it('must be able to not hide filled outcome information', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/profile.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    summaryOverralValidator.checkOutcome(overallData.fullOutcome);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isOutcomeExpended())
      .toBe(true, 'The section need to be expended');

    summaryOverralValidator.isOutcomePresent(overallData.fullOutcome);
  });

});
