import {AbstractValidator} from '../../abstract-validator';
import {SummaryOrganisationPage} from '../../../../pages/summary/outcome/summary-organisation.po';

export class OrganisationValidator extends AbstractValidator {

  private summaryOrganisationPage: SummaryOrganisationPage = new SummaryOrganisationPage();

  checkOrganisations(organisations: any) {
    let index = 0;
    for (let organisation of organisations) {
      this.checkOrganisation(organisation, index);
      index++;
    }
  }

  private checkOrganisation(organisation: any, index: number) {
    expect(this.summaryOrganisationPage.getDateOfIssuance(index).getText())
      .toBe(this.getJsonDateToString(organisation['dateOfIssuance']),
        'Error on the content of date of issuance ' + index);

    expect(this.summaryOrganisationPage.getPlaceOfIssuance(index).getText())
      .toBe(this.getValue(organisation, 'placeOfIssuance'),
        'Error on the content of place of issuance ' + index);

    expect(this.summaryOrganisationPage.getTypeOfOrganisation(index).getText())
      .toBe(this.getOrganisationTypeTranslation(organisation['type']),
        'Error on the content of type of organisation ' + index);

    expect(this.summaryOrganisationPage.getNameOfOrganisation(index).getText())
      .toBe(this.getValue(organisation, 'organisation'),
        'Error on the content of name of organisation ' + index);

    expect(this.summaryOrganisationPage.getResponsibleOfficer(index).getText())
      .toBe(this.getValue(organisation, 'responsibleOfficer'),
        'Error on the content of responsible officer ' + index);

    this.checkOrganisationContactInfo(organisation, index);
  }

  private checkOrganisationContactInfo(organisation: any, index: number) {
    const organisationContactInfo = organisation['organisationContactInfo'];

    expect(this.summaryOrganisationPage.getAddress(index).getText())
      .toBe(this.getValue(organisationContactInfo, 'address'),
        'Error on the content of address ' + index);

    expect(this.summaryOrganisationPage.getCountry(index).getText())
      .toBe(this.getCountryTranslation(organisationContactInfo['country']),
        'Error on the content of country ' + index);

    const phoneNumber = this.formatPhoneNumber(
      organisationContactInfo['phoneNumber']['prefix'],
      organisationContactInfo['phoneNumber']['suffix']
    );
    expect(this.summaryOrganisationPage.getTelephoneNumber(index).getText())
      .toEqual(phoneNumber,
        'Error on the content of the phone number.');

    let i = 0;
    organisationContactInfo['phoneNumbers']
      .map(element => this.formatPhoneNumber(element['prefix'], element['suffix']))
      .forEach(phone => {
        let phoneNumberRegex = /^[0-9+\/ ]+$/;
        if (phone.match(phoneNumberRegex)) {
          expect(this.summaryOrganisationPage.getOtherTelephoneNumber(index, i).getText())
            .toBe(phone,
              'Error on the content of the other phone number.');
          i++;
        }
      });

    let emailAddress = this.formatEmail(
      organisationContactInfo['email']['prefix'],
      organisationContactInfo['email']['suffix']
    );
    expect(this.summaryOrganisationPage.getEmailAddress(index).getText())
      .toBe(emailAddress,
        'Error on the content of email address ' + index);
  }

  checkOrganisationsPresent(organisations: any) {
    let index = 0;
    for (let organisation of organisations) {
      this.checkOrganisationPresent(organisation, index);
      index++;
    }
  }

  private checkOrganisationPresent(organisation: any, index: number) {
    expect(this.summaryOrganisationPage.isDateOfIssuancePresent(index))
      .toBe(this.getJsonDateToString(organisation['dateOfIssuance']) !== '',
        'Error on the presence of date of issuance ' + index);

    expect(this.summaryOrganisationPage.isPlaceOfIssuancePresent(index))
      .toBe(this.getValue(organisation, 'placeOfIssuance') !== '',
        'Error on the presence of place of issuance ' + index);

    expect(this.summaryOrganisationPage.isTypeOfOrganisationPresent(index))
      .toBe(this.getOrganisationTypeTranslation(organisation['type']) !== '',
        'Error on the presence of type of organisation ' + index);

    expect(this.summaryOrganisationPage.isNameOfOrganisationPresent(index))
      .toBe(this.getValue(organisation, 'organisation') !== '',
        'Error on the presence of name of organisation ' + index);

    expect(this.summaryOrganisationPage.isResponsibleOfficerPresent(index))
      .toBe(this.getValue(organisation, 'responsibleOfficer') !== '',
        'Error on the presence of responsible officer ' + index);

    this.checkOrganisationContactInfoPresent(organisation, index);
  }

  private checkOrganisationContactInfoPresent(organisation: any, index: number) {
    const organisationContactInfo = organisation['organisationContactInfo'];

    expect(this.summaryOrganisationPage.isAddressPresent(index))
      .toBe(this.getValue(organisationContactInfo, 'address') !== '',
        'Error on the presence of address ' + index);

    expect(this.summaryOrganisationPage.isCountryPresent(index))
      .toBe(this.getCountryTranslation(organisationContactInfo['country']) !== '',
        'Error on the presence of country ' + index);

    const phoneNumber = this.formatPhoneNumber(
      organisationContactInfo['phoneNumber']['prefix'],
      organisationContactInfo['phoneNumber']['suffix']
    );
    expect(this.summaryOrganisationPage.isTelephoneNumberPresent(index))
      .toEqual(phoneNumber !== '',
        'Error on the presence of the phone number.');

   organisationContactInfo['phoneNumbers']
     .map(element => this.formatPhoneNumber(element['prefix'], element['suffix']))
     .forEach((phone, i) => {
       let phoneNumberRegex = /^[0-9+\/ ]+$/;
       expect(this.summaryOrganisationPage.isOtherTelephoneNumberPresent(index, i))
         .toBe(phone.match(phoneNumberRegex) !== null,
           'Error on the presence of the other phone number.');
     });

    let emailAddress = this.formatEmail(
      organisationContactInfo['email']['prefix'],
      organisationContactInfo['email']['suffix']
    );
    expect(this.summaryOrganisationPage.isEmailAddressPresent(index))
      .toBe(emailAddress !== '',
        'Error on the presence of email address ' + index);
  }
}
