import {AbstractValidator} from '../../abstract-validator';
import {SummaryOutcomePage} from '../../../../pages/summary/outcome/summary-outcome.po';

export class SummaryOutcomeValidator extends AbstractValidator {

  private outcomePage: SummaryOutcomePage = new SummaryOutcomePage();

  checkOutcome(outcome: any) {
    expect(this.outcomePage.getStrenghts().getText()).toBe(
      outcome['keySkills'] ? outcome['keySkills'] : '',
      'Error on the content of strengths');

    expect(this.outcomePage.getRecognitionRecommandation().getText()).toBe(
      outcome['recognitionRecommendation'] ? outcome['recognitionRecommendation'] : '',
      'Error on the content of recognition recommandation');

    expect(this.outcomePage.getRecognitionReferral().getText()).toBe(
      outcome['recognitionReferral'] ? outcome['recognitionReferral'] : '',
      'Error on the content of recognition referral');

    expect(this.outcomePage.getValidationRecommandation().getText()).toBe(
      outcome['validationRecommendation'] ? outcome['validationRecommendation'] : '',
      'Error on the content of validation recommendation');

    expect(this.outcomePage.getValidationReferral().getText()).toBe(
      outcome['validationReferral'] ? outcome['validationReferral'] : '',
      'Error on the content of validation referral');

    expect(this.outcomePage.getTrainingAdvice().getText()).toBe(
      outcome['educationOrTrainingAdvice'] ? outcome['educationOrTrainingAdvice'] : '',
      'Error on the content of training recommendation');

    expect(this.outcomePage.getTrainingReferral().getText()).toBe(
      outcome['educationOrTrainingReferral'] ? outcome['educationOrTrainingReferral'] : '',
      'Error on the content of training referral');

    expect(this.outcomePage.getEmploymentBusiness().getText()).toBe(
      outcome['employmentBusiness'] ? outcome['employmentBusiness'] : '',
      'Error on the content of employment business');

    expect(this.outcomePage.getGuidance().getText()).toBe(
      outcome['guidanceOtherOrganisations'] ? outcome['guidanceOtherOrganisations'] : '',
      'Error on the content of guidance');
  }

  isOutcomePresent(outcome: any) {
    expect(this.outcomePage.isStrenghtsPresent()).toBe(
      !!outcome['keySkills'],
      'Error on the presence of strengths');

    expect(this.outcomePage.isRecognitionRecommandationPresent()).toBe(
      !!outcome['recognitionRecommendation'],
      'Error on the presence of recognition recommendation');

    expect(this.outcomePage.isRecognitionReferralPresent()).toBe(
      !!outcome['recognitionReferral'],
      'Error on the presence of recognition referral');

    expect(this.outcomePage.isValidationRecommandationPresent()).toBe(
      !!outcome['validationRecommendation'],
      'Error on the presence of validation recommendation');

    expect(this.outcomePage.isValidationReferralPresent()).toBe(
      !!outcome['validationReferral'],
      'Error on the presence of validation referral');

    expect(this.outcomePage.isTrainingAdvicePresent()).toBe(
      !!outcome['educationOrTrainingAdvice'],
      'Error on the presence of training advice present');

    expect(this.outcomePage.isTrainingReferralPresent()).toBe(
      !!outcome['educationOrTrainingReferral'],
      'Error on the presence of training referral');

    expect(this.outcomePage.isEmploymentBusinessPresent()).toBe(
      !!outcome['employmentBusiness'],
      'Error on the presence of employment business');

    expect(this.outcomePage.isGuidancePresent()).toBe(
      !!outcome['guidanceOtherOrganisations'],
      'Error on the presence of guidance');
  }
}
