import * as path from 'path';
import {HeaderPage} from '../../../pages/header.po';
import {HomePage} from '../../../pages/home.po';
import {SummaryPage} from '../../../pages/summary/summary.po';
import {PersonalInformationData} from '../../../data/personal-information-data';
import {ContactInformationValidator} from './validator/summary-contact-information-validator';
import {browser} from 'protractor';
import {PersonalInfoContactPage} from '../../../pages/personal-info.contact.po';
import {SummaryContactInformationPage} from '../../../pages/summary/personal-info/summary-contact-information.po';

describe('A user on the contact information part of the summary page', function () {
  let headerPage: HeaderPage;
  let homePage: HomePage;
  let personalInfoContactPage: PersonalInfoContactPage;
  let summaryPage: SummaryPage;
  let summaryContactInformationPage: SummaryContactInformationPage;
  let personalInfoData: PersonalInformationData;

  let contactInformationValidator: ContactInformationValidator;

  beforeAll(() => {
    headerPage = new HeaderPage();
    homePage = new HomePage();
    personalInfoContactPage = new PersonalInfoContactPage();
    summaryPage = new SummaryPage();
    summaryContactInformationPage = new SummaryContactInformationPage();
    personalInfoData = new PersonalInformationData();

    contactInformationValidator = new ContactInformationValidator();
  });

  it('must be able to hide all empty contact information', () => {
    homePage.navigateTo();
    homePage.getCreateProfileButton().click();

    headerPage.getSummaryButton().click();
    contactInformationValidator.checkContactInformation(personalInfoData.emptyPersonalInformation);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isPersonalInfoSectionExpended())
      .toBe(false, 'The section need to be collapsed');
    summaryPage.getPersonalInfoButton().click();

    contactInformationValidator.checkContactInformationPresent(personalInfoData.emptyPersonalInformation);
  });

  it('must be able to not hide filled contact information', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/profile.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    contactInformationValidator.checkContactInformation(personalInfoData.fullPersonalInformation);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isPersonalInfoSectionExpended())
      .toBe(true, 'The section need to be expended');

    contactInformationValidator.checkContactInformationPresent(personalInfoData.fullPersonalInformation);
  });

  it('should not be able to see the line other phone numbers in the summary when the list is empty', () => {
    homePage.navigateTo();
    homePage.getCreateProfileButton().click();

    headerPage.getContactInformationTabButton().click();
    personalInfoContactPage.getAddPhoneNumberButton().click();
    personalInfoContactPage.getAllMultiPhoneNumberPrefixInput().get(0).sendKeys('01');
    personalInfoContactPage.getAllMultiPhoneNumberSuffixInput().get(0).sendKeys('23456789');
    headerPage.getSummaryButton().click();
    expect(summaryContactInformationPage.getOtherTelephoneNumber(0).get(0).getText())
      .toBe('0123456789');

    headerPage.getPersonalInformationButton().click();
    headerPage.getContactInformationTabButton().click();
    personalInfoContactPage.getRemovePhoneNumberButton(0).click();
    headerPage.getSummaryButton().click();
    expect(summaryContactInformationPage.isOtherTelephoneNumberTitlePresent())
      .toBe(false);
  });

  it('should not be able to see the line other email address in the summary when the list is empty', () => {
    homePage.navigateTo();
    homePage.getCreateProfileButton().click();

    headerPage.getContactInformationTabButton().click();
    personalInfoContactPage.getAddMailButton().click();
    personalInfoContactPage.getAllMultiMailPrefixInput().get(0).sendKeys('test');
    personalInfoContactPage.getAllMultiMailSuffixInput().get(0).sendKeys('test.fr');
    headerPage.getSummaryButton().click();
    expect(summaryContactInformationPage.getOtherEmailAddress(0).get(0).getText())
      .toBe('test@test.fr');

    headerPage.getPersonalInformationButton().click();
    headerPage.getContactInformationTabButton().click();
    personalInfoContactPage.getRemoveMailButton(0).click();
    headerPage.getSummaryButton().click();
    expect(summaryContactInformationPage.isOtherEmailAddressTitlePresent())
      .toBe(false);
  });

});
