import * as path from 'path';
import {HeaderPage} from '../../../pages/header.po';
import {HomePage} from '../../../pages/home.po';
import {SummaryPage} from '../../../pages/summary/summary.po';
import {PersonalInformationData} from '../../../data/personal-information-data';
import {MigrationInformationValidator} from './validator/summary-migration-information-validator';
import {browser} from 'protractor';

describe('A user on the migration information part of the summary page', function () {
  let headerPage: HeaderPage;
  let homePage: HomePage;
  let summaryPage: SummaryPage;
  let personalInformationData: PersonalInformationData;

  let migrationInformationValidator: MigrationInformationValidator;

  beforeAll(() => {
    headerPage = new HeaderPage();
    homePage = new HomePage();
    summaryPage = new SummaryPage();
    personalInformationData = new PersonalInformationData();

    migrationInformationValidator = new MigrationInformationValidator();
  });

  it('must be able to hide all empty migration information', () => {
    homePage.navigateTo();
    homePage.getCreateProfileButton().click();

    headerPage.getSummaryButton().click();
    migrationInformationValidator.checkMigrationInformation(personalInformationData.emptyPersonalInformation);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isPersonalInfoSectionExpended())
      .toBe(false, 'The section need to be collapsed');
    summaryPage.getPersonalInfoButton().click();

    migrationInformationValidator.checkMigrationInformationPresent(personalInformationData.emptyPersonalInformation);
  });

  it('must be able to not hide filled migration information', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/profile.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    migrationInformationValidator.checkMigrationInformation(personalInformationData.fullPersonalInformation);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isPersonalInfoSectionExpended())
      .toBe(true, 'The section need to be expended');

    migrationInformationValidator.checkMigrationInformationPresent(personalInformationData.fullPersonalInformation);
  });

  it('must be able to not hide information from Didier Ridoux', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/Didier_Ridoux_20180608.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    migrationInformationValidator.checkMigrationInformation(personalInformationData.didierRidoux);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isPersonalInfoSectionExpended())
      .toBe(true, 'The section need to be expended');

    migrationInformationValidator.checkMigrationInformationPresent(personalInformationData.didierRidoux);
  });

  it('must be able to hide \'No\' labels', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/profile_full_of_no.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    migrationInformationValidator.checkMigrationInformation(personalInformationData.profileFullOfNo);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isPersonalInfoSectionExpended())
      .toBe(true, 'The section need to be expended');

    migrationInformationValidator.checkMigrationInformationPresent(personalInformationData.profileFullOfNo);
  });

});
