import {AbstractValidator} from '../../abstract-validator';
import {SummaryContactInformationPage} from '../../../../pages/summary/personal-info/summary-contact-information.po';

export class ContactInformationValidator extends AbstractValidator {

  private summaryContactInformationPage: SummaryContactInformationPage = new SummaryContactInformationPage();

  checkContactInformation(personalInformation: any) {
    expect(this.summaryContactInformationPage.getAddress().getText())
      .toEqual(this.getValue(personalInformation['contactInfo'], 'address'),
        'Error on the content of the address.');

    expect(this.summaryContactInformationPage.getPostalCode().getText())
      .toEqual(this.getValue(personalInformation['contactInfo'], 'postalCode'),
        'Error on the content of the postal code.');

    expect(this.summaryContactInformationPage.getCountry().getText())
      .toEqual(this.getCountryTranslation(this.getValue(personalInformation['contactInfo'], 'country')),
        'Error on the content of the country.');

    const phoneNumber = this.formatPhoneNumber(
      personalInformation['contactInfo']['phoneNumber']['prefix'], personalInformation['contactInfo']['phoneNumber']['suffix']
    );
    expect(this.summaryContactInformationPage.getTelephoneNumber().getText())
      .toEqual(phoneNumber,
        'Error on the content of the phone number.');

    const otherPhoneNumber = personalInformation['contactInfo']['phoneNumbers'].map(
      element => this.formatPhoneNumber(element['prefix'], element['suffix'])
    );
    this.summaryContactInformationPage.getOtherTelephoneNumber(0).map(function (element) {
      return element.getText();
    }).then(function (elements) {
      for (let element of elements as Array<string>) {
        expect(otherPhoneNumber.includes(element))
          .toBe(true,
            'Error on the content of the other phone numbers.');
      }
    });

    const email = this.formatEmail(
      personalInformation['contactInfo']['email']['prefix'], personalInformation['contactInfo']['email']['suffix']
    );
    expect(this.summaryContactInformationPage.getEmailAddress().getText())
      .toEqual(email,
        'Error on the content of the email.');

    const otherEmailAddress = personalInformation['contactInfo']['emails'].map(
      element => this.formatEmail(element['prefix'], element['suffix'])
    );
    this.summaryContactInformationPage.getOtherEmailAddress(0).map(function (element) {
      return element.getText();
    }).then(function (elements) {
      for (let element of elements as Array<string>) {
        expect(otherEmailAddress.includes(element))
          .toBe(true,
            'Error on the content of the other email address.');
      }
    });
  }

  checkContactInformationPresent(personalInformation: any) {
    expect(this.summaryContactInformationPage.isAddressPresent())
      .toBe(this.getValue(personalInformation['contactInfo'], 'address') !== '',
        'Error on the presence of the address.');

    expect(this.summaryContactInformationPage.isPostalCodePresent())
      .toBe(this.getValue(personalInformation['contactInfo'], 'postalCode') !== '',
        'Error on the presence of the postal code.');

    expect(this.summaryContactInformationPage.isCountryPresent())
      .toBe(this.getValue(personalInformation['contactInfo'], 'country') !== '',
        'Error on the presence of the country.');

    const phoneNumber = this.formatPhoneNumber(
      personalInformation['contactInfo']['phoneNumber']['prefix'], personalInformation['contactInfo']['phoneNumber']['suffix']
    );
    expect(this.summaryContactInformationPage.isTelephoneNumberPresent())
      .toBe(phoneNumber !== '',
        'Error on the presence of the phone number.');

    const otherPhoneNumber = personalInformation['contactInfo']['phoneNumbers'].map(
      element => this.formatPhoneNumber(element['prefix'], element['suffix'])
    );
    expect(this.summaryContactInformationPage.isOtherTelephoneNumberPresent(0))
      .toBe(otherPhoneNumber.length !== 0,
        'Error on the presence of the other phone number');

    const email = this.formatEmail(
      personalInformation['contactInfo']['email']['prefix'], personalInformation['contactInfo']['email']['suffix']
    );
    expect(this.summaryContactInformationPage.isEmailAddressPresent())
      .toBe(email !== '',
        'Error on the presence of the email.');

    const otherEmailAddress = personalInformation['contactInfo']['emails'].map(
      element => this.formatEmail(element['prefix'], element['suffix'])
    );
    expect(this.summaryContactInformationPage.isOtherEmailAddressPresent(0))
      .toBe(otherEmailAddress.length !== 0,
        'Error on the presence of the other email address.');
  }

}
