import {AbstractValidator} from '../../abstract-validator';
import {SummaryGeneralInformationPage} from '../../../../pages/summary/personal-info/summary-general-information.po';

export class GeneralInformationValidator extends AbstractValidator {

  private generalInformationPage: SummaryGeneralInformationPage = new SummaryGeneralInformationPage();

  checkGeneralInformation(personalInformation: any) {
    expect(this.generalInformationPage.getFamilyName().getText()).toEqual(personalInformation['familyName']);
    expect(this.generalInformationPage.getFirstName().getText()).toEqual(personalInformation['firstName']);
    // tslint:disable-next-line:forin
    for (let index in personalInformation['firstNames']) {
      expect(this.generalInformationPage.getOtherFirstNames(index).getText())
        .toEqual(personalInformation['firstNames'][index]['name']);
    }
    expect(this.generalInformationPage.getGender().getText()).toEqual(this.getGenderTranslation(personalInformation['gender']));
    expect(this.generalInformationPage.getDateOfBirth().getText()).toEqual(this.getJsonDateToString(personalInformation['birthDate']));
    expect(this.generalInformationPage.getCountryOfBirth().getText()).toEqual(
      this.getCountryTranslation(personalInformation['countryOfBirth']));
    expect(this.generalInformationPage.getCountryOfNationality().getText())
      .toEqual(this.getCountryTranslation(personalInformation['nationality']));
    expect(this.generalInformationPage.getMaritalStatus().getText())
      .toEqual(this.getMaritalStatusTranslation(personalInformation['maritalStatus']));
    if (personalInformation['maritalStatus'] === 'other') {
      // tslint:disable-next-line:forin
      for (let index in personalInformation['otherMaritalStatuses']) {
        expect(this.generalInformationPage.getOtherMaritalStatuses(index).getText())
          .toEqual(personalInformation['otherMaritalStatuses'][index]['name']);
      }
    }
  }

  checkGeneralInformationPresent(personalInformation: any) {
    expect(this.generalInformationPage.isFamilyNamePresent()).toBe(personalInformation['familyName'] !== '');
    expect(this.generalInformationPage.isFirstNamePresent()).toBe(personalInformation['firstName'] !== '');
    // tslint:disable-next-line:forin
    for (let index in personalInformation['firstNames']) {
      expect(this.generalInformationPage.isOtherFirstNamesPresent(index))
        .toBe(personalInformation['firstNames'][index]['name'] !== '');
    }
    expect(this.generalInformationPage.isGenderPresent()).toBe(personalInformation['gender'] !== '');
    expect(this.generalInformationPage.isDateOfBirthPresent()).toBe(this.isDateValid(personalInformation['birthDate']));
    expect(this.generalInformationPage.isCountryOfBirthPresent()).toBe(personalInformation['countryOfBirth'] !== '');
    expect(this.generalInformationPage.isCountryOfNationalityPresent()).toBe(personalInformation['nationality'] !== '');
    expect(this.generalInformationPage.isMaritalStatusPresent()).toBe(personalInformation['maritalStatus'] !== '');
    if (personalInformation['maritalStatus'] === 'other') {
      // tslint:disable-next-line:forin
      for (let index in personalInformation['otherMaritalStatuses']) {
        expect(this.generalInformationPage.isOtherMaritalStatusesPresent(index))
          .toBe(personalInformation['otherMaritalStatuses'][index]['name'] !== '');
      }
    }
  }

  checkIdentificationDocument(personalInformation: any) {
    let identificationDocuments: any[] = personalInformation['identificationDocuments'];
    if (identificationDocuments && identificationDocuments.length > 0) {
      let identificationDocument = identificationDocuments[0];
      expect(this.generalInformationPage.getType().getText()).toEqual(
        this.getDocumentTypeTranslation(identificationDocument['name']));
      expect(this.generalInformationPage.getNumber().getText()).toEqual(
        this.getValue(identificationDocument, 'number'));
      expect(this.generalInformationPage.getCountryOfIssue().getText()).toEqual(
        this.getCountryTranslation(identificationDocument['country']));
      expect(this.generalInformationPage.getExpirationDate().getText()).toEqual(
        this.getJsonDateToString(identificationDocument['expirationDate']));
    }
  }

  checkIdentificationDocumentPresent(personalInformation: any) {
    let identificationDocuments: any[] = personalInformation['identificationDocuments'];
    if (identificationDocuments && identificationDocuments.length > 0) {
      let identificationDocument = identificationDocuments[0];
      expect(this.generalInformationPage.isTypePresent()).toBe(identificationDocument['name'] !== '');
      expect(this.generalInformationPage.isNumberPresent()).toBe(
        this.getValue(identificationDocument, 'number') !== '');
      expect(this.generalInformationPage.isCountryOfIssuePresent()).toBe(identificationDocument['country'] !== '');
      expect(this.generalInformationPage.isExpirationDate()).toBe(this.isDateValid(identificationDocument['expirationDate']));
    }
  }

  checkTitleIdentificationDocuments(personalInformation: any) {
    let identificationDocuments: any[] = personalInformation['identificationDocuments'];
    expect(this.generalInformationPage.getAllIdentificationDocumentTitle().count())
      .toBe(identificationDocuments.length,
        'Bad number of identification document displayed');

    for (let i = 0; i < identificationDocuments.length; i++) {
      expect(this.generalInformationPage.getAllIdentificationDocumentTitle().get(i).getText())
        .toBe('Personal identification document ' + (i + 1),
          'Bad title displayed');
    }

  }

}
