import {AbstractValidator} from '../../abstract-validator';
import {SummaryMigrationInformationPage} from '../../../../pages/summary/personal-info/summary-migration-information.po';

export class MigrationInformationValidator extends AbstractValidator {
  private migrationInformationPage: SummaryMigrationInformationPage = new SummaryMigrationInformationPage();

  checkMigrationInformation(migrationInformation: any) {
    expect(this.migrationInformationPage.getDateOfArrival().getText()).toBe(
      this.getJsonDateToString(migrationInformation['dateOfArrival']), 'Date of arrival different');

    let residentialStatus = migrationInformation['residentialStatus'];
    expect(this.migrationInformationPage.getResidentialStatus().getText()).toBe(
      this.getResidentialStatusTranslation(residentialStatus), 'Residential status different');

    if (residentialStatus === 'other') {
      this.checkResidentialStatusOther(migrationInformation);
    }

    expect(this.migrationInformationPage.getWorkPermitStatus().getText()).toBe(
      this.getWorkPermitStatusTranslation(migrationInformation['workPermitStatus']), 'Work permit status different');

    let travellingWithDependants = migrationInformation['travelling'];
    expect(this.migrationInformationPage.getTravellingWithDependants().getText()).toBe(
      this.getBooleanTranslation(travellingWithDependants), 'Travelling with dependants different');

    if (travellingWithDependants === 'true') {
      expect(this.migrationInformationPage.getMinorUnder15().getText()).toBe(
        String(migrationInformation['minor15']), 'Minor under 15 different');
      expect(this.migrationInformationPage.getMinor16To18().getText()).toBe(
        String(migrationInformation['minor16To18']), 'Minor 16 to 18 different');
      expect(this.migrationInformationPage.getAdult().getText()).toBe(
        String(migrationInformation['adult']), 'Adult different');
      expect(this.migrationInformationPage.getElderly().getText()).toBe(
        String(migrationInformation['elderly']), 'Elderly different');
      expect(this.migrationInformationPage.getSickOrDisabled().getText()).toBe(
        String(migrationInformation['sick']), 'Sick or disabled different');
    }
  }

  private checkResidentialStatusOther(migrationInformation: any) {
    this.migrationInformationPage.getOtherResidencyStatuses().map(function (element) {
      return element.getText();
    }).then(function (elements) {
      let jsonResidencyStatuses = migrationInformation['otherResidencyStatuses'];
      let jsonResidencyStatusesArray: string[] = [];

      for (let jsonResidencyStatus of jsonResidencyStatuses) {
        jsonResidencyStatusesArray.push(jsonResidencyStatus['name']);
      }

      for (let element of elements as Array<string>) {
        expect(jsonResidencyStatusesArray.indexOf(element.toString()) >= 0).toBe(true,
          element.toString() + ' cannot be found');
      }
    });
  }

  checkMigrationInformationPresent(migrationInformation: any) {
    expect(this.migrationInformationPage.isDateOfArrivalPresent()).toBe(
      this.isDateValid(migrationInformation['dateOfArrival']), 'Date of arrival not present');
    expect(this.migrationInformationPage.isResidentialStatusPresent()).toBe(
      migrationInformation['residentialStatus'] !== '', 'Residential status not present');
    expect(this.migrationInformationPage.isWorkPermitStatusPresent()).toBe(
      !!migrationInformation['workPermitStatus'], 'Work permit status not present');

    let travellingWithDependant = migrationInformation['travelling'] === 'true';
    expect(this.migrationInformationPage.isTravellingWithDependantsPresent()).toBe(travellingWithDependant,
      'Travelling with dependant not present');
    expect(this.migrationInformationPage.isMinorUnder15Present()).toBe(travellingWithDependant && migrationInformation['minor15'] !== '',
      'Travelling with minor under 15 not present');
    expect(this.migrationInformationPage.isMinor16To18Present()).toBe(travellingWithDependant && migrationInformation['minor16To18'] !== '',
      'Travelling with minor 16 - 18 not present');
    expect(this.migrationInformationPage.isAdultPresent()).toBe(travellingWithDependant && migrationInformation['adult'] !== '',
      'Travelling with adult not present');
    expect(this.migrationInformationPage.isElderlyPresent()).toBe(travellingWithDependant && migrationInformation['elderly'] !== '',
      'Travelling with elderly not present');
    expect(this.migrationInformationPage.isSickOrDisabledPresent()).toBe(travellingWithDependant && migrationInformation['sick'] !== '',
      'Travelling with sick or disabled not present');
  }

}
