import {HomePage} from '../../../pages/home.po';
import {SummaryPage} from '../../../pages/summary/summary.po';
import {HeaderPage} from '../../../pages/header.po';
import {SkillsData} from '../../../data/skills-data';
import {SummaryBasicTransversalValidator} from './validator/summary-basic-transversal-validator';
import * as path from 'path';
import {browser} from 'protractor';

describe('A user on the other basic and transversal skills part of the summary page', function () {
  let headerPage: HeaderPage;
  let homePage: HomePage;
  let summaryPage: SummaryPage;

  let skillsData: SkillsData;

  let summaryBasicTransversalValidator: SummaryBasicTransversalValidator;

  beforeAll(() => {
    headerPage = new HeaderPage();
    homePage = new HomePage();
    summaryPage = new SummaryPage();

    skillsData = new SkillsData();

    summaryBasicTransversalValidator = new SummaryBasicTransversalValidator();
  });

  it('must be able to hide empty basic and transversal information', () => {
    homePage.navigateTo();
    homePage.getCreateProfileButton().click();

    headerPage.getSummaryButton().click();
    summaryBasicTransversalValidator.checkBasicAndTransversalSkills(skillsData.emptySkills['otherBasicTransversalSkills']);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isSkillsIdentificationExpended())
      .toBe(false, 'The section need to be collapsed');
    summaryPage.getSkillsIdentificationButton().click();

    summaryBasicTransversalValidator.isBasicAndTransversalSkillsPresent(skillsData.emptySkills['otherBasicTransversalSkills']);
  });

  it('must be able to not hide filled basic and transversal information', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/profile.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    summaryBasicTransversalValidator.checkBasicAndTransversalSkills(skillsData.fullSkills['otherBasicTransversalSkills']);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isSkillsIdentificationExpended())
      .toBe(true, 'The section need to be expended');

    summaryBasicTransversalValidator.isBasicAndTransversalSkillsPresent(skillsData.fullSkills['otherBasicTransversalSkills']);
  });

});
