import {SummaryPage} from '../../../pages/summary/summary.po';
import {HeaderPage} from '../../../pages/header.po';
import {HomePage} from '../../../pages/home.po';
import {SkillsData} from '../../../data/skills-data';
import {SummaryDigitalValidator} from './validator/summary-digital-validator';
import * as path from 'path';
import {browser} from 'protractor';
import {SkillsIdentificationDrivingSkillsPage} from '../../../pages/skills-identification.driving.po';
import {SummaryDigitalPage} from '../../../pages/summary/skills/summary-digital.po';

describe('A user on the digital skills part of the summary page', function () {
  let headerPage: HeaderPage;
  let homePage: HomePage;
  let skillsIdentificationDrivingSkillsPage: SkillsIdentificationDrivingSkillsPage;
  let summaryPage: SummaryPage;
  let summaryDigitalPage: SummaryDigitalPage;

  let skillsData: SkillsData;

  let summaryDigitalValidator: SummaryDigitalValidator;

  beforeAll(() => {
    headerPage = new HeaderPage();
    homePage = new HomePage();
    skillsIdentificationDrivingSkillsPage = new SkillsIdentificationDrivingSkillsPage();
    summaryPage = new SummaryPage();
    summaryDigitalPage = new SummaryDigitalPage();

    skillsData = new SkillsData();

    summaryDigitalValidator = new SummaryDigitalValidator();
  });

  it('must be able to hide empty digital information', () => {
    homePage.navigateTo();
    homePage.getCreateProfileButton().click();

    headerPage.getSummaryButton().click();
    summaryDigitalValidator.checkDigital(skillsData.emptySkills['digitalSkills']);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isSkillsIdentificationExpended())
      .toBe(false, 'The section need to be collapsed');
    summaryPage.getSkillsIdentificationButton().click();

    summaryDigitalValidator.checkDigitalPresent(skillsData.emptySkills['digitalSkills']);
  });

  it('must be able to not hide filled digital information', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/profile.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    summaryDigitalValidator.checkDigital(skillsData.fullSkills['digitalSkills']);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isSkillsIdentificationExpended())
      .toBe(true, 'The section need to be expended');

    summaryDigitalValidator.checkDigitalPresent(skillsData.fullSkills['digitalSkills']);
  });

  it('should not be able to see the line other digital skills in the summary when the list is empty', () => {
    homePage.navigateTo();
    homePage.getCreateProfileButton().click();

    headerPage.getSkillsIdentificationButton().click();
    headerPage.getDigitalSkillsTabButton().click();
    skillsIdentificationDrivingSkillsPage.getAddOtherDigitalSkillsButton().click();
    skillsIdentificationDrivingSkillsPage.getOtherDigitalSkillsInput(0).sendKeys('other digital skill');
    headerPage.getSummaryButton().click();
    expect(summaryDigitalPage.getOtherDigitalSkills(0).getText())
      .toBe('other digital skill');

    headerPage.getSkillsIdentificationButton().click();
    headerPage.getDigitalSkillsTabButton().click();
    skillsIdentificationDrivingSkillsPage.getRemoveOtherDigitalSkillsButton(0).click();
    headerPage.getSummaryButton().click();
    expect(summaryDigitalPage.isOtherDigitalSkillsTitlePresent())
      .toBe(false);
  });

});
