import {SummaryPage} from '../../../pages/summary/summary.po';
import {HomePage} from '../../../pages/home.po';
import {SkillsData} from '../../../data/skills-data';
import {HeaderPage} from '../../../pages/header.po';
import {SummaryDrivingSkillsValidator} from './validator/summary-driving-skills-validator';
import * as path from 'path';
import {browser} from 'protractor';

describe('A user on the driving skills part of the summary page', function () {
  let headerPage: HeaderPage;
  let homePage: HomePage;
  let summaryPage: SummaryPage;

  let skillsData: SkillsData;

  let summaryDrivingSkillsValidator: SummaryDrivingSkillsValidator;

  beforeAll(() => {
    headerPage = new HeaderPage();
    homePage = new HomePage();
    summaryPage = new SummaryPage();

    skillsData = new SkillsData();

    summaryDrivingSkillsValidator = new SummaryDrivingSkillsValidator();
  });

  it('must be able to hide empty driving skills', () => {
    homePage.navigateTo();
    homePage.getCreateProfileButton().click();

    headerPage.getSummaryButton().click();
    summaryDrivingSkillsValidator.checkDrivingSkills(skillsData.emptySkills['drivingSkills']);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isSkillsIdentificationExpended())
      .toBe(false, 'The section need to be collapsed');
    summaryPage.getSkillsIdentificationButton().click();

    summaryDrivingSkillsValidator.checkDrivingSkillsPresent(skillsData.emptySkills['drivingSkills']);
  });

  it('must be able to not hide filled driving skills', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/profile.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    summaryDrivingSkillsValidator.checkDrivingSkills(skillsData.fullSkills['drivingSkills']);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isSkillsIdentificationExpended())
      .toBe(true, 'The section need to be expended');

    summaryDrivingSkillsValidator.checkDrivingSkillsPresent(skillsData.fullSkills['drivingSkills']);
  });
});
