import {HeaderPage} from '../../../pages/header.po';
import {HomePage} from '../../../pages/home.po';
import {SummaryPage} from '../../../pages/summary/summary.po';
import {SummaryEducationTrainingValidator} from './validator/summary-education-training-validator';
import {SkillsData} from '../../../data/skills-data';
import * as path from 'path';
import {browser} from 'protractor';

describe('A user on the education and training part of the summary page', function () {
  let headerPage: HeaderPage;
  let homePage: HomePage;
  let summaryPage: SummaryPage;
  let skillsData: SkillsData;

  let summaryEducationTrainingValidator: SummaryEducationTrainingValidator;

  beforeAll(() => {
    headerPage = new HeaderPage();
    homePage = new HomePage();
    summaryPage = new SummaryPage();
    skillsData = new SkillsData();

    summaryEducationTrainingValidator = new SummaryEducationTrainingValidator();
  });

  it('must be able to hide empty education and training information', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/empty.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    summaryEducationTrainingValidator.checkEducationAndTraining(skillsData.emptySkills);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isSkillsIdentificationExpended())
      .toBe(true, 'The section need to be expended');

    summaryEducationTrainingValidator.checkEducationAndTrainingPresent(skillsData.emptySkills);
  });

  it('must be able to not hide filled education and training information', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/profile.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    summaryEducationTrainingValidator.checkEducationAndTraining(skillsData.fullSkills);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isSkillsIdentificationExpended())
      .toBe(true, 'The section need to be expended');

    summaryEducationTrainingValidator.checkEducationAndTrainingPresent(skillsData.fullSkills);
  });

  it('must be able to not hide semi-filled education and training information', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/profile_bug_sumary_education_and_training.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    summaryEducationTrainingValidator.checkEducationAndTraining(skillsData.semiFilledSkills);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isSkillsIdentificationExpended())
      .toBe(true, 'The section need to be expended');

    summaryEducationTrainingValidator.checkEducationAndTrainingPresent(skillsData.semiFilledSkills);
  });

  it('must be able to hide \'No\' labels', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/profile_full_of_no.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    summaryEducationTrainingValidator.checkEducationAndTraining(skillsData.profileFullOfNo);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isSkillsIdentificationExpended())
      .toBe(true, 'The section need to be expended');

    summaryEducationTrainingValidator.checkEducationAndTrainingPresent(skillsData.profileFullOfNo);
  });

  it('must be able to hide \'No\' labels (2)', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/profile_full_of_no_2.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    summaryEducationTrainingValidator.checkEducationAndTraining(skillsData.profileFullOfNo2);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isSkillsIdentificationExpended())
      .toBe(true, 'The section need to be expended');

    summaryEducationTrainingValidator.checkEducationAndTrainingPresent(skillsData.profileFullOfNo2);
  });
});
