import {HeaderPage} from '../../../pages/header.po';
import {HomePage} from '../../../pages/home.po';
import {LanguageSkillsValidator} from './validator/summary-language-validator';
import * as path from 'path';
import {SkillsData} from '../../../data/skills-data';
import {SummaryPage} from '../../../pages/summary/summary.po';
import {browser} from 'protractor';
import {SkillsIdentificationLanguageSkillsPage} from '../../../pages/skills-identification.language.po';
import {SummaryLanguageSkillsPage} from '../../../pages/summary/skills/summary-language.po';

describe('A user on the language part of the summary page', function () {
  let headerPage: HeaderPage;
  let homePage: HomePage;
  let skillsIdentificationLanguageSkillsPage: SkillsIdentificationLanguageSkillsPage;
  let summaryPage: SummaryPage;
  let summaryLanguageSkillsPage: SummaryLanguageSkillsPage;

  let data: SkillsData;

  let summaryLanguageSkillsValidator: LanguageSkillsValidator;

  beforeAll(() => {
    headerPage = new HeaderPage();
    homePage = new HomePage();
    skillsIdentificationLanguageSkillsPage = new SkillsIdentificationLanguageSkillsPage();
    summaryPage = new SummaryPage();
    summaryLanguageSkillsPage = new SummaryLanguageSkillsPage();

    data = new SkillsData();

    summaryLanguageSkillsValidator = new LanguageSkillsValidator();
  });

  it('must be able to hide empty language skills', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/empty.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    summaryLanguageSkillsValidator.checkLanguageSkills(data.emptySkills);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isSkillsIdentificationExpended())
      .toBe(true, 'The section need to be expended');

    summaryLanguageSkillsValidator.checkLanguageSkillsPresent(data.emptySkills);
  });

  it('must be able to not hide filled language skills', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/profile.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    summaryLanguageSkillsValidator.checkLanguageSkills(data.fullSkills);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isSkillsIdentificationExpended())
      .toBe(true, 'The section need to be expended');

    summaryLanguageSkillsValidator.checkLanguageSkillsPresent(data.fullSkills);
  });

  it('must be able to hide \'No\' labels', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/profile_full_of_no.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    summaryLanguageSkillsValidator.checkLanguageSkills(data.profileFullOfNo);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isSkillsIdentificationExpended())
      .toBe(true, 'The section need to be expended');

    summaryLanguageSkillsValidator.checkLanguageSkillsPresent(data.profileFullOfNo);
  });

  it('should not be able to see the `can you communicate in a language of the host country` paragraph in the summary when the list is empty', () => {
    homePage.navigateTo();
    homePage.getCreateProfileButton().click();

    headerPage.getSkillsIdentificationButton().click();
    skillsIdentificationLanguageSkillsPage.getCommunicateInLanguageOfTheHostCountryRadioButton().get(0).click();
    headerPage.getSummaryButton().click();
    expect(summaryLanguageSkillsPage.isLanguageHostCountryTitlePresent())
      .toBe(true);

    headerPage.getSkillsIdentificationButton().click();
    skillsIdentificationLanguageSkillsPage.getCommunicateInLanguageOfTheHostCountryRadioButton().get(1).click();
    headerPage.getSummaryButton().click();
    expect(summaryLanguageSkillsPage.isLanguageHostCountryTitlePresent())
      .toBe(false);
  });

});
