import {HeaderPage} from '../../../pages/header.po';
import {HomePage} from '../../../pages/home.po';
import {SkillsData} from '../../../data/skills-data';
import * as path from 'path';
import {SummaryLiteracyValidator} from './validator/summary-literacy-validator';
import {SummaryPage} from '../../../pages/summary/summary.po';
import {browser} from 'protractor';

describe('A user on the literacy skills part of the summary page', function () {
  let headerPage: HeaderPage;
  let homePage: HomePage;
  let summaryPage: SummaryPage;

  let data: SkillsData;

  let summaryLiteracyValidator: SummaryLiteracyValidator;

  beforeAll(() => {
    headerPage = new HeaderPage();
    homePage = new HomePage();
    summaryPage = new SummaryPage();
    data = new SkillsData();

    summaryLiteracyValidator = new SummaryLiteracyValidator();
  });

  it('must be able to hide empty literacy information', () => {
    homePage.navigateTo();
    homePage.getCreateProfileButton().click();

    headerPage.getSummaryButton().click();
    summaryLiteracyValidator.checkLiteracy(data.emptySkills['literacySkills'], false);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isSkillsIdentificationExpended())
      .toBe(false, 'The section need to be collapsed');
    summaryPage.getSkillsIdentificationButton().click();

    summaryLiteracyValidator.checkLiteracyPresent(data.emptySkills['literacySkills'], false);
  });

  it('must be able to not hide filled literacy information', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/profile_low_education.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    summaryLiteracyValidator.checkLiteracy(data.lowLevelEducationSkill['literacySkills'], false);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isSkillsIdentificationExpended())
      .toBe(true, 'The section need to be expended');

    summaryLiteracyValidator.checkLiteracyPresent(data.lowLevelEducationSkill['literacySkills'], false);
  });

  it('must be able to hide literacy skill because the level of education is higher than \'primary\'', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/profile.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    summaryLiteracyValidator.checkLiteracy(data.fullSkills['literacySkills'], true);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isSkillsIdentificationExpended())
      .toBe(true, 'The section need to be expended');

    summaryLiteracyValidator.checkLiteracyPresent(data.fullSkills['literacySkills'], true);
  });

});
