import {HomePage} from '../../../pages/home.po';
import {HeaderPage} from '../../../pages/header.po';
import {SkillsData} from '../../../data/skills-data';
import {SummaryNumeracySkillValidator} from './validator/summary-numeracy-skills-validator';
import * as path from 'path';
import {SummaryPage} from '../../../pages/summary/summary.po';
import {browser} from 'protractor';

describe('A user on the numeracy skills part of the summary page', function () {
  let headerPage: HeaderPage;
  let homePage: HomePage;
  let summaryPage: SummaryPage;
  let skillsData: SkillsData;

  let summaryNumeracySkillsValidator: SummaryNumeracySkillValidator;

  beforeAll(() => {
    headerPage = new HeaderPage();
    homePage = new HomePage();
    summaryPage = new SummaryPage();
    skillsData = new SkillsData();

    summaryNumeracySkillsValidator = new SummaryNumeracySkillValidator();
  });

  it('must be able to hide empty numeracy skills information', () => {
    homePage.navigateTo();
    homePage.getCreateProfileButton().click();

    headerPage.getSummaryButton().click();
    summaryNumeracySkillsValidator.checkNumeracySkills(skillsData.emptySkills);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isSkillsIdentificationExpended())
      .toBe(false, 'The section need to be collapsed');
    summaryPage.getSkillsIdentificationButton().click();

    summaryNumeracySkillsValidator.checkNumeracySkillsPresent(skillsData.emptySkills);
  });

  it('must be able to not hide filled numeracy skills information', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/profile.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    summaryNumeracySkillsValidator.checkNumeracySkills(skillsData.fullSkills);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isSkillsIdentificationExpended())
      .toBe(true, 'The section need to be expended');

    summaryNumeracySkillsValidator.checkNumeracySkillsPresent(skillsData.fullSkills);
  });

  it('must be able to not hide Didier Ridoux\' numeracy skills information', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/Didier_Ridoux_20180608.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    summaryNumeracySkillsValidator.checkNumeracySkills(skillsData.didierRidoux);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isSkillsIdentificationExpended())
      .toBe(true, 'The section need to be expended');

    summaryNumeracySkillsValidator.checkNumeracySkillsPresent(skillsData.didierRidoux);
  });

});
