import {HeaderPage} from '../../../pages/header.po';
import {HomePage} from '../../../pages/home.po';
import {SkillsData} from '../../../data/skills-data';
import {ProfessionalSkillsValidator} from './validator/summary-professional-validator';
import {SummaryPage} from '../../../pages/summary/summary.po';
import * as path from 'path';
import {browser} from 'protractor';

describe('A user on the professional skills part of the summary page', function () {
  let headerPage: HeaderPage;
  let homePage: HomePage;
  let summaryPage: SummaryPage;

  let data: SkillsData;

  let summaryProfessionalSkillsValidator: ProfessionalSkillsValidator;

  beforeAll(() => {
    headerPage = new HeaderPage();
    homePage = new HomePage();
    summaryPage = new SummaryPage();

    data = new SkillsData();

    summaryProfessionalSkillsValidator = new ProfessionalSkillsValidator();
  });

  it('must be able to hide empty professional skills', () => {
    homePage.navigateTo();
    homePage.getCreateProfileButton().click();

    headerPage.getSummaryButton().click();
    summaryProfessionalSkillsValidator.checkProfessionalSkills(data.emptySkills['professionalSkills']);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isSkillsIdentificationExpended())
      .toBe(false, 'The section need to be collapsed');
    summaryPage.getSkillsIdentificationButton().click();

    summaryProfessionalSkillsValidator.checkProfessionalSkillsPresent(data.emptySkills['professionalSkills']);
  });

  it('must be able to not hide filled professional skills', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/profile.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    summaryProfessionalSkillsValidator.checkProfessionalSkills(data.fullSkills['professionalSkills']);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isSkillsIdentificationExpended())
      .toBe(true, 'The section need to be expended');

    summaryProfessionalSkillsValidator.checkProfessionalSkillsPresent(data.fullSkills['professionalSkills']);
  });

  it('must be able to hide \'No\' labels', () => {
    homePage.navigateTo();
    // path of the file
    const fileToUpload = '../../../resources/profile_full_of_no.xml';
    const absolutePath = path.resolve(__dirname, fileToUpload);

    // unhide input (not working in firefox otherwise)
    browser.executeScript(
      'document.getElementById("file-reader").style.visibility = "visible"; document.getElementById("file-reader").style.display = "inline"'
    );

    homePage.getFileReaderInput().sendKeys(absolutePath);
    expect(browser.getCurrentUrl()).toEqual(summaryPage.getFirstSection());

    headerPage.getSummaryButton().click();
    summaryProfessionalSkillsValidator.checkProfessionalSkills(data.profileFullOfNo['professionalSkills']);

    // hide all elements not filled
    summaryPage.getToggleButton().click();
    expect(summaryPage.isSkillsIdentificationExpended())
      .toBe(true, 'The section need to be expended');

    summaryProfessionalSkillsValidator.checkProfessionalSkillsPresent(data.profileFullOfNo['professionalSkills']);
  });

});
