import {AbstractValidator} from '../../abstract-validator';
import {SummaryBasicTransversalSkillsPage} from '../../../../pages/summary/skills/summary-basic-transversal-skills.po';

export class SummaryBasicTransversalValidator extends AbstractValidator {
  private basicTransversalSkillsPage: SummaryBasicTransversalSkillsPage = new SummaryBasicTransversalSkillsPage();

  checkBasicAndTransversalSkills(basicTransversalSkills: any) {

    expect(this.basicTransversalSkillsPage.getWorkIndependently().getText()).toBe(
      this.getRatingTranslation(basicTransversalSkills['workIndependently']),
      'Error on the content of work independently');

    expect(this.basicTransversalSkillsPage.getMakeDecisionsIndependently().getText()).toBe(
      this.getRatingTranslation(basicTransversalSkills['makeDecisionsIndependently']),
      'Error on the content of work make decisions independently');

    expect(this.basicTransversalSkillsPage.getWorkInStructuredWay().getText()).toBe(
      this.getRatingTranslation(basicTransversalSkills['workInStructuredWay']),
      'Error on the content of work in structured way');

    expect(this.basicTransversalSkillsPage.getSolveProblems().getText()).toBe(
      this.getRatingTranslation(basicTransversalSkills['solveProblems']),
      'Error on the content of solve problems');

    expect(this.basicTransversalSkillsPage.getWorkWithOthers().getText()).toBe(
      this.getRatingTranslation(basicTransversalSkills['workWithOthers']),
      'Error on the content of work with others');

    expect(this.basicTransversalSkillsPage.getWorkWithPeople().getText()).toBe(
      this.getRatingTranslation(basicTransversalSkills['workWithPeople']),
      'Error on the content of work with people');

    expect(this.basicTransversalSkillsPage.getWorkWithCustomers().getText()).toBe(
      this.getRatingTranslation(basicTransversalSkills['workWithCustomers']),
      'Error on the content of work with customers');

    expect(this.basicTransversalSkillsPage.getWorkAsLeader().getText()).toBe(
      this.getRatingTranslation(basicTransversalSkills['workAsLeader']),
      'Error on the content of work as leader');

    expect(this.basicTransversalSkillsPage.getManageProject().getText()).toBe(
      this.getRatingTranslation(basicTransversalSkills['manageProject']),
      'Error on the content of manage project');

    expect(this.basicTransversalSkillsPage.getWorkInStressfulConditions().getText()).toBe(
      this.getRatingTranslation(basicTransversalSkills['workInStressfulConditions']),
      'Error on the content of work in stressful conditions');

    expect(this.basicTransversalSkillsPage.getDevelopIdeas().getText()).toBe(
      this.getRatingTranslation(basicTransversalSkills['developIdeas']),
      'Error on the content of develop ideas');

    expect(this.basicTransversalSkillsPage.getInspireEnthuseOthers().getText()).toBe(
      this.getRatingTranslation(basicTransversalSkills['inspireEnthuseOthers']),
      'Error on the content of inspire and enthuse others');

    expect(this.basicTransversalSkillsPage.getTakeResponsability().getText()).toBe(
      this.getRatingTranslation(basicTransversalSkills['takeResponsability']),
      'Error on the content of take responsability');
  }

  isBasicAndTransversalSkillsPresent(basicTransversalSkills: any) {
    expect(this.basicTransversalSkillsPage.isWorkIndependentlyPresent()).toBe(
      !!basicTransversalSkills['workIndependently'],
      'Error on the presence of work independently');

    expect(this.basicTransversalSkillsPage.isMakeDecisionsIndependentlyPresent()).toBe(
      !!basicTransversalSkills['makeDecisionsIndependently'],
      'Error on the presence of work make decisions independently');

    expect(this.basicTransversalSkillsPage.isWorkInStructuredWayPresent()).toBe(
      !!basicTransversalSkills['workInStructuredWay'],
      'Error on the presence of work in structured way');

    expect(this.basicTransversalSkillsPage.isSolveProblemsPresent()).toBe(
      !!basicTransversalSkills['solveProblems'],
      'Error on the presence of solve problems');

    expect(this.basicTransversalSkillsPage.isWorkWithOthersPresent()).toBe(
      !!basicTransversalSkills['workWithOthers'],
      'Error on the presence of work with others');

    expect(this.basicTransversalSkillsPage.isWorkWithPeoplePresent()).toBe(
      !!basicTransversalSkills['workWithPeople'],
      'Error on the presence of work with people');

    expect(this.basicTransversalSkillsPage.isWorkWithCustomersPresent()).toBe(
      !!basicTransversalSkills['workWithCustomers'],
      'Error on the presence of work with customers');

    expect(this.basicTransversalSkillsPage.isWorkAsLeaderPresent()).toBe(
      !!basicTransversalSkills['workAsLeader'],
      'Error on the presence of work as leader');

    expect(this.basicTransversalSkillsPage.isManageProjectPresent()).toBe(
      !!basicTransversalSkills['manageProject'],
      'Error on the presence of manage project');

    expect(this.basicTransversalSkillsPage.isWorkInStressfulConditionsPresent()).toBe(
      !!basicTransversalSkills['workInStressfulConditions'],
      'Error on the presence of work in stressful conditions');

    expect(this.basicTransversalSkillsPage.isDevelopIdeasPresent()).toBe(
      !!basicTransversalSkills['developIdeas'],
      'Error on the presence of develop ideas');

    expect(this.basicTransversalSkillsPage.isInspireEnthuseOthersPresent()).toBe(
      !!basicTransversalSkills['inspireEnthuseOthers'],
      'Error on the presence of inspire and enthuse others');

    expect(this.basicTransversalSkillsPage.isTakeResponsabilityPresent()).toBe(
      !!basicTransversalSkills['takeResponsability'],
      'Error on the presence of take responsability');
  }
}
