import {AbstractValidator} from '../../abstract-validator';
import {SummaryDigitalPage} from '../../../../pages/summary/skills/summary-digital.po';

export class SummaryDigitalValidator extends AbstractValidator {
  private summaryDigitalPage: SummaryDigitalPage = new SummaryDigitalPage();

  checkDigital(skills: any) {
    expect(this.summaryDigitalPage.getSmartphoneOrTablet().getText())
      .toBe(this.getRatingTranslation(skills['usingSmartphone']),
        'Error on the content of using smartphone.');

    expect(this.summaryDigitalPage.getLaptop().getText())
      .toBe(this.getRatingTranslation(skills['usingLaptop']),
        'Error on the content of using laptop.');

    expect(this.summaryDigitalPage.getManagingFilesAndFolders().getText())
      .toBe(this.getRatingTranslation(skills['managingFiles']),
        'Error on the content of managing files or folder.');

    expect(this.summaryDigitalPage.getTextDocuments().getText())
      .toBe(this.getRatingTranslation(skills['createTextDocs']),
        'Error on the content of text documents.');

    expect(this.summaryDigitalPage.getSpreadSheets().getText())
      .toBe(this.getRatingTranslation(skills['createSpreadsheets']),
        'Error on the content of spreadsheets.');

    expect(this.summaryDigitalPage.getPresentations().getText())
      .toBe(this.getRatingTranslation(skills['createPresentations']),
        'Error on the content of presentations.');

    expect(this.summaryDigitalPage.getEmails().getText())
      .toBe(this.getRatingTranslation(skills['useEmails']),
        'Error on the content of emails.');

    expect(this.summaryDigitalPage.getFindingAndManagingInformationOnInternet().getText())
      .toBe(this.getRatingTranslation(skills['findInfoOnInternet']),
        'Error on the content of finding and managing information on the internet.');

    expect(this.summaryDigitalPage.getInternetCalls().getText())
      .toBe(this.getRatingTranslation(skills['useInternetCalls']),
        'Error on the content of internet calls.');

    expect(this.summaryDigitalPage.getPurchasingGoodsAndServicesOnline().getText())
      .toBe(this.getRatingTranslation(skills['purchaseOnline']),
        'Error on the content of purchasing goods and services online.');

    expect(this.summaryDigitalPage.getLearningOnline().getText())
      .toBe(this.getRatingTranslation(skills['learningOnline']),
        'Error on the content of learning online.');

    expect(this.summaryDigitalPage.getProducingGraphic().getText())
      .toBe(this.getRatingTranslation(skills['makingGraphicDesigns']),
        'Error on the content of producing graphic.');

    expect(this.summaryDigitalPage.getOtherDigitalSkills().getText())
      .toBe(this.getValue(skills, 'other'),
        'Error on the content of other digital skills');

    let otherDigitalSkills = [].concat(skills['others'].map(element => element['name']));
    for (let index = 0; index < otherDigitalSkills.length; index++) {
      this.summaryDigitalPage.getOtherDigitalSkills(index).getText()
        .then(label => {
          expect(otherDigitalSkills.some(elm => elm === label))
            .toBe(true,
              'Error on the content of other digital skill : ' + label);
        });
    }
  }

  checkDigitalPresent(skills: any) {
    expect(this.summaryDigitalPage.isSmartphoneOrTabletPresent())
      .toBe(this.getRatingTranslation(skills['usingSmartphone']) !== 'None',
        'Error on the presence of using smartphone.');

    expect(this.summaryDigitalPage.isLaptopPresent())
      .toBe(this.getRatingTranslation(skills['usingLaptop']) !== 'None',
        'Error on the presence of using laptop.');

    expect(this.summaryDigitalPage.isManagingFilesAndFoldersPresent())
      .toBe(this.getRatingTranslation(skills['managingFiles']) !== 'None',
        'Error on the presence of managing files or folder.');

    expect(this.summaryDigitalPage.isTextDocumentsPresent())
      .toBe(this.getRatingTranslation(skills['createTextDocs']) !== 'None',
        'Error on the presence of text documents.');

    expect(this.summaryDigitalPage.isSpreadSheetsPresent())
      .toBe(this.getRatingTranslation(skills['createSpreadsheets']) !== 'None',
        'Error on the presence of spreadsheets.');

    expect(this.summaryDigitalPage.isPresentationsPresent())
      .toBe(this.getRatingTranslation(skills['createPresentations']) !== 'None',
        'Error on the presence of presentations.');

    expect(this.summaryDigitalPage.isEmailsPresent())
      .toBe(this.getRatingTranslation(skills['useEmails']) !== 'None',
        'Error on the presence of emails.');

    expect(this.summaryDigitalPage.isFindingAndManagingInformationOnInternetPresent())
      .toBe(this.getRatingTranslation(skills['findInfoOnInternet']) !== 'None',
        'Error on the presence of finding and managing information on the internet.');

    expect(this.summaryDigitalPage.isInternetCallsPresent())
      .toBe(this.getRatingTranslation(skills['useInternetCalls']) !== 'None',
        'Error on the presence of internet calls.');

    expect(this.summaryDigitalPage.isPurchasingGoodsAndServicesOnlinePresent())
      .toBe(this.getRatingTranslation(skills['purchaseOnline']) !== 'None',
        'Error on the presence of purchasing goods and services online.');

    expect(this.summaryDigitalPage.isLearningOnlinePresent())
      .toBe(this.getRatingTranslation(skills['learningOnline']) !== 'None',
        'Error on the presence of learning online.');

    expect(this.summaryDigitalPage.isProducingGraphicPresent())
      .toBe(this.getRatingTranslation(skills['makingGraphicDesigns']) !== 'None',
        'Error on the presence of producing graphic.');

    expect(this.summaryDigitalPage.isOtherDigitalSkillsPresent())
      .toBe(!!this.getValue(skills, 'other'),
        'Error on the presence of other digital skills');

    let otherDigitalSkills = [].concat(skills['others'].map(element => element['name']));
    for (let index = 0; index < otherDigitalSkills.length; index++) {
      expect(this.summaryDigitalPage.isOtherDigitalSkillsPresent(index))
        .toBe(otherDigitalSkills.length > index,
          'Error on the presence of ' + otherDigitalSkills);
    }
  }

}
