import {AbstractValidator} from '../../abstract-validator';
import {SummaryEducationTrainingPage} from '../../../../pages/summary/skills/summary-education-training.po';

export class SummaryEducationTrainingValidator extends AbstractValidator {
  private summaryEductionTrainingPage: SummaryEducationTrainingPage = new SummaryEducationTrainingPage();

  checkEducationAndTraining(skills: any) {
    expect(this.summaryEductionTrainingPage.getAttented().getText()).toBe(
      this.getBooleanTranslation(skills['educationTraining']['attended']),
      'Error for the content of attended');

    if (skills['educationTraining']['attended'] === 'true') {
      expect(this.summaryEductionTrainingPage.getLastIn().getText()).toBe(
        this.getValue(skills['educationTraining'], 'last'),
        'Error for the content of last');

      this.checkFullTimeDuration(skills);

      this.checkPartTimeDuration(skills);

      expect(this.summaryEductionTrainingPage.getHighestLevel().getText()).toBe(
        this.getEducationLevel(skills['educationTraining']['highestLevel']),
        'Error for the content of highestLevel');

      this.checkStudyFields(skills);

      this.checkOtherFieldsOfStudy(skills);

      this.checkOtherFieldsOfStudyDuration(skills);

      this.checkTypesOfEducation(skills);

      expect(this.summaryEductionTrainingPage.getPriorLearning().getText()).toBe(
        this.getBooleanTranslation(skills['educationTraining']['priorLearning']),
        'Error for the content of priorLearning');
      expect(this.summaryEductionTrainingPage.getCertificateOrDiploma().getText()).toBe(
        this.getBooleanTranslation(skills['educationTraining']['certificate']),
        'Error for the content of certificate');
    }
  }

  private checkStudyFields(skills: any) {
    let studyField = skills['educationTraining']['studyField'];
    let studyFieldTranslation = !!studyField ? this.getStudyFieldTranslation(studyField) : '';

    let studyFields = skills['educationTraining']['studyFields'];
    let studyFieldsTranslations = !!studyFields ? studyFields.map(field => this.getStudyFieldTranslation(field['name'])) : [];

    if (!!studyFieldTranslation) {
      studyFieldsTranslations.push(studyFieldTranslation);
    }

    this.testMultipleElements(this.summaryEductionTrainingPage.getStudyFields(),
      studyFieldsTranslations,
      'Error for the content of study fields');
  }

  private checkOtherFieldsOfStudy(skills: any) {
    let otherStudyFields = skills['educationTraining']['otherStudyFields'];
    let otherStudyFieldsNames = !!otherStudyFields ? otherStudyFields.map(element => element['name']) : [];

    this.testMultipleElements(this.summaryEductionTrainingPage.getOtherStudyFields(),
      otherStudyFieldsNames,
      'Error for the content of other fields of study');
  }

  private checkOtherFieldsOfStudyDuration(skills: any) {
    expect(this.summaryEductionTrainingPage.getOtherFieldsOfStudyWeek().getText()).toBe(
      this.getDuration(skills['educationTraining']['studyFieldWeek']) + 'Week(s)',
      'Error for the content of studyFieldWeek');
    expect(this.summaryEductionTrainingPage.getOtherFieldsOfStudyMonth().getText()).toBe(
      this.getDuration(skills['educationTraining']['studyFieldMonth']) + 'Month(s)',
      'Error for the content of studyFieldMonth');
    expect(this.summaryEductionTrainingPage.getOtherFieldsOfStudyYear().getText()).toBe(
      this.getDuration(skills['educationTraining']['studyFieldYear']) + 'Year(s)',
      'Error for the content of studyFieldYear');
  }

  private checkPartTimeDuration(skills: any) {
    expect(this.summaryEductionTrainingPage.getPartTimeWeek().getText()).toBe(
      this.getDuration(skills['educationTraining']['partTimeWeek']) + 'Week(s)',
      'Error for the content of partTimeWeek');
    expect(this.summaryEductionTrainingPage.getPartTimeMonth().getText()).toBe(
      this.getDuration(skills['educationTraining']['partTimeMonth']) + 'Month(s)',
      'Error for the content of partTimeMonth');
    expect(this.summaryEductionTrainingPage.getPartTimeYear().getText()).toBe(
      this.getDuration(skills['educationTraining']['partTimeYear']) + 'Year(s)',
      'Error for the content of partTimeYear');
  }

  private checkFullTimeDuration(skills: any) {
    expect(this.summaryEductionTrainingPage.getFullTimeWeek().getText()).toBe(
      this.getDuration(skills['educationTraining']['fullTimeWeek']) + 'Week(s)',
      'Error for the content of fullTimeWeek');
    expect(this.summaryEductionTrainingPage.getFullTimeMonth().getText()).toBe(
      this.getDuration(skills['educationTraining']['fullTimeMonth']) + 'Month(s)',
      'Error for the content of fullTimeMonth');
    expect(this.summaryEductionTrainingPage.getFullTimeYear().getText()).toBe(
      this.getDuration(skills['educationTraining']['fullTimeYear']) + 'Year(s)',
      'Error for the content of fullTimeYear');
  }

  private checkTypesOfEducation(skills: any) {
    this.summaryEductionTrainingPage.getAllTypesOfEducation().map(function (elm) {
      return elm.getText();
    }).then(function (types) {
      if (skills['educationTraining']['educationType']['schoolBased'] != null) {
        expect(types).toContain(
          'School based learning',
          'Error for the content of schoolBased');
      }

      if (skills['educationTraining']['educationType']['workBased'] != null) {
        expect(types).toContain(
          'Work-based learning',
          'Error for the content of workBased');
      }

      if (skills['educationTraining']['educationType']['apprenticeship'] != null) {
        expect(types).toContain(
          'Apprenticeship',
          'Error for the content of apprenticeship');
      }

      if (skills['educationTraining']['educationType']['internship'] != null) {
        expect(types).toContain(
          'Internship',
          'Error for the content of internship');
      }
    });
  }

  checkEducationAndTrainingPresent(skills: any) {
    expect(this.summaryEductionTrainingPage.isAttentedPresent()).toBe(
      !!skills['educationTraining']['attended'],
      'Error for the presence of attended');

    if (skills['educationTraining']['attended'] === 'true') {
      expect(this.summaryEductionTrainingPage.isLastInPresent()).toBe(
        !!skills['educationTraining']['last'],
        'Error for the presence of last');

      this.isFullTimeDurationPresent(skills);

      this.isPartTimeDurationPresent(skills);

      expect(this.summaryEductionTrainingPage.isHighestLevelPresent()).toBe(
        !!skills['educationTraining']['highestLevel'],
        'Error for the presence of highestLevel');

      expect(this.summaryEductionTrainingPage.isStudyFieldsPresent()).toBe(
        !!skills['educationTraining']['studyField'] || (!!skills['educationTraining']['studyFields'] &&
        skills['educationTraining']['studyFields'].length > 0),
        'Error for the presence of studyField or studyFields');

      this.isOtherFieldDurationPresent(skills);


      const typesOfEducationPresenceExpected =
        !!skills['educationTraining']['educationType']['schoolBased']
        || !!skills['educationTraining']['educationType']['workBased']
        || !!skills['educationTraining']['educationType']['apprenticeship']
        || !!skills['educationTraining']['educationType']['internship'];
      expect(this.summaryEductionTrainingPage.isTypesOfEducationPresent()).toBe(
        typesOfEducationPresenceExpected,
        'Error for the content of types of education');

      expect(this.summaryEductionTrainingPage.isPriorLearningPresent()).toBe(
        !!skills['educationTraining']['priorLearning'],
        'Error for the presence of priorLearning');
      expect(this.summaryEductionTrainingPage.isCertificateOrDiplomaPresent()).toBe(
        !!skills['educationTraining']['certificate'],
        'Error for the presence of certificate');
    }
  }

  private isOtherFieldDurationPresent(skills: any) {
    expect(this.summaryEductionTrainingPage.isOtherFieldWeekPresent()).toBe(
      !!skills['educationTraining']['studyFieldWeek'],
      'Error for the presence of studyFieldWeek');
    expect(this.summaryEductionTrainingPage.isOtherFieldMonthPresent()).toBe(
      !!skills['educationTraining']['studyFieldMonth'],
      'Error for the presence of studyFieldMonth');
    expect(this.summaryEductionTrainingPage.isOtherFieldYearPresent()).toBe(
      !!skills['educationTraining']['studyFieldYear'],
      'Error for the presence of studyFieldYear');
  }

  private isPartTimeDurationPresent(skills: any) {
    expect(this.summaryEductionTrainingPage.isPartTimeWeekPresent()).toBe(
      !!skills['educationTraining']['partTimeWeek'],
      'Error for the presence of partTimeWeek');
    expect(this.summaryEductionTrainingPage.isPartTimeMonthPresent()).toBe(
      !!skills['educationTraining']['partTimeMonth'],
      'Error for the presence of partTimeMonth');
    expect(this.summaryEductionTrainingPage.isPartTimeYearPresent()).toBe(
      !!skills['educationTraining']['partTimeYear'],
      'Error for the presence of partTimeYear');
  }

  private isFullTimeDurationPresent(skills: any) {
    expect(this.summaryEductionTrainingPage.isFullTimeWeekPresent()).toBe(
      !!skills['educationTraining']['fullTimeWeek'],
      'Error for the presence of fullTimeWeek');
    expect(this.summaryEductionTrainingPage.isFullTimeMonthPresent()).toBe(
      !!skills['educationTraining']['fullTimeMonth'],
      'Error for the presence of fullTimeMonth');
    expect(this.summaryEductionTrainingPage.isFullTimeYearPresent()).toBe(
      !!skills['educationTraining']['fullTimeYear'],
      'Error for the presence of fullTimeYear');
  }

}
