import {AbstractValidator} from '../../abstract-validator';
import {SummaryLanguageSkillsPage} from '../../../../pages/summary/skills/summary-language.po';

export class LanguageSkillsValidator extends AbstractValidator {

  private summaryLanguageSkillsPage: SummaryLanguageSkillsPage = new SummaryLanguageSkillsPage();

  checkLanguageSkills(languagesSkills: any) {
    languagesSkills = languagesSkills['languageSkills'];

    let motherTongues = this.getValue(languagesSkills, 'motherTongue') === '' ?
      [] : [this.getLanguageTranslation(languagesSkills['motherTongue'])];
    motherTongues = motherTongues.concat(languagesSkills['otherMotherTongue'].map(
      element => this.getLanguageTranslation(element['name'])
    ));
    this.testMultipleElements(
      this.summaryLanguageSkillsPage.getWhatIsYourMotherTongue(),
      motherTongues,
      'Error on the content of the mother tongues : ');

    expect(this.summaryLanguageSkillsPage.getCanYouCommunicateInALanguageOfTheHostCountry().getText())
      .toBe(this.getBooleanTranslation(languagesSkills['communicateInHostCountry']),
        'Error on the content of the communicate in a language of the host country');

    if (this.getBooleanTranslation(languagesSkills['communicateInHostCountry']) === 'true') {
      this.checkLanguage(languagesSkills['hostCountry']);

      this.checkOtherLanguage(languagesSkills['otherLanguages']);
    }
  }

  private checkLanguage(languagesSkills: any) {
    expect(this.summaryLanguageSkillsPage.getLanguage().getText())
      .toBe(this.getLanguageTranslation(languagesSkills['code']),
        'Error on the content of language');

    expect(this.summaryLanguageSkillsPage.getSpeaking().getText())
      .toBe(this.getCapacitiesTranslation(languagesSkills['speaking']),
        'Error on the content of speaking');

    expect(this.summaryLanguageSkillsPage.getListening().getText())
      .toBe(this.getCapacitiesTranslation(languagesSkills['listening']),
        'Error on the content of listening');

    expect(this.summaryLanguageSkillsPage.getReading().getText())
      .toBe(this.getCapacitiesTranslation(languagesSkills['reading']),
        'Error on the content of reading');

    expect(this.summaryLanguageSkillsPage.getWriting().getText())
      .toBe(this.getCapacitiesTranslation(languagesSkills['writing']),
        'Error on the content of writing');
  }

  private checkOtherLanguage(languagesSkills: any) {
    for (let languageSkill of languagesSkills) {
      expect(this.summaryLanguageSkillsPage.getOtherLanguage().getText())
        .toBe(this.getLanguageTranslation(languageSkill['code']),
          'Error on the content of other language');

      expect(this.summaryLanguageSkillsPage.getOtherSpeaking().getText())
        .toBe(this.getCapacitiesTranslation(languageSkill['speaking']),
          'Error on the content of other speaking');

      expect(this.summaryLanguageSkillsPage.getOtherListening().getText())
        .toBe(this.getCapacitiesTranslation(languageSkill['listening']),
          'Error on the content of other listening');

      expect(this.summaryLanguageSkillsPage.getOtherReading().getText())
        .toBe(this.getCapacitiesTranslation(languageSkill['reading']),
          'Error on the content of other reading');

      expect(this.summaryLanguageSkillsPage.getOtherWriting().getText())
        .toBe(this.getCapacitiesTranslation(languageSkill['writing']),
          'Error on the content of other writing');
    }
  }

  checkLanguageSkillsPresent(languagesSkills: any) {
    languagesSkills = languagesSkills['languageSkills'];

    let motherTongues = this.getValue(languagesSkills, 'motherTongue') === '' ?
      [] : [this.getLanguageTranslation(languagesSkills['motherTongue'])];
    motherTongues = motherTongues.concat(languagesSkills['otherMotherTongue'].map(
      element => this.getLanguageTranslation(element['name'])
    ));
    expect(this.summaryLanguageSkillsPage.isWhatIsYourMotherTonguePresent())
      .toBe(motherTongues.length !== 0,
        'Error on the presence of the mother tongues');

    expect(this.summaryLanguageSkillsPage.isCanYouCommunicateInALanguageOfTheHostCountryPresent())
      .toBe(this.getBooleanTranslation(languagesSkills['communicateInHostCountry']) !== ''
        && this.getBooleanTranslation(languagesSkills['communicateInHostCountry']) !== 'No',
        'Error on the presence of the communicate in a language of the host country');

    this.checkLanguagePresent(languagesSkills['hostCountry']);

    this.checkOtherLanguagePresent(languagesSkills['otherLanguages']);
  }

  private checkLanguagePresent(languagesSkills: any) {
    expect(this.summaryLanguageSkillsPage.isLanguagePresent())
      .toBe(this.getLanguageTranslation(languagesSkills['code']) !== '',
        'Error on the presence of the language');

    expect(this.summaryLanguageSkillsPage.isSpeakingPresent())
      .toBe(this.getCapacitiesTranslation(languagesSkills['speaking']) !== 'None',
        'Error on the presence of the speaking');

    expect(this.summaryLanguageSkillsPage.isListeningPresent())
      .toBe(this.getCapacitiesTranslation(languagesSkills['listening']) !== 'None',
        'Error on the presence of the listening');

    expect(this.summaryLanguageSkillsPage.isReadingPresent())
      .toBe(this.getCapacitiesTranslation(languagesSkills['reading']) !== 'None',
        'Error on the presence of the reading');

    expect(this.summaryLanguageSkillsPage.isWritingPresent())
      .toBe(this.getCapacitiesTranslation(languagesSkills['writing']) !== 'None',
        'Error on the presence of the writing');
  }

  private checkOtherLanguagePresent(languagesSkills: any) {
    for (let languageSkill of languagesSkills) {
      expect(this.summaryLanguageSkillsPage.isOtherLanguagePresent())
        .toBe(this.getLanguageTranslation(languageSkill['code']) !== '',
          'Error on the presence of the other language');

      expect(this.summaryLanguageSkillsPage.isOtherSpeakingPresent())
        .toBe(this.getCapacitiesTranslation(languageSkill['speaking']) !== 'None',
          'Error on the presence of the other speaking');

      expect(this.summaryLanguageSkillsPage.isOtherListeningPresent())
        .toBe(this.getCapacitiesTranslation(languageSkill['listening']) !== 'None',
          'Error on the presence of the other listening');

      expect(this.summaryLanguageSkillsPage.isOtherReadingPresent())
        .toBe(this.getCapacitiesTranslation(languageSkill['reading']) !== 'None',
          'Error on the presence of the other reading');

      expect(this.summaryLanguageSkillsPage.isOtherWritingPresent())
        .toBe(this.getCapacitiesTranslation(languageSkill['writing']) !== 'None',
          'Error on the presence of the other writing');
    }
  }

}
