import {AbstractValidator} from '../../abstract-validator';
import {SummaryEducationTrainingPage} from '../../../../pages/summary/skills/summary-education-training.po';
import {SummaryLiteracyPage} from '../../../../pages/summary/skills/summary-literacy.po';

export class SummaryLiteracyValidator extends AbstractValidator {
  private summaryLiteracyPage: SummaryLiteracyPage = new SummaryLiteracyPage();

  checkLiteracy(skills: any, allHide: boolean) {
    if (!allHide) {
      expect(this.summaryLiteracyPage.getReadRegularly().getText())
        .toBe(this.getBooleanTranslation(this.getValue(skills, 'readRegularly')),
          'Error on the content of read regularly');

      if (skills['readRegularly'] === true) {
        this.checkSkills(skills['readPaperMediaType'], this.summaryLiteracyPage.getReadPaperMediaTypes());

        if (skills['otherReadPaper'] !== null) {
          expect(this.summaryLiteracyPage.getReadPaperMediaTypesOther().getText())
            .toBe(this.getValue(skills, 'otherReadPaper'),
              'Error on the content of the other read paper media');
        }

        this.checkSkills(skills['readLinerMediaType'], this.summaryLiteracyPage.getReadOnlineMediaTypes());

        if (skills['otherReadLinerSocial'] !== null) {
          expect(this.summaryLiteracyPage.getReadOnlineMediaTypesOther().getText())
            .toBe(this.getValue(skills, 'otherReadLinerSocial'),
              'Error on the content of the other read online media');
        }
      }

      expect(this.summaryLiteracyPage.getWriteRegularly().getText())
        .toBe(this.getBooleanTranslation(this.getValue(skills, 'writeRegularly')),
          'Error on the content of write regularly');

      if (skills['writeRegularly'] === true) {
        this.checkSkills(skills['writeMediaType'], this.summaryLiteracyPage.getWriteMediaTypes());

        if (skills['otherWriteDigital'] !== null) {
          expect(this.summaryLiteracyPage.getWriteMediaTypesOther().getText())
            .toBe(this.getValue(skills, 'otherWriteDigital'),
              'Error on the content of the other write media');
        }
      }
    }
  }

  private checkSkills(skills: any, mediasFromView: any) {
    let mediaTypes = [];
    for (let media in skills) {
      if (skills[media] !== null) {
        mediaTypes = mediaTypes.concat(this.getMediaTypeTranslation(media));
      }
    }
    this.testMultipleElements(
      mediasFromView,
      mediaTypes,
      'Error on the content of ');
  }

  checkLiteracyPresent(skills: any, highEducation: boolean) {
    expect(this.summaryLiteracyPage.isSectionPresent())
      .toBe(!highEducation,
        'Error on the visibility of the section');

    if (!highEducation) {
      expect(this.summaryLiteracyPage.isReadRegularlyPresent())
        .toBe(this.getValue(skills, 'readRegularly') !== '',
          'Error on the visibility of read regularly');

      if (skills['readRegularly'] === true) {
        this.checkSkillsPresent(skills['readPaperMediaType'], this.summaryLiteracyPage.isReadPaperMediaTypesPresent());

        if (skills['otherReadPaper'] !== null) {
          expect(this.summaryLiteracyPage.isReadPaperMediaTypesOtherPresent())
            .toBe(skills['otherReadPaper'] !== null,
              'Error on the presence of the other read paper media');
        }

        this.checkSkillsPresent(skills['readLinerMediaType'], this.summaryLiteracyPage.isReadOnlineMediaTypesPresent());

        if (skills['otherReadLinerSocial'] !== null) {
          expect(this.summaryLiteracyPage.isReadOnlineMediaTypesOtherPresent())
            .toBe(skills['otherReadLinerSocial'] !== null,
              'Error on the presence of the other read online media');
        }
      }

      expect(this.summaryLiteracyPage.isWriteRegularlyPresent())
        .toBe(this.getValue(skills, 'writeRegularly') !== '',
          'Error on the visibility of write regularly');

      if (skills['writeRegularly'] === true) {
        this.checkSkillsPresent(skills['writeMediaType'], this.summaryLiteracyPage.isWriteMediaTypesPresent());

        if (skills['otherWriteDigital'] !== null) {
          expect(this.summaryLiteracyPage.isWriteMediaTypesOtherPresent())
            .toBe(skills['otherWriteDigital'] !== null,
              'Error on the presence of the other write media');
        }
      }
    }
  }

  private checkSkillsPresent(skills: any, mediasFromView: any) {
    let mediaTypes = [];
    for (let media in skills) {
      if (skills[media] !== null) {
        mediaTypes = mediaTypes.concat(this.getMediaTypeTranslation(media));
      }
    }
    expect(mediasFromView)
      .toBe(mediaTypes.length !== 0,
        'Error on the presence of ' + mediaTypes);
  }

}
