import {SummaryNumeracySkillsPage} from '../../../../pages/summary/skills/summary-numeracy-skills.po';
import {AbstractValidator} from '../../abstract-validator';

export class SummaryNumeracySkillValidator extends AbstractValidator {

  private summaryNumeracySkillsPage: SummaryNumeracySkillsPage = new SummaryNumeracySkillsPage();

  checkNumeracySkills(skills: any) {
    this.checkMeasuringSkills(skills);

    this.checkCalculationWholeNumbers(skills);

    this.checkCalculationFractions(skills);

    this.checkCalculationPercentage(skills);

    this.checkGeometry(skills);

    this.checkCharts(skills);

    this.checkComplexGeometric(skills);

    this.checkFamiliarWithMetricSystem(skills);
  }

  private checkMeasuringSkills(skills: any) {
    let measuring = skills['numeracySkills']['measuring'];
    expect(this.summaryNumeracySkillsPage.getMeasuring().getText()).toBe(
      this.getRatingTranslation(measuring['rate']),
      'Error for the content of measuring');

    this.testMultipleElements(this.summaryNumeracySkillsPage.getMeasuringUsage(),
      this.getUsage(measuring['usage']),
      'Error for the content of measuring with calculator');
  }

  private checkCalculationWholeNumbers(skills: any) {
    let calculationWholeNumbers = skills['numeracySkills']['calculationWholeNumbers'];
    expect(this.summaryNumeracySkillsPage.getWholeNumbers().getText()).toBe(
      this.getRatingTranslation(calculationWholeNumbers['rate']),
      'Error for the content of calculating with whole numbers');

    this.testMultipleElements(this.summaryNumeracySkillsPage.getWholeNumbersCalculator(),
      this.getCalculator(calculationWholeNumbers['calculator']),
      'Error for the content of calculating whole numbers with calculator');

    this.testMultipleElements(this.summaryNumeracySkillsPage.getWholeNumbersUsage(),
      this.getUsage(calculationWholeNumbers['usage']),
      'Error for the content of calculating whole numbers usage');
  }

  private checkCalculationFractions(skills: any) {
    let calculationFractions = skills['numeracySkills']['calculationFractions'];
    expect(this.summaryNumeracySkillsPage.getFractions().getText()).toBe(
      this.getRatingTranslation(calculationFractions['rate']),
      'Error for the content of calculating with fractions');

    this.testMultipleElements(this.summaryNumeracySkillsPage.getFractionsCalculator(),
      this.getCalculator(calculationFractions['calculator']),
      'Error for the content of calculating fractions with calculator');

    this.testMultipleElements(this.summaryNumeracySkillsPage.getFractionsUsage(),
      this.getUsage(calculationFractions['usage']),
      'Error for the content of calculating fractions usage');
  }

  private checkCalculationPercentage(skills: any) {
    let wholeNumbers = skills['numeracySkills']['calculationPercentage'];
    expect(this.summaryNumeracySkillsPage.getPercentage().getText()).toBe(
      this.getRatingTranslation(wholeNumbers['rate']),
      'Error for the content of calculating with percentage');

    this.testMultipleElements(this.summaryNumeracySkillsPage.getPercentageCalculator(),
      this.getCalculator(wholeNumbers['calculator']),
      'Error for the content of calculating percentage with calculator');

    this.testMultipleElements(this.summaryNumeracySkillsPage.getPercentageUsage(),
      this.getUsage(wholeNumbers['usage']),
      'Error for the content of calculating percentage usage');
  }

  private checkGeometry(skills: any) {
    let geometry = skills['numeracySkills']['geometry'];
    expect(this.summaryNumeracySkillsPage.getGeometry().getText()).toBe(
      this.getRatingTranslation(geometry['rate']),
      'Error for the content of doing basic geometry');

    this.testMultipleElements(this.summaryNumeracySkillsPage.getGeometryUsage(),
      this.getUsage(geometry['usage']),
      'Error for the content of doing basic geometry usage');
  }

  private checkCharts(skills: any) {
    let charts = skills['numeracySkills']['charts'];
    expect(this.summaryNumeracySkillsPage.getCharts().getText()).toBe(
      this.getRatingTranslation(charts),
      'Error for the content of using charts');
  }

  private checkComplexGeometric(skills: any) {
    let complex = skills['numeracySkills']['complex'];
    expect(this.summaryNumeracySkillsPage.getGeometryComplex().getText()).toBe(
      this.getRatingTranslation(complex['rate']),
      'Error for the content of doing complex geometry');

    this.testMultipleElements(this.summaryNumeracySkillsPage.getCalculationComplexCalculator(),
      this.getCalculator(complex['calculator']),
      'Error for the content of complex geometry with calculator');

    this.testMultipleElements(this.summaryNumeracySkillsPage.getCalculationComplexUsage(),
      this.getUsage(complex['usage']),
      'Error for the content of complex geometry usage');
  }

  private checkFamiliarWithMetricSystem(skills: any) {
    let metric = skills['numeracySkills']['metric'];
    expect(this.summaryNumeracySkillsPage.getMetric().getText()).toBe(
      this.getRatingTranslation(metric),
      'Error for the content of using metric');
  }

  checkNumeracySkillsPresent(skills: any) {
    this.isMeasuringSkillsPresent(skills);

    this.isCalculationWholeNumbersPresent(skills);

    this.isCalculationFractionsPresent(skills);

    this.isCalculationPercentagePresent(skills);

    this.isGeometryPresent(skills);

    this.isChartsPresent(skills);

    this.isComplexGeometricPresent(skills);

    this.isFamiliarWithMetricSystemPresent(skills);
  }


  private isMeasuringSkillsPresent(skills: any) {
    let measuring = skills['numeracySkills']['measuring'];
    expect(this.summaryNumeracySkillsPage.isMeasuringPresent()).toBe(
      !!measuring['rate'],
      'Error for the presence of measuring');

    expect(this.summaryNumeracySkillsPage.isMeasuringUsagePresent()).toBe(
      !!measuring['usage'],
      'Error for the presence of measuring with calculator');
  }

  private isCalculationWholeNumbersPresent(skills: any) {
    let calculationWholeNumbers = skills['numeracySkills']['calculationWholeNumbers'];
    expect(this.summaryNumeracySkillsPage.isWholeNumbersPresent()).toBe(
      !!calculationWholeNumbers['rate'],
      'Error for the presence of calculating with whole numbers');

    expect(this.summaryNumeracySkillsPage.isWholeNumbersCalculatorPresent()).toBe(
      this.isNotEmptyCalculator(calculationWholeNumbers['calculator']),
      'Error for the presence of calculating whole numbers with calculator');

    expect(this.summaryNumeracySkillsPage.isWholeNumbersUsagePresent()).toBe(
      this.isNotEmptyUsage(calculationWholeNumbers['usage']),
      'Error for the presence of calculating whole numbers usage');
  }

  private isCalculationFractionsPresent(skills: any) {
    let calculationFractions = skills['numeracySkills']['calculationFractions'];
    expect(this.summaryNumeracySkillsPage.isFractionsPresent()).toBe(
      !!calculationFractions['rate'],
      'Error for the presence of calculating with fractions');

    expect(this.summaryNumeracySkillsPage.isFractionsCalculatorPresent()).toBe(
      this.isNotEmptyCalculator(calculationFractions['calculator']),
      'Error for the presence of calculating fractions with calculator');

    expect(this.summaryNumeracySkillsPage.isFractionsUsagePresent()).toBe(
      this.isNotEmptyUsage(calculationFractions['usage']),
      'Error for the presence of calculating fractions usage');
  }

  private isCalculationPercentagePresent(skills: any) {
    let percentage = skills['numeracySkills']['calculationPercentage'];
    expect(this.summaryNumeracySkillsPage.isPercentagePresent()).toBe(
      !!percentage['rate'],
      'Error for the presence of calculating with percentage');

    expect(this.summaryNumeracySkillsPage.isPercentageCalculatorPresent()).toBe(
      this.isNotEmptyCalculator(percentage['calculator']),
      'Error for the presence of calculating percentage with calculator');

    expect(this.summaryNumeracySkillsPage.isPercentageUsagePresent()).toBe(
      this.isNotEmptyUsage(percentage['usage']),
      'Error for the presence of calculating percentage usage');
  }

  private isGeometryPresent(skills: any) {
    let geometry = skills['numeracySkills']['geometry'];
    expect(this.summaryNumeracySkillsPage.isGeometryPresent()).toBe(
      !!geometry['rate'],
      'Error for the presence of doing basic geometry');

    expect(this.summaryNumeracySkillsPage.isGeometryUsagePresent()).toBe(
      this.isNotEmptyUsage(geometry['usage']),
      'Error for the presence of doing basic geometry usage');
  }

  private isChartsPresent(skills: any) {
    let charts = skills['numeracySkills']['charts'];
    expect(this.summaryNumeracySkillsPage.isChartsPresent()).toBe(
      !!charts,
      'Error for the presence of using charts');
  }

  private isComplexGeometricPresent(skills: any) {
    let complex = skills['numeracySkills']['complex'];
    expect(this.summaryNumeracySkillsPage.isGeometryComplexPresent()).toBe(
      !!complex['rate'],
      'Error for the presence of doing complex geometry');

    expect(this.summaryNumeracySkillsPage.isCalculationComplexCalculatorPresent()).toBe(
      this.isNotEmptyCalculator(complex['calculator']),
      'Error for the presence of complex geometry with calculator');

    expect(this.summaryNumeracySkillsPage.isCalculationComplexUsagePresent()).toBe(
      this.isNotEmptyUsage(complex['usage']),
      'Error for the presence of complex geometry usage');
  }

  private isFamiliarWithMetricSystemPresent(skills: any) {
    let metric = skills['numeracySkills']['metric'];
    expect(this.summaryNumeracySkillsPage.isMetricPresent()).toBe(
      !!metric,
      'Error for the presence of using metric');
  }

  private getCalculator(calculatorJson: any): any[] {
    let calculatorValues = [];

    if (!!calculatorJson) {
      if (calculatorJson['with'] === true) {
        calculatorValues.push('With calculator');
      }
      if (calculatorJson['without'] === true) {
        calculatorValues.push('Without calculator');
      }
    }
    return calculatorValues;
  }

  private getUsage(usageJson): any[] {
    let usageValues = [];

    if (!!usageJson) {
      if (usageJson['daily'] === true) {
        usageValues.push('In daily life');
      }
      if (usageJson['university'] === true) {
        usageValues.push('In school / University');
      }
      if (usageJson['professionally'] === true) {
        usageValues.push('Professionally');
      }
    }
    return usageValues;
  }

  private isNotEmptyCalculator(value: any) {
    if (!value) {
      return false;
    }
    return value['with'] != null || value['without'] != null;
  }

  private isNotEmptyUsage(value: any) {
    if (!value) {
      return false;
    }
    return value['daily'] != null || value['university'] != null || value['professionally'] != null;
  }
}
