import {AbstractValidator} from '../../abstract-validator';
import {SummaryOutsideSkillsPage} from '../../../../pages/summary/skills/summary-outside-skills.po';

export class SummaryOutsideSkillsValidator extends AbstractValidator {
  private summaryOutsideSkillsPage: SummaryOutsideSkillsPage = new SummaryOutsideSkillsPage();

  checkOutsideSkills(skills: any) {
    this.checkSkillCaringForChildren(skills);
    this.checkSkillCaringForElderlyPeople(skills);
    this.checkSkillMakingClothing(skills);
    this.checkSkillPreparingMeals(skills);
    this.checkSkillCultivatingCrops(skills);
    this.checkSkillTakingCareOfLiveStock(skills);
    this.checkSkillMakingPottery(skills);
    this.checkSkillSellingOrTradingProducts(skills);
    this.checkSkillMakingFurniture(skills);
    this.checkSkillHouseConstruction(skills);
    this.checkSkillCoaching(skills);
  }

  private checkSkillCaringForChildren(skills: any) {
    expect(this.summaryOutsideSkillsPage.getCaringForChildren().getText())
      .toBe(this.getRatingTranslation(skills['caringChildren']['rate']),
        'Error on the content of caring children');
    if (skills['caringChildren']['rate'] > 0) {
      this.checkSkill(
        this.summaryOutsideSkillsPage.getCaringForChildrenHowMany().getText(),
        this.summaryOutsideSkillsPage.getCaringForChildrenHowOften().getText(),
        this.summaryOutsideSkillsPage.getCaringForChildrenHowLongMonths().getText(),
        this.summaryOutsideSkillsPage.getCaringForChildrenHowLongYears().getText(),
        skills['caringChildren'],
        'Error on the content of caring children : ');
    }
  }

  private checkSkillCaringForElderlyPeople(skills: any) {
    expect(this.summaryOutsideSkillsPage.getCaringForElderlyPeople().getText())
      .toBe(this.getRatingTranslation(skills['caringElderlyPeople']['rate']),
        'Error on the content of elderly people');
    if (skills['caringElderlyPeople']['rate'] > 0) {
      this.checkSkill(
        this.summaryOutsideSkillsPage.getCaringForElderlyPeopleHowMany().getText(),
        this.summaryOutsideSkillsPage.getCaringForElderlyPeopleHowOften().getText(),
        this.summaryOutsideSkillsPage.getCaringForElderlyPeopleHowLongMonths().getText(),
        this.summaryOutsideSkillsPage.getCaringForElderlyPeopleHowLongYears().getText(),
        skills['caringElderlyPeople'],
        'Error on the content of caring elderly people : ');
    }
  }

  private checkSkillMakingClothing(skills: any) {
    expect(this.summaryOutsideSkillsPage.getMakingClothing().getText())
      .toBe(this.getRatingTranslation(skills['makingClothing']['rate']),
        'Error on the content of making clothing');
    if (skills['makingClothing']['rate'] > 0) {
      this.checkSkill(
        null,
        this.summaryOutsideSkillsPage.getMakingClothingHowOften().getText(),
        this.summaryOutsideSkillsPage.getMakingClothingHowLongMonths().getText(),
        this.summaryOutsideSkillsPage.getMakingClothingHowLongYears().getText(),
        skills['makingClothing'],
        'Error on the content of making clothing : ');
    }
  }

  private checkSkillPreparingMeals(skills: any) {
    expect(this.summaryOutsideSkillsPage.getPreparingMeals().getText())
      .toBe(this.getRatingTranslation(skills['preparingMeals']['rate']),
        'Error on the content of preparing meals');
    if (skills['preparingMeals']['rate'] > 0) {
      this.checkSkill(
        this.summaryOutsideSkillsPage.getPreparingMealsHowMany().getText(),
        this.summaryOutsideSkillsPage.getPreparingMealsHowOften().getText(),
        this.summaryOutsideSkillsPage.getPreparingMealsHowLongMonths().getText(),
        this.summaryOutsideSkillsPage.getPreparingMealsHowLongYears().getText(),
        skills['preparingMeals'],
        'Error on the content of preparing meals : ');
    }
  }

  private checkSkillCultivatingCrops(skills: any) {
    expect(this.summaryOutsideSkillsPage.getCultivatingCrops().getText())
      .toBe(this.getRatingTranslation(skills['cultivatingCrops']['rate']),
        'Error on the content of cultivating crops');
    if (skills['cultivatingCrops']['rate'] > 0) {
      this.checkSkill(
        null,
        this.summaryOutsideSkillsPage.getCultivatingCropsHowOften().getText(),
        this.summaryOutsideSkillsPage.getCultivatingCropsHowLongMonths().getText(),
        this.summaryOutsideSkillsPage.getCultivatingCropsHowLongYears().getText(),
        skills['cultivatingCrops'],
        'Error on the content of cultivating crops : ');
    }
  }

  private checkSkillTakingCareOfLiveStock(skills: any) {
    expect(this.summaryOutsideSkillsPage.getTakingCareOfLivestock().getText())
      .toBe(this.getRatingTranslation(skills['livestock']['rate']),
        'Error on the content of livestock');
    if (skills['livestock']['rate'] > 0) {
      this.checkSkill(
        this.summaryOutsideSkillsPage.getTakingCareOfLivestockHowMany().getText(),
        this.summaryOutsideSkillsPage.getTakingCareOfLivestockHowOften().getText(),
        this.summaryOutsideSkillsPage.getTakingCareOfLivestockHowLongMonths().getText(),
        this.summaryOutsideSkillsPage.getTakingCareOfLivestockHowLongYears().getText(),
        skills['livestock'],
        'Error on the content of livestock : ');
    }
  }

  private checkSkillMakingPottery(skills: any) {
    expect(this.summaryOutsideSkillsPage.getMakingPottery().getText())
      .toBe(this.getRatingTranslation(skills['makingPottery']['rate']),
        'Error on the content of making pottery');
    if (skills['makingPottery']['rate'] > 0) {
      this.checkSkill(
        null,
        this.summaryOutsideSkillsPage.getMakingPotteryHowOften().getText(),
        this.summaryOutsideSkillsPage.getMakingPotteryHowLongMonths().getText(),
        this.summaryOutsideSkillsPage.getMakingPotteryHowLongYears().getText(),
        skills['makingPottery'],
        'Error on the content of making pottery : ');
    }
  }

  private checkSkillSellingOrTradingProducts(skills: any) {
    expect(this.summaryOutsideSkillsPage.getSellingOrTradingProducts().getText())
      .toBe(this.getRatingTranslation(skills['sellingTradingProducts']['rate']),
        'Error on the content of selling trading products');
    if (skills['sellingTradingProducts']['rate'] > 0) {
      this.checkSkill(
        null,
        this.summaryOutsideSkillsPage.getSellingOrTradingProductsHowOften().getText(),
        this.summaryOutsideSkillsPage.getSellingOrTradingProductsHowLongMonths().getText(),
        this.summaryOutsideSkillsPage.getSellingOrTradingProductsHowLongYears().getText(),
        skills['sellingTradingProducts'],
        'Error on the content of selling trading products: ');
    }
  }

  private checkSkillMakingFurniture(skills: any) {
    expect(this.summaryOutsideSkillsPage.getMakingFurniture().getText())
      .toBe(this.getRatingTranslation(skills['makingFurniture']['rate']),
        'Error on the content of making furniture');
    if (skills['makingFurniture']['rate'] > 0) {
      this.checkSkill(
        null,
        this.summaryOutsideSkillsPage.getMakingFurnitureHowOften().getText(),
        this.summaryOutsideSkillsPage.getMakingFurnitureHowLongMonths().getText(),
        this.summaryOutsideSkillsPage.getMakingFurnitureHowLongYears().getText(),
        skills['makingFurniture'],
        'Error on the content of making furniture : ');
    }
  }

  private checkSkillHouseConstruction(skills: any) {
    expect(this.summaryOutsideSkillsPage.getHouseConstruction().getText())
      .toBe(this.getRatingTranslation(skills['houseConstruction']['rate']),
        'Error on the content of house construction');
    if (skills['houseConstruction']['rate'] > 0) {
      this.checkSkill(
        null,
        this.summaryOutsideSkillsPage.getHouseConstructionHowOften().getText(),
        this.summaryOutsideSkillsPage.getHouseConstructionHowLongMonths().getText(),
        this.summaryOutsideSkillsPage.getHouseConstructionHowLongYears().getText(),
        skills['houseConstruction'],
        'Error on the content of house construction : ');
    }
  }

  private checkSkillCoaching(skills: any) {
    expect(this.summaryOutsideSkillsPage.getCoaching().getText())
      .toBe(this.getRatingTranslation(skills['coachingTeaching']['rate']),
        'Error on the content of coaching teaching');
    if (skills['coachingTeaching']['rate'] > 0) {
      this.checkSkill(
        null,
        this.summaryOutsideSkillsPage.getCoachingHowOften().getText(),
        this.summaryOutsideSkillsPage.getCoachingHowLongMonths().getText(),
        this.summaryOutsideSkillsPage.getCoachingHowLongYears().getText(),
        skills['coachingTeaching'],
        'Error on the content of coaching teaching : ');
    }
  }

  private checkSkill(elementViewTotal: any,
                     elementViewDurationMonth: any,
                     elementViewDurationYear: any,
                     elementViewFrequency: any,
                     skill: any,
                     errorMessage: string) {
    const elementsToTest = [
      'total', 'durationMonth', 'durationYear', 'frequency'
    ];

    if (elementViewTotal) {
      expect(elementViewTotal)
        .toBe(skill[elementsToTest[0]],
          errorMessage + elementsToTest[0]);
    }

    expect(elementViewDurationMonth)
      .toBe(skill[elementsToTest[1]] + ' Months(s)',
        errorMessage + elementsToTest[1]);

    expect(elementViewDurationYear)
      .toBe(skill[elementsToTest[2]] + ' Years',
        errorMessage + elementsToTest[2]);

    expect(elementViewFrequency)
      .toBe(this.getFrequencyTranslation(skill[elementsToTest[3]]),
        errorMessage + elementsToTest[3]);
  }

  checkOutsideSkillsPresent(skills: any) {
    this.checkSkillCaringForChildrenPresent(skills);
    this.checkSkillCaringForElderlyPeoplePresent(skills);
    this.checkSkillMakingClothingPresent(skills);
    this.checkSkillPreparingMealsPresent(skills);
    this.checkSkillCultivatingCropsPresent(skills);
    this.checkSkillTakingCareOfLiveStockPresent(skills);
    this.checkSkillMakingPotteryPresent(skills);
    this.checkSkillSellingOrTradingProductsPresent(skills);
    this.checkSkillMakingFurniturePresent(skills);
    this.checkSkillHouseConstructionPresent(skills);
    this.checkSkillCoachingPresent(skills);
  }

  private checkSkillCaringForChildrenPresent(skills: any) {
    expect(this.summaryOutsideSkillsPage.isCaringForChildrenPresent())
      .toBe(skills['caringChildren']['rate'] > 0,
        'Error on the presence of caring children');
    if (skills['caringChildren']['rate'] > 0) {
      this.checkSkillPresent(
        this.summaryOutsideSkillsPage.isCaringForChildrenHowManyPresent(),
        this.summaryOutsideSkillsPage.isCaringForChildrenHowOftenPresent(),
        this.summaryOutsideSkillsPage.isCaringForChildrenHowLongMonthsPresent(),
        this.summaryOutsideSkillsPage.isCaringForChildrenHowLongYearsPresent(),
        skills['caringChildren'],
        'Error on the presence of caring children : ');
    }
  }

  private checkSkillCaringForElderlyPeoplePresent(skills: any) {
    expect(this.summaryOutsideSkillsPage.isCaringForElderlyPeoplePresent())
      .toBe(skills['caringElderlyPeople']['rate'] > 0,
        'Error on the presence of elderly people');
    if (skills['caringElderlyPeople']['rate'] > 0) {
      this.checkSkillPresent(
        this.summaryOutsideSkillsPage.isCaringForElderlyPeopleHowManyPresent(),
        this.summaryOutsideSkillsPage.isCaringForElderlyPeopleHowOftenPresent(),
        this.summaryOutsideSkillsPage.isCaringForElderlyPeopleHowLongMonthsPresent(),
        this.summaryOutsideSkillsPage.isCaringForElderlyPeopleHowLongYearsPresent(),
        skills['caringElderlyPeople'],
        'Error on the presence of caring elderly people : ');
    }
  }

  private checkSkillMakingClothingPresent(skills: any) {
    expect(this.summaryOutsideSkillsPage.isMakingClothingPresent())
      .toBe(skills['makingClothing']['rate'] > 0,
        'Error on the presence of making clothing');
    if (skills['makingClothing']['rate'] > 0) {
      this.checkSkillPresent(
        null,
        this.summaryOutsideSkillsPage.isMakingClothingHowOftenPresent(),
        this.summaryOutsideSkillsPage.isMakingClothingHowLongMonthsPresent(),
        this.summaryOutsideSkillsPage.isMakingClothingHowLongYearsPresent(),
        skills['makingClothing'],
        'Error on the presence of making clothing : ');
    }
  }

  private checkSkillPreparingMealsPresent(skills: any) {
    expect(this.summaryOutsideSkillsPage.isPreparingMealsPresent())
      .toBe(skills['preparingMeals']['rate'] > 0,
        'Error on the presence of preparing meals');
    if (skills['preparingMeals']['selected'] > 0) {
      this.checkSkillPresent(
        this.summaryOutsideSkillsPage.isPreparingMealsHowManyPresent(),
        this.summaryOutsideSkillsPage.isPreparingMealsHowOftenPresent(),
        this.summaryOutsideSkillsPage.isPreparingMealsHowLongMonthsPresent(),
        this.summaryOutsideSkillsPage.isPreparingMealsHowLongYearsPresent(),
        skills['preparingMeals'],
        'Error on the presence of preparing meals : ');
    }
  }

  private checkSkillCultivatingCropsPresent(skills: any) {
    expect(this.summaryOutsideSkillsPage.isCultivatingCropsPresent())
      .toBe(skills['cultivatingCrops']['rate'] > 0,
        'Error on the presence of cultivating crops');
    if (skills['cultivatingCrops']['rate'] > 0) {
      this.checkSkillPresent(
        null,
        this.summaryOutsideSkillsPage.isCultivatingCropsHowOftenPresent(),
        this.summaryOutsideSkillsPage.isCultivatingCropsHowLongMonthsPresent(),
        this.summaryOutsideSkillsPage.isCultivatingCropsHowLongYearsPresent(),
        skills['cultivatingCrops'],
        'Error on the presence of cultivating crops : ');
    }
  }

  private checkSkillTakingCareOfLiveStockPresent(skills: any) {
    expect(this.summaryOutsideSkillsPage.isTakingCareOfLivestockPresent())
      .toBe(skills['livestock']['rate'] > 0,
        'Error on the presence of livestock');
    if (skills['livestock']['rate'] > 0) {
      this.checkSkillPresent(
        this.summaryOutsideSkillsPage.isTakingCareOfLivestockHowManyPresent(),
        this.summaryOutsideSkillsPage.isTakingCareOfLivestockHowOftenPresent(),
        this.summaryOutsideSkillsPage.isTakingCareOfLivestockHowLongMonthsPresent(),
        this.summaryOutsideSkillsPage.isTakingCareOfLivestockHowLongYearsPresent(),
        skills['livestock'],
        'Error on the presence of livestock : ');
    }
  }

  private checkSkillMakingPotteryPresent(skills: any) {
    expect(this.summaryOutsideSkillsPage.isMakingPotteryPresent())
      .toBe(skills['makingPottery']['rate'] > 0,
        'Error on the presence of making pottery');
    if (skills['makingPottery']['rate'] > 0) {
      this.checkSkillPresent(
        null,
        this.summaryOutsideSkillsPage.isMakingPotteryHowOftenPresent(),
        this.summaryOutsideSkillsPage.isMakingPotteryHowLongMonthsPresent(),
        this.summaryOutsideSkillsPage.isMakingPotteryHowLongYearsPresent(),
        skills['makingPottery'],
        'Error on the presence of making pottery : ');
    }
  }

  private checkSkillSellingOrTradingProductsPresent(skills: any) {
    expect(this.summaryOutsideSkillsPage.isSellingOrTradingProductsPresent())
      .toBe(skills['sellingTradingProducts']['rate'] > 0,
        'Error on the presence of selling trading products');
    if (skills['sellingTradingProducts']['rate'] > 0) {
      this.checkSkillPresent(
        null,
        this.summaryOutsideSkillsPage.isSellingOrTradingProductsHowOftenPresent(),
        this.summaryOutsideSkillsPage.isSellingOrTradingProductsHowLongMonthsPresent(),
        this.summaryOutsideSkillsPage.isSellingOrTradingProductsHowLongYearsPresent(),
        skills['sellingTradingProducts'],
        'Error on the presence of selling trading products: ');
    }
  }

  private checkSkillMakingFurniturePresent(skills: any) {
    expect(this.summaryOutsideSkillsPage.isMakingFurniturePresent())
      .toBe(skills['makingFurniture']['rate'] > 0,
        'Error on the presence of making furniture');
    if (skills['makingFurniture']['rate'] > 0) {
      this.checkSkillPresent(
        null,
        this.summaryOutsideSkillsPage.isMakingFurnitureHowOftenPresent(),
        this.summaryOutsideSkillsPage.isMakingFurnitureHowLongMonthsPresent(),
        this.summaryOutsideSkillsPage.isMakingFurnitureHowLongYearsPresent(),
        skills['makingFurniture'],
        'Error on the presence of making furniture : ');
    }
  }

  private checkSkillHouseConstructionPresent(skills: any) {
    expect(this.summaryOutsideSkillsPage.isHouseConstructionPresent())
      .toBe(skills['houseConstruction']['rate'] > 0,
        'Error on the presence of house construction');
    if (skills['houseConstruction']['rate'] > 0) {
      this.checkSkillPresent(
        null,
        this.summaryOutsideSkillsPage.isHouseConstructionHowOftenPresent(),
        this.summaryOutsideSkillsPage.isHouseConstructionHowLongMonthsPresent(),
        this.summaryOutsideSkillsPage.isHouseConstructionHowLongYearsPresent(),
        skills['houseConstruction'],
        'Error on the presence of house construction : ');
    }
  }

  private checkSkillCoachingPresent(skills: any) {
    expect(this.summaryOutsideSkillsPage.isCoachingPresent())
      .toBe(skills['coachingTeaching']['rate'] > 0,
        'Error on the presence of coaching teaching');
    if (skills['coachingTeaching']['rate'] > 0) {
      this.checkSkillPresent(
        null,
        this.summaryOutsideSkillsPage.isCoachingHowOftenPresent(),
        this.summaryOutsideSkillsPage.isCoachingHowLongMonthsPresent(),
        this.summaryOutsideSkillsPage.isCoachingHowLongYearsPresent(),
        skills['coachingTeaching'],
        'Error on the presence of coaching teaching : ');
    }
  }

  private checkSkillPresent(elementViewTotal: any,
                     elementViewDurationMonth: any,
                     elementViewDurationYear: any,
                     elementViewFrequency: any,
                     skill: any,
                     errorMessage: string) {
    const elementsToTest = [
      'total', 'durationMonth', 'durationYear', 'frequency'
    ];

    if (elementViewTotal) {
      expect(elementViewTotal)
        .toBe(true,
          errorMessage + elementsToTest[0]);
    }

    expect(elementViewDurationMonth)
      .toBe(skill[elementsToTest[1]] !== 0,
        errorMessage + elementsToTest[1]);

    expect(elementViewDurationYear)
      .toBe(skill[elementsToTest[2]] !== 0,
        errorMessage + elementsToTest[2]);

    expect(elementViewFrequency)
      .toBe(this.getFrequencyTranslation(skill[elementsToTest[3]]) !== '',
        errorMessage + elementsToTest[3]);
  }

}
