import {AbstractValidator} from '../../abstract-validator';
import {SummaryProfessionalSkillsPage} from '../../../../pages/summary/skills/summary-professional.po';

export class ProfessionalSkillsValidator extends AbstractValidator {

  private summaryProfessionalSkillsPage = new SummaryProfessionalSkillsPage();

  checkProfessionalSkills(professionalSkills: any) {
    expect(this.summaryProfessionalSkillsPage.getDoYouHaveAnyProfessionalExperience().getText())
      .toBe(this.getBooleanTranslation(professionalSkills['experience']),
        'Error on the content of the professional experience');

    if (this.getBooleanTranslation(professionalSkills['experience'])) {
      const weeks = professionalSkills['durationWeek'];
      const months = professionalSkills['durationMonth'];
      const years = professionalSkills['durationYear'];
      if (weeks !== 0) {
        expect(this.summaryProfessionalSkillsPage.getForHowLongWeeks().getText())
          .toBe(weeks + ' Week(s)',
            'Error on the content of the how long weeks');
      }
      if (months !== 0) {
        expect(this.summaryProfessionalSkillsPage.getForHowLongMonths().getText())
          .toBe(months + ' Month(s)',
            'Error on the content of the how long months');
      }
      if (years !== 0) {
        expect(this.summaryProfessionalSkillsPage.getForHowLongYears().getText())
          .toBe(years + ' Year(s)',
            'Error on the content of the how long years');
      }

      expect(this.summaryProfessionalSkillsPage.getWhenWereYouLastInProfessionalExperience().getText())
        .toBe(this.getValue(professionalSkills, 'last'),
          'Error on the content of the last professional experience');

      expect(this.summaryProfessionalSkillsPage.getAllExperienceSectionTitle().count())
        .toBe(professionalSkills['experiences'].length,
          'Error on the number of sections experience');

      let index = 0;
      for (let experience of professionalSkills['experiences']) {
        this.checkProfessionalExperience(experience, index);
        index++;
      }
    }
  }

  private checkProfessionalExperience(experience: any, index: number) {
    expect(this.summaryProfessionalSkillsPage.getPleaseDescribeTheNatureOfYouProfessionalExperience(index).getText())
      .toBe(this.getProfessionalExperienceTranslation(experience['nature']),
        'Error on the content of the professional experience nature');

    const weeks = experience['durationWeek'];
    const months = experience['durationMonth'];
    const years = experience['durationYear'];
    if (weeks !== 0) {
      expect(this.summaryProfessionalSkillsPage.gethowLongDidThisExperienceLastWeeks(index).getText())
        .toBe(weeks + ' Week(s)',
          'Error on the content of the weeks duration');
    }
    if (months !== 0) {
      expect(this.summaryProfessionalSkillsPage.getHowLongDidThisExperienceLastMonths(index).getText())
        .toBe(months + ' Month(s)',
          'Error on the content of the months duration');
    }
    if (years !== 0) {
      expect(this.summaryProfessionalSkillsPage.getHowLongDidThisExperienceLastYears(index).getText())
        .toBe(years + ' Year(s)',
          'Error on the content of the years duration');
    }

    expect(this.summaryProfessionalSkillsPage.getInWhichCountryWasThisExperience(index).getText())
      .toBe(this.getCountryTranslation(experience['country']),
        'Error on the content of the county');

    let languages = this.getValue(experience, 'language') === '' ?
      [] : [this.getLanguageTranslation(experience['language'])];
    languages = languages.concat(experience['otherLanguages'].map(
      element => this.getLanguageTranslation(element['name'])
    ));
    this.testMultipleElements(
      this.summaryProfessionalSkillsPage.getAllWhichLanguageDidYouMainlyUse(index),
      languages,
      'Error on the content of the languages mainly used : ');

    expect(this.summaryProfessionalSkillsPage.getOccupationFromTheListThatBestFitsTheTypeOfWorkYouCarriedOut(index).getText())
      .toBe(this.getOccupationTranslation(experience['occupation']),
        'Error on the content of the occupation');

    let skills = this.getValue(experience, 'skill') === '' ?
      [] : [this.getSkillTranslation(experience['skill'])];
    skills = skills.concat(experience['otherSkills'].map(
      element => this.getSkillTranslation(element['name'])
    ));
    this.testMultipleElements(
      this.summaryProfessionalSkillsPage.getAllWhichSkillsDidYouNeedToDoYourJobWell(index),
      skills,
      'Error on the content of the skills : ');

    expect(this.summaryProfessionalSkillsPage.getWhatWasTheSizeOfTheOrganisation(index).getText())
      .toBe(this.getSizeTranslation(experience['organisationSize']),
        'Error on the content of the organisation size');

    expect(this.summaryProfessionalSkillsPage.getWhatWasTheSizeOfTheWorkplace(index).getText())
      .toBe(this.getSizeTranslation(experience['workplaceSize']),
        'Error on the content of the workplace size');

    expect(this.summaryProfessionalSkillsPage.getDoYouHaveAnyProofOfThisProfessionalExperienceWithYou(index).getText())
      .toBe(this.getBooleanTranslation(experience['proof']),
        'Error on the content of the proof');
  }

  checkProfessionalSkillsPresent(professionalSkills: any) {
    expect(this.summaryProfessionalSkillsPage.isDoYouHaveAnyProfessionalExperiencePresent())
      .toBe(this.getBooleanTranslation(professionalSkills['experience']) !== '',
        'Error on the presence of the professional experience');

    expect(this.summaryProfessionalSkillsPage.isForHowLongWeeksPresent())
      .toBe(professionalSkills['durationWeek'] !== 0,
        'Error on the presence of the how long weeks');
    expect(this.summaryProfessionalSkillsPage.isForHowLongMonthsPresent())
      .toBe(professionalSkills['durationMonth'] !== 0,
        'Error on the presence of the how long months');
    expect(this.summaryProfessionalSkillsPage.isForHowLongYearsPresent())
      .toBe(professionalSkills['durationYear'] !== 0,
        'Error on the presence of the how long years');

    expect(this.summaryProfessionalSkillsPage.isWhenWereYouLastInProfessionalExperiencePresent())
      .toBe(this.getValue(professionalSkills, 'last') !== '',
        'Error on the presence of the last professional experience');

    expect(this.summaryProfessionalSkillsPage.getAllExperienceSectionTitle().count())
      .toBe(this.countNbNotEmptyExperience(professionalSkills['experiences']),
        'Error on the number of sections experience');

    let index = 0;
    for (let experience of professionalSkills['experiences']) {
      this.checkProfessionalExperiencePresent(experience, index);
      index++;
    }
  }

  private countNbNotEmptyExperience(experiences: any): number {
    let cmpt = 0;
    for (let experience of experiences) {
      if (this.getValue(experience, 'nature') !== '' || this.getValue(experience, 'durationWeek') !== ''
        || this.getValue(experience, 'durationMonth') !== '' || this.getValue(experience, 'durationYear')
        || this.getValue(experience, 'country') !== '' || this.getValue(experience, 'language') !== ''
        || experience['otherLanguages'].length !== 0 || this.getValue(experience, 'occupation') !== ''
        || this.getValue(experience, 'skill') !== '' || experience['otherSkills'].length !== 0
        || this.getValue(experience, 'organisationSize') !== '' || this.getValue(experience, 'workplaceSize') !== ''
        || this.getValue(experience, 'proof') !== '' || this.getValue(experience, 'attachment') !== '') {
        cmpt++;
      }
    }
    return cmpt;
  }

  private checkProfessionalExperiencePresent(experience: any, index: number) {
    expect(this.summaryProfessionalSkillsPage.isPleaseDescribeTheNatureOfYouProfessionalExperiencePresent(index))
      .toBe(this.getProfessionalExperienceTranslation(experience['nature']) !== '',
        'Error on the presence of the professional experience nature');

    const durationWeek = experience['durationWeek'] !== 0;
    const durationMonth = experience['durationMonth'] !== 0;
    const durationYear = experience['durationYear'] !== 0;
    if (durationWeek || durationMonth || durationYear) {
      expect(this.summaryProfessionalSkillsPage.isHowLongDidThisExperienceLastWeeksPresent(index))
        .toBe(true,
          'Error on the presence of the how long weeks');
      expect(this.summaryProfessionalSkillsPage.isHowLongDidThisExperienceLastMonthsPresent(index))
        .toBe(true,
          'Error on the presence of the how long months');
      expect(this.summaryProfessionalSkillsPage.isHowLongDidThisExperienceLastYearsPresent(index))
        .toBe(true,
          'Error on the presence of the how long years');

      expect(this.summaryProfessionalSkillsPage.isInWhichCountryWasThisExperiencePresent(index))
        .toBe(this.getCountryTranslation(experience['country']) !== '',
          'Error on the presence of the country');
    }

    let languages = this.getValue(experience, 'language') === '' ?
      [] : [this.getLanguageTranslation(experience['language'])];
    languages = languages.concat(experience['otherLanguages'].map(
      element => this.getLanguageTranslation(element['name'])
    ));
    expect(this.summaryProfessionalSkillsPage.isWhichLanguageDidYouMainlyUsePresent(index))
      .toBe(languages.length !== 0,
        'Error on the presence of the languages mainly used : ');

    expect(this.summaryProfessionalSkillsPage.isPleaseIndicateTheOccupationFromTheListThatBestFitsTheTypeOfWorkYouCarriedOutPresent(index))
      .toBe(this.getOccupationTranslation(experience['occupation']) !== '',
        'Error on the presence of the occupation');

    let skills = this.getValue(experience, 'skill') === '' ?
      [] : [this.getSkillTranslation(experience['skill'])];
    skills = skills.concat(experience['otherSkills'].map(
      element => this.getSkillTranslation(element['name'])
    ));
    expect(this.summaryProfessionalSkillsPage.isWhichSkillsDidYouNeedToDoYourJobWellPresent(index))
      .toBe(skills.length !== 0,
        'Error on the presence of the skills : ');

    expect(this.summaryProfessionalSkillsPage.isWhatWasTheSizeOfTheOrganisationPresent(index))
      .toBe(this.getSizeTranslation(experience['organisationSize']) !== '',
        'Error on the presence of the organisation size');

    expect(this.summaryProfessionalSkillsPage.isWhatWasTheSizeOfTheWorkplacePresent(index))
      .toBe(this.getSizeTranslation(experience['workplaceSize']) !== '',
        'Error on the presence of the workplace size');

    expect(this.summaryProfessionalSkillsPage.isDoYouHaveAnyProofOfThisProfessionalExperienceWithYouPresent(index))
      .toBe(!!experience['proof'],
        'Error on the presence of the proof');
  }

}
