// Protractor configuration file, see link for more information
// https://github.com/angular/protractor/blob/master/docs/referenceConf.js

/*global jasmine */
let SpecReporter = require('jasmine-spec-reporter').SpecReporter;

let reportFolderPath = './e2e/report';

module.exports.configuration = {
  allScriptsTimeout: 120000,
  baseUrl: 'http://localhost:4200/',
  framework: 'jasmine',
  jasmineNodeOpts: {
    showColors: true,
    defaultTimeoutInterval: 120000,
    print: function() {}
  },
  useAllAngular2AppRoots: true,
  beforeLaunch: function() {
    require('ts-node').register({
      project: 'e2e'
    });
  },
  onPrepare: function() {
    // for run tests slowly
    // let origFn = browser.driver.controlFlow().execute;
    // browser.driver.controlFlow().execute = function() {
    //   let args = arguments;
    //   // queue 100ms wait
    //   origFn.call(browser.driver.controlFlow(), function() {
    //     return protractor.promise.delayed(100);
    //   });
    //   return origFn.apply(browser.driver.controlFlow(), args);
    // };

    jasmine.getEnv().addReporter(new SpecReporter({
      spec: {
        displayFailuresSummary: true,
        displayFailuredSpec: true,
        displaySuiteNumber: true,
        displaySpecDuration: true
      }
    }));
    require('ts-node').register({
      project: 'e2e'
    });

    // report generation
    let fs = require('fs-extra');
    let jasmineReporters = require('jasmine-reporters');
    jasmine.getEnv().addReporter(new jasmineReporters.JUnitXmlReporter({
      consolidateAll: false,
      savePath: reportFolderPath + '/xml',
      filePrefix: 'xml-result-' + Date.now() + '-'
    }));

    fs.emptyDir(reportFolderPath + '/screenshots/', function (err) {
      console.log(err);
    });
    jasmine.getEnv().addReporter({
      specDone: function(result) {
        browser.getCapabilities().then(function (caps) {
          let browserName = caps.get('browserName');

          browser.takeScreenshot().then(function (png) {
            let stream = fs.createWriteStream(reportFolderPath + '/screenshots/' + browserName + '-' + result.fullName+ '.png');
            stream.write(new Buffer(png, 'base64'));
            stream.end();
          });
        });
      }
    });
  },
  onComplete: function() {
    mergeXmlReportFiles();

    let browserName, browserVersion;
    let capsPromise = browser.getCapabilities();

    capsPromise.then(function (caps) {
      browserName = caps.get('browserName');
      browserVersion = caps.get('version');
      platform = caps.get('platform');

      let HTMLReport = require('protractor-html-reporter-2');

      let fs = require('fs');

      let version = fs.readFileSync('./pom.xml', 'utf8')
        .split('<version>')[1]
        .split('</version>')[0];

      testConfig = {
        reportTitle: 'SKPT end-to-end testing report v' + version,
        outputPath: reportFolderPath,
        outputFilename: 'SKPTTestReport',
        screenshotPath: 'screenshots',
        testBrowser: browserName,
        browserVersion: browserVersion,
        modifiedSuiteName: true,
        screenshotsOnlyOnFailure: true,
        testPlatform: platform
      };
      new HTMLReport().from(reportFolderPath + '/xml/skpt_xml_results.xml', testConfig);
    });
  }
};

function mergeXmlReportFiles() {
  let finalContent = '';
  let totalDisabled = 0;
  let totalErrors = 0;
  let totalFailures = 0;
  let totalTests = 0;
  let totalTime = 0;

  let fs = require('fs');
  if (fs.existsSync(reportFolderPath + '/xml/skpt_xml_results.xml')) {
    fs.unlinkSync(reportFolderPath + '/xml/skpt_xml_results.xml');
  }

  fs.readdirSync(reportFolderPath + '/xml/').forEach(filename => {
    fs.readFileSync(reportFolderPath + '/xml/' + filename, 'utf8')
      .split('\n')
      .forEach(line => {
        if (!line.includes('<?xml') && !line.includes('<testsuites') && !line.includes('</testsuites')) {
          finalContent = finalContent + line.replace('.', ' ') + '\n';

          if (line.includes('<testsuite')) {
            totalTime += parseFloat(line.split('time="')[1].split('"')[0]);
            totalErrors += parseFloat(line.split('errors="')[1].split('"')[0]);
            totalTests += parseFloat(line.split('tests="')[1].split('"')[0]);
            totalDisabled += parseFloat(line.split('disabled="')[1].split('"')[0]);
            totalFailures += parseFloat(line.split('failures="')[1].split('"')[0]);
          }
        }
      });
  });

  finalContent = '<?xml version="1.0" encoding="UTF-8" ?>\n'
    + '<testsuites disabled="' + totalDisabled + '" errors="' + totalErrors + '" failures="' + totalFailures
      + '" tests="' + totalTests + '" time="' + totalTime + '">\n'
    + finalContent
    + '</testsuites>';

  fs.writeFileSync(reportFolderPath + '/xml/skpt_xml_results.xml', finalContent, 'utf8');
}
