import {ControlValueAccessor, NG_VALUE_ACCESSOR} from '@angular/forms';
import {forwardRef, Provider} from '@angular/core';

export abstract class AbstractControlValueAccessor implements ControlValueAccessor {
  _value: any = '';

  get value(): any {
    return this._value;
  };

  set value(v: any) {
    if (v !== this._value) {
      this._value = v;
      this.priorOnChange(v);
    }
  }

  writeValue(value: any) {
    this._value = this.parseFromModel(value);
    this.priorOnChange(this._value);
  }

  priorOnChange(value: any): void {
    this.onChange(this.formatToModel(value));
  }

  /**
   * Formats the value to an external representation. The default is to return the value without any modifications.
   * This method is meant to be overridden if needed.
   * @param value the inner value
   * @returns {any} the formatted value
   */
  formatToModel(value: any): any {
    return value;
  }

  /**
   * Parses the value from an external representation. The default is to return the value without any modifications.
   * This method is meant to be overridden if needed.
   * @param value the external representation of the value
   * @returns {any} the parsed value
   */
  parseFromModel(value: any): any {
    return value;
  }

  onChange = (_) => {
  }
  onTouched = () => {
  }

  registerOnChange(fn: (_: any) => void): void {
    this.onChange = fn;
  }

  registerOnTouched(fn: () => void): void {
    this.onTouched = fn;
  }
}

export function makeProvider(type: any): Provider {
  return <Provider> {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => type),
    multi: true
  };
}
