import {Component, Input, EventEmitter, Output} from '@angular/core';
import {makeProvider} from '../abstract-control-value-accessor.component';
import {LabelKeyValuePair} from '../../profile/field/label-key-value-pair';
import {TranslateService} from '../../../service/translate/translate.service';

/**
 * Component to display a checkbox field in the profile form.
 */
@Component({
  selector: 'app-checkbox-group',
  templateUrl: './checkbox-group.component.html',
  styleUrls: ['./checkbox-group.component.less'],
  providers: [
    makeProvider(CheckboxGroupComponent)
  ]
})
export class CheckboxGroupComponent {

  private selectionInternal: any = {};

  @Output()
  selectionChange = new EventEmitter<string>();

  /**
   * The HTML id attribute of the input created by this component.
   */
  @Input()
  htmlId: string;

  /**
   * The values of the checkbox to display.
   */
  @Input()
  values: LabelKeyValuePair[];

  @Input()
  get selection(): any {
    return this.selectionInternal;
  }

  set selection(value) {
    this.selectionInternal = value;
    this.selectionChange.emit(value);
  }

  constructor(public translateService: TranslateService) { }

}
