import {Component, Input} from '@angular/core';
import {FormGroup} from '@angular/forms';
import {AbstractControlValueAccessor, makeProvider} from '../abstract-control-value-accessor.component';

/**
 * Component to display a form free text field in the profile form.
 */
@Component({
  selector: 'app-form-free-text',
  templateUrl: './form-free-text.component.html',
  styleUrls: ['./form-free-text.component.less'],
  providers: [
    makeProvider(FormFreeTextComponent)
  ]
})
export class FormFreeTextComponent extends AbstractControlValueAccessor {

  /**
   * The HTML id attribute of the input created by this component.
   */
  @Input()
  htmlId: string;

  /**
   * The FormGroup attribute.
   */
  @Input()
  group: FormGroup;

  /**
   * The control name attribute.
   */
  @Input()
  controlName: string;

  /**
   * The HTML placeholder attribute of the textarea created by this component.
   */
  @Input()
  htmlPlaceholder: string;

  get childValue(): any {
    return this.value;
  }

  set childValue(value) {
    this.value = value;
  }

}
