import {Component, ElementRef, Input, Renderer} from '@angular/core';
import {ViewChild} from '@angular/core/src/metadata/di';
import {Output} from '@angular/core/src/metadata/directives';
import {EventEmitter} from '@angular/common/src/facade/async';
import {AbstractControlValueAccessor, makeProvider} from '../abstract-control-value-accessor.component';

/**
 * Component to display a free text field in the profile form.
 */
@Component({
  selector: 'app-free-text',
  templateUrl: './free-text.component.html',
  styleUrls: ['./free-text.component.less'],
  providers: [
    makeProvider(FreeTextComponent)
  ]
})
export class FreeTextComponent extends AbstractControlValueAccessor {

  /**
   * The HTML id attribute of the input created by this component.
   */
  @Input()
  htmlId: string;

  /**
   * The HTML placeholder attribute of the textarea created by this component.
   */
  @Input()
  htmlPlaceholder: string;

  @ViewChild('inputId')
  input: ElementRef;

  /**
   * Attribute to know if the current element should get the focus
   */
  @Input()
  shouldFocus: boolean;

  @Input()
  isLittleInput = false;

  @Output()
  created: EventEmitter<number> = new EventEmitter<any>();

  @Output()
  change = new EventEmitter();

  constructor(private  renderer: Renderer) {
    super();
  }

  get childValue(): any {
    return this.value;
  }

  set childValue(value) {
    this.value = value;
  }

  ngAfterViewInit() {
    if (this.shouldFocus) {
      setTimeout(() => {
        this.input.nativeElement.focus();
        this.created.emit();
      });
    }
  }

  hasChanged() {
    this.change.emit();
  }
}
