import {AfterViewInit, Component, ElementRef, ViewChild} from '@angular/core';
import {CloseGuard, DialogRef, ModalComponent} from 'angular2-modal';
import {BSModalContext} from 'angular2-modal/plugins/bootstrap';
import {TranslateService} from '../../../service/translate/translate.service';
import {ReportService} from '../../../service/data/report.service';
import {TranslatePipe} from '../../../pipe/translate.pipe';
import {constants} from '../../../constants/profile-label-keys';
import {ValidationService} from '../../../service/validation/validation.service';

declare var displayCaptcha: any;

export class ReportModalContext extends BSModalContext {
  public page: string;
}

@Component({
  selector: 'app-report-modal',
  templateUrl: './report-modal.component.html',
  styleUrls: [
    './report-modal.component.less'
  ]
})
export class ReportModalComponent implements CloseGuard, ModalComponent<ReportModalContext>, AfterViewInit {

  constants: Object;

  typeOfRequest = '';
  page = '';
  message = '';
  attachments = [];
  contactEmail = '';

  isCaptchaValid: boolean = undefined;

  @ViewChild('captcha') captcha: ElementRef;

  constructor(public dialog: DialogRef<ReportModalContext>,
              public translate: TranslateService,
              private reportService: ReportService,
              private validationService: ValidationService,
              public translateService: TranslateService) {
    if (dialog.context.page) {
      this.page = dialog.context.page;
    }
    this.constants = constants;
    dialog.setCloseGuard(this);
  }

  ngAfterViewInit() {
    displayCaptcha();
  }

  /**
   * Confirm modal.
   */
  sendReport(): void {
    this.isCaptchaValid = window['reportCaptcha'];

    if (this.isCaptchaValid) {
      this.reportService
        .sendMail(
          this.translateInPrimaryLanguage(constants.report.typeOfRequest, this.typeOfRequest),
          this.translateInPrimaryLanguage(constants.report.page, this.page),
          this.message,
          this.attachments,
          this.contactEmail)
        .subscribe();
      this.cancel();
    }
  }

  private translateInPrimaryLanguage(keyValues, value) {
    let translatePipe = new TranslatePipe(this.translate);
    return translatePipe.transform(
      keyValues.filter(type => type.value === value)[0].labelKey,
      this.translate.getPrimaryLanguage(),
      []);
  }

  /**
   * Cancel modal.
   */
  cancel(): void {
    this.dialog.dismiss();
  }

  beforeDismiss(): boolean {
    return false;
  }

  beforeClose(): boolean {
    return false;
  }

  /**
   * Return true if all fields of the modale are filled.
   *
   * @returns {boolean}
   */
  isReportValid() {
    return this.typeOfRequest && this.typeOfRequest !== ''
      && this.page && this.page !== ''
      && this.message && this.message !== ''
      && this.isContactEmailValid();
  }

  isContactEmailValid() {
    return this.contactEmail && this.contactEmail.match(this.validationService.mailRegex);
  }

  addAttachment(event: any) {
    let files = [].slice.call(event.target.files);
    for (let file of files) {
      let reader = new FileReader();
      reader.onloadend = () => {
        // Get a dataURL in format "data:image/png;base64,somecharactersrepresentingthefileinbase64"
        // and only get the part "somecharactersrepresentingthefileinbase64"
        let base64Content = reader.result.split(',')[1];
        let fileName = file.name;
        this.attachments.push({
          'base64Data': base64Content,
          'fileName': fileName
        });
      };
      reader.readAsDataURL(file);
    }
  }

  removeAttachment(filename: string) {
    this.attachments = this.attachments.filter(file => file.fileName !== filename);
  }

}
