import {Component, ElementRef, EventEmitter, Input, OnInit, Output, ViewChild} from '@angular/core';
import {TranslateService} from '../../../service/translate/translate.service';
import {ConfigurationService} from '../../../service/configuration/configuration.service';

/**
 * Component to display a row in the profile form.
 */
@Component({
  selector: 'app-row',
  templateUrl: './row.component.html',
  styleUrls: ['./row.component.less']
})
export class RowComponent implements OnInit {

  /**
   * The HTML id attribute of the input created by this component.
   */
  @Input()
  htmlId: string;

  /**
   * The HTML for attribute of the label tag created by this component.
   */
  @Input()
  htmlFor: string;

  /**
   * The i18n key of the label that will be displayed for this component.
   */
  @Input()
  labelKey: string;

  @Input()
  tooltipKey: string;

  @Input()
  displayCheckbox: boolean;

  @Input()
  image: string;
  imageName: string;

  @Input()
  primaryLanguageOnly: boolean;

  @Input()
  multipleLabel = true;

  tooltipOpen: boolean;

  private _value: boolean;

  @Input()
  pageLocation: string;

  @Input()
  isMandatory = false;

  @ViewChild('tooltipeButton')
  tooltipeButton: ElementRef;

  get value(): any {
    return this._value;
  }

  @Input()
  set value(value) {
    this._value = value === 'true' || value === true;
    this.valueChange.emit(this._value);
  }

  @Input()
  subQuestion: boolean;

  @Input()
  mainQuestionLabelKey: string;

  @Output()
  valueChange: EventEmitter<boolean> = new EventEmitter();

  constructor(public translateService: TranslateService,
              private configurationService: ConfigurationService) {
  }

  ngOnInit() {
    if (this.image) {
      this.imageName = this.image.split('/').pop().split('.')[0];
    }
  }

  isTrue(value) {
    return value && (value === 'true' || value === true);
  }

  setFocusOnTooltipButton() {
    this.tooltipeButton.nativeElement.focus();
  }

  isRowEnabled() {
    if (this.subQuestion) {
      return this.configurationService.isSubQuestionEnabled(this.mainQuestionLabelKey, this.labelKey);
    }
    return this.configurationService.isQuestionEnabled(this.labelKey, this.htmlFor);
  }
}
