import {Component} from '@angular/core';
import {DialogRef} from 'angular2-modal';
import {TranslateService} from '../../../service/translate/translate.service';

declare var euCookieConsent: any;

@Component({
  selector: 'app-survey-modal',
  templateUrl: './survey-modal.component.html',
  styleUrls: [
    './survey-modal.component.less'
  ]
})
export class SurveyModalComponent {

  isCookiesAccepted: boolean;
  isCookiesQuestionAnswered: boolean;
  surveyUrl: string = window['surveyUrl'];
  readonly skptSurveyCookieName = 'skpt_survey';

  constructor(public dialog: DialogRef<SurveyModalComponent>,
              public translate: TranslateService) {
  }

  ngOnInit() {
    this.isCookiesAccepted = this.cookieAccepted();
    this.isCookiesQuestionAnswered = false;
  }

  updateCookiesQuestionAnswered(cookieAccepted: boolean) {
    this.isCookiesQuestionAnswered = true;
    this.isCookiesAccepted = cookieAccepted;
  }

  /**
   * Confirm modal.
   */
  confirm(): void {
    setTimeout(() => window.open(this.surveyUrl), 150);
    this.cancel();
  }

  /**
   * Cancel modal.
   */
  cancel(): void {
    this.addSurveyCookie();
    this.dialog.dismiss();
  }


  cookieAccepted(): boolean {
    return euCookieConsent.accepted(this.skptSurveyCookieName);
  }

  private addSurveyCookie() {
    if (this.isCookiesAccepted) {
      const value = 'true';
      const surveyEndDate = new Date(window['surveyEndDate'] + '');
      document.cookie = this.skptSurveyCookieName + '=' + value + '; expires=' + surveyEndDate.toUTCString() + '; path=/';
    }
  }

}
