import {Component, OnInit} from '@angular/core';
import {ActivatedRoute, NavigationEnd, Router} from '@angular/router';
import {TranslateService} from '../../../service/translate/translate.service';
import {navigationLabels} from '../../../constants/profile-label-keys';

@Component({
  selector: 'breadcrumb',
  templateUrl: './breadcrumb.component.html',
})
export class BreadcrumbComponent implements OnInit {

  /**
   * Contents for each breadcrumb-item
   */
  items: any[];

  constructor(public translate: TranslateService,
              private activatedRoute: ActivatedRoute,
              private router: Router) {
    this.items = [];
  }

  ngOnInit() {
    this.router.events
      .filter(event => event instanceof NavigationEnd)
      .subscribe(event => {

        // use substring(1) to remove the first '/'
        // ex: in the home page, (<NavigationEnd> event).urlAfterRedirects returns '/'
        const urlPath = (<NavigationEnd> event).urlAfterRedirects.substring(1).replace('profile/', '');

        if (!!urlPath) {
          this.items = urlPath.split('/')
            .map(pathElement => {
              return {
                linkUrl: this.getLinkUrl(pathElement, urlPath.split('/')),
                labelKey: this.getLabelKey(pathElement)
              };
            });
        } else {
          this.items = [];
        }
      });
  }

  isSiteHome(): boolean {
    return !this.items || !this.items.length;
  }

  private getLinkUrl(element, elements) {
    let result = '#/profile';
    for (let i = 0; i < elements.indexOf(element); i++) {
      result += '/' + element;
    }
    return result;
  }

  private getLabelKey(value) {
    const element = navigationLabels.find(elm => elm.value === value);
    return !!element ? element.labelKey : 'null';
  }

}
