import {AfterViewInit, Component, ElementRef, EventEmitter, OnInit, Output, ViewChild} from '@angular/core';
import {LanguageService} from '../../../../service/data/language.service';
import {TranslateService} from '../../../../service/translate/translate.service';

@Component({
  selector: 'app-language-selector-overlay',
  templateUrl: './language-selector-overlay.component.html',
  styleUrls: ['./language-selector-overlay.component.less']
})
export class LanguageSelectorOverlayComponent implements OnInit, AfterViewInit {

  leftLanguageList: any[];
  rightLanguageList: any[];

  @ViewChild('closeLanguageOverlay') closeLanguageOverlay: ElementRef;

  @Output()
  onClose = new EventEmitter<void>();

  constructor(private languageService: LanguageService,
              public translate: TranslateService) {
    this.leftLanguageList = [];
    this.rightLanguageList = [];
  }

  ngOnInit() {
    // for fill the drop down of available languages
    let languages = this.languageService.supportedLanguages;
    if (languages === undefined) {
      this.languageService.languageNotification.subscribe(lang => this.separateLanguageList(lang));
    } else {
      this.separateLanguageList(languages);
    }
  }

  ngAfterViewInit() {
    this.closeLanguageOverlay.nativeElement.focus();
  }

  private separateLanguageList(languages: any[]) {
    if (!this.leftLanguageList.length && !this.rightLanguageList.length) {
      for (let i = 0; i < languages.length; i++) {
        if (i < languages.length / 2) {
          this.leftLanguageList.push(languages[i]);
        } else {
          this.rightLanguageList.push(languages[i]);
        }
      }
    }
  }

  getActualLanguage() {
    return this.translate.getPrimaryLanguage();
  }

  setLanguage(isoCode1: string) {
    this.translate.useAsPrimary(isoCode1);
    this.close();
  }

  close() {
    this.onClose.emit();
  }

}
