import {Component, HostListener, ViewContainerRef} from '@angular/core';
import {Router} from '@angular/router';
import {NgProgressService} from 'ng2-progressbar';
import {Observable} from 'rxjs';
import {Response} from '@angular/http';
import * as $ from 'jquery';
import {Modal, overlayConfigFactory} from 'angular2-modal';
import {BSModalContext} from 'angular2-modal/plugins/bootstrap';
import {TranslateService} from '../../service/translate/translate.service';
import {VersionService} from '../../service/data/version.service';
import {ProfileService} from '../profile/profile.service';
import {HttpErrorService} from '../../service/error/http-error.service';
import {ValidationService} from '../../service/validation/validation.service';
import {SurveyModalComponent} from '../common/survey-modal/survey-modal.component';
import {InfoModalComponent} from '../info-modal/info-modal.component';

@Component({
  selector: 'app-home',
  templateUrl: './home.component.html',
  styleUrls: ['./home.component.less']
})
export class HomeComponent {

  releaseDate: string;

  importingProfile = false;

  surveyStartDate: Date;
  surveyEndDate: Date;

  constructor(public translate: TranslateService,
              private router: Router,
              private versionService: VersionService,
              private profileService: ProfileService,
              private pService: NgProgressService,
              private httpErrorService: HttpErrorService,
              private validationService: ValidationService,
              private modal: Modal) {
  }

  ngOnInit(): void {
    this.setLastUpdatedDate();
    this.displaySurveyModal();
    this.displayIEInfoModal();
  }

  private displayIEInfoModal() {
    let ua = navigator.userAgent;
    let isIE = ua.indexOf('MSIE ') > -1 || ua.indexOf('Trident/') > -1;
    if (isIE) {
      this.modal.open(InfoModalComponent, overlayConfigFactory({}, BSModalContext));
    }
  }

  private displaySurveyModal() {
    if (document.cookie.indexOf('skpt_survey=') === -1
      && window['surveyStartDate'] + '' !== '' && window['surveyEndDate'] + '' !== '' && window['surveyUrl'] + '' !== '') {

      this.surveyStartDate = new Date(window['surveyStartDate'] + '');
      this.surveyEndDate = new Date(window['surveyEndDate'] + '');

      if (this.surveyStartDate < new Date() && new Date() < this.surveyEndDate) {
        this.modal.open(SurveyModalComponent, overlayConfigFactory({}, BSModalContext));
      }
    }
  }

  importProfile(data: any): void {

    this.pService.start();
    this.importingProfile = true;

    let file: File = data.target.files[0];

    this.profileService.load(file)
      .catch((error: Response) => {
        this.httpErrorService.handleError(error);
        return Observable.throw(error);
      })
      .finally(() => {
        this.importingProfile = false;
        this.pService.done();
      })
      .subscribe(() => {
        this.router.navigate(['/profile']);
      });
  }

  newProfile(): void {
    this.profileService.clear();
    this.validationService.resetFormGroup();
    this.router.navigate(['/profile']);
  }

  private setLastUpdatedDate() {
    this.versionService.getVersion().subscribe(version => {
      this.releaseDate = version.date;
    });
  }

  private computeFooter() {
    // target .app-fixed-footer
    let appFixedFooter__target = $('.app-fixed-footer');
    let appFixedFooter__height = appFixedFooter__target.innerHeight();

    // windows height
    let window__height = $(window).height();

    // target .ecl-footer
    let eclFooter__target = $('.ecl-footer');
    let eclFooter__pos = eclFooter__target.position();
    let eclFooter__posTop = eclFooter__pos.top;

    // scrollbar : get position top
    let scrollbar__posTop = $(document).scrollTop();

    // calcul scroll position
    let scrollbar__posTop__listen = scrollbar__posTop + (window__height - appFixedFooter__height);


    //  add class
    if (scrollbar__posTop__listen >= eclFooter__posTop) {

      appFixedFooter__target.addClass('inherit');

      //  on ajout la hauteur de .app-fixed-footer dans le calcul
      //  puis que celui-ci est dans le flux naturel et plus en position fixe
      //  et donc la position du footer change et la hauteur de la page également
    } else if ((scrollbar__posTop__listen + appFixedFooter__height) < eclFooter__posTop) {

      appFixedFooter__target.removeClass('inherit');

    }
  }

  @HostListener('window:scroll', [])
  onWindowScroll() {
    this.computeFooter();
  }

  @HostListener('window:resize', [])
  onWindowResize() {
    this.computeFooter();
  }

}
