import {Component, Input} from '@angular/core';
import {MenuItem} from '../../menu/menu-item';
import {ConfigurationService} from '../../../../service/configuration/configuration.service';

@Component({
  selector: 'menus',
  templateUrl: './configuration-menus.component.html',
  styleUrls: [
    './configuration-menus.component.less'
  ]
})
export class Menus {
  @Input()
  menu: MenuItem;

  @Input()
  index;

  constructor(private configurationService: ConfigurationService) {
  }

  toggleMainMenu(menu: MenuItem) {
    this.toggleMenu(menu);
    if (menu.subMenuItems) {
      menu.subMenuItems.forEach(subMenu => {
        subMenu.isEnabled = menu.isEnabled;
        this.toggleQuestions(subMenu.labelKey, menu.isEnabled);
      });
    }
  }

  private toggleMenu(menu: MenuItem) {
    let enabled = !menu.isEnabled;
    menu.isEnabled = enabled;
    this.toggleQuestions(menu.labelKey, enabled);
  }

  toggleQuestions(menuLabelKey: string, menuEnabled: boolean) {
    if (this.configurationService.configuration[menuLabelKey]) {
      Object.keys(this.configurationService.configuration[menuLabelKey]).forEach(questionLabelKey => {
        let question = this.configurationService.configuration[menuLabelKey][questionLabelKey];
        question.showLabel = menuEnabled;

        if (question.hasOwnProperty('showImage')) {
          question.showImage = menuEnabled;
        }
        this.toggleSubQuestions(question, menuEnabled);
      });
    }
  }

  toggleSubQuestions(mainQuestion, mainQuestionEnabled) {
    if (mainQuestion.subQuestions) {
      mainQuestion.subQuestions.forEach(subQ => {
        subQ.showLabel = mainQuestionEnabled;
      });
    }

  }

  toggleSubMenu(subMenu: MenuItem, menu: MenuItem) {
    this.toggleMenu(subMenu);
    if (!menu.isEnabled || !menu.subMenuItems.filter(subMenuItem => subMenuItem.isEnabled).length) {
      this.toggleMenu(menu);
    }
  }

  getQuestionsForMenu(subMenu) {
    let questions = this.configurationService.configuration[subMenu];
    return questions;
  }

  getSubQuestionsForQuestion(subMenu, question) {
    let subQuestions = this.configurationService.configuration[subMenu][question]['subQuestions'];
    return subQuestions;
  }

  toggleQuestion(subMenuLabel: string, questionLabel: string) {
    let question = this.configurationService.configuration[subMenuLabel][questionLabel];
    let showLabel = question.showLabel;

    if (question.hasOwnProperty('showImage')) {
      question.showImage = !showLabel;
    }
    question.showLabel = !showLabel;
    this.toggleSubQuestions(question, question.showLabel);
  }

  toggleSubQuestion(question) {
    question.showLabel = !question.showLabel;
  }

  toggleImage(subMenuLabel: string, questionLabel: string) {
    let question = this.configurationService.configuration[subMenuLabel][questionLabel];
    question.showImage = !question.showImage;
  }

  hasImage(subMenuLabel: string, questionLabel: string) {
    return this.configurationService.configuration[subMenuLabel][questionLabel].hasOwnProperty('showImage');
  }

  getObjectKeys(subMenu) {
    if (subMenu) {
      return Object.keys(subMenu);
    }
    return [];
  }

  isQuestionEnabled(subMenu: string, questionLabelKey: string) {
    let question = this.configurationService.configuration[subMenu][questionLabelKey];
    return this.configurationService.isQuestionEnabled(questionLabelKey, question.elementId);
  }

  isQuestionMandatory(subMenu: string, questionLabelKey: string) {
    let question = this.configurationService.configuration[subMenu][questionLabelKey];
    if (question.hasOwnProperty('mandatory')) {
      return question.mandatory;
    }
    return false;
  }

  isImageEnabled(subMenu: string, questionLabelKey: string) {
    let question = this.configurationService.configuration[subMenu][questionLabelKey];
    return this.configurationService.isImageEnabled(questionLabelKey, question.elementId);
  }

  isMainQuestion(questionMenu: string, questionLabelKey: string) {
    return this.configurationService.configuration[questionMenu][questionLabelKey]['isMainQuestion'];
  }
}
