import {AfterViewInit, Component, ElementRef, ViewChild} from '@angular/core';
import {MenuItem} from '../menu/menu-item';
import {appMenu} from '../menu/menu.component';
import {ConfigurationService} from '../../../service/configuration/configuration.service';
import {ConfigurationWrapper} from './configuration-wrapper';
import {saveAs} from 'file-saver';
import {DateFormatPipe} from './dateformat.pipe';
import {overlayConfigFactory} from 'angular2-modal';
import {BSModalContext, Modal} from 'angular2-modal/plugins/bootstrap';
import {ImportConfigurationModalComponent} from '../modal/import-configuration-modal/import-configuration-modal.component';
import {ClearConfigurationModalComponent} from '../modal/clear-configuration-modal/clear-configuration-modal.component';

@Component({
  selector: 'app-configuration',
  templateUrl: './configuration.component.html',
  styleUrls: [
    './configuration.component.less'
  ]
})
export class ConfigurationComponent implements AfterViewInit {

  profile: Object;
  mainMenu: MenuItem;

  @ViewChild('clearConfigurationButton')
  clearConfigurationButton: ElementRef;

  @ViewChild('fileinput')
  importConfigurationInput: ElementRef;

  constructor(private configurationService: ConfigurationService,
              private dateFormatPipe: DateFormatPipe,
              private modal: Modal) {
    this.mainMenu = appMenu;
  }

  importConfigurationFile(data: any): void {
    let file: File = data.target.files[0];
    let fileReader = new FileReader();

    fileReader.onload = (e) => {
      let fileContent = fileReader.result;
      let configurationWrapper: ConfigurationWrapper = JSON.parse(fileContent);
      appMenu.subMenuItems = configurationWrapper.menuConfiguration.subMenuItems;
      this.configurationService.configuration = configurationWrapper.questionConfiguration;
    };
    fileReader.readAsText(file);
  }

  importConfiguration(data: any): void {
    this.modal
    .open(ImportConfigurationModalComponent, overlayConfigFactory({}, BSModalContext))
    .then((resultPromise) => {
      resultPromise.result.then((result) => {
        this.importConfigurationFile(data);
        this.importConfigurationInput.nativeElement.focus();
      }, () => {
        this.importConfigurationInput.nativeElement.focus();
      });
    });
  }

  private exportConfiguration() {
    let configurationWrapper = new ConfigurationWrapper(this.mainMenu, this.configurationService.configuration);
    let configurationWrapperAsString = JSON.stringify(configurationWrapper, null, 2);
    let fileName = 'skpt_config_' + this.dateFormatPipe.transform(new Date()) + '.json';

    saveAs(new Blob([configurationWrapperAsString], {
      type: 'text/plain'
    }), fileName);
  }

  selectMenu(menuLabelKey: string) {
    this.mainMenu.subMenuItems.forEach((menu) => {
      menu.isSelected = false;
    });
    this.getMenu(menuLabelKey).isSelected = true;
  }

  getMenu(menuLabelKey: string) {
    return this.mainMenu.subMenuItems.filter(menu => menu.labelKey === menuLabelKey)[0];
  }

  ngAfterViewInit(): void {
    this.selectMenu(this.mainMenu.subMenuItems[0].labelKey);
  }

  clearConfiguration(): void {
    this.modal
    .open(ClearConfigurationModalComponent, overlayConfigFactory({}, BSModalContext))
    .then((resultPromise) => {
      resultPromise.result.then((result) => {
        this.configurationService.clear();
        this.mainMenu.subMenuItems.forEach(menu => {
          menu.isEnabled = true;
          if (menu.subMenuItems) {
            menu.subMenuItems.forEach(subMenu => subMenu.isEnabled = true);
          }
        });
      });
    });
  }
}
