import {Component, ElementRef, EventEmitter, Input, Output, ViewChild} from '@angular/core';
import {NgProgressService} from 'ng2-progressbar';
import {Observable} from 'rxjs';
import {Response} from '@angular/http';
import {Attachment} from '../../../../service/data/attachment';
import {AttachmentService} from '../../../../service/data/attachment.service';
import {HttpErrorService} from '../../../../service/error/http-error.service';

@Component({
  selector: 'app-attachment',
  templateUrl: 'attachment.component.html',
  styleUrls: [
    './attachment.component.less'
  ]
})
export class AttachmentComponent {

  @Input()
  htmlId: string;

  @Input()
  value: Attachment;

  @Output()
  valueChange = new EventEmitter<Attachment>();

  @ViewChild('fileinput')
  fileinput: ElementRef;

  loading = false;

  /**
   * Attribute to know if the current element should get the focus
   */
  @Input()
  shouldFocus: boolean;

  @Output()
  created: EventEmitter<number> = new EventEmitter<any>();

  constructor(private attachmentService: AttachmentService,
              private pService: NgProgressService,
              private httpErrorService: HttpErrorService) {
  }

  clear(): void {
    this.fileinput.nativeElement.value = '';
    this.value = undefined;
    this.valueChange.next(undefined);
  }

  onFileChange(event: Event): void {
    let file: File = (<any> event.target).files[0];

    if (!file) {
      this.value = undefined;
      this.valueChange.next(undefined);
    } else {

      this.loading = true;
      this.pService.start();

      this.attachmentService.save(file)
        .catch((error: Response) => {
          this.httpErrorService.handleError(error);
          return Observable.throw(error);
        })
        .finally(() => {
          this.loading = false;
          this.pService.done();
        })
        .subscribe((attachment) => {
          this.value = attachment;
          this.valueChange.next(attachment);
        });

    }
  }


}
