import {Component, Input, OnDestroy} from '@angular/core';
import {Subscription} from 'rxjs';
import {LanguageChangeEvent, TranslateService} from '../../../../service/translate/translate.service';

/**
 * Component to display a esco as text.
 */
@Component({
  selector: 'app-boolean-as-text',
  templateUrl: './boolean-as-text.component.html',
  styleUrls: []
})
export class BooleanAsTextComponent implements OnDestroy {

  private _htmlId: string;
  private _value: any;
  private _trueLabelKey = 'common.yes';
  private _falseLabelKey = 'common.no';

  @Input()
  set htmlId(htmlId: string) {
    this._htmlId = htmlId;
  }

  get htmlId(): string {
    return this._htmlId;
  }

  @Input()
  set value(value: any) {
    this._value = value;
    this.onChange(value);
  }

  get value(): any {
    return this._value;
  }

  @Input()
  set trueLabelKey(value: string) {
    this._trueLabelKey = value;
    this.changeText();
  }

  get trueLabelKey(): string {
    return this._trueLabelKey;
  }

  @Input()
  set falseLabelKey(value: string) {
    this._falseLabelKey = value;
    this.changeText();
  }

  get falseLabelKey(): string {
    return this._falseLabelKey;
  }

  textValue: string;
  private onPrimaryLanguageChange: Subscription;

  constructor(private translateService: TranslateService) {
    this.onPrimaryLanguageChange = translateService.onPrimaryLanguageChange.subscribe((langChangeEvent: LanguageChangeEvent) => {
      this.changeLang();
    });
  }

  private onChange(value: any): void {
    this.changeText();
  }

  private changeText(): void {
    if (this.value != null) {
      if (typeof this.value === 'string') {
        if (this.value === 'true') {
          this.setTrueLabel();
        } else {
          this.setFalseLabel();
        }
      } else {
        if (this.value) {
          this.setTrueLabel();
        } else {
          this.setFalseLabel();
        }
      }
    }
  }

  private setTrueLabel() {
    if (this.trueLabelKey) {
      this.translateService.translate(this.trueLabelKey, this.translateService.getPrimaryLanguage()).subscribe(
        (value) => {
          this.textValue = value;
        }
      );
    } else {
      this.textValue = '';
    }
  }

  private setFalseLabel() {
    if (this.falseLabelKey) {
      this.translateService.translate(this.falseLabelKey, this.translateService.getPrimaryLanguage()).subscribe(
        (value) => {
          this.textValue = value;
        }
      );
    } else {
      this.textValue = '';
    }
  }

  private changeLang() {
    this.changeText();
  }

  ngOnDestroy(): void {
    this.onPrimaryLanguageChange.unsubscribe();
  }
}
