import {Component, ElementRef, Input, Output} from '@angular/core';
import {ViewChild} from '@angular/core/src/metadata/di';
import {EventEmitter} from '@angular/common/src/facade/async';
import {AbstractControlValueAccessor, makeProvider} from '../../../common/abstract-control-value-accessor.component';
import {TranslateService} from '../../../../service/translate/translate.service';

declare var $: any;

/**
 * Component to display a checkbox field in the profile form.
 */
@Component({
  selector: 'app-checkbox',
  templateUrl: './checkbox.component.html',
  styleUrls: ['./checkbox.component.less'],
  providers: [
    makeProvider(CheckboxComponent)
  ]
})
export class CheckboxComponent extends AbstractControlValueAccessor {

  /**
   * The HTML id attribute of the input created by this component.
   */
  @Input()
  htmlId: string;

  /**
   * The i18n key of the label that will be displayed for this component.
   */
  @Input()
  labelKey: string;

  @ViewChild('inputId')
  input: ElementRef;

  @Output()
  change = new EventEmitter();

  get childValue(): any {
    return this.value;
  }

  set childValue(value) {
    this.value = value;
  }

  constructor(public translateService: TranslateService) {
    super();
  }

  formatToModel(value: any): any {
    return value;
  }

  parseFromModel(value: any): any {
    return (value === 'true' || value === true);
  }

  scrollIntoViewIfNeeded() {
    let element = $(this.input.nativeElement);
    let top_of_element = element.offset().top;
    let bottom_of_element = element.offset().top + element.outerHeight();
    let bottom_of_screen = ($(window).scrollTop() + window.innerHeight) - 60;
    let top_of_screen = $(window).scrollTop();
    if (!((bottom_of_screen > top_of_element) && (top_of_screen < bottom_of_element))) {
      window.scrollTo(0, top_of_element -  window.innerHeight / 2);
    }
  }

  hasChanged() {
    this.change.emit();
  }

}
