import {AfterViewChecked, AfterViewInit, Component, Input, OnInit} from '@angular/core';
import {AbstractControlValueAccessor, makeProvider} from '../../../common/abstract-control-value-accessor.component';

declare var Pikaday: any;

@Component({
  selector: 'app-date-picker',
  templateUrl: './date-picker.component.html',
  styleUrls: ['./date-picker.component.less'],
  providers: [
    makeProvider(DatePickerComponent)
  ]
})
export class DatePickerComponent extends AbstractControlValueAccessor implements OnInit, AfterViewInit, AfterViewChecked {

  private picker;
  private lastDate;

  /**
   * The HTML id attribute of the input created by this component.
   */
  @Input()
  htmlId: string;

  @Input()
  maxYear = new Date().getFullYear();

  constructor() {
    super();
  }

  ngOnInit() {
  }

  ngAfterViewInit() {
    this.picker = new Pikaday({
      field: document.getElementById(this.htmlId),
      format: 'D/M/YYYY',
      toString(date, format) {
        const day = date.getDate();
        const month = date.getMonth() + 1;
        const year = date.getFullYear();
        return `${day}/${month}/${year}`;
      },
      parse(dateString, format) {
        const parts = dateString.split('/');
        const day = parseInt(parts[0], 10);
        const month = parseInt(parts[1], 10) - 1;
        const year = parseInt(parts[2], 10);
        return new Date(year, month, day);
      },
      firstDay: 1,
      maxDate: new Date(this.maxYear, 12, 31),
      theme: 'ecl-pika-theme',
      yearRange: [1900, this.maxYear]
    });
  }

  ngAfterViewChecked() {
    if (this.value !== null && this.value !== undefined
      && (!this.lastDate || (this.value.day !== this.lastDate.day && this.value.month !== this.lastDate.month && this.value.year !== this.lastDate.year))) {
      this.lastDate = this.value;
      if (Object.keys(this.value).length !== 0) {
        this.picker.setDate(
          this.value.year + '-' + ('0' + this.value.month).slice(-2) + '-' + ('0' + this.value.day).slice(-2));
      }
    }
  }

  changeDate(newDate) {
    if (newDate) {
      const parsedDate = newDate.split('/');
      this.value = {
        day: parsedDate[0],
        month: parsedDate[1],
        year: parsedDate[2]
      };
    }
  }

}
