import {Component, ElementRef, EventEmitter, Input, Output, ViewChild} from '@angular/core';
import {AbstractControlValueAccessor, makeProvider} from '../../../common/abstract-control-value-accessor.component';
import {LabelKeyValuePair} from '../label-key-value-pair';
import {TranslateService} from '../../../../service/translate/translate.service';

/**
 * Component to display a dropdown field in the profile form.
 */
@Component({
  selector: 'app-dropdown',
  templateUrl: './dropdown.component.html',
  styleUrls: ['./dropdown.component.less'],
  providers: [
    makeProvider(DropdownComponent)
  ]
})
export class DropdownComponent extends AbstractControlValueAccessor {

  /**
   * The HTML id attribute of the dropdown input created by this component.
   */
  @Input()
  htmlId: string;

  /**
   * The HTML name attribute of the dropdown input created by this component.
   */
  @Input()
  htmlName: string;

  /**
   * The values of the dropdown to display.
   */
  @Input()
  values: LabelKeyValuePair[];

  @Output()
  change = new EventEmitter();

  @ViewChild('select')
  select: ElementRef;

  /**
   * Attribute to know if the current element should get the focus
   */
  @Input()
  shouldFocus: boolean;

  @Output()
  created: EventEmitter<number> = new EventEmitter<any>();

  constructor(public translateService: TranslateService) {
    super();
  }

  ngAfterViewInit() {
    if (this.shouldFocus) {
      setTimeout(() => {
        this.select.nativeElement.focus();
        this.created.emit();
      });
    }
  }

  writeValue(value: any): any {
    if (!value) {
      value = '';
    }
    return super.writeValue(value);
  }

  get childValue(): any {
    return this.value;
  }

  set childValue(value) {
    this.value = value;
  }

  hasChanged() {
    this.change.emit();
  }
}
