import {Component, Input, OnDestroy} from '@angular/core';
import {Subscription} from 'rxjs';
import {LabelKeyValuePair} from '../label-key-value-pair';
import {LanguageChangeEvent, TranslateService} from '../../../../service/translate/translate.service';

/**
 * Component to display a esco as text.
 */
@Component({
  selector: 'app-key-value-as-text',
  templateUrl: './key-value-as-text.component.html',
  styleUrls: []
})
export class KeyValueAsTextComponent implements OnDestroy {

  private _htmlId: string;
  private _value: string;
  private _values: Array<LabelKeyValuePair>;

  @Input()
  set htmlId(htmlId: string) {
    this._htmlId = htmlId;
  }

  get htmlId(): string {
    return this._htmlId;
  }

  @Input()
  set value(value: string) {
    this._value = value;
    this.onChange(value);
  }

  get value(): string {
    return this._value;
  }

  @Input()
  set values(value: Array<LabelKeyValuePair>) {
    this._values = value;
    this.changeText();
  }

  get values(): Array<LabelKeyValuePair> {
    return this._values;
  }

  textValue: string;
  private onPrimaryLanguageChange: Subscription;

  constructor(private translateService: TranslateService) {
    this.onPrimaryLanguageChange = translateService.onPrimaryLanguageChange.subscribe((langChangeEvent: LanguageChangeEvent) => {
      this.changeLang();
    });
  }

  private onChange(value: string): void {
    this.changeText();
  }

  private changeText(): void {
    let labelKey = this.getLabelKey();
    if (labelKey) {
      this.translateService.translate(labelKey, this.translateService.getPrimaryLanguage()).subscribe(
        (value) => {
          this.textValue = value;
        }
      );
    } else {
      this.textValue = '';
    }
  }

  private getLabelKey(): string {
    if (this.values && (this.value !== null && this.value !== undefined)) {
      for (let i = 0; i < this.values.length; i++) {
        let obj = this.values[i];
        if (obj.value === this.value.toString()) {
          return obj.labelKey;
        }
      }
    }
    return undefined;
  }

  private changeLang() {
    this.changeText();
  }

  ngOnDestroy(): void {
    this.onPrimaryLanguageChange.unsubscribe();
  }
}
