import {Component, Input, Output} from '@angular/core';
import {EventEmitter} from '@angular/common/src/facade/async';
import {AbstractControlValueAccessor, makeProvider} from '../../../common/abstract-control-value-accessor.component';

@Component({
  selector: 'app-multi-free-text',
  templateUrl: './multi-free-text.component.html',
  styleUrls: ['./multi-free-text.component.less'],
  providers: [
    makeProvider(MultiFreeTextComponent)
  ]
})
export class MultiFreeTextComponent extends AbstractControlValueAccessor {

  @Input()
  init: boolean;

  @Input()
  max = 3;

  @Input()
  htmlId: string;

  @Input()
  addOtherLabel: string;

  private selectionInternal: string[];

  @Output()
  selectionChange = new EventEmitter<string>();

  /**
   * The HTML placeholder attribute of the textarea created by this component.
   */
  @Input()
  htmlPlaceholder: string;

  private focusOnNew: boolean;

  @Output()
  change = new EventEmitter();

  get childValue(): any {
    return this.value;
  }

  set childValue(value) {
    this.value = value;
  }

  @Input()
  get selection(): any {
    return this.selectionInternal;
  }

  set selection(value) {
    this.selectionInternal = value;
    this.selectionChange.emit(value);
  }

  ngOnInit(): void {
    if (this.init && this.selection.length === 0) {
      this.selection.push({});
    }
  }

  add(): void {
    this.selection.push({});
    this.focusOnNew = true;

    this.hasChanged();
  }

  switchFocus(): void {
    this.focusOnNew = false;
  }

  del(index: number): void {
    document.getElementById('focusOnRemove-freeText-' + index).focus();
    this.selection.splice(index, 1);

    this.hasChanged();
  }

  hasChanged() {
    this.change.emit();
  }
}
