import {Component, Input, Output} from '@angular/core';
import {EventEmitter} from '@angular/common/src/facade/async';
import {makeProvider} from '../../../common/abstract-control-value-accessor.component';

@Component({
  selector: 'app-multi-language',
  templateUrl: './multi-language.component.html',
  styleUrls: ['./multi-language.component.less'],
  providers: [
    makeProvider(MultiLanguageComponent)
  ]
})
export class MultiLanguageComponent {

  @Input()
  max: number;

  @Input()
  htmlId: string;

  private selectionInternal = [];

  @Output()
  selectionChange = new EventEmitter<string>();

  @Output()
  change = new EventEmitter();

  /**
   * The HTML placeholder attribute of the textarea created by this component.
   */
  @Input()
  htmlPlaceholder: string;

  @Input()
  autoWidth: boolean;

  private focusOnNew: boolean;

  @Input()
  get selection(): any {
    return this.selectionInternal;
  }

  set selection(value) {
    this.selectionInternal = value;
    this.selectionChange.emit(value);
  }

  add(): void {
    this.selection.push({});
    this.focusOnNew = true;

    this.hasChanged();
  }

  switchFocus(): void {
    this.focusOnNew = false;
  }

  del(index: number): void {
    document.getElementById('focusOnRemove-language-' + index).focus();
    this.selection.splice(index, 1);

    this.hasChanged();
  }

  hasChanged() {
    this.change.emit();
  }
}
