import {Component, ElementRef, Input, Output} from '@angular/core';
import {EventEmitter} from '@angular/common/src/facade/async';
import {ViewChild} from '@angular/core/src/metadata/di';
import {FormArray, FormBuilder, FormControl, FormGroup, Validators} from '@angular/forms';
import {AbstractControlValueAccessor, makeProvider} from '../../../common/abstract-control-value-accessor.component';
import {ValidationService} from '../../../../service/validation/validation.service';

declare var $: any;

@Component({
  selector: 'app-multi-split-mail',
  templateUrl: './multi-split-mail.component.html',
  styleUrls: ['./multi-split-mail.component.less'],
  providers: [
    makeProvider(MultiSplitMailComponent)
  ]
})
export class MultiSplitMailComponent extends AbstractControlValueAccessor {

  @Input()
  htmlId: string;

  @Input()
  max = 3;

  private selectionInternal = [];

  @Output()
  selectionChange = new EventEmitter<string>();

  /**
   * The HTML placeholder attribute of the textarea created by this component.
   */
  @Input()
  htmlPlaceholderPrefix: string;

  @Input()
  htmlPlaceholder: string;

  @Input()
  autoWidth: boolean;

  @ViewChild('lastId')
  lastFocus: ElementRef;

  private focusOnNew: boolean;

  get childValue(): any {
    return this.value;
  }

  set childValue(value) {
    this.value = value;
  }

  @Input()
  get selection(): any {
    return this.selectionInternal;
  }

  set selection(value) {
    this.selectionInternal = value;
    this.selectionChange.emit(value);
  }

  constructor(public validation: ValidationService,
              public formBuilder: FormBuilder) {
    super();
  }

  ngOnInit() {
    for (let sel of this.selection) {
      this.addValidationSubEmail();
    }
  }

  add() {
    this.selection.push({});
    this.focusOnNew = true;

    this.addValidationSubEmail();
  }

  private addValidationSubEmail() {
    (<FormArray> this.validation.formGroup.controls['subEmails'])
      .push(new FormGroup({
        prefix: new FormControl('', Validators.compose([
          this.validation.emailPrefixValidator
        ])),
        suffix: new FormControl('', Validators.compose([
          this.validation.emailSuffixValidator
        ]))
      }));
  }

  switchFocus(): void {
    this.focusOnNew = false;
  }

  del(index: number): void {
    document.getElementById('focusOnRemove-splittedMail-' + index).focus();
    this.selection.splice(index, 1);

    (<FormArray> this.validation.formGroup.controls['subEmails'])
      .removeAt(index);
  }
}
