import {Component, ElementRef, Input, Output} from '@angular/core';
import {EventEmitter} from '@angular/common/src/facade/async';
import {ViewChild} from '@angular/core/src/metadata/di';
import {AbstractControlValueAccessor, makeProvider} from '../../../common/abstract-control-value-accessor.component';
import {LabelKeyValuePair} from '../../field/label-key-value-pair';
import {TranslateService} from '../../../../service/translate/translate.service';
import {ConfigurationService} from '../../../../service/configuration/configuration.service';

/**
 * Component to display a radio buttons field in the profile form.
 */
@Component({
  selector: 'app-radio',
  templateUrl: './radio.component.html',
  styleUrls: ['./radio.component.less'],
  providers: [
    makeProvider(RadioComponent)
  ]
})
export class RadioComponent extends AbstractControlValueAccessor {

  /**
   * The HTML id attribute of the input created by this component.
   */
  @Input()
  htmlId: string;

  /**
   * The HTML name attribute of the radio inputs created by this component.
   */
  @Input()
  htmlName: string;

  /**
   * The values of the radio buttons to display.
   */
  @Input()
  values: LabelKeyValuePair[];

  /**
   * If the radio buttons should be rendered inline
   */
  @Input()
  inline = false;

  @Output()
  change = new EventEmitter();

  @ViewChild('radio')
  radio: ElementRef;

  /**
   * Attribute to know if the current element should get the focus
   */
  @Input()
  shouldFocus: boolean;

  @Input()
  parentQuestionLabelKey: string;

  @Output()
  created: EventEmitter<number> = new EventEmitter<any>();

  constructor(public translateService: TranslateService,
              public configurationService: ConfigurationService) {
    super();
  }

  ngAfterViewInit() {
    if (this.shouldFocus) {
      setTimeout(() => {
        this.radio.nativeElement.focus();
        this.created.emit();
      });
    }
  }

  get childValue(): any {
    return this.value;
  }

  set childValue(value) {
    this.value = value;
  }

  parseFromModel(value: any): any {
    if (value === true) {
      return 'true';
    } else if (value === false) {
      return 'false';
    }
    return value;
  }

  hasChanged() {
    this.change.emit();
  }

  isRadioEnabled(answerLabelKey: string, elementId: string) {
    return this.configurationService.isQuestionEnabled(answerLabelKey, elementId);
  }

}
