import {Component, Input, OnDestroy, OnInit} from '@angular/core';
import {Subscription} from 'rxjs';
import {LanguageChangeEvent, TranslateService} from '../../../../service/translate/translate.service';

/**
 * Component to display a rating as text.
 */
@Component({
  selector: 'app-rating-as-text',
  templateUrl: './rating-as-text.component.html',
  styleUrls: [
    './rating-as-text.component.less'
  ]
})
export class RatingAsTextComponent implements OnDestroy, OnInit {

  private _htmlId: string;
  private _value: string;
  private _values: Array<string>;

  @Input()
  set value(value: string) {
    this._value = value;
    this.onChange(value);
  }

  get value(): string {
    return this._value;
  }

  @Input()
  set values(value: Array<string>) {
    this._values = value;
    this.changeText();
  }

  get values(): Array<string> {
    return this._values;
  }

  @Input()
  max: number;

  /**
   * The HTML id attribute of the input created by this component.
   */
  @Input()
  set htmlId(htmlId: string) {
    this._htmlId = htmlId;
  }

  get htmlId(): string {
    return this._htmlId;
  }

  counter: Array<any> = [];

  textValue: string;
  private onPrimaryLanguageChange: Subscription;

  constructor(private translateService: TranslateService) {
    this.onPrimaryLanguageChange = translateService.onPrimaryLanguageChange.subscribe((langChangeEvent: LanguageChangeEvent) => {
      this.changeLang();
    });
  }

  private onChange(value: string): void {
    this.changeText();
  }

  private changeText(): void {
    let labelKey = this.getLabelKey();
    if (labelKey) {
      this.translateService.translate(labelKey, this.translateService.getPrimaryLanguage()).subscribe(
        (value) => {
          this.textValue = value;
        }
      );
    } else {
      this.textValue = '';
    }
  }

  private getLabelKey(): string {
    if (this.values) {
      if (this.value) {
        return this.values[this.value];
      } else {
        return this.values[0];
      }
    }
    return undefined;
  }

  private changeLang() {
    this.changeText();
  }

  ngOnDestroy(): void {
    this.onPrimaryLanguageChange.unsubscribe();
  }

  ngOnInit(): void {
    this.counter = new Array(this.max);
  }
}
