import {Component, Input} from '@angular/core';
import {NgbRatingConfig} from '@ng-bootstrap/ng-bootstrap';
import {AbstractControlValueAccessor, makeProvider} from '../../../common/abstract-control-value-accessor.component';
import {TranslateService} from '../../../../service/translate/translate.service';

/**
 * Component to display a rating field in the profile form.
 */
@Component({
  selector: 'app-rating',
  templateUrl: './rating.component.html',
  styleUrls: [
    './rating.component.less'
  ],
  providers: [
    makeProvider(RatingComponent),
    NgbRatingConfig
  ]
})
export class RatingComponent extends AbstractControlValueAccessor {

  /**
   * The HTML id attribute of the input created by this component.
   */
  @Input()
  htmlId: string;

  @Input()
  max = 10;

  @Input()
  labelKeys: Array<string>;

  rateText: string;

  constructor(private config: NgbRatingConfig,
              public translateService: TranslateService) {
    super();
  }

  get childValue(): any {
    return this.value;
  }

  set childValue(value) {
    this.value = value;
  }

  writeValue(value: any): any {
    if (isNaN(value)) {
      value = 0;
    }
    return super.writeValue(value);
  }

  clear(): void {
    this.childValue = 0;
  }

  updateTitle(index: number): void {
    this.rateText = this.labelKeys[index];
  }
}
