import {OnDestroy} from '@angular/core';
import {LanguageChangeEvent, TranslateService} from '../../../service/translate/translate.service';
import {Observable, Subscription} from 'rxjs';

/**
 * Component to display a esco as text.
 */
export abstract class RefDataAsTextComponent implements OnDestroy {

  private _htmlId: string;
  private _value: any;

  set htmlId(htmlId: string) {
    this._htmlId = htmlId;
  }

  get htmlId(): string {
    return this._htmlId;
  }

  set value(value: any) {
    this._value = value;
    this.onChange(value);
  }

  get value(): any {
    return this._value;
  }

  textValue: string;
  protected serverState;
  private onPrimaryLanguageChange: Subscription;

  constructor(protected translateService: TranslateService) {
    this.onPrimaryLanguageChange = translateService.onPrimaryLanguageChange.subscribe((langChangeEvent: LanguageChangeEvent) => {
      this.changeLang();
    });
  }

  protected abstract request(value: any): Observable<any>;

  protected onChange(value: any): void {
    if (value) {
      this.request(value).subscribe(
        (response) => {
          this.serverState = response;
          this.changeText();
        }
      );
    } else {
      this.serverState = undefined;
      this.changeText();
    }
  }

  protected changeText(): void {
    if (this.serverState) {
      if (this.serverState.values) {
        let lang = this.serverState.values[this.translateService.getPrimaryLanguage()];
        if (lang && lang.value) {
          this.textValue = lang.value;
        } else {
          lang = this.serverState.values[this.translateService.getDefaultLanguage()];
          if (lang && lang.value) {
            this.textValue = lang.value;
          } else {
            this.textValue = '';
          }
        }
      }
    } else {
      this.textValue = '';
    }
  }

  private changeLang() {
    this.changeText();
  }

  ngOnDestroy(): void {
    this.onPrimaryLanguageChange.unsubscribe();
  }
}
