import {Component, Input, Output} from '@angular/core';
import {FormGroup} from '@angular/forms';
import {EventEmitter} from '@angular/forms/src/facade/async';
import {AbstractControlValueAccessor, makeProvider} from '../../../common/abstract-control-value-accessor.component';
import {ValidationService} from '../../../../service/validation/validation.service';
import {split} from 'ts-node/dist';

/**
 * Component to display a email field with 2 input areas
 */
@Component({
  selector: 'app-split-email',
  templateUrl: './split-email.component.html',
  styleUrls: ['./split-email.component.less'],
  providers: [
    makeProvider(SplitEmailComponent)
  ]
})
export class SplitEmailComponent extends AbstractControlValueAccessor {

  /**
   * The HTML id attribute of the input created by this component.
   */
  @Input()
  htmlId: string;

  /**
   * The FormGroup attribute.
   */
  @Input()
  group: FormGroup;

  /**
   * The control name attribute.
   */
  @Input()
  controlNamePre: string;

  @Input()
  controlNameSuff: string;

  private selectionInternal: string[];

  @Output()
  selectionChange = new EventEmitter<string>();

  /**
   * The HTML placeholder attribute of the textarea created by this component.
   */
  @Input()
  htmlPlaceholder: string;

  @Input()
  autoWidth: boolean;

  get childValue(): any {
    return this.value;
  }

  set childValue(value) {
    this.value = value;
  }

  @Input()
  get selection(): any {
    return this.selectionInternal;
  }

  set selection(value) {
    this.selectionInternal = value;
    this.selectionChange.emit(value);
  }

}
