import {Component, Input, Output} from '@angular/core';
import {FormGroup} from '@angular/forms';
import {EventEmitter} from '@angular/forms/src/facade/async';
import {makeProvider} from '../../../common/abstract-control-value-accessor.component';

/**
 * Component to display a phone number field with 2 input areas
 */
@Component({
  selector: 'app-split-phone-number',
  templateUrl: './split-phone-number.component.html',
  styleUrls: ['./split-phone-number.component.less'],
  providers: [
    makeProvider(SplitPhoneNumberComponent)
  ]
})
export class SplitPhoneNumberComponent {

  /**
   * The HTML id attribute of the input created by this component.
   */
  @Input()
  htmlId: string;

  /**
   * The FormGroup attribute.
   */
  @Input()
  group: FormGroup;

  /**
   * The control name attribute.
   */
  @Input()
  controlNamePre: string;

  @Input()
  controlNameSuff: string;

  private selectionInternal = {};

  @Output()
  selectionChange = new EventEmitter<any>();

  /**
   * The HTML placeholder attribute of the textarea created by this component.
   */
  @Input()
  htmlPlaceholder: string;

  @Input()
  htmlPlaceholderPrefix: string;

  @Input()
  get selection(): any {
    return this.selectionInternal;
  }

  set selection(value) {
    this.selectionInternal = value;
    this.selectionChange.emit(value);
  }

}
