import {AfterViewInit, Component, ElementRef, HostListener, OnInit, ViewChild, ViewContainerRef} from '@angular/core';
import {saveAs} from 'file-saver';
import {ProfileService} from '../../profile.service';
import {NgProgressService} from 'ng2-progressbar';
import {HttpErrorService} from '../../../../service/error/http-error.service';
import {ValidationService} from '../../../../service/validation/validation.service';
import {BSModalContext, Modal} from 'angular2-modal/plugins/bootstrap';
import {TranslateService} from '../../../../service/translate/translate.service';
import {RouteService} from '../../../../service/navigation/route.service';
import {ExportService} from '../../../../service/export/export.service';
import {overlayConfigFactory} from 'angular2-modal';
import {ConsentModalComponent} from '../../modal/consent-modal/consent-modal.component';
import {Router} from '@angular/router';
import {ClearProfileModalComponent} from '../../modal/clear-profile-modal/clear-profile-modal.component';
import {ConfigurationService} from '../../../../service/configuration/configuration.service';

declare var $: any;
declare var ECL: any;

@Component({
  selector: 'app-title-bar-fixed',
  templateUrl: './header-action-bar.component.html',
  styleUrls: ['./header-action-bar.component.less']
})
export class HeaderActionBarComponent implements OnInit, AfterViewInit {

  savingProfile = false;

  profile: Object;

  private eclExpandable;

  @ViewChild('exportProfileExpandable')
  exportProfileExpandable: ElementRef;

  @ViewChild('exportAsXml')
  exportAsXml: ElementRef;

  @ViewChild('clearButton')
  clearButton: ElementRef;

  isExportSectionFocused = false;

  // Fixed management

  @HostListener('window:scroll', [])
  onWindowScroll() {
    this.computeTitleBarFixed();
  }

  @HostListener('window:resize', [])
  onWindowResize() {
    this.computeTitleBarFixed();
  }

  constructor(private router: Router,
              private profileService: ProfileService,
              private exportService: ExportService,
              private pService: NgProgressService,
              private httpErrorService: HttpErrorService,
              private modal: Modal,
              public translate: TranslateService,
              public validation: ValidationService,
              public routeService: RouteService,
              private configurationService: ConfigurationService) {
    this.profile = profileService.profile;
  }

  ngOnInit() {
    this.computeTitleBarFixed();
  }

  ngAfterViewInit() {
    // add action on the expandable button
    this.eclExpandable = new ECL.Expandable(this.exportProfileExpandable.nativeElement, undefined);
    this.eclExpandable.init();
  }

  focusOnExportAsXml() {
    setTimeout(() => this.exportAsXml.nativeElement.focus(), 100);
  }

  closeExpandableButton(forceClose?: boolean) {
    // check if the expandable button is expanded
    setTimeout(() => {
      if ((forceClose || !this.isExportSectionFocused) && this.eclExpandable.element.innerHTML.includes('aria-expanded="true"')) {
        this.eclExpandable.handleClickOnToggle();
      }
    }, 100);
  }

  exportTo(format: string): void {
    if (this.profile['outcome']['statistics'] === undefined && this.profile['outcome']['stored'] === undefined) {

      this.modal
        .open(ConsentModalComponent, overlayConfigFactory({}, BSModalContext))
        .then(dialog => dialog.result
          .then((result) => {
            this.profile['outcome']['statistics'] = result['statistics'];
            this.profile['outcome']['stored'] = result['stored'];

            this.exportProfile(format);
          })
        );
    } else {
      this.exportProfile(format);
    }
  }

  private exportProfile(format) {
    this.closeExpandableButton(true);

    this.pService.start();
    this.savingProfile = true;
    this.exportService.exportAs(format)
      .finally(() => {
        this.savingProfile = false;
        this.pService.done();
      })
      .subscribe(
        success => {
          switch (format) {
            case 'pdf':
              this.downloadFile(success, 'application/pdf');
              break;
            case 'word':
              this.downloadFile(success, 'application/vnd.openxmlformats-officedocument.wordprocessingml.document');
              break;
            case 'excel':
              this.downloadFile(success, 'application/vnd.ms-excel');
              break;
            case 'xml':
              this.downloadFile(success, 'application/xml');
              break;
            default:
              console.error('Error on the export profile format');
          }
        },
        () => {
          this.httpErrorService.displayErrorMessage('042');
        });
    this.profileService.sendStatistics().subscribe();
  }

  private downloadFile(requestResult: any, typeFile: string) {
    let fileName = undefined;
    requestResult.headers._headers.forEach((value, key) => {
      if (key === 'content-disposition') {
        fileName = value[0].split('\'')[2];
      }
    });
    let blobFile = new Blob([requestResult._body], { type: typeFile });
    saveAs(blobFile, fileName);
  }

  print(): void {
    window.print();
    this.profileService.sendStatistics().subscribe();
  }

  clear(): void {
    this.modal
      .open(ClearProfileModalComponent, overlayConfigFactory({}, BSModalContext))
      .then((resultPromise) => {
        resultPromise.result.then((result) => {
          this.profileService.clear();
          this.configurationService.clear();
          this.validation.resetFormGroup();
          this.clearButton.nativeElement.focus();
        }, () => {
          this.clearButton.nativeElement.focus();
        });
      });
  }

  private computeTitleBarFixed() {

    // scrollbar : get position top
    let scrollbar__posTop = $(document).scrollTop();

    // target .header-container
    let headerContainer__target = $('.header-container');
    let headerContainer__height = headerContainer__target.innerHeight();
    let headerContainer__width = headerContainer__target.innerWidth();
    let headerContainer__pos = headerContainer__target.position();
    let headerContainer__posTop = headerContainer__pos.top;

    // target app-title-bar-fixed
    let appTitleBarFixed__target = $('.title-bar-fixed');
    let appTitleBarFixed__height = appTitleBarFixed__target.innerHeight();

    if (headerContainer__width > 768) {
      // target title-bar-fixed-phantom
      let appTitleBarFixedPhantom__target = $('.title-bar-fixed-phantom');

      if (scrollbar__posTop > headerContainer__posTop + headerContainer__height - appTitleBarFixed__height) {
        appTitleBarFixed__target.removeClass('inherit');
        appTitleBarFixedPhantom__target.height(appTitleBarFixed__height);
      } else {
        // a part of the header is displayed
        appTitleBarFixed__target.addClass('inherit');
        appTitleBarFixedPhantom__target.height(0);
      }
    } else {
      let headerProfileContainer__target = $('.header-profile-container');
      let headerProfileContainer__height = headerProfileContainer__target.innerHeight();
      let headerProfileContainer__pos = headerProfileContainer__target.position();
      let headerProfileContainer__posTop = headerProfileContainer__pos.top;

      if (scrollbar__posTop + window.innerHeight > headerProfileContainer__posTop + headerProfileContainer__height + appTitleBarFixed__height) {
        appTitleBarFixed__target.removeClass('inherit');
      } else {
        appTitleBarFixed__target.addClass('inherit');
      }
    }

  }

}
