import {Component, EventEmitter, Input, Output, ViewContainerRef} from '@angular/core';
import {CropperSettings} from 'ng2-img-cropper';
import {Modal, overlayConfigFactory} from 'angular2-modal';
import {BSModalContext} from 'angular2-modal/plugins/bootstrap';
import {Attachment} from '../../../../../service/data/attachment';
import {ProfilePictureModal} from './profile-picture-modal/profile-picture-modal.component';

/**
 * Component to display a image upload field in the profile form.
 */
@Component({
  selector: 'app-header-profile-image',
  templateUrl: './header-profile-image.component.html',
  styleUrls: [
    './header-profile-image.component.less'
  ]
})
export class HeaderProfileImageComponent {

  /**
   * Base64 encoded image content.
   */
  @Input()
  image: Attachment;

  @Output()
  imageChange: EventEmitter<any> = new EventEmitter();

  @Input()
  defaultImage: string;

  loading = false;

  private cropperSettings: CropperSettings;

  constructor(vcRef: ViewContainerRef,
              private modal: Modal) {

    this.cropperSettings = new CropperSettings();
    this.cropperSettings.noFileInput = true;
    this.cropperSettings.width = 200;
    this.cropperSettings.height = 200;
    this.cropperSettings.croppedWidth = 200;
    this.cropperSettings.croppedHeight = 200;
    this.cropperSettings.canvasWidth = 300;
    this.cropperSettings.canvasHeight = 300;
    this.cropperSettings.minWidth = 200;
    this.cropperSettings.minHeight = 200;
    this.cropperSettings.rounded = false;
    this.cropperSettings.cropperDrawSettings.strokeColor = 'rgba(255,255,255,1)';
    this.cropperSettings.cropperDrawSettings.strokeWidth = 2;
  }

  openModal() {
    this.modal.open(ProfilePictureModal,
      overlayConfigFactory({cropperSettings: this.cropperSettings, currentProfilePicture: this.image},
        BSModalContext))
      .then(dialog => dialog.result.then((result) => {
          this.image = <Attachment> result;
          this.imageChange.emit(this.image);
        })
      )
      .catch(reason => {
      });
  }

}
