import {Component, ViewChild} from '@angular/core';
import {CloseGuard, DialogRef, ModalComponent} from 'angular2-modal';
import {Bounds, CropperSettings, ImageCropperComponent} from 'ng2-img-cropper';
import {BSModalContext} from 'angular2-modal/plugins/bootstrap';
import {NgProgressService} from 'ng2-progressbar';
import {Response} from '@angular/http';
import {Observable} from 'rxjs';
import {TranslateService} from '../../../../../../service/translate/translate.service';
import {HttpErrorService} from '../../../../../../service/error/http-error.service';
import {AttachmentService} from '../../../../../../service/data/attachment.service';
import {Attachment} from '../../../../../../service/data/attachment';

export class ProfilePictureModalContext extends BSModalContext {
  public cropperSettings: CropperSettings;
  public currentProfilePicture: Attachment;
}

/**
 * Profile picture modal component.
 */
@Component({
  selector: 'app-profile-picture-modal',
  templateUrl: './profile-picture-modal.component.html',
  styleUrls: [
    './profile-picture-modal.component.less'
  ],
})
export class ProfilePictureModal implements CloseGuard, ModalComponent<ProfilePictureModalContext> {

  context: ProfilePictureModalContext;

  @ViewChild('cropper', undefined)
  cropper: ImageCropperComponent;

  fileIsImage: boolean;

  data: any;

  loading = false;

  constructor(public dialog: DialogRef<ProfilePictureModalContext>,
              public translate: TranslateService,
              private pService: NgProgressService,
              private httpErrorService: HttpErrorService,
              private attachmentService: AttachmentService) {
    this.context = dialog.context;
    this.fileIsImage = true;
    this.data = {};
    dialog.setCloseGuard(this);
  }

  onFileChange($event) {

    let file: File = $event.target.files[0];
    this.fileIsImage = !!file.type.match('image.*');
    if (this.fileIsImage) {
      let myReader: FileReader = new FileReader();
      myReader.onloadend = (loadEvent: any) => {
        let image: any = new Image();
        image.src = loadEvent.target.result;
        this.cropper.setImage(image);
      };
      myReader.readAsDataURL(file);
    }
  }

  /**
   * Cropped event.
   *
   * @param bounds
   */
  cropped(bounds: Bounds) {
  }

  /**
   * Confirm modal.
   */
  confirm(): void {

    if (this.data && this.data.image) {
      let blob = this.dataURItoBlob(this.data.image);

      this.loading = true;
      this.pService.start();

      this.attachmentService.saveBlob(blob)
        .catch((error: Response) => {
          this.httpErrorService.handleError(error);
          return Observable.throw(error);
        })
        .finally(() => {
          this.loading = false;
          this.pService.done();
        })
        .subscribe((attachment) => {
          this.dialog.close(attachment);
        });
    } else {
      this.dialog.dismiss();
    }

  }

  /**
   * Cancel modal.
   */
  cancel(): void {
    this.dialog.dismiss();
  }

  beforeDismiss(): boolean {
    return false;
  }

  beforeClose(): boolean {
    return false;
  }

  private dataURItoBlob(dataURI): Blob {
    // convert base64/URLEncoded data component to raw binary data held in a string
    let byteString;
    if (dataURI.split(',')[0].indexOf('base64') >= 0) {
      byteString = atob(dataURI.split(',')[1]);
    } else {
      byteString = decodeURI(dataURI.split(',')[1]);
    }

    // separate out the mime component
    let mimeString = dataURI.split(',')[0].split(':')[1].split(';')[0];

    // write the bytes of the string to a typed array
    let ia = new Uint8Array(byteString.length);
    for (let i = 0; i < byteString.length; i++) {
      ia[i] = byteString.charCodeAt(i);
    }

    return new Blob([ia], {type: mimeString});
  }

  closeErrorMessage() {
    this.fileIsImage = true;
  }
}
