import {Component, HostListener, OnInit} from '@angular/core';
import {summary} from '../summary/summary.component';
import {outcome} from '../outcome/outcome.component';
import {skillsIdentification} from '../skills-identification/skills-identification.component';
import {MenuItem} from './menu-item';
import {personalInfo} from '../personal-info/personal-info.component';
import {expectations} from '../expectations/expectations.component';
import {NavigationEnd, Router} from '@angular/router';
import {menuItemCreationEmitter, ProfileService} from '../profile.service';
import {ValidationService} from '../../../service/validation/validation.service';

declare var $: any;

export let appMenu = new MenuItem('menu',
  true, false, '/', true, 'menu',
  [personalInfo, expectations, skillsIdentification, outcome, summary]);

@Component({
  selector: 'app-menu',
  templateUrl: './menu.component.html',
  styleUrls: ['./menu.component.less']
})
export class MenuComponent implements OnInit {

  profile: Object;

  menu = appMenu;

  currentMenu: string;
  currentMenuLabelKey: string;

  headerActionBarHeight: number;

  menuPhantomHeight = 0;
  isSecondaryMenuDisplayed = false;

  constructor(private router: Router,
              private profileService: ProfileService,
              public validation: ValidationService) {
    this.profile = this.profileService.profile;

    this.router.events.subscribe((val) => {
      if (val instanceof NavigationEnd) {
        this.updateMenu();
      } else {
        window.scrollTo(0, 0);
      }
    });
  }

  ngOnInit() {
    this.emitMenuItemCreation(this.menu);
    this.updateMenu();
  }

  private emitMenuItemCreation(menu: MenuItem) {
    if (menu.subMenuItems) {
      menu.subMenuItems.forEach(menuItem => {
        menuItemCreationEmitter.emit({
          menu: menuItem,
          key: menuItem.labelKey
        });
        this.emitMenuItemCreation(menuItem);
      });
    }
  }

  private updateMenu() {
    this.currentMenu = '';
    this.currentMenuLabelKey = '';
    this.menu.subMenuItems.forEach(menuItem => {
      if (menuItem.routerLink === this.router.url.split('/')[2]) {
        this.currentMenu = menuItem.name;
        this.currentMenuLabelKey = menuItem.labelKey;
      }
    });
  }

  navigateTo(route: string) {
    this.router.navigateByUrl(route);
  }

  @HostListener('window:scroll', [])
  onWindowScroll() {
    this.createSubMenuForMobile();
  }

  @HostListener('window:resize', [])
  onWindowResize() {
    this.createSubMenuForMobile();
  }

  private createSubMenuForMobile() {
    // scrollbar : get position top
    let scrollbar__posTop = $(document).scrollTop();

    // target .header-container
    let headerContainer = $('.header-container');
    let headerContainer__pos = headerContainer.position();
    let headerContainer__posTop = headerContainer__pos.top;
    let headerContainer__width = headerContainer.innerWidth();
    let headerContainer__height = headerContainer.innerHeight();

    let phantomMenu__height = $('.menu-phantom').innerHeight();

    let menu = $('.ecl-inpage-navigation');
    let menu__height = menu.innerHeight();

    // the '+ 16' refer to the 1em added (1em = 16 px)
    if (headerContainer__width < 768) {
      if (this.menuPhantomHeight === 0 && scrollbar__posTop > headerContainer__posTop + headerContainer__height + menu__height + 16) {
        this.menuPhantomHeight = menu__height;
        menu.addClass('fixed');
      } else if (this.menuPhantomHeight !== 0 && scrollbar__posTop <= headerContainer__posTop + headerContainer__height + phantomMenu__height + 16) {
        this.menuPhantomHeight = 0;
        this.isSecondaryMenuDisplayed = false;
        menu.removeClass('fixed');
      }
    } else {
      this.menuPhantomHeight = 0;
      this.isSecondaryMenuDisplayed = false;
      menu.removeClass('fixed');
    }

    let ua = navigator.userAgent;
    if (ua.indexOf('MSIE ') > -1 || ua.indexOf('Trident/') > -1) {
      this.headerActionBarHeight = 0;
    } else {
      this.headerActionBarHeight = headerContainer__width < 768 ? 0 : (document.getElementsByClassName('title-bar-fixed').item(0).clientHeight + 16);
    }
  }

}
