import {AfterViewChecked, ChangeDetectorRef, Component, OnInit} from '@angular/core';
import {TranslateService} from '../../../../service/translate/translate.service';
import {ProfileService} from '../../profile.service';
import {ValidationService} from '../../../../service/validation/validation.service';
import {constants} from '../../../../constants/profile-label-keys';
import {SectionAbstractComponent} from '../../../common/section-abstract.component';
import {MenuItem} from '../../menu/menu-item';
import {professionalSkills} from '../../skills-identification/professional-skills/professional-skills.component';

declare var $: any;

export let organisation = new MenuItem('profile.outcome.details_issuing_organisation.title',
  true, false, 'issuing-organisation', false, 'organisation');

@Component({
  selector: 'app-issuing-organisation',
  templateUrl: './issuing-organisation.component.html',
  styleUrls: ['./issuing-organisation.component.less']
})
export class IssuingOrganisationComponent extends SectionAbstractComponent implements OnInit, AfterViewChecked {

  profile: Object;
  constants: Object;

  private focusOnNew: boolean;

  constructor(private changeDetectorRef: ChangeDetectorRef,
              public translate: TranslateService,
              public profileService: ProfileService,
              public validation: ValidationService) {
    super(profileService, professionalSkills);
    this.profile = profileService.profile;
    this.constants = constants;
  }

  ngOnInit() {
    if (this.profile['outcome']['organisations'].length === 0) {
      this.add();
    }

    let array = this.profile['outcome']['organisations'];
    array.forEach((value: string, index: number) => {
      this.addValidation(index);
    });
  }

  ngAfterViewChecked() {
    this.changeDetectorRef.detectChanges();
  }

  add(): void {
    let array = this.profile['outcome']['organisations'];
    array.push({
      dateOfIssuance: {},
      organisationContactInfo: {
        phoneNumber: {},
        email: {},
        phoneNumbers: []
      }
    });

    this.addValidation(array.length - 1);

    this.focusOnNew = true;
  }

  switchFocus(): void {
    this.focusOnNew = false;
  }

  remove(index: number) {
    document.getElementById('focusOnRemove-organisation-' + index).focus();
    this.profile['outcome']['organisations'].splice(index, 1);
  }

  addValidation(index: number) {
    this.validation.addPhoneControl('organisationPhonePrefix' + index);
    this.validation.addPhoneControl('organisationPhoneSuffix' + index);
    this.validation.addMailPrefixControl('organisationEmailPrefix' + index);
    this.validation.addMailSuffixControl('organisationEmailSuffix' + index);
  }

}
