import {Component, Input, Output} from '@angular/core';
import {EventEmitter} from '@angular/common/src/facade/async';
import {AbstractControlValueAccessor, makeProvider} from '../../../../common/abstract-control-value-accessor.component';
import {TranslateService} from '../../../../../service/translate/translate.service';
import {ProfileService} from '../../../profile.service';
import {ValidationService} from '../../../../../service/validation/validation.service';
import {constants} from '../../../../../constants/profile-label-keys';

declare var $: any;

@Component({
  selector: 'app-identification-document',
  templateUrl: './identification-document.component.html',
  styleUrls: ['./identification-document.component.less'],
  providers: [
    makeProvider(IdentificationDocument)
  ]
})
export class IdentificationDocument  extends AbstractControlValueAccessor {

  @Input()
  htmlId: string;

  private selectionInternal = [];

  @Output()
  selectionChange = new EventEmitter<string>();

  /**
   * The HTML placeholder attribute of the textarea created by this component.
   */
  @Input()
  htmlPlaceholder: string;

  @Input()
  autoWidth: boolean;

  profile: Object;
  constants: Object;

  private focusOnNew: boolean;

  constructor(public translate: TranslateService, private profileService: ProfileService, public validation: ValidationService) {
    super();
    this.profile = profileService.profile;
    this.constants = constants;
  }

  get childValue(): any {
    return this.value;
  }

  set childValue(value) {
    this.value = value;
  }

  @Input()
  get selection(): any {
    return this.selectionInternal;
  }

  set selection(value) {
    this.selectionInternal = value;
    this.selectionChange.emit(value);
  }

  add() {
    this.selection.push({expirationDate: {}});
    setTimeout(() => {
      this.scrollIntoViewIfNeeded('identification-document-' + (this.selection.length - 1));
      }, 100);

    this.focusOnNew = true;
  }

  switchFocus(): void {
    this.focusOnNew = false;
  }

  remove(index) {
    document.getElementById('focusOnRemove-identificationDocument-' + index).focus();
    this.selection.splice(index, 1);
  }

  scrollIntoViewIfNeeded(elementId: string) {
    let top_of_element = $('#' + elementId).offset().top;
    let bottom_of_element = $('#' + elementId).offset().top + $('#' + elementId).outerHeight();
    let bottom_of_screen = ($(window).scrollTop() + window.innerHeight) - 60;
    let top_of_screen = $(window).scrollTop();

    if (!((bottom_of_screen > top_of_element) && (top_of_screen < bottom_of_element))) {
      document.getElementById(elementId).scrollIntoView();
    }
  }

  getMaxYear(): number {
    return new Date().getFullYear() + 50;
  }
}
