import {NgModule} from '@angular/core';
import {RouterModule, Routes} from '@angular/router';
import {ProfileComponent} from './profile.component';
import {ExpectationsComponent} from './expectations/expectations.component';
import {CoursesViewComponent} from '../../mooc/components/courses-view/courses-view.component';
import {RecommendedCoursesComponent} from '../../mooc/components/recommended-courses/recommended-courses.component';
import {PersonalInfoComponent} from './personal-info/personal-info.component';
import {GeneralComponent} from './personal-info/general/general.component';
import {ContactInformationComponent} from './personal-info/contact-information/contact-information.component';
import {MigrationComponent} from './personal-info/migration-information/migration-information.component';
import {SummaryComponent} from './summary/summary.component';
import {LanguageSkillsComponent} from './skills-identification/language-skills/language-skills.component';
import {EducationTrainingHistoryComponent} from './skills-identification/education-training-history/education-training-history.component';
import {LiteracySkillsComponent} from './skills-identification/literacy-skills/literacy-skills.component';
import {NumeracySkillsComponent} from './skills-identification/numeracy-skills/numeracy-skills.component';
import {DigitalSkillsComponent} from './skills-identification/digital-skills/digital-skills.component';
import {ProfessionalSkillsComponent} from './skills-identification/professional-skills/professional-skills.component';
import {AcquiredOutsideComponent} from './skills-identification/acquired-outside/acquired-outside.component';
import {OtherBasicTransversalComponent} from './skills-identification/other-basic-transversal/other-basic-transversal.component';
import {SkillsIdentificationComponent} from './skills-identification/skills-identification.component';
import {DrivingSkillsComponent} from './skills-identification/driving-skills/driving-skills.component';
import {OutcomeComponent} from './outcome/outcome.component';
import {KeySkillsComponent} from './outcome/key-skills/key-skills.component';
import {RecognitionQualificationsComponent} from './outcome/recognition-qualifications/recognition-qualifications.component';
import {ValidationLearningComponent} from './outcome/validation-learning/validation-learning.component';
import {EducationOrTrainingComponent} from './outcome/education-or-training/education-or-training.component';
import {EmploymentBusinessComponent} from './outcome/employment-business/employment-business.component';
import {FurtherInformationComponent} from './outcome/further-information/further-information.component';
import {IssuingOrganisationComponent} from './outcome/issuing-organisation/issuing-organisation.component';
import {SkipSectionGuard} from '../../service/guard/skip-section.guard';
import {ConfigurationComponent} from './configuration/configuration.component';

const routes: Routes = [
  {
    path: 'profile',
    component: ProfileComponent,
    children: [
      {
        path: '',
        redirectTo: '/profile/personal-info/general',
        pathMatch: 'full',
      },
      {
        path: 'personal-info',
        canActivate: [SkipSectionGuard],
        component: PersonalInfoComponent,
        children: [
          {
            path: '',
            redirectTo: '/profile/personal-info/general',
            pathMatch: 'full',
          },
          {
            path: 'general',
            canActivate: [SkipSectionGuard],
            component: GeneralComponent,
            data: {
              metadata: {
                title: 'profile.general.section.name',
                route: {
                  next: './personal-info/contact'
                }
              }
            }
          },
          {
            path: 'contact',
            canActivate: [SkipSectionGuard],
            component: ContactInformationComponent,
            data: {
              metadata: {
                title: 'profile.contact.section.name',
                route: {
                  previous: './personal-info/general',
                  next: './personal-info/migration'
                }
              }
            }
          },
          {
            path: 'migration',
            canActivate: [SkipSectionGuard],
            component: MigrationComponent,
            data: {
              metadata: {
                title: 'profile.migration.section.name',
                route: {
                  previous: './personal-info/contact',
                  next: './expectations'
                }
              }
            }
          }
        ]
      },
      {
        path: 'outcome',
        canActivate: [SkipSectionGuard],
        component: OutcomeComponent,
        children: [
          {
            path: '',
            redirectTo: '/profile/outcome/key-skills',
            pathMatch: 'full',
          },
          {
            path: 'key-skills',
            canActivate: [SkipSectionGuard],
            component: KeySkillsComponent,
            data: {
              metadata: {
                title: 'profile.outcome.key_skills.title',
                route: {
                  previous: './skills-identification/driving',
                  next: './outcome/recognition'
                }
              }
            }
          },
          {
            path: 'recognition',
            canActivate: [SkipSectionGuard],
            component: RecognitionQualificationsComponent,
            data: {
              metadata: {
                title: 'profile.outcome.recognition.section.name',
                route: {
                  previous: './outcome/key-skills',
                  next: './outcome/validation'
                }
              }
            }
          },
          {
            path: 'validation',
            canActivate: [SkipSectionGuard],
            component: ValidationLearningComponent,
            data: {
              metadata: {
                title: 'profile.outcome.validation.section.name',
                route: {
                  previous: './outcome/recognition',
                  next: './outcome/education-or-training'
                }
              }
            }
          },
          {
            path: 'education-or-training',
            canActivate: [SkipSectionGuard],
            component: EducationOrTrainingComponent,
            data: {
              metadata: {
                title: 'profile.outcome.education-or-training.section.name',
                route: {
                  previous: './outcome/validation',
                  next: './outcome/employment-business'
                }
              }
            }
          },
          {
            path: 'employment-business',
            canActivate: [SkipSectionGuard],
            component: EmploymentBusinessComponent,
            data: {
              metadata: {
                title: 'profile.outcome.employment-business.section.name',
                route: {
                  previous: './outcome/education-or-training',
                  next: './outcome/further-information'
                }
              }
            }
          },
          {
            path: 'further-information',
            canActivate: [SkipSectionGuard],
            component: FurtherInformationComponent,
            data: {
              metadata: {
                title: 'profile.outcome.further-information.section.name',
                route: {
                  previous: './outcome/employment-business',
                  next: './outcome/issuing-organisation'
                }
              }
            }
          },
          {
            path: 'issuing-organisation',
            canActivate: [SkipSectionGuard],
            component: IssuingOrganisationComponent,
            data: {
              metadata: {
                title: 'profile.outcome.details_issuing_organisation.title',
                route: {
                  previous: './outcome/further-information',
                  next: './outcome/mooc-search'
                }
              }
            }
          },
          {
            path: 'mooc-search',
            canActivate: [SkipSectionGuard],
            component: CoursesViewComponent,
            data: {
              metadata: {
                title: 'profile.outcome.courses.section.name',
                route: {
                  previous: './outcome/issuing-organisation',
                  next: './outcome/mooc-recommended'
                }
              }
            }
          },
          {
            path: 'mooc-recommended',
            canActivate: [SkipSectionGuard],
            component: RecommendedCoursesComponent,
            data: {
              metadata: {
                title: 'profile.outcome.recommendations.section.name',
                route: {
                  previous: './outcome/mooc-search',
                  next: './summary'
                }
              }
            }
          }
        ]
      },
      {
        path: 'skills-identification',
        canActivate: [SkipSectionGuard],
        component: SkillsIdentificationComponent,
        children: [
          {
            path: '',
            redirectTo: '/profile/skills-identification/languages',
            pathMatch: 'full',
          },
          {
            path: 'languages',
            canActivate: [SkipSectionGuard],
            component: LanguageSkillsComponent,
            data: {
              metadata: {
                title: 'profile.languages.section.name',
                route: {
                  previous: './expectations',
                  next: './skills-identification/education-and-training'
                }
              }
            }
          },
          {
            path: 'education-and-training',
            canActivate: [SkipSectionGuard],
            component: EducationTrainingHistoryComponent,
            data: {
              metadata: {
                title: 'profile.skills_id.education_training.section.name',
                route: {
                  previous: './skills-identification/languages',
                  next: './skills-identification/literacy'
                }
              }
            }
          },
          {
            path: 'literacy',
            canActivate: [SkipSectionGuard],
            component: LiteracySkillsComponent,
            data: {
              metadata: {
                title: 'profile.literacy.section.name',
                route: {
                  previous: './skills-identification/education-and-training',
                  next: './skills-identification/numeracy'
                }
              }
            }
          },
          {
            path: 'numeracy',
            canActivate: [SkipSectionGuard],
            component: NumeracySkillsComponent,
            data: {
              metadata: {
                title: 'profile.numeracy.section.name',
                route: {
                  previous: './skills-identification/literacy',
                  next: './skills-identification/digital'
                }
              }
            }
          },
          {
            path: 'digital',
            canActivate: [SkipSectionGuard],
            component: DigitalSkillsComponent,
            data: {
              metadata: {
                title: 'profile.skills_id.digital_skills.section.name',
                route: {
                  previous: './skills-identification/numeracy',
                  next: './skills-identification/professional'
                }
              }
            }
          },
          {
            path: 'professional',
            canActivate: [SkipSectionGuard],
            component: ProfessionalSkillsComponent,
            data: {
              metadata: {
                title: 'profile.skills_id.professional_skills.section.name',
                route: {
                  previous: './skills-identification/digital',
                  next: './skills-identification/acquired-outside'
                }
              }
            }
          },
          {
            path: 'acquired-outside',
            canActivate: [SkipSectionGuard],
            component: AcquiredOutsideComponent,
            data: {
              metadata: {
                title: 'profile.skills_id.outside_skills.section.name',
                route: {
                  previous: './skills-identification/professional',
                  next: './skills-identification/other-basic-transversal'
                }
              }
            }
          },
          {
            path: 'other-basic-transversal',
            canActivate: [SkipSectionGuard],
            component: OtherBasicTransversalComponent,
            data: {
              metadata: {
                title: 'profile.skills_id.other_basic_transversal_skills.section.name',
                route: {
                  previous: './skills-identification/acquired-outside',
                  next: './skills-identification/driving'
                }
              }
            }
          },
          {
            path: 'driving',
            canActivate: [SkipSectionGuard],
            component: DrivingSkillsComponent,
            data: {
              metadata: {
                title: 'profile.driving.section.name',
                route: {
                  previous: './skills-identification/other-basic-transversal',
                  next: './outcome/key-skills'
                }
              }
            }
          }
        ]
      },
      {
        path: 'summary',
        canActivate: [SkipSectionGuard],
        component: SummaryComponent,
        data: {
          metadata: {
            title: 'step.summary',
            printable: true,
            route: {
              previous: './outcome/mooc-recommended'
            }
          }
        }
      },
      {
        path: 'expectations',
        canActivate: [SkipSectionGuard],
        component: ExpectationsComponent,
        data: {
          metadata: {
            title: 'step.expectations',
            route: {
              previous: './personal-info/migration',
              next: './skills-identification/languages'
            }
          }
        }
      },
      {
        path: 'configuration',
        component: ConfigurationComponent,
        data: {
          metadata: {
            title: 'Configuration',
          }
        }
      }
    ]
  }
];

@NgModule({
  imports: [
    RouterModule.forChild(routes)
  ],
  exports: [
    RouterModule
  ]
})
export class ProfileRoutingModule {
}
