import {NgModule} from '@angular/core';
import {FormsModule} from '@angular/forms';
import {ProfileRoutingModule} from './profile-routing.module';
import {ProfileComponent} from './profile.component';
import {SharedModule} from '../../shared.module';
import {ProfileService} from './profile.service';
import {NgbDateISOParserFormatter} from '@ng-bootstrap/ng-bootstrap/datepicker/ngb-date-parser-formatter';
import {ExpectationsComponent} from './expectations/expectations.component';
import {AttachmentService} from '../../service/data/attachment.service';
import {SummaryExpectationsComponent} from './summary/expectations/expectations.component';
import {SummaryOverallAppraisalComponent} from './summary/overall-appraisal/overall-appraisal.component';
import {SummaryPersonalInformationComponent} from './summary/personal-information/personal-information.component';
import {SummaryDigitalSkillsComponent} from './summary/skills-identification/digital-skills/digital-skills.component';
import {SummaryDrivingSkillsComponent} from './summary/skills-identification/driving-skills/driving-skills.component';
import {SummaryEducationTrainingComponent} from './summary/skills-identification/education-training/education-training.component';
import {SummaryLanguageSkillsComponent} from './summary/skills-identification/language-skills/language-skills.component';
import {SummaryLiteracySkillsComponent} from './summary/skills-identification/literacy-skills/literacy-skills.component';
import {SummaryNumeracySkillsComponent} from './summary/skills-identification/numeracy-skills/numeracy-skills.component';
import {SummaryOtherBasicTransversalSkillsComponent} from './summary/skills-identification/other-basic-transversal-skills/other-basic-transversal-skills.component';
import {SummaryProfessionalSkillsComponent} from './summary/skills-identification/professional-skills/professional-skills.component';
import {SummarySkillsIdentificationComponent} from './summary/skills-identification/skills-identification.component';
import {SummaryAcquireOutsideSkillsComponent} from './summary/skills-identification/acquire-outside-skills/acquire-outside-skills.component';
import {ProfilePictureModal} from './header/header-profile/header-profile-image/profile-picture-modal/profile-picture-modal.component';
import {HeaderProfileImageComponent} from './header/header-profile/header-profile-image/header-profile-image.component';
import {HeaderComponent} from './header/header.component';
import {HeaderActionBarComponent} from './header/header-action-bar/header-action-bar.component';
import {HeaderProfileComponent} from './header/header-profile/header-profile.component';
import {AttachmentComponent} from './field/attachment/attachment.component';
import {CountryComponent} from './field/country/country.component';
import {MultiCountryComponent} from './field/multi-country/multi-country.component';
import {IscedFoetComponent} from './field/isced-foet/isced-foet.component';
import {MultiIscedComponent} from './field/multi-isced/multi-isced.component';
import {MultiLanguageComponent} from './field/multi-language/multi-language.component';
import {LanguageComponent} from './field/language/language.component';
import {NaceComponent} from './field/nace/nace.component';
import {MultiNaceComponent} from './field/multi-nace/multi-nace.component';
import {EscoComponent} from './field/esco/esco.component';
import {MultiEscoComponent} from './field/multi-esco/multi-esco.component';
import {NumberComponent} from './field/number/number.component';
import {DatePickerComponent} from './field/date-picker/date-picker.component';
import {SplitEmailComponent} from './field/split-email/split-email.component';
import {MultiSplitMailComponent} from './field/multi-split-mail/multi-split-mail.component';
import {CheckboxComponent} from './field/checkbox/checkbox.component';
import {DropdownComponent} from './field/dropdown/dropdown.component';
import {RatingComponent} from './field/rating/rating.component';
import {RadioComponent} from './field/radio/radio.component';
import {SplitPhoneNumberComponent} from './field/split-phone-number/split-phone-number.component';
import {MultiSplitPhoneNumberComponent} from './field/multi-split-phone-number/multi-split-phone-number.component';
import {KeyValueAsTextComponent} from './field/key-value-as-text/key-value-as-text.component';
import {CountryAsTextComponent} from './field/country-as-text/country-as-text.component';
import {LanguageAsTextComponent} from './field/language-as-text/language-as-text.component';
import {EscoOccupationAsTextComponent} from './field/esco-occupation-as-text/esco-occupation-as-text.component';
import {FreeTextareaComponent} from './field/free-textarea/free-textarea.component';
import {RatingDigitalSkillsComponent} from './field/rating-digital-skills/rating-digital-skills.component';
import {EscoSkillAsTextComponent} from './field/esco-skill-as-text/esco-skill-as-text.component';
import {CheckboxGroupAsTextComponent} from './field/checkbox-group-as-text/checkbox-group-as-text.component';
import {IscedFoetAsTextComponent} from './field/isced-foet-as-text/isced-foet-as-text.component';
import {RatingAsTextComponent} from './field/rating-as-text/rating-as-text.component';
import {BooleanAsTextComponent} from './field/boolean-as-text/boolean-as-text.component';
import {NaceAsTextComponent} from './field/nace-as-text/nace-as-text.component';
import {PersonalInfoComponent} from './personal-info/personal-info.component';
import {GeneralComponent} from './personal-info/general/general.component';
import {ContactInformationComponent} from './personal-info/contact-information/contact-information.component';
import {MigrationComponent} from './personal-info/migration-information/migration-information.component';
import {IdentificationDocument} from './personal-info/general/identification-document/identification-document.component';
import {SummaryComponent} from './summary/summary.component';
import {SummarySectionComponent} from './summary/summary-section/summary-section.component';
import {PersonalInformationGeneralComponent} from './summary/personal-information/personal-information-general/personal-information-general.component';
import {SummaryRowComponent} from './summary/summary-row/summary-row.component';
import {PersonalInformationIdentificationDocumentsComponent} from './summary/personal-information/personal-information-identification-documents/personal-information-identification-documents.component';
import {PersonalInformationContactInformationComponent} from './summary/personal-information/personal-information-contact-information/personal-information-contact-information.component';
import {PersonalInformationMigrationInformationComponent} from './summary/personal-information/personal-information-migration-information/personal-information-migration-information.component';
import {OverallAppraisalStrengthsComponent} from './summary/overall-appraisal/overall-appraisal-strengths/overall-appraisal-strengths.component';
import {OverallAppraisalRecognitionComponent} from './summary/overall-appraisal/overall-appraisal-recognition/overall-appraisal-recognition.component';
import {OverallAppraisalValidationComponent} from './summary/overall-appraisal/overall-appraisal-validation/overall-appraisal-validation.component';
import {OverallAppraisalTrainingComponent} from './summary/overall-appraisal/overall-appraisal-training/overall-appraisal-training.component';
import {OverallAppraisalWorkComponent} from './summary/overall-appraisal/overall-appraisal-work/overall-appraisal-work.component';
import {OverallAppraisalGuidanceComponent} from './summary/overall-appraisal/overall-appraisal-guidance/overall-appraisal-guidance.component';
import {OverallAppraisalOrganisationComponent} from './summary/overall-appraisal/overall-appraisal-organisation/overall-appraisal-organisation.component';
import {SummaryRowDateComponent} from './summary/summary-row/summary-row-date/summary-row-date.component';
import {SummaryRowTitleComponent} from './summary/summary-row/summary-row-title/summary-row-title.component';
import {SummaryRowPhoneComponent} from './summary/summary-row/summary-row-phone/summary-row-phone.component';
import {SummaryRowEmailComponent} from './summary/summary-row/summary-row-email/summary-row-email.component';
import {SummaryRowDurationComponent} from './summary/summary-row/summary-row-duration/summary-row-duration.component';
import {SummaryRowKeyValueAsTextComponent} from './summary/summary-row/summary-row-key-value-as-text/summary-row-key-value-as-text.component';
import {SummaryRowMultiStringComponent} from './summary/summary-row/summary-row-multi-string/summary-row-multi-string.component';
import {SummaryRowCountryAsTextComponent} from './summary/summary-row/summary-row-country-as-text/summary-row-country-as-text.component';
import {SummaryRowBooleanAsTextComponent} from './summary/summary-row/summary-row-boolean-as-text/summary-row-boolean-as-text.component';
import {SummaryRowLanguageAsTextComponent} from './summary/summary-row/summary-row-language-as-text/summary-row-language-as-text.component';
import {SummaryRowIscedFoetAsTextComponent} from './summary/summary-row/summary-row-isced-foet-as-text/summary-row-isced-foet-as-text.component';
import {SummaryRowNaceAsTextComponent} from './summary/summary-row/summary-row-nace-as-text/summary-row-nace-as-text.component';
import {SummaryRowEscoOccupationAsTextComponent} from './summary/summary-row/summary-row-esco-occupation-as-text/summary-row-esco-occupation-as-text.component';
import {SummaryRowEscoSkillAsTextComponent} from './summary/summary-row/summary-row-esco-skill-as-text/summary-row-esco-skill-as-text.component';
import {SummaryRowRatingAsTextComponent} from './summary/summary-row/summary-row-rating-as-text/summary-row-rating-as-text.component';
import {SummaryRowCheckboxGroupAsTextComponent} from './summary/summary-row/summary-row-checkbox-group-as-text/summary-row-checkbox-group-as-text.component';
import {SummaryRowStringComponent} from './summary/summary-row/summary-row-string/summary-row-string.component';
import {MultiFreeTextComponent} from './field/multi-free-text/multi-free-text.component';
import {LanguageSkillsComponent} from './skills-identification/language-skills/language-skills.component';
import {EducationTrainingHistoryComponent} from './skills-identification/education-training-history/education-training-history.component';
import {LiteracySkillsComponent} from './skills-identification/literacy-skills/literacy-skills.component';
import {NumeracySkillsComponent} from './skills-identification/numeracy-skills/numeracy-skills.component';
import {DigitalSkillsComponent} from './skills-identification/digital-skills/digital-skills.component';
import {ProfessionalSkillsComponent} from './skills-identification/professional-skills/professional-skills.component';
import {AcquiredOutsideComponent} from './skills-identification/acquired-outside/acquired-outside.component';
import {OtherBasicTransversalComponent} from './skills-identification/other-basic-transversal/other-basic-transversal.component';
import {SkillsIdentificationComponent} from './skills-identification/skills-identification.component';
import {DrivingSkillsComponent} from './skills-identification/driving-skills/driving-skills.component';
import {OutcomeComponent} from './outcome/outcome.component';
import {KeySkillsComponent} from './outcome/key-skills/key-skills.component';
import {RecognitionQualificationsComponent} from './outcome/recognition-qualifications/recognition-qualifications.component';
import {ValidationLearningComponent} from './outcome/validation-learning/validation-learning.component';
import {EducationOrTrainingComponent} from './outcome/education-or-training/education-or-training.component';
import {EmploymentBusinessComponent} from './outcome/employment-business/employment-business.component';
import {FurtherInformationComponent} from './outcome/further-information/further-information.component';
import {IssuingOrganisationComponent} from './outcome/issuing-organisation/issuing-organisation.component';
import {MenuComponent} from './menu/menu.component';
import {RowFooterComponent} from './skills-identification/other-basic-transversal/row-footer/row-footer.component';
import {ConsentModalComponent} from './modal/consent-modal/consent-modal.component';
import {ConsentComponent} from './modal/consent-modal/consent/consent.component';
import {ClearProfileModalComponent} from './modal/clear-profile-modal/clear-profile-modal.component';
import {ConfigurationComponent} from './configuration/configuration.component';
import {EclMessageInfoComponent} from './common/ecl-message-info/ecl-message-info.component';
import {Menus} from './configuration/configuration-menus/configuration-menus.component';
import {ConfigurationService} from '../../service/configuration/configuration.service';
import {ClearConfigurationModalComponent} from './modal/clear-configuration-modal/clear-configuration-modal.component';
import {DateFormatPipe} from './configuration/dateformat.pipe';
import {ImportConfigurationModalComponent} from './modal/import-configuration-modal/import-configuration-modal.component';


@NgModule({
  imports: [
    SharedModule,
    FormsModule,
    ProfileRoutingModule
  ],
  declarations: [
    ProfileComponent,
    PersonalInfoComponent,
    OutcomeComponent,
    SkillsIdentificationComponent,
    GeneralComponent,
    LanguageSkillsComponent,
    EducationTrainingHistoryComponent,
    ExpectationsComponent,
    DrivingSkillsComponent,
    SummaryComponent,
    KeySkillsComponent,
    IssuingOrganisationComponent,
    CheckboxComponent,
    CheckboxGroupAsTextComponent,
    DropdownComponent,
    EscoComponent,
    EscoOccupationAsTextComponent,
    EscoSkillAsTextComponent,
    FreeTextareaComponent,
    NumberComponent,
    RatingComponent,
    RatingAsTextComponent,
    CountryComponent,
    CountryAsTextComponent,
    IscedFoetComponent,
    IscedFoetAsTextComponent,
    NaceComponent,
    NaceAsTextComponent,
    LanguageComponent,
    LanguageAsTextComponent,
    BooleanAsTextComponent,
    KeyValueAsTextComponent,
    ConsentComponent,
    HeaderProfileImageComponent,
    ProfilePictureModal,
    MigrationComponent,
    ContactInformationComponent,
    LiteracySkillsComponent,
    NumeracySkillsComponent,
    DigitalSkillsComponent,
    ProfessionalSkillsComponent,
    AcquiredOutsideComponent,
    OtherBasicTransversalComponent,
    RecognitionQualificationsComponent,
    ValidationLearningComponent,
    EducationOrTrainingComponent,
    EmploymentBusinessComponent,
    FurtherInformationComponent,
    MultiFreeTextComponent,
    MultiCountryComponent,
    IdentificationDocument,
    SplitPhoneNumberComponent,
    MultiSplitPhoneNumberComponent,
    SplitEmailComponent,
    MultiSplitMailComponent,
    RatingDigitalSkillsComponent,
    AttachmentComponent,
    MultiLanguageComponent,
    MultiIscedComponent,
    MultiNaceComponent,
    MultiEscoComponent,
    RowFooterComponent,
    SummaryExpectationsComponent,
    SummaryOverallAppraisalComponent,
    SummaryPersonalInformationComponent,
    SummarySkillsIdentificationComponent,
    SummaryEducationTrainingComponent,
    SummaryAcquireOutsideSkillsComponent,
    SummaryOtherBasicTransversalSkillsComponent,
    SummaryDigitalSkillsComponent,
    SummaryDrivingSkillsComponent,
    SummaryLanguageSkillsComponent,
    SummaryLiteracySkillsComponent,
    SummaryNumeracySkillsComponent,
    SummaryProfessionalSkillsComponent,
    DatePickerComponent,
    HeaderComponent,
    HeaderActionBarComponent,
    HeaderProfileComponent,
    SummarySectionComponent,
    PersonalInformationGeneralComponent,
    SummaryRowComponent,
    PersonalInformationIdentificationDocumentsComponent,
    PersonalInformationContactInformationComponent,
    PersonalInformationMigrationInformationComponent,
    OverallAppraisalStrengthsComponent,
    OverallAppraisalRecognitionComponent,
    OverallAppraisalValidationComponent,
    OverallAppraisalTrainingComponent,
    OverallAppraisalWorkComponent,
    OverallAppraisalGuidanceComponent,
    OverallAppraisalOrganisationComponent,
    SummaryRowDateComponent,
    SummaryRowTitleComponent,
    SummaryRowPhoneComponent,
    SummaryRowEmailComponent,
    SummaryRowDurationComponent,
    SummaryRowKeyValueAsTextComponent,
    SummaryRowMultiStringComponent,
    SummaryRowCountryAsTextComponent,
    SummaryRowBooleanAsTextComponent,
    SummaryRowLanguageAsTextComponent,
    SummaryRowIscedFoetAsTextComponent,
    SummaryRowNaceAsTextComponent,
    SummaryRowEscoOccupationAsTextComponent,
    SummaryRowEscoSkillAsTextComponent,
    SummaryRowRatingAsTextComponent,
    SummaryRowCheckboxGroupAsTextComponent,
    SummaryRowStringComponent,
    MenuComponent,
    SummaryProfessionalSkillsComponent,
    ConsentModalComponent,
    ClearProfileModalComponent,
    ClearConfigurationModalComponent,
    ConfigurationComponent,
    Menus,
    EclMessageInfoComponent,
    DateFormatPipe,
    ImportConfigurationModalComponent,
    RadioComponent
  ],
  entryComponents: [
    ProfilePictureModal,
    ConsentModalComponent,
    ClearProfileModalComponent,
    ClearConfigurationModalComponent,
    ImportConfigurationModalComponent
  ],
  providers: [
    ProfileService,
    AttachmentService,
    NgbDateISOParserFormatter,
    ConfigurationService,
    DateFormatPipe
  ]
})
export class ProfileModule {
}
