import {AfterViewInit, Component, OnInit, ViewChild} from '@angular/core';
import {ProfileService} from '../profile.service';
import {SummarySectionComponent} from './summary-section/summary-section.component';
import {MenuItem} from '../menu/menu-item';
import {RouteService} from '../../../service/navigation/route.service';

export let summary = new MenuItem('step.summary',
  true, true, 'summary', false, 'summary');

@Component({
  selector: 'app-summary',
  templateUrl: './summary.component.html',
  styleUrls: [
    './summary.component.less'
  ]
})
export class SummaryComponent implements OnInit, AfterViewInit {

  isPersonalInformationEmpty: boolean;
  isPersonalInformationSectionEnable: boolean;
  @ViewChild('personalInformationSummarySection') personalInformationSummarySection: SummarySectionComponent;

  isExpectationsEmpty: boolean;
  isExpectationsSectionEnable: boolean;
  @ViewChild('expectationsSummarySection') expectationsSummarySection: SummarySectionComponent;

  isSkillsIdentificationEmpty: boolean;
  isSkillsIdentificationSectionEnable: boolean;
  @ViewChild('skillsIdentificationSummarySection') skillsIdentificationSummarySection: SummarySectionComponent;

  isOverallEmpty: boolean;
  isOverallSectionEnable: boolean;
  @ViewChild('overallSummarySection') overallSummarySection: SummarySectionComponent;

  constructor(public profileService: ProfileService,
              public routeService: RouteService) { }

  ngOnInit() {
    this.isPersonalInformationSectionEnable = this.isMenuEnabled('step.personal');
    this.isExpectationsSectionEnable = this.isMenuEnabled('step.expectations');
    this.isSkillsIdentificationSectionEnable = this.isMenuEnabled('step.skills');
    this.isOverallSectionEnable = this.isMenuEnabled('step.outcome');
  }

  ngAfterViewInit(): void {
    if (this.profileService.showEmpty) {
      this.switchChange();
    }
  }

  isMenuEnabled(menuIndex: string): boolean {
    return this.routeService.menuList.get(menuIndex).isEnabled;
  }

  switchChange() {
    if (this.isPersonalInformationSectionEnable
      && (this.isPersonalInformationEmpty || !this.personalInformationSummarySection.isExpended)) {
      this.personalInformationSummarySection.handleClickOnToggle(this.profileService.showEmpty);
    }
    if (this.isExpectationsSectionEnable
      && (this.isExpectationsEmpty || !this.expectationsSummarySection.isExpended)) {
      this.expectationsSummarySection.handleClickOnToggle(this.profileService.showEmpty);
    }
    if (this.isSkillsIdentificationSectionEnable
      && (this.isSkillsIdentificationEmpty || !this.skillsIdentificationSummarySection.isExpended)) {
      this.skillsIdentificationSummarySection.handleClickOnToggle(this.profileService.showEmpty);
    }
    if (this.isOverallSectionEnable
      && (this.isOverallEmpty || !this.overallSummarySection.isExpended)) {
      this.overallSummarySection.handleClickOnToggle(this.profileService.showEmpty);
    }
  }

}
