import {Component, ChangeDetectorRef} from '@angular/core';
import {User} from '../../../service/data/user';
import {CloseGuard, ModalComponent, DialogRef} from 'angular2-modal';
import {BSModalContext} from 'angular2-modal/plugins/bootstrap';
import {ValidationService} from '../../../service/validation/validation.service';
import {AuthService} from '../../../service/security/auth.service';

export class UserEditModalContext extends BSModalContext {
  constructor(public user: User) { super(); }
}

@Component({
  selector: 'app-user-edit',
  templateUrl: './user-edit.modal.component.html',
  styleUrls: []
})
export class UserEditModal implements CloseGuard, ModalComponent<UserEditModalContext> {

  context: UserEditModalContext;
  user: User;

  constructor(private changeDetectorRef: ChangeDetectorRef,
              public dialog: DialogRef<UserEditModalContext>,
              public validation: ValidationService,
              private authService: AuthService) {
    this.context = dialog.context;
    this.user = this.context.user;
    dialog.setCloseGuard(this);
  }

  ngAfterViewChecked() {
    this.changeDetectorRef.detectChanges();
  }

  /**
   * Confirm modal.
   */
  confirm(): void {
    this.dialog.close(this.user);
  }

  /**
   * Cancel modal.
   */
  cancel(): void {
    this.dialog.dismiss();
  }

  beforeDismiss(): boolean {
    return false;
  }

  beforeClose(): boolean {
    return false;
  }

  isRoot(): boolean {
    return (this.authService.getCurrentUser().roles.indexOf('ROOT') > -1);
  }

  isAdmin(): boolean {
    return (this.authService.getCurrentUser().roles.indexOf('ADMIN') > -1);
  }

  isCurrentUser(): boolean {
    return (this.authService.getCurrentUser().id === this.user.id);
  }

  setRole(role: string, user: User): void {
    let roleIndex = user.roles.indexOf(role);
    if (roleIndex > -1) {
      user.roles.splice(roleIndex, 1);
    } else {
      user.roles.push(role);
    }
  }
}
