import {Injectable} from '@angular/core';
import {NgbDatepickerI18n} from '@ng-bootstrap/ng-bootstrap';
import {TranslateService, LanguageChangeEvent} from '../service/translate/translate.service';
import {Subscription} from 'rxjs';

/**
 * i18n provider for the datepicker
 */
@Injectable()
export class CustomDatepickerI18nService extends NgbDatepickerI18n {

  private onPrimaryLanguageChange: Subscription;

  private i18nValues = {
    weekdays: [],
    months: []
  };

  constructor(private translate: TranslateService) {
    super();

    this.onPrimaryLanguageChange = translate.onPrimaryLanguageChange.subscribe((langChangeEvent: LanguageChangeEvent) => {
      this.changeLang();
    });

    this.changeLang();
  }

  getWeekdayName(weekday: number): string {
    return this.i18nValues.weekdays[weekday - 1];
  }

  getMonthName(month: number): string {
    return this.i18nValues.months[month - 1];
  }

  private changeLang(): void {

    for (let i = 1; i <= 7; i++) {
      this.translateText('weekdays', i);
    }

    for (let i = 1; i <= 12; i++) {
      this.translateText('months', i);
    }

  }

  private translateText(component: string, index: number): void {
    this.translate.translate('component.datepicker.' + component + '.' + index, this.translate.getPrimaryLanguage()).subscribe((v) => {
      this.i18nValues[component][index - 1] = v;
    });
  }

}
