import {Component, EventEmitter, Input, OnInit, Output} from '@angular/core';
import {IdTextElement} from '../../../model/id-text-element';
import {Preconditions} from '../../../util/preconditions';
import {AttributeModel} from '../../../model/attribute-model';

@Component({
  selector: 'mooc-course-filter',
  templateUrl: './course-filter.component.html',
  styleUrls: ['./course-filter.component.less']
})
export class CourseFilterComponent implements OnInit {

  @Input() elements: IdTextElement[] = [];
  @Input() currentElements: IdTextElement[];
  @Input() multiple = true;

  @Input() placeholder: string;
  @Input() labelKey: string;
  @Input() firstLabel = false;

  @Input() editMode = true;
  @Output() onChange = new EventEmitter();

  @Input() key: string;
  @Input() model: AttributeModel;

  @Input()
  eventLoading: EventEmitter<any>;

  ngOnInit() {
    Preconditions.checkNotNull(this.key, 'key was null');
  }

  getValue(): any {
    return this.model.getProperty(this.key);
  }

  setValue(value: string[]): void {
    if (this.arrayEquals(this.model.getProperty(this.key), value)) {
      return;
    }
    this.model.setProperty(this.key, value);

    this.onChange.emit();
  }

  arrayEquals(a1: string[], a2: string[]): boolean {
    if (!a1 && a2 || a1 && !a2) {
      return false;

    } else if (!a1 && !a2) {
      return true;
    }

    return a1.length === a2.length && a1.every((v, i) => v === a2[i]);
  }
}
