import {
  AfterViewInit,
  Component,
  ContentChild,
  ElementRef,
  EventEmitter,
  Input,
  OnChanges,
  OnDestroy,
  OnInit,
  Output,
  SimpleChanges,
  TemplateRef,
  ViewEncapsulation
} from '@angular/core';
import {IdTextElement} from '../../../../model/id-text-element';

declare var $: any;

@Component({
  selector: 'mooc-select2',
  templateUrl: './select2.component.html',
  styleUrls: ['./select2.component.less'],
  encapsulation: ViewEncapsulation.None,
})
export class Select2Component implements OnInit, OnChanges, OnDestroy, AfterViewInit {

  @Input() options: IdTextElement[];

  @Input() disabled = false;
  @Input() placeholder = '';


  @ContentChild(TemplateRef)
  private template: TemplateRef<any>;

  private _selectedValues: string[] = [];
  private _selectedIdTextElements: IdTextElement[] = [];

  @Input() set selectedValues(values: string[]) {
    this._selectedValues = values;

    if (this.select2) {
      this.select2.select2('val', [this._selectedValues]);
    }
  }

  @Input() set selectedIdTextElements(values: IdTextElement[]) {
    this._selectedValues = values.map(el => el.id);
    this._selectedIdTextElements = values;

    if (this.select2) {
      this.select2.select2('val', [this._selectedValues]);
    }
  }

  @Output() selectedValuesEmitter = new EventEmitter<string[]>();
  @Output() selectedIdTextElementsEmitter = new EventEmitter<IdTextElement[]>();

  @Input()
  eventLoading: EventEmitter<any>;

  select2: any;
  private el: ElementRef;

  constructor(el: ElementRef) {
    this.el = el;
  }

  ngOnInit() {
  }

  ngAfterViewInit() {
    if (this.needsInit()) {
      this.initSelect2();
    }
    this.select2.select2('val', [this._selectedValues]);

    if (this.eventLoading !== undefined) {
      this.eventLoading.subscribe(response => {
        this.options = response;
        this.select2.select2('destroy');
        this.initSelect2();
        this.select2.select2('val', [this._selectedValues]);
      });
    }
  }

  ngOnChanges(changes: SimpleChanges) {
    if (this.needsInit()) {
      this.initSelect2();
    } else if (changes['options']) {
      // the next line is commented to avoid the bug when the languages load
      // this.select2.empty();
      this.select2.select2({
        allowClear: true,
        data: this.options,
        placeholder: this.placeholder,
        width: '100%',
        matcher: this.matchCustom
      });
    }
    this.select2.trigger('change');
  }

  needsInit(): boolean {
    return !this.select2 || !this.select2.hasClass('select2-hidden-accessible');
  }

  initSelect2(): void {
    this.select2 = $(this.el.nativeElement)
      .find('select').select2({
        allowClear: true,
        data: this.options,
        placeholder: this.placeholder,
        width: '100%',
        matcher: this.matchCustom
      })
      .on('select2:select', (event) => {
        const data = event.params.data;
        this._selectedValues = this.select2.val();
        this._selectedIdTextElements.push({id: data.id, text: data.text});
        this.emitChanges();
      })
      .on('select2:unselect', (event) => {
        const data = event.params.data;
        this._selectedValues = this.select2.val();
        this._selectedIdTextElements = this._selectedIdTextElements.filter(elem => elem.id !== data.id);
        this.emitChanges();
      });
  }


  private emitChanges() {
    if (this._selectedValues === null) {
      this._selectedValues = [];
    }
    this.selectedValuesEmitter.emit(this._selectedValues);
  }

  matchCustom(params, data) {
    // If there are no search terms, return all of the data
    if ($.trim(params.term) === '') {
      return data;
    }

    // Do not display the item if there is no 'text' property
    if (typeof data.text === 'undefined') {
      return null;
    }

    // match first part of the search term
    if (params.term.length < 3 && data.text.substr(0, params.term.length).toLowerCase() === params.term.toLowerCase()) {
      return data;
    }

    // check if the result includes the search term
    if (params.term.length >= 3 && data.text.toLowerCase().indexOf(params.term.toLowerCase()) > -1) {
      return data;
    }

    // Return `null` if the term should not be displayed
    return null;
  }

  ngOnDestroy() {
    this.select2.select2('destroy');
  }
}
