import {Injectable} from '@angular/core';
import {workTypes} from '../../../../constants/profile-label-keys';
import {RestCall} from '../../../service/rest-call';
import {EduLevelsHostAppToMooc} from '../../../model/EducationLevels';
import {iscedHostAppToMooc} from '../../../model/IscedObj';
import {JsonModel} from '../../../model/json-model';
import {ProfileService} from '../../../../component/profile/profile.service';
import {RestCallService} from '../../../service/rest-call.service';

@Injectable()
export class RecommendationCoursesService {

  hostCountryLang: any;
  preferredGeneral: any;
  motherTongue: string;
  otherMotherTongues: Object[];

  host = window['moocUrl'] + '';
  pre = '/moocs/recommendations/courses';

  workType = workTypes;

  constructor(private profileService: ProfileService,
              private restCallService: RestCallService) {
    // get host country language
    this.hostCountryLang = this.profileService.profile['skillsIdentification']
      ['languageSkills']['hostCountry']['code'];

    this.preferredGeneral = this.profileService.profile['skillsIdentification']
      ['languageSkills']['preferredGeneral']['code'];

    this.motherTongue = this.profileService.profile['skillsIdentification']
      ['languageSkills']['motherTongue'];
    this.otherMotherTongues = this.profileService.profile['skillsIdentification']
      ['languageSkills']['otherMotherTongue'];
  }

  getCoursesForExpectation(exp, observables: any[]) {
    if (exp['doNext'] === this.workType['followCourse']) {
      observables.push(this.searchIntegration(exp));
    }

    if (exp['doNext'] === this.workType['improveLanguage']) {
      observables.push(this.searchLanguage(exp));
    }

    if (exp['doNext'] === this.workType['undertakeEducation']) {
      observables.push(this.searchStudy(exp));
    }
  }

  private searchIntegration(expectation: any) {
    const understoodLanguages = this.fillArrayMainSecondaryByKey(this.motherTongue, this.otherMotherTongues, 'name');

    this.profileService.profile['skillsIdentification']
      ['languageSkills']['otherLanguages'].map(lang => understoodLanguages.push(lang['code']));

    if (this.hostCountryLang) {
      understoodLanguages.push(this.hostCountryLang);
    }

    if (this.preferredGeneral) {
      understoodLanguages.push(this.preferredGeneral);
    }

    const call = RestCall.builder()
      .withHost(this.host)
      .withPath(this.pre + '/integration')
      .addParams('hostCountryLanguage', this.hostCountryLang ? this.hostCountryLang : 'en')
      .addParams('understoodLanguages', understoodLanguages)
      .get();


    return this.restCallService.get(call)
    /*an array.map needed to use the json property inside the course result component*/
      .map(res => expectation['courses'] = res.json()
        .map(course => this.toJsonModel(course)));
  }

  private searchLanguage(expectation: any) {
    const mainImprove = expectation['language'];
    const otherImprove = expectation['otherImproveLanguage'];

    const languagesForImproval = this.fillArrayMainSecondaryByKey(mainImprove, otherImprove, 'name');

    const motherTongueList = this.fillArrayMainSecondaryByKey(this.motherTongue, this.otherMotherTongues, 'name');

    const call = RestCall.builder()
      .withHost(this.host)
      .withPath(this.pre + '/language')
      .addParams('language', languagesForImproval)
      .addParams('motherTongue', motherTongueList)
      .get();


    return this.restCallService.get(call)
    /*an array.map needed to convert to JsonModel */
      .map(res => expectation['courses'] = res.json()
        .map(course => this.toJsonModel(course)));
  }

  private searchStudy(expectation: any) {
    const educationLevel = EduLevelsHostAppToMooc[expectation.educationType];
    const mainStudyField = expectation['undertakeEducationStudyField'];
    const otherStudyFields = expectation['otherUndertakeEducationStudyFields'];

    const studyFields = this.fillArrayMainSecondaryByKey(mainStudyField, otherStudyFields, 'name').map(field => iscedHostAppToMooc[field]);

    const understoodLanguages = this.fillArrayMainSecondaryByKey(this.motherTongue, this.otherMotherTongues, 'name');
    if (this.hostCountryLang) {
      understoodLanguages.push(this.hostCountryLang);
    }
    if (this.preferredGeneral) {
      understoodLanguages.push(this.preferredGeneral);
    }

    this.profileService.profile['skillsIdentification']
      ['languageSkills']['otherLanguages'].map(lang => understoodLanguages.push(lang['code']));

    const call = RestCall.builder()
      .withHost(this.host)
      .withPath(this.pre + '/study')
      .addParams('educationLevel', educationLevel)
      .addParams('studyField', studyFields)
      .addParams('understoodLanguages', understoodLanguages)
      .get();


    return this.restCallService.get(call)
    /*an array.map needed to convert to JsonModel */
      .map(res => expectation['courses'] = res.json()
        .map(course => this.toJsonModel(course)));
  }


  private fillArrayMainSecondaryByKey(main: string, secondary: Object[], key) {
    const arr = [];
    if (main) {
      arr.push(main);
    }
    secondary.forEach(n => n[key] ? arr.push(n[key]) : '');

    return arr;
  }

  private toJsonModel(el) {
    return new JsonModel(el);
  }
}
