import {Injectable} from '@angular/core';
import {LanguageService} from '../../../../service/data/language.service';
import {IscedService} from '../../../../service/data/isced.service';

@Injectable()
export class RecommendationLabelsService {

  constructor(private languageService: LanguageService,
              private iscedService: IscedService) {
  }

  getLabelsForExpectation(exp, observables: any[]) {
    if (exp['undertakeEducationStudyField']) {
      observables.push(this.getOtherEducationStudy(exp)
      );
    }

    if (exp['otherUndertakeEducationStudyFields']) {
      exp['otherUndertakeEducationStudyFields'].forEach(field => {
        // check if user actually filled the input out
        if (field['name']) {
          observables.push(this.getEducationStudy(field, exp)
          );
        }
      });
    }

    if (exp['language']) {
      observables.push(this.getMainLanguage(exp)
      );
    }

    if (exp['otherImproveLanguage']) {
      exp['otherImproveLanguage'].forEach(field => {
        // check if user actually filled the input out
        if (field['name']) {
          observables.push(this.getOtherLanguage(field, exp)
          );
        }
      });
    }
  }

  private getOtherLanguage(field, exp) {
    return this.languageService.getLanguageByCode(field['name'])
      .map(res => {
        if (!exp['otherLang']) {
          exp['otherLang'] = [];
        }
        exp['otherLang'].push(res['values']['en']);
      });
  }

  private getMainLanguage(exp) {
    return this.languageService
      .getLanguageByCode(exp['language'])
      .map(res => {
        exp['mainLang'] = res['values']['en'];
      });
  }

  private getEducationStudy(field, exp) {
    return this.iscedService.getIscedById(field['name'])
      .map(res => {
        if (!exp['otherLabelsStudyField']) {
          exp['otherLabelsStudyField'] = [];
        }
        exp['otherLabelsStudyField'].push(res['values']['en']);
      });
  }

  private getOtherEducationStudy(exp) {
    return this.iscedService.getIscedById(exp['undertakeEducationStudyField'])
      .map(res => {
        exp['labelStudyField'] = res['values']['en'];
      });
  }

}
