import {Component, Input, OnInit} from '@angular/core';
import {MoocIconsPath} from '../../../model/MoocIconsPaths';
import {IscedObj} from '../../../model/IscedObj';
import {EducationLevels} from '../../../model/EducationLevels';
import {UtilityFunctions} from '../../../util/UtilityFunctions';
import {JsonModel} from '../../../model/json-model';
import {IdTextElement} from '../../../model/id-text-element';
import {Topics} from '../../../model/Topics';

declare var $: any;

@Component({
  selector: 'mooc-course-card',
  templateUrl: './course-card.component.html',
  styleUrls: ['./course-card.component.less']
})
export class CourseCardComponent implements OnInit {

  @Input()
  course: JsonModel;

  collapse = true;

  util: any;

  iconsPath = MoocIconsPath;

  @Input()
  languages: IdTextElement[] = [];

  topics = Topics;
  iscedObj = IscedObj;
  educationLvl = EducationLevels;

  @Input()
  selectedCourses: any[];

  constructor() {
    this.util = UtilityFunctions;
  }

  ngOnInit() {
  }

  collapsible() {
    this.collapse = !this.collapse;
  }

  private getLanguage(language: string): string {
    if (this.languages !== undefined) {
      for (let lang of this.languages) {
        if (lang['id'] === language) {
          return lang['text'];
        }
      }
    }
    return '';
  }

  selectCourse() {
    if (!this.isSelected()) {
      this.selectedCourses.push(
        {
          'uri' : this.course['json']['uri'],
          'name' : this.course['json']['name']
        }
      );
    } else {
      const index = this.selectedCourses.findIndex(
        elm => elm['uri'] === this.course.getProperty('uri')
      );
      this.selectedCourses.splice(index, 1);
    }
  }

  isSelected(): boolean {
    const index = this.selectedCourses.findIndex(
      elm => elm['uri'] === this.course.getProperty('uri')
    );
    return index !== -1;
  }

  getLanguagesAsString(): string {
    let result = '';
    this.course.getProperty('languages')
      .forEach(uriLanguage => result += this.getLanguage(uriLanguage) + ', ');
    return result.slice(0, -2);
  }

  getIscedsAsStringArray(): string[] {
    let result = [];
    this.course.getProperty('isceds')
      .forEach(uriIsced => result.push(this.util.codeFromUri(uriIsced) + ' - ' + this.iscedObj[uriIsced]));
    return result;
  }

  getEducationLevelAsString(): string {
    return this.util.codeFromUri(this.course.getProperty('educationLevel')).toUpperCase()
      + ' - '
      + this.educationLvl[this.course.getProperty('educationLevel')];
  }

  getSubtitlesAsStringArray(): string[] {
    let result = [];
    let subtitles = this.course.getProperty('subtitles');
    if (subtitles) {
      subtitles.forEach(uriLanguage => result.push(this.getLanguage(uriLanguage)));
    }
    return result;
  }

}
