import {
  Component,
  ElementRef,
  EventEmitter,
  Input,
  OnInit,
  Output,
  ViewChild,
  ViewEncapsulation
} from '@angular/core';
import {TranslatePipe} from '../../../../../pipe/translate.pipe';
import {ProfileService} from '../../../../../component/profile/profile.service';
import {ValidationService} from '../../../../../service/validation/validation.service';

declare var $: any;


@Component({
  selector: 'mooc-email-select',
  templateUrl: './email-select.component.html',
  styleUrls: ['../../../courses-view/course-filter/select2/select2.component.less', './email-select.component.less'],
  encapsulation: ViewEncapsulation.None,
  providers: [TranslatePipe]
})

export class EmailSelectComponent implements OnInit {

  @Input() theme: string;

  @Input() id;

  @Output() selectedValuesEmitter = new EventEmitter<string[]>();

  @ViewChild('input') input: ElementRef;

  selectedValues: any[] = [];

  private el: ElementRef;

  constructor(el: ElementRef,
              public profileService: ProfileService,
              public validationService: ValidationService) {
    this.el = el;
  }

  ngOnInit() {
    this.selectedValues = this.profileService.emails;
    this.selectedValuesEmitter.emit(this.selectedValues);
  }

  onKeyUp(event: any, data: string) {
    // false if a space char is not entered at the end of the data
    let lastCharIsOk = true;

    if (event.key === ' ' || event.key === 'Spacebar') {
      if (data.replace(' ', '') !== data.slice(0, -1)) {
        // the last char is not a space char
        lastCharIsOk = false;
      }

      // remove the empty char
      data = data.replace(' ', '');
      this.input.nativeElement.value = data;
    }

    if ((event.key === 'Enter' || event.key === ' ' || event.key === 'Spacebar') && lastCharIsOk) {
      this.checkData(data);
    }
  }

  loseFocus(data: string) {
    this.checkData(data);
  }

  private checkData(data: string) {
    const dataAlreadyExist = this.selectedValues.some(
      email => email === data
    );

    if (this.validationService.mailRegex.test(data) && !dataAlreadyExist) {
      this.addData(data);
    }
  }

  private addData(data: string) {
    this.selectedValues.push(data);
    this.input.nativeElement.value = '';
    this.emitChanges();
  }

  editData(data: string) {
    // remove the data from the list of tags
    this.removeData(data);

    // add the data to the input
    this.input.nativeElement.value = data;

    // switch the focus for ie
    this.input.nativeElement.focus();
  }

  removeData(data: string) {
    this.selectedValues = this.selectedValues.filter(
      email => email !== data
    );
    this.emitChanges();
  }

  private emitChanges() {
    if (this.selectedValues === null) {
      this.selectedValues = [];
    }
    this.selectedValuesEmitter.emit(this.selectedValues);
  }

  clear() {
    this.selectedValues = [];
  }

}
