import {Component, Input, OnInit, ViewChild} from '@angular/core';
import {EmailSelectComponent} from './email-select/email-select.component';
import {RestCallService} from '../../../service/rest-call.service';
import {RestCall} from '../../../service/rest-call';
import {environment} from '../../../../../environments/environment';

@Component({
  selector: 'mooc-email',
  templateUrl: './email.component.html',
  styleUrls: ['./email.component.css']
})
export class EmailComponent implements OnInit {

  @Input() label: string;
  @Input() show = true;
  @Input() id;

  @ViewChild(EmailSelectComponent) emailComponent: EmailSelectComponent;

  @Input()
  selectedCourses: any[];

  sending = false;
  sentSuccess = false;

  selected: string[] = [];

  constructor(private restCallService: RestCallService) { }

  ngOnInit() {
  }

  onSelectedValues(vals) {
    this.selected = vals;
  }

  emailClick () {
    const courses = this.selectedCourses
      .map(course => course['uri'].replace('http://data.europa.eu/lo/course/', ''));
    if (this.selected.length === 0 || courses.length === 0) {
      return;
    }

    this.sending = true;

    this.restCallService.post(
      RestCall.builder()
        .withHost(window['moocUrl'])
        .withPath('/courses/mail/send')
        .addParams('courseId', courses)
        .addParams('address', this.selected).get())
      .catch(err => {
        console.error(err);
        return err;
      })
      .subscribe(() => {
        this.selectedCourses.splice(this.selectedCourses.length * -1);
        this.emailComponent.clear();
        this.sending = false;
        this.sentSuccess = true;
        this.showThenHide();

      });
  }

  showThenHide() {
    setTimeout(() => {
      this.sentSuccess = false;
    }, 2000);

  }

  cantSendMail(): boolean {
    return this.selected.length === 0 || this.selectedCourses.length === 0 || this.sending;
  }
}
