import {Preconditions} from '../util/preconditions';
import {AttributeModel} from './attribute-model';

export class JsonModel implements AttributeModel {
  private _json: Object;

  constructor(json: Object) {
    Preconditions.checkNotNull(json);
    this._json = json;
  }

  getProperty(key: string) {
    return this._json[key];
  }

  setProperty(key: string, value: any) {
    this._json[key] = value;
  }

  removeProperty(key: string) {
    delete this._json[key];
  }

  isPropertyObject(key: string) {
    return this._json[key] instanceof Object;
  }

  isPropertyArray(key: string) {
    return this._json[key] instanceof Array;
  }

  getPropertyKeys(): string[] {
    if (this._json == null) {
      return [];
    }
    return Object.keys(this._json);
  }

  get json(): Object {
    return this._json;
  }

  set json(value: Object) {
    this._json = value;
  }

  getObjectId(): string {
    return 'json';
  }


  public getObjectsByAttributeTrail(trail: string[], filters?: { key: string, value: any }[]): JsonModel[] {
    Preconditions.checkState(trail instanceof Array, 'trail must be array');
    if (filters) {
      Preconditions.checkState(filters instanceof Array, 'filters must be array');

    }

    let objects: JsonModel[] = [this];
    trail.forEach
    (
      p => objects = objects
        .map(obj => this.getChildObjectsOfProperty(obj, p))
        .reduce((a, b) => a.concat(b), [])
    );

    if (filters) {
      filters.forEach
      (
        filter => objects = objects
          .filter(obj => obj.getProperty(filter.key) === filter.value)
      );

    }
    return objects;
  }

  public getOneObjectByAttributeTrail(trail: string[], filters?: { key: string, value: any }[]): JsonModel {
    const objects = this.getObjectsByAttributeTrail(trail, filters);
    if (objects.length === 0) {
      return null;

    }
    Preconditions.checkState(objects.length === 1, 'found more than one object');
    return objects[0];
  }

  public getChildObjectsOfProperty(parent: JsonModel, property: string): JsonModel[] {

    const children = parent.getProperty(property);

    if (children instanceof Array) {
      return children.map(child => new JsonModel(child));
    } else if (children instanceof Object) {
      return [new JsonModel(children)];
    }

    throw new Error('Could not find children');
  }

  public getOneChildObjectOfProperty(parent: JsonModel, property: string): JsonModel {
    const objects = this.getChildObjectsOfProperty(parent, property);
    if (objects.length === 0) {
      return null;

    }
    Preconditions.checkState(objects.length === 1, 'found more than one object');
    return objects[0];
  }


}
