import {Injectable} from '@angular/core';
import {RestCallService} from './rest-call.service';
import {RestCall} from './rest-call';
import {Observable} from 'rxjs/Observable';
import {SearchFilters} from './search/searchfilter/search-filters';
import {ElasticSearchResult} from './search/elastic-search-result';
import {Sort} from './search/sort';

@Injectable()
export class ElasticSearchService {

  host = window['moocUrl'];
  index = 'courses';

  constructor(private restCallService: RestCallService) {
  }

  searchWithFilters(filters: SearchFilters,
                    from?: number,
                    size?: number,
                    sort?: Sort,
                    withAggs = true): Observable<ElasticSearchResult> {

    const q = filters.toElasticQuery(withAggs);
    q.from = from ? from : 0;
    q.size = size ? size : 10;
    if (sort) {
      q.sort = sort.toElasticQuerySort();

    }

   // console.log(JSON.stringify(q));

    return this.search(q);
  }

  search(query: any): Observable<ElasticSearchResult> {

    const call = RestCall.builder()
      .withHost(this.host)
      .withPath('/api/elastic/' + this.index + '/_search')

      .withBody(query)
      .addHeaders('Content-Type', 'application/json');

    return this.restCallService.post(
      call.get())
      .map(response => response.json())
      .map(json => new ElasticSearchResult(json));
  }

}
