import {Headers, URLSearchParams} from '@angular/http';
import {Preconditions} from '../util/preconditions';

export class RestCall {

  private _url: string;
  private _parameters = new URLSearchParams();
  private _headers =  new Headers();
  private _body: any;

  static builder (): RestCallBuilder {
    return new RestCallBuilder();
  }

  constructor(url: string, parameters: URLSearchParams, headers: Headers, body: any) {
    this._url = url;
    this._parameters = parameters;
    this._headers = headers;
    this._body = body;
  }

  get url(): string {
    return this._url;
  }

  get parameters(): URLSearchParams {
    return this._parameters;
  }


  get headers(): Headers {
    return this._headers;
  }

  get body(): any {
    return this._body;
  }


}

export class RestCallBuilder {
  private _host: string;
  private _path: string;
  private _parameters = new URLSearchParams();
  private _headers =  new Headers();
  private _body: any = '';

  public addHeaders (name: string, value: string): RestCallBuilder {
    this._headers.append(name, value);
    return this;
  }

  public addParams (name: string, value: any): RestCallBuilder {
    this._parameters.append(name, value);
    return this;
  }

  public withPath (path: string): RestCallBuilder {
    Preconditions.checkState(path.startsWith('/'), 'Path must start with \'/\'');
    this._path = path;
    return this;
  }

  public withHost (host: string): RestCallBuilder {
    this._host = host;
    return this;
  }

  public withBody (body: any): RestCallBuilder {
    this._body = body;
    return this;
  }

  public get(): RestCall {

    // Preconditions.checkNotNull(this._host, 'host was null');

    return new RestCall(this._host + this._path, this._parameters, this._headers, this._body);
  }
}
