import {JsonModel} from '../../model/json-model';
import {IdTextElement} from '../../model/id-text-element';

export class ElasticSearchResult extends JsonModel {

  hits: JsonModel[];

  constructor(json: Object) {
    super(json);

    const elasticHits = this.json['hits']['hits'];

    if (elasticHits) {
      this.hits = this.json['hits']['hits'].map(hit => new JsonModel(hit['_source']));

    } else {
      this.hits = [];

    }
  }

  getHitsTotal(): number {
    return this.json['hits']['total'];
  }

  getHits(): JsonModel[] {
    return this.hits;
  }

  getBuckets(key: string): Bucket[] {

    if (this.json['aggregations'][key]) {
      return this.json['aggregations'][key]['buckets']
        .map(rawBucket => this.elasticBucketToBucket(rawBucket));
    } else if (this.json['aggregations']['globalAggs'][key]) {
      return this.json['aggregations']['globalAggs'][key]['buckets']['buckets']
        .map(rawBucket => this.elasticBucketToBucket(rawBucket));
    } else {
      return [];
    }
  }

  private elasticBucketToBucket(elasticBucket: any): Bucket {
    return {
      count: elasticBucket['doc_count'],
      value: elasticBucket['key_as_string'] ? elasticBucket['key_as_string'] : elasticBucket['key']
    };
  }

  getValueLabelElements(key: string): IdTextElement[] {
    const buckets = this.getBuckets(key);

    return buckets.map(bucket => ({id: bucket.value, text: bucket.value}));
  }
}

export interface Bucket {
  value: string;
  count: number;
}
