import {ElasticQueryJson} from '../elastic-query-json';
import {AbstractAggregation} from './abstract-aggregation';

export class GlobalTermAggregation extends AbstractAggregation {

  public addAggregationToQuery(query: ElasticQueryJson): void {

    const globalAgg = {
      aggs: {buckets: {terms: {field: this.key + '.keyword', size: 100}}},
      filter: {bool: {filter: [], must: []}}
    };

    query.aggs.globalAggs.aggs[this.key] = globalAgg;

    query.query.bool.filter
      .filter(f => this.elasticFilterIsSelf(f))
      .forEach(f => globalAgg.filter.bool.filter.push(f));

    query.query.bool.must
      .filter(f => this.elasticFilterIsSelf(f))
      .forEach(f => globalAgg.filter.bool.must.push(f));

  }

  private elasticFilterIsSelf (elasticFilter: any) {
    return (elasticFilter['terms'] == null || elasticFilter['terms'][this.key + '.keyword'] == null)
      && (elasticFilter['term'] == null || elasticFilter['term'][this.key + '.keyword'] == null);
  }


}
