import {Filter} from './filter';
import {Aggregation} from '../aggregation/aggregation';
import {ElasticQueryJson} from '../elastic-query-json';

export abstract class AbstractFilter implements Filter {

  private active = false;
  private filterKey: string; // same key as it has in the filter map
  private queryKey: string;
  private value: any;

  agg: Aggregation;

  constructor(aggregation: Aggregation, queryKey: string, value?: any, filterKey?: string) {
    this.filterKey = filterKey ? filterKey : queryKey;
    this.queryKey = queryKey;
    this.value = value;
    this.agg = aggregation;
    this.active = value && value.length > 0;
  }

  abstract addFilterToQuery(query: ElasticQueryJson): void;

  public addAggregationToQuery(query: ElasticQueryJson): void {
    if (this.agg) {
      this.agg.addAggregationToQuery(query);
    }
  }

  public setActive(active: boolean) {
    this.active = active;
  }

  public isActive(): boolean {
    return this.active;
  }

  public getValue(): any {
    return this.value;
  }

  public setValue(value: any) {
    this.value = value;
  }

  public getValuePretty(): any {
    return this.value;
  }

  public clearValue() {
    this.setValue(null);
  }

  public abstract valueIsArray();

  public getQueryKey(): string {
    return this.queryKey;
  }

  public getFilterKey(): string {
    return this.filterKey;
  }

}
