import {AbstractFilter} from './abstract-filter';
import {ElasticQueryJson} from '../elastic-query-json';

export class MultiMatchFilter extends AbstractFilter {

  boost: number;
  protected queryKeys: string[];

  constructor (queryKeys: string[], value?: any, filterKey?: string, boost = 1) {

    super(null, null, value, filterKey);

    this.boost = boost;
    this.queryKeys = queryKeys;
    super.setActive(value && value.length > 0);
  }

  public addFilterToQuery (query: ElasticQueryJson): void {
    if (this.isActive()) {
      query.query.bool.must.push(this.toElasticFilter());
    }
  }

  protected toElasticFilter() {
    const inner = {query: this.getValue(), fields: this.queryKeys, fuzziness: 'auto', boost: this.boost};
    const outer = {multi_match : null};
    outer.multi_match = inner;
    return outer;
  }

  public valueIsArray() {
    return false;
  }
}
