import {AbstractFilter} from './abstract-filter';
import {ElasticQueryJson} from '../elastic-query-json';

export class MultiTermFilter extends AbstractFilter {

  public addFilterToQuery (query: ElasticQueryJson): void {
    if (this.isActive()) {
      this.getValue().forEach(val => {
        query.query.bool.filter.push(this.toElasticFilter(val));
      });
    }
  }

  private toElasticFilter(val: string) {
    const inner = {};
    inner[this.getQueryKey() + '.keyword'] = val;
    const outer = {};
    outer['term'] = inner;

    return outer;
  }

  public valueIsArray() {
    return true;
  }

  public setValue(value: any) {
    if (value instanceof Array) {
      super.setValue(value);
    } else {
      super.setValue([value]);
    }
  }

  public clearValue() {
    this.setValue([]);
  }
}
