import {AbstractFilter} from './abstract-filter';
import {ElasticQueryJson} from '../elastic-query-json';

export class TermsFilter extends AbstractFilter {

  public addFilterToQuery (query: ElasticQueryJson): void {
    if (this.isActive()) {
      query.query.bool.filter.push(this.toElasticFilter());
    }
  }

  private toElasticFilter() {
    const inner = {};
    inner[this.getQueryKey() + '.keyword'] = this.getValue();
    const outer = {};
    outer['terms'] = inner;

    return outer;

  }

  public valueIsArray() {
    return true;
  }

  public setValue(value: any) {
    if (value instanceof Array) {
      super.setValue(value);
    } else {
      super.setValue([value]);
    }
  }

  public clearValue() {
    this.setValue([]);
  }
}
