/**
 * Service handling profile logic.
 */
import {Injectable} from '@angular/core';
import {appMenu} from '../../component/profile/menu/menu.component';

@Injectable()
export class ConfigurationService {

  configuration: Object;

  constructor() {
    this.configuration = this.questionConfiguration();
  }

  private questionConfiguration() {
    return {
      'profile.general.section.name': {
        'profile.general.name.family': {
          showLabel: true,
          elementId: 'family-name',
          mandatory: true
        },
        'profile.general.name.first': {
          showLabel: true,
          elementId: 'first-name',
          mandatory: true
        },
        'profile.general.gender.label': {
          showLabel: true,
          elementId: 'gender'
        },
        'profile.general.birth.date': {
          showLabel: true,
          elementId: 'birth-date'

        },
        'profile.general.birth.country': {
          showLabel: true,
          elementId: 'birth-country'

        },
        'profile.general.nationality': {
          showLabel: true,
          elementId: 'nationality'

        },
        'profile.general.marital.status': {
          showLabel: true,
          elementId: 'marital-status'
        },
        'profile.personal.general.identification.document.choose': {
          showLabel: true,
          elementId: 'personal-identification-document-'
        },
        'profile.personal.general.identification.document.type': {
          showLabel: true,
          elementId: 'document-type-'
        },
        'profile.personal.general.identification.document.number': {
          showLabel: true,
          elementId: 'document-number-'
        },
        'profile.personal.general.identification.document.country': {
          showLabel: true,
          elementId: 'document-country-of-issue-'
        },
        'profile.personal.general.identification.document.valid': {
          showLabel: true,
          elementId: 'document-validity-date-picker-'
        },
      },
      'profile.contact.section.name': {
        'profile.general.contact.address': {
          showLabel: true,
          elementId: 'contact-info-address'
        },
        'profile.general.contact.postCode': {
          showLabel: true,
          elementId: 'contact-info-post-code'
        },
        'profile.general.contact.country': {
          showLabel: true,
          elementId: 'contact-info-country'
        },
        'profile.general.contact.phone': {
          showLabel: true,
          elementId: 'contact-info-phone'
        },
        'profile.general.contact.email': {
          showLabel: true,
          elementId: 'contact-info-email'
        },
      },
      'profile.migration.section.name': {
        'profile.general.country.reception_arrival_date': {
          showLabel: true,
          elementId: 'date-of-arrival-date-picker'
        },
        'profile.general.residence.status': {
          showLabel: true,
          elementId: 'residence-status'
        },
        'profile.general.work.permit.label': {
          showLabel: true,
          elementId: 'work-permit-status'
        },
        'profile.personal.migration.travelling.label': {
          showLabel: true,
          elementId: 'travelling-with-dependants'
        },
        'profile.personal.migration.travelling.minor_15': {
          showLabel: true,
          elementId: 'minor-15-or-under-travelling'
        },
        'profile.personal.migration.travelling.minor_16_to_18': {
          showLabel: true,
          elementId: 'minor-16-to-18-travelling'
        },
        'profile.personal.migration.travelling.adult': {
          showLabel: true,
          elementId: 'adult-travelling'
        },
        'profile.personal.migration.travelling.elderly': {
          showLabel: true,
          elementId: 'elderly-travelling'
        },
        'profile.personal.migration.travelling.sick': {
          showLabel: true,
          elementId: 'sick-travelling'
        }
      },
      'step.expectations': {
        'profile.expectations.instructions': {
          showLabel: true,
          elementId: 'key-skills',
          isMainQuestion: false
        },
        'profile.expectations.do_next.label': {
          showLabel: true,
          elementId: 'expectation-do-next-',
          isMainQuestion: false
        },
        'profile.expectations.improve_language.label': {
          showLabel: true,
          elementId: 'improve_language',
          isMainQuestion: true,
          subQuestions: [
            {
              labelKey: 'profile.expectations.improve_language.rowLabel',
              showLabel: true,
            }]
        },
        'profile.expectations.follow_course.label': {
          showLabel: true,
          elementId: 'follow_course',
          isMainQuestion: true
        },
        'profile.expectations.undertake_education.label': {
          showLabel: true,
          elementId: 'undertake_education',
          isMainQuestion: true,
          subQuestions: [
            {
              labelKey: 'profile.expectations.undertake_education.time_commitment.label',
              showLabel: true,
            },
            {
              labelKey: 'profile.expectations.undertake_education.education_type.label',
              showLabel: true,
            },
            {
              labelKey: 'profile.expectations.undertake_education.study_field.label',
              showLabel: true,
            }],
        },
        'profile.expectations.find_work.label': {
          showLabel: true,
          elementId: 'find_work',
          isMainQuestion: true,
          subQuestions: [
            {
              labelKey: 'profile.expectations.find_work.rowLabel',
              showLabel: true,
            },
            {
              labelKey: 'profile.expectations.undertake_education.time_commitment.label',
              showLabel: true,
            },
            {
              labelKey: 'profile.expectations.find_work.activity_field.label',
              showLabel: true,
            },
            {
              labelKey: 'profile.expectations.find_work.occupation.label',
              showLabel: true,
            }]
        },
        'profile.expectations.other.label': {
          showLabel: true,
          elementId: 'other',
          isMainQuestion: true,
          subQuestions: [
            {
              labelKey: 'profile.expectations.other.label',
              showLabel: true
            }
          ]
        }
      },
      'profile.languages.section.name': {
        'profile.skills_id.language_skills.mother_tongue.label': {
          showLabel: true,
          elementId: 'language-skills-mother-tongue'
        },
        'profile.skills_id.language_skills.host_country.label': {
          showLabel: true,
          elementId: 'language-skills-host-country'
        },
      },
      'profile.skills_id.education_training.section.name': {
        'profile.skills_id.education_training.attended.label': {
          showLabel: true,
          elementId: 'education-training-attended'
        },
        'profile.skills_id.education_training.last.label': {
          showLabel: true,
          elementId: 'education-training-last'
        },
        'profile.skills_id.education_training.full_time.label': {
          showLabel: true,
          elementId: 'education-training-full-time-week'
        },
        'profile.skills_id.education_training.part_time.label': {
          showLabel: true,
          elementId: 'education-training-part-time-week'
        },
        'profile.skills_id.education_training.highest_level.label': {
          showLabel: true,
          elementId: 'education-training-level'
        },
        'profile.skills_id.education_training.study_field.label': {
          showLabel: true,
          elementId: 'education-training-study-field-area'
        },
        'profile.skills_id.education_training.education_type.label': {
          showLabel: true,
          elementId: 'education-training-seducation-type'
        },
        'profile.skills_id.education_training.prior_learning.label': {
          showLabel: true,
          elementId: 'education-training-prior-learning'
        },
        'profile.skills_id.education_training.certificate.label': {
          showLabel: true,
          elementId: 'education-training-certificate'
        },
        'profile.skills_id.education_training.certificate.upload.label': {
          showLabel: true,
          elementId: 'education-training-certificate-upload'
        },
        'profile.skills_id.education_training.certificate.title.label': {
          showLabel: true,
          elementId: 'education-training-certificate-title'
        },
        'profile.skills_id.education_training.certificate.name.label': {
          showLabel: true,
          elementId: 'education-training-certificate-name'
        },
        'profile.skills_id.education_training.certificate.country.label': {
          showLabel: true,
          elementId: 'education-training-certificate-country-'
        },
        'profile.skills_id.education_training.certificate.year.label': {
          showLabel: true,
          elementId: 'education-training-certificate-year'
        },
      },
      'profile.literacy.section.name': {
        'profile.skills_id.literacy_skills.read_regularly.label': {
          showLabel: true,
          elementId: 'read-regularly',
          showImage: true
        },
        'profile.skills_id.literacy_skills.read_paper_media_type.label': {
          showLabel: true,
          elementId: 'paper-read-media-type'
        },
        'profile.skills_id.literacy_skills.read_liner_media_type.label': {
          showLabel: true,
          elementId: 'paper-read-liner-media-type'
        },
        'profile.skills_id.literacy_skills.write_regularly.label': {
          showLabel: true,
          elementId: 'write-regularly'
        },
        'profile.skills_id.literacy_skills.write_media_type.label': {
          showLabel: true,
          elementId: 'paper-write-media-type'
        }
      },
      'profile.numeracy.section.name': {
        'profile.skills_id.numeracy_skills.measuring.label': {
          showLabel: true,
          elementId: 'numeracy-skills-measuring',
          showImage: true
        },
        'profile.skills_id.numeracy_skills.calculation.whole_numbers.label': {
          showLabel: true,
          elementId: 'numeracy-skills-calculation-whole-numbers',
          showImage: true
        },
        'profile.skills_id.numeracy_skills.calculation.factions.label': {
          showLabel: true,
          elementId: 'numeracy-skills-calculation-fractions'
        },
        'profile.skills_id.numeracy_skills.calculation.percentage.label': {
          showLabel: true,
          elementId: 'numeracy-skills-calculation-percentage',
          showImage: true
        },
        'profile.skills_id.numeracy_skills.geometry.label': {
          showLabel: true,
          elementId: 'numeracy-skills-geometry'
        },
        'profile.skills_id.numeracy_skills.charts.label': {
          showLabel: true,
          elementId: 'numeracy-skills-charts',
          showImage: true
        },
        'profile.skills_id.numeracy_skills.complex.label': {
          showLabel: true,
          elementId: 'numeracy-skills-complex',
          showImage: true
        },
        'profile.skills_id.numeracy_skills.metric.label': {
          showLabel: true,
          elementId: 'numeracy-skills-metric'
        },
      },
      'profile.skills_id.digital_skills.section.name': {
        'profile.skills_id.digital_skills.using_smartphone.label': {
          showLabel: true,
          elementId: 'using-smartphone'
        },
        'profile.skills_id.digital_skills.using_laptop.label': {
          showLabel: true,
          elementId: 'using-laptop',
          showImage: true
        },
        'profile.skills_id.digital_skills.managing_files.label': {
          showLabel: true,
          elementId: 'managing-files',
          showImage: true
        },
        'profile.skills_id.digital_skills.create_text_docs.label': {
          showLabel: true,
          elementId: 'create-text-docs'
        },
        'profile.skills_id.digital_skills.create_spread_sheets.label': {
          showLabel: true,
          elementId: 'create-spread-sheets'
        },
        'profile.skills_id.digital_skills.create_presentations.label': {
          showLabel: true,
          elementId: 'create-presentations',
          showImage: true
        },
        'profile.skills_id.digital_skills.emails.label': {
          showLabel: true,
          elementId: 'emails'
        },
        'profile.skills_id.digital_skills.find_info_internet.label': {
          showLabel: true,
          elementId: 'find-info-internet',
          showImage: true
        },
        'profile.skills_id.digital_skills.internet_phone.label': {
          showLabel: true,
          elementId: 'internet-phone'
        },
        'profile.skills_id.digital_skills.online_purchase.label': {
          showLabel: true,
          elementId: 'online-purchase'
        },
        'profile.skills_id.digital_skills.online_learning.label': {
          showLabel: true,
          elementId: 'online-learning'
        },
        'profile.skills_id.digital_skills.making_graphic_designs.label': {
          showLabel: true,
          elementId: 'making-graphic-designs'
        },
        'profile.skills_id.digital_skills.other.label': {
          showLabel: true,
          elementId: 'other-digital-skills'
        },
      },
      'profile.skills_id.professional_skills.section.name': {
        'profile.skills_id.professional_skills.professional_experience.label': {
          showLabel: true,
          elementId: 'professional-experience'
        },
        'profile.skills_id.professional_skills.professional_experience.duration.label': {
          showLabel: true,
          elementId: 'professional-experience-duration-week'
        },
        'profile.skills_id.professional_skills.professional_experience_last.label': {
          showLabel: true,
          elementId: 'professional-experience-last'
        },
        'profile.skills_id.professional_skills.professional_experience.history.nature.label': {
          showLabel: true,
          elementId: 'professional-experience-nature'
        },
        'profile.skills_id.professional_skills.professional_experience.history.duration.label': {
          showLabel: true,
          elementId: 'professional-experience-history-duration-week'
        },
        'profile.skills_id.professional_skills.professional_experience.history.country.label': {
          showLabel: true,
          elementId: 'professional-experience-history-country'
        },
        'profile.skills_id.professional_skills.professional_experience.history.language.label': {
          showLabel: true,
          elementId: 'professional-experience-history-language'
        },
        'profile.skills_id.professional_skills.professional_experience.history.occupation.label': {
          showLabel: true,
          elementId: 'professional-experience-history-occupation'
        },
        'profile.skills_id.professional_skills.professional_experience.history.skill.label': {
          showLabel: true,
          elementId: 'professional-experience-history-skill'
        },
        'profile.skills_id.professional_skills.professional_experience.history.organisation.size.label': {
          showLabel: true,
          elementId: 'professional-experience-history-organisation-size'
        },
        'profile.skills_id.professional_skills.professional_experience.history.workplace.size.label': {
          showLabel: true,
          elementId: 'professional-experience-history-workplace-size'
        },
        'profile.skills_id.professional_skills.professional_experience.history.proof.label': {
          showLabel: true,
          elementId: 'professional-experience-history-proof'
        },
      },
      'profile.skills_id.outside_skills.section.name': {
        'profile.skills_id.outside_skills.caring_children.label': {
          showLabel: true,
          elementId: 'outside-skills-caring-children',
          showImage: true
        },
        'profile.skills_id.outside_skills.caring_elderly_people.label': {
          showLabel: true,
          elementId: 'outside-skills-caring-elderly-people',
          showImage: true
        },
        'profile.skills_id.outside_skills.caring_sick_people.label': {
          showLabel: true,
          elementId: 'outside-skills-caring-sick-people',
          showImage: true
        },
        'profile.skills_id.outside_skills.making_clothing.label': {
          showLabel: true,
          elementId: 'outside-skills-making-clothing',
          showImage: true
        },
        'profile.skills_id.outside_skills.preparing_meals.label': {
          showLabel: true,
          elementId: 'outside-skills-preparing-meals'
        },
        'profile.skills_id.outside_skills.cultivating_crops.label': {
          showLabel: true,
          elementId: 'outside-skills-cultivating-crops',
          showImage: true
        },
        'profile.skills_id.outside_skills.livestock.label': {
          showLabel: true,
          elementId: 'outside-skills-livestock'
        },
        'profile.skills_id.outside_skills.making_pottery.label': {
          showLabel: true,
          elementId: 'outside-skills-making-pottery'
        },
        'profile.skills_id.outside_skills.selling_trading_products.label': {
          showLabel: true,
          elementId: 'outside-skills-selling-products',
          showImage: true
        },
        'profile.skills_id.outside_skills.making_furniture.label': {
          showLabel: true,
          elementId: 'outside-skills-making-furniture',
          showImage: true
        },
        'profile.skills_id.outside_skills.house_construction.label': {
          showLabel: true,
          elementId: 'outside-skills-house-construction'
        },
        'profile.skills_id.outside_skills.coaching_teaching.label': {
          showLabel: true,
          elementId: 'outside-skills-coaching-teaching',
          showImage: true
        },
      },
      'profile.skills_id.other_basic_transversal_skills.section.name': {
        'profile.skills_id.other_basic_transversal_skills.work_independently.label': {
          showLabel: true,
          showImage: true,
          elementId: 'other-transversal-work-independently'
        },
        'profile.skills_id.other_basic_transversal_skills.make_decisions_independently.label': {
          showLabel: true,
          showImage: true,
          elementId: 'other-transversal-make-decision-independently'
        },
        'profile.skills_id.other_basic_transversal_skills.work_in_structured_way.label': {
          showLabel: true,
          showImage: true,
          elementId: 'other-transversal-work-structured-way'
        },
        'profile.skills_id.other_basic_transversal_skills.solve_problems.label': {
          showLabel: true,
          showImage: true,
          elementId: 'other-transversal-solve-problems'
        },
        'profile.skills_id.other_basic_transversal_skills.work_with_others.label': {
          showLabel: true,
          showImage: true,
          elementId: 'other-transversal-work-with-others'
        },
        'profile.skills_id.other_basic_transversal_skills.work_with_people.label': {
          showLabel: true,
          showImage: true,
          elementId: 'other-transversal-work-with-people'
        },
        'profile.skills_id.other_basic_transversal_skills.work_with_customers.label': {
          showLabel: true,
          showImage: true,
          elementId: 'other-transversal-work-with-customers'
        },
        'profile.skills_id.other_basic_transversal_skills.work_as_leader.label': {
          showLabel: true,
          showImage: true,
          elementId: 'other-transversal-work-as-leader'
        },
        'profile.skills_id.other_basic_transversal_skills.manage_project.label': {
          showLabel: true,
          showImage: true,
          elementId: 'other-transversal-manage-projects'
        },
        'profile.skills_id.other_basic_transversal_skills.work_in_stressful_conditions.label': {
          showLabel: true,
          showImage: true,
          elementId: 'work-stressful-conditions'
        },
        'profile.skills_id.other_basic_transversal_skills.develop_ideas.label': {
          showLabel: true,
          showImage: true,
          elementId: 'develop-new-ideas'
        },
        'profile.skills_id.other_basic_transversal_skills.inspire_enthuse_others.label': {
          showLabel: true,
          showImage: true,
          elementId: 'inspire-enthuse-others'
        },
        'profile.skills_id.other_basic_transversal_skills.take_responsability.label': {
          showLabel: true,
          showImage: true,
          elementId: 'take-responsibility'
        },
      },
      'profile.driving.section.name': {
        'profile.skills_id.driving_skills.instructions': {
          showLabel: true,
          elementId: 'driving-skills'
        },
        'profile.skills_id.driving_skills.carriage.label': {
          showLabel: true,
          elementId: 'carriage-driving-skills'
        },
        'profile.skills_id.driving_skills.two_wheeled.label': {
          showLabel: true,
          elementId: 'twoWheeled-driving-skills'
        },
        'profile.skills_id.driving_skills.manual.label': {
          showLabel: true,
          elementId: 'manual-driving-skills'
        },
        'profile.skills_id.driving_skills.automatic.label': {
          showLabel: true,
          elementId: 'automatic-driving-skills'
        },
        'profile.skills_id.driving_skills.heavy_truck.label': {
          showLabel: true,
          elementId: 'heavyTruck-driving-skills'
        },
        'profile.skills_id.driving_skills.bus.label': {
          showLabel: true,
          elementId: 'bus-driving-skills'
        },
        'profile.skills_id.driving_skills.tram.label': {
          showLabel: true,
          elementId: 'tram-driving-skills'
        },
        'profile.skills_id.driving_skills.train.label': {
          showLabel: true,
          elementId: 'train-driving-skills'
        },
        'profile.skills_id.driving_skills.machinery.label': {
          showLabel: true,
          elementId: 'machinery-driving-skills'
        },
        'profile.skills_id.driving_skills.vessel.label': {
          showLabel: true,
          elementId: 'vessel-driving-skills'
        },
        'profile.skills_id.driving_skills.fork_lift.label': {
          showLabel: true,
          elementId: 'fork-lift-driving-skills'
        },
        'profile.skills_id.driving_skills.construction_machinery.label': {
          showLabel: true,
          elementId: 'construction-machinery-driving-skills'
        },
        'profile.skills_id.driving_skills.aircraft.label': {
          showLabel: true,
          elementId: 'aircraft-driving-skills'
        },
        'profile.skills_id.driving_skills.other.label': {
          showLabel: true,
          elementId: 'other-driving-skill'
        }
      },
      'profile.outcome.employment-business.section.name': {
        'profile.outcome.employment_business.label': {
          showLabel: true,
          elementId: 'employment-business'
        },
      },
      'profile.outcome.further-information.section.name': {
        'profile.outcome.guidance.other_organisation.label': {
          showLabel: true,
          elementId: 'other-organisations'
        },
      },
      'profile.outcome.details_issuing_organisation.title': {
        'profile.outcome.details_issuing_organisation.data_of_issuance': {
          showLabel: true,
          elementId: 'date-of-issuance'
        },
        'profile.outcome.details_issuing_organisation.place_of_issuance': {
          showLabel: true,
          elementId: 'place-of-issuance'
        },
        'profile.outcome.details_issuing_organisation.type.label': {
          showLabel: true,
          elementId: 'organisation-type'
        },
        'profile.outcome.organisation.label': {
          showLabel: true,
          elementId: 'organisations'
        },
        'profile.outcome.details_issuing_organisation.responsible_officer': {
          showLabel: true,
          elementId: 'responsible-officer'
        },
        'profile.general.contact.address': {
          showLabel: true,
          elementId: 'organisation-contact-info-address'
        },
        'profile.general.contact.country': {
          showLabel: true,
          elementId: 'organisation-contact-info-country'
        },
        'profile.general.contact.phone': {
          showLabel: true,
          elementId: 'organisation-contact-info-phone'
        },
        'profile.general.contact.email': {
          showLabel: true,
          elementId: 'organisation-contact-info-email'
        },
      },
      'profile.outcome.key_skills.title': {
        'profile.outcome.key_skills.label': {
          showLabel: true,
          elementId: 'key-skills'
        },
      },
      'profile.outcome.education-or-training.section.name': {
        'profile.outcome.education_or_training.label_1.label': {
          showLabel: true,
          elementId: 'education-or-training-advice'
        },
        'profile.outcome.education_or_training.label_2.label': {
          showLabel: true,
          elementId: 'education-or-training-referral'
        }
      },
      'profile.outcome.recognition.section.name': {
        'profile.outcome.recognition.label_1.label': {
          showLabel: true,
          elementId: 'recognition-qualifications-recommendation'
        },
        'profile.outcome.recognition.label_2.label': {
          showLabel: true,
          elementId: 'recognition-qualifications-referral'
        },
      },
      'profile.outcome.validation.section.name': {
        'profile.outcome.validation.label_1.label': {
          showLabel: true,
          elementId: 'validation-learning-recommendation'
        },
        'profile.outcome.validation.label_2.label': {
          showLabel: true,
          elementId: 'validation-learning-referral'
        }
      }
    };
  }

  isQuestionEnabled(questLabel, elementId) {
    let question = this.getQuestion(questLabel, elementId);
    if (question) {
      return question.showLabel;
    }
    return true;
  }


  isImageEnabled(questionLabelKey: string, elementId: string): boolean {
    let question = this.getQuestion(questionLabelKey, elementId);

    if (question && question.hasOwnProperty('showImage')) {
      return question.showImage;
    }
    return true;
  }

  getQuestion(questionLabelKey: string, elementId?: string) {
    return Object.keys(this.configuration).filter((menu) => {
      return this.configuration[menu][questionLabelKey] !== undefined;
    }).map(menu => {
      return this.configuration[menu][questionLabelKey];
    }).filter(question => {
      if (elementId) {
        return elementId.startsWith(question.elementId);
      }
      return true;
    })[0];
  }

  clear(): void {
    this.configuration = this.questionConfiguration();
  }

  isSubQuestionEnabled(mainQuestionLabelKey: string, labelKey: string) {
    let mainQuestion = this.getQuestion(mainQuestionLabelKey);
    let subQuestion = mainQuestion.subQuestions.filter(quest => quest.labelKey === labelKey)[0];
    return subQuestion.showLabel;
  }
}
