import {EventEmitter, Injectable, OnInit, Output} from '@angular/core';
import {Http} from '@angular/http';

import './../../rxjs-extensions';

import {Observable} from 'rxjs';
import {Language} from './language';
import {ApplicationLanguage} from './application-language';
import {TranslateService} from '../translate/translate.service';

@Injectable()
export class LanguageService {

  private url = 'api/language';
  private urlLanguages = 'api/languages';
  private urlSupportedLanguages = 'api/languages/supported';

  /**
   * languages available in the app
   */
  private languages: any;

  private supportedLanguagesEvent: EventEmitter<any> = new EventEmitter();

  private primaryLanguageFullNameEvent: EventEmitter<any> = new EventEmitter();

  constructor(private http: Http,
              public translate: TranslateService) {
  }



  get supportedLanguages(): any {
    if (this.languages !== undefined) {
      return this.languages;
    } else {
      this.getSupportedLanguages()
        .subscribe(response => {
          this.languages = response;
          this.supportedLanguagesEvent.emit(this.languages);
        });
    }
  }

  get languageNotification(): EventEmitter<any> {
    return this.supportedLanguagesEvent;
  }



  get primaryLanguageFullName(): any {
    if (this.languages !== undefined) {
      return this.extractFullPrimaryLanguage();
    } else {
      this.getSupportedLanguages()
        .subscribe(response => {
          this.languages = response;
          this.primaryLanguageFullNameEvent.emit(this.extractFullPrimaryLanguage());
        });
    }
  }

  /**
   * Extracts the full name of a language from the primary language iso code.
   * ex: if this.translate.getPrimaryLanguage() returns fr, the method returns 'Français'
   *
   * @returns {string}
   */
  private extractFullPrimaryLanguage(): string {
    return this.languages.filter(l => l.isoCode1 === this.translate.getPrimaryLanguage())[0].name;
  }

  get primaryLanguageFullNameNotification(): EventEmitter<any> {
    return this.primaryLanguageFullNameEvent;
  }



  getLanguagesIn(isoLanguage: string): Observable<any> {
    let isoLanguages = this.supportedLanguages === undefined ? [] : this.supportedLanguages;
    let params = '?searchLanguages=';
    for (let lang of isoLanguages) {
      params = params + lang.isoCode1 + ',';
    }
    params = params.slice(0, -1) + '&resultLanguages=' + isoLanguage + '&pageSize=30';

    return this.http
      .get(this.urlLanguages + params)
      .map(response => <any>response.json());
  }

  getLanguageByCode(code): Observable<Language> {
    return this.http.get(this.url + '/' + code)
      .map(response => <Language>response.json());
  }

  getSupportedLanguages(): Observable<ApplicationLanguage> {
    return this.http.get(this.urlSupportedLanguages + '?pageSize=30&sortField=selectorOrder')
      .map(response => <ApplicationLanguage>response.json());
  }

}
