import {Injectable} from '@angular/core';
import {Http, Headers, RequestOptions, URLSearchParams} from '@angular/http';
import './../../rxjs-extensions';
import {Observable} from 'rxjs';
import {User} from './user';
import {PageWrapper} from '../common/page.wrapper';
import {PageRequest} from '../common/page.request';

@Injectable()
export class UserService {

  private usersUrl = 'api/users';
  private userUrl = 'api/user';
  private currentUserUrl = 'api/user/current';
  private currentUserObs = this.newCurrentUserObs();

  constructor(private http: Http) {
  }

  private newCurrentUserObs() {
    return Observable
      .defer(() => this.http.get(this.currentUserUrl))
      .map(response => <User>response.json())
      .publishReplay(1, 1000)
      .refCount();
  }

  getUserById(id): Observable<User> {
    return this.http.get(this.userUrl + '/' + id)
      .map(response => <User>response.json());
  }

  getUsers(pageRequest: PageRequest): Observable<PageWrapper<User>> {
    let params = new URLSearchParams();
    params.set('page', pageRequest.page.toString());
    params.set('pageSize', pageRequest.size.toString());
    params.set('sortField', pageRequest.sortField);
    params.set('sortDirection', pageRequest.sortDirection);

    return this.http.get(this.usersUrl, { search: params })
      .map(response => response.json());
  }

  getCurrentUser(): Observable<User> {
    return this.currentUserObs.take(1).catch(error => {
      this.currentUserObs = this.newCurrentUserObs();
      return Observable.throw(error);
    });
  }

  saveUser(user: User): Observable<User> {
    return this.http.post(this.userUrl, user)
      .map(response => <User>response.json());
  }

  deleteUser(id: string): Observable<any> {
    return this.http.delete(this.userUrl + '/' + id);
  }

}
