import {Injectable} from '@angular/core';
import {ActivatedRouteSnapshot, CanActivate, Router, RouterStateSnapshot} from '@angular/router';
import {Observable} from 'rxjs/Observable';
import {RouteService} from '../navigation/route.service';
import {ProfileService} from '../../component/profile/profile.service';

@Injectable()
export class SkipSectionGuard implements CanActivate {

  constructor(
    private routeService: RouteService,
    private router: Router,
    private profileService: ProfileService) {
  }

  canActivate(next: ActivatedRouteSnapshot, state: RouterStateSnapshot): Observable<boolean> | Promise<boolean> | boolean {
    let route = next;
    while (route.firstChild) {
      route = route.firstChild;
    }
    if (route.outlet === 'primary') {
      let routeData = route.data;
      let routeTitle = routeData['metadata']['title'];
      let menuItem = this.routeService.menuList.get(routeTitle);
      if (menuItem && !menuItem.isEnabled) {
        let routeMetadataRoute = routeData['metadata']['route'];
        let pathToNextSection = '/profile' + routeMetadataRoute[this.profileService.navigationButton].slice(1);
        if (pathToNextSection) {
          this.router.navigate([pathToNextSection]);
          return false;
        }
      }
      return true;
    }
  }
}
