import {Injectable} from '@angular/core';
import {ActivatedRoute, NavigationEnd, Router} from '@angular/router';
import {Route} from './route';
import {Observable} from 'rxjs';
import {menuItemCreationEmitter} from '../../component/profile/profile.service';
import {MenuItem} from '../../component/profile/menu/menu-item';

@Injectable()
export class RouteService {

  currentRoute: Route;
  menuList = new Map<string, MenuItem>();

  nextRoute: boolean;
  previousRoute: boolean;

  constructor(private router: Router, private activatedRoute: ActivatedRoute) {
    this.currentRoute = new Route();

    menuItemCreationEmitter.subscribe(menuItem => {
      this.menuList.set(menuItem.key, menuItem.menu);
    });
  }

  public getCurrentRoute(): Observable<Route> {
    return this.router.events
      .filter(event => (event instanceof NavigationEnd))
      .map((routeData: any) => {
        let route = this.getLastActivatedRoute(this.activatedRoute);
        this.currentRoute.url = routeData.url;
        this.currentRoute.data = route.snapshot.routeConfig.data;

        this.updateNextAndPreviousRoute();

        return this.currentRoute;
      });
  }

  private updateNextAndPreviousRoute() {
    this.nextRoute = this.hasNextRoute();
    this.previousRoute = this.hasPreviousRoute();
  }

  private getLastActivatedRoute(route: ActivatedRoute) {
    if (route.children.length > 0) {
      return this.getLastActivatedRoute(route.firstChild);
    } else {
      return route;
    }
  }

  private hasPreviousRoute() {
    let reversedMenuArray = Array.from(this.menuList).reverse();
    reversedMenuArray.pop();
    return this.hasNextRouteOn(reversedMenuArray);
  }

  private hasNextRoute() {
    return this.hasNextRouteOn(Array.from(this.menuList));
  }

  private hasNextRouteOn(array) {
    let currentRoutePassed = false;
    if (this.currentRoute.data && this.currentRoute.data.metadata) {
      for (let menu of array) {
        let menuItem = menu[1];
        if (currentRoutePassed && menuItem.isEnabled) {
          return true;
        }
        if (this.currentRoute.data.metadata.title === menuItem.labelKey) {
          currentRoutePassed = true;
        }
      }
    }
    return false;
  }

  public getPreviousRoute() {
    if (!!this.currentRoute.data && !!this.currentRoute.data.metadata && !!this.currentRoute.data.metadata.route) {
      return '/profile' + this.currentRoute.data.metadata.route.previous.substring(1);
    }
  }

  public getNextRoute() {
    if (!!this.currentRoute.data && !!this.currentRoute.data.metadata && !!this.currentRoute.data.metadata.route) {
      return '/profile' + this.currentRoute.data.metadata.route.next.substring(1);
    }
  }

  public isPrintableRoute() {
    if (!!this.currentRoute.data && !!this.currentRoute.data.metadata) {
      return this.currentRoute.data.metadata.printable;
    }
  }
}
