import {NgModule} from '@angular/core';
import {CommonModule} from '@angular/common';
import {Http} from '@angular/http';
import {TranslateDirective} from './directive/translate.directive';
import {TranslatePipe} from './pipe/translate.pipe';
import {NgbDatepickerI18n, NgbModule} from '@ng-bootstrap/ng-bootstrap';
import {CustomDatepickerI18nService} from './i18n/custom-datepicker-i18n.service';
import {TranslateModule} from './service/translate/translate.module';
import {TranslateLoader, TranslateService, TranslateStaticLoader} from './service/translate/translate.service';
import {LocalStorageService} from './service/storage/local-storage.service';
import {ModalModule} from 'angular2-modal';
import {BootstrapModalModule, Modal} from 'angular2-modal/plugins/bootstrap';
import {ImageCropperModule} from 'ng2-img-cropper';
import {NgProgressModule} from 'ng2-progressbar';
import {FormsModule, ReactiveFormsModule} from '@angular/forms';
import {ValidationService} from './service/validation/validation.service';
import {ToasterModule} from 'angular2-toaster';
import {UtilsService} from './service/utils/utils.service';
import {RouteService} from './service/navigation/route.service';
import {DisplayDatePipe} from './pipe/display-date.pipe';
import {SvgIconComponent} from './component/common/svg-icon/svg-icon.component';
import {RowComponent} from './component/common/row/row.component';
import {FormErrorComponent} from './component/common/form-error/form-error.component';
import {CheckboxGroupComponent} from './component/common/checkbox-group/checkbox-group.component';
import {FormFreeTextComponent} from './component/common/form-free-text/form-free-text.component';
import {FreeTextComponent} from './component/common/free-text/free-text.component';
import {ReportModalComponent} from './component/common/report-modal/report-modal.component';
import {ReportService} from './service/data/report.service';
import { ReportButtonComponent } from './component/common/report-button/report-button.component';
import {TranslateConfigurationPipe} from './pipe/translate-configuration.pipe';

@NgModule({
  exports: [
    CommonModule,
    FormsModule,
    TranslateModule,
    TranslateDirective,
    TranslatePipe,
    TranslateConfigurationPipe,
    DisplayDatePipe,
    NgbModule,
    ImageCropperModule,
    NgProgressModule,
    ToasterModule,
    RowComponent,
    FreeTextComponent,
    FormFreeTextComponent,
    CheckboxGroupComponent,
    FormErrorComponent,
    ReactiveFormsModule,
    SvgIconComponent,
    ReportButtonComponent
  ],
  imports: [
    CommonModule,
    FormsModule,
    TranslateModule.forRoot({
      provide: TranslateLoader,
      useFactory: useFactory,
      deps: [Http]
    }),
    ModalModule.forRoot(),
    BootstrapModalModule,
    NgbModule.forRoot(),
    NgProgressModule,
    ToasterModule,
    ReactiveFormsModule
  ],
  declarations: [
    TranslateDirective,
    TranslateConfigurationPipe,
    TranslatePipe,
    DisplayDatePipe,
    RowComponent,
    FreeTextComponent,
    FormFreeTextComponent,
    CheckboxGroupComponent,
    FormErrorComponent,
    ReportModalComponent,
    SvgIconComponent,
    ReportButtonComponent
  ],
  entryComponents: [
    ReportModalComponent
  ],
  providers: [
    LocalStorageService,
    ValidationService,
    RouteService,
    UtilsService,
    Modal,
    ReportService,
    {provide: NgbDatepickerI18n, useClass: CustomDatepickerI18nService, deps: [TranslateService]}]
})
export class SharedModule { }

export function useFactory(http: Http) {
  return new TranslateStaticLoader(http, './api/labels', '.json');
}
